(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     87690,       2897]
NotebookOptionsPosition[     84548,       2795]
NotebookOutlinePosition[     85203,       2824]
CellTagsIndexPosition[     85130,       2819]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["Chapter 1  Complex Numbers",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["Overview",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell["\<\
\tGet ready for a treat.  You're about to begin studying some of the most \
beautiful ideas in mathematics.  They are ideas with surprises.  They evolved \
over several centuries, yet they greatly simplify extremely difficult \
computations, making some as easy as sliding a hot knife through butter.  \
They also have applications in a variety of areas, ranging from fluid flow, \
to electric circuits, to the mysterious quantum world. Generally, they are \
described as belonging to the area of mathematics known as complex analysis.\
\>", "Text",
 CellChangeTimes->{{3.39896788496875*^9, 3.398967892859375*^9}}],

Cell[TextData[StyleBox["Section 1.1  The Origin of Complex Numbers",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
 "\tComplex analysis can roughly be thought of as the subject that applies \
the theory of calculus to imaginary numbers.  But what exactly are imaginary \
numbers?  Usually, students learn about them in high school with introductory \
remarks from their teachers along the following lines: \"We can't take the \
square root of a negative number.  But let's pretend we can and begin by \
using the symbol ",
 Cell[BoxData[
  RowBox[{"\[ImaginaryI]", "=", 
   SqrtBox[
    RowBox[{"-", "1"}]]}]]],
 ".\"  Rules are then learned for doing arithmetic with these numbers.  At \
some level the rules make sense.  If ",
 Cell[BoxData[
  RowBox[{"\[ImaginaryI]", "=", 
   SqrtBox[
    RowBox[{"-", "1"}]]}]]],
 ", it stands to reason that ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[ImaginaryI]", "2"], "=", 
   RowBox[{"-", "1"}]}]]],
 ". However, it is not uncommon for students to wonder whether they are \
really doing magic rather than mathematics."
}], "Text",
 CellChangeTimes->{{3.398967897234375*^9, 3.398967910390625*^9}}],

Cell["\<\
\tIf you ever felt that way, congratulate yourself!  You're in the company of \
some of the great mathematicians from the sixteenth through the nineteenth \
centuries.  They, too, were perplexed by the notion of roots of negative \
numbers.  Our purpose in this section is to highlight some of the episodes in \
the very colorful history of how thinking about imaginary numbers developed.  \
We intend to show you that, contrary to popular belief, there is really \
nothing imaginary about \"imaginary numbers.\"  They are just as real as \
\"real numbers.\"\
\>", "Text",
 CellChangeTimes->{{3.39896791690625*^9, 3.398967928140625*^9}}],

Cell[TextData[{
 "\tOur story begins in 1545.  In that year the Italian mathematician ",
 StyleBox[ButtonBox["Girolamo Cardano",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Cardan.\
html"], None}],
  FontFamily->"Times New Roman",
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[0, 0, 1]],
 " published Ars Magna (The Great Art), a 40-chapter masterpiece in which he \
gave for the first time an algebraic solution to the ",
 StyleBox["general cubic equation",
  FontColor->RGBColor[0, 0, 1]],
 "  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["z", "3"], "+", 
    RowBox[{
     SubscriptBox["a", "2"], " ", 
     SuperscriptBox["z", "2"]}], "+", 
    RowBox[{
     SubscriptBox["a", "1"], " ", "z"}], " ", "+", " ", 
    SubscriptBox["a", "0"]}], " ", "=", " ", "0"}]]],
 ". "
}], "Text",
 Evaluatable->False,
 CellChangeTimes->{3.398967929875*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "\tCardano did not have at his disposal the power of today's algebraic \
notation, and he tended to think of cubes or squares as geometric objects \
rather than algebraic quantities.  Essentially, however, his solution began \
with the substiution ",
 Cell[BoxData[
  RowBox[{"z", " ", "=", " ", 
   RowBox[{"x", "-", 
    RowBox[{
     FractionBox["1", "3"], 
     SubscriptBox["a", "2"]}]}]}]]],
 ".  This move transforms  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["z", "3"], "+", 
    RowBox[{
     SubscriptBox["a", "2"], " ", 
     SuperscriptBox["z", "2"]}], "+", 
    RowBox[{
     SubscriptBox["a", "1"], " ", "z"}], " ", "+", " ", 
    SubscriptBox["a", "0"]}], " ", "=", " ", "0"}]]],
 "  into the cubic equation  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["x", "3"], "+", 
    RowBox[{"b", " ", "x"}], " ", "+", " ", "c"}], " ", "=", " ", "0"}]]],
 "  without a squared term, which is called a depressed cubic and can be \
written as \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["x", "3"], "+", 
    RowBox[{"b", " ", "x"}], " ", "+", " ", "c"}], " ", "=", " ", "0"}]]],
 ". \n\nYou need not worry about the computational details, but the \
coefficients are  ",
 Cell[BoxData[
  RowBox[{"b", " ", "=", " ", 
   RowBox[{
    SubscriptBox["a", "1"], "-", 
    RowBox[{
     FractionBox["1", "3"], 
     SubsuperscriptBox["a", "2", "2"]}]}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{"c", " ", "=", " ", 
   RowBox[{
    SubscriptBox["a", "0"], "-", 
    RowBox[{
     FractionBox["1", "3"], 
     SubscriptBox["a", "1"], " ", 
     SubscriptBox["a", "2"]}], "+", 
    RowBox[{
     FractionBox["1", "27"], "2", " ", 
     SubsuperscriptBox["a", "2", "3"]}]}]}]]],
 ". "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration.",
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"eqn0", " ", "=", 
     RowBox[{
      SuperscriptBox["z", "3"], "+", 
      RowBox[{
       SubscriptBox["a", "2"], " ", 
       SuperscriptBox["z", "2"]}], "+", 
      RowBox[{
       SubscriptBox["a", "1"], " ", "z"}], " ", "+", " ", 
      SubscriptBox["a", "0"]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqn1", " ", "=", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{"eqn0", ",", " ", 
       RowBox[{"z", "\[Rule]", " ", 
        RowBox[{"x", "-", 
         RowBox[{
          SubscriptBox["a", "2"], "/", "3"}]}]}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"eqn2", " ", "=", 
     RowBox[{"ExpandAll", "[", "eqn1", "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"eqn3", " ", "=", " ", 
     RowBox[{"Collect", "[", 
      RowBox[{"eqn2", ",", "x"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"eqn0", "\[Equal]", "0"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Substitute  \>\"", ",", 
      RowBox[{"z", "\[Rule]", " ", 
       RowBox[{"x", "-", 
        RowBox[{
         SubscriptBox["a", "2"], "/", "3"}]}]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Get\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"eqn1", "\[Equal]", "0"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"eqn2", "\[Equal]", "0"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"eqn3", "\[Equal]", "0"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"A", "=", 
     RowBox[{"CoefficientList", "[", 
      RowBox[{"eqn3", ",", "x"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      SuperscriptBox["x", "3"], ",", "\"\< + (\>\"", ",", 
      SubscriptBox["A", 
       RowBox[{"\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]], ",", 
      "\"\<)\>\"", ",", "x", ",", "\"\< + (\>\"", ",", 
      SubscriptBox["A", 
       RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], ",", 
      "\"\<) = 0\>\""}], "]"}], ";"}], "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.398968590234375*^9, 3.398968591546875*^9}}]
}, Closed]],

Cell[TextData[{
 "\tTo illustrate, begin with  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["z", "3"], "+", 
    RowBox[{"9", 
     SuperscriptBox["z", "2"]}], "+", 
    RowBox[{"24", "z"}], "+", "20"}], " ", "=", " ", "0"}]]],
 "  and substitute  ",
 Cell[BoxData[
  RowBox[{"z", " ", "=", " ", 
   RowBox[{
    RowBox[{"x", "-", 
     RowBox[{
      FractionBox["1", "3"], 
      SubscriptBox["a", "2"]}]}], " ", "=", "  ", 
    RowBox[{
     RowBox[{"x", "-", 
      FractionBox["9", "3"]}], " ", "=", "  ", 
     RowBox[{"x", "-", "3"}]}]}]}]]],
 ".  The equation then becomes  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"x", "-", "3"}], ")"}], "3"], "+", 
    RowBox[{"9", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"x", "-", "3"}], ")"}], "2"]}], "+", 
    RowBox[{"24", " ", 
     RowBox[{"(", 
      RowBox[{"x", "-", "3"}], ")"}]}], "+", "20"}], " ", "=", " ", "0"}]]],
 ", which simplifies to  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["x", "3"], "-", 
    RowBox[{"3", " ", "x"}], "+", "2"}], " ", "=", " ", "0"}]]],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration.",
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"eqn0", " ", "=", 
     RowBox[{
      SuperscriptBox["z", "3"], "+", 
      RowBox[{"9", 
       SuperscriptBox["z", "2"]}], "+", 
      RowBox[{"24", "z"}], "+", "20"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqn1", " ", "=", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{"eqn0", ",", " ", 
       RowBox[{"z", "\[Rule]", " ", 
        RowBox[{"x", "-", 
         RowBox[{"9", "/", "3"}]}]}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"eqn2", " ", "=", 
     RowBox[{"ExpandAll", "[", "eqn1", "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"eqn0", "\[Equal]", "0"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Substitute  \>\"", ",", 
      RowBox[{"z", "\[Rule]", " ", 
       RowBox[{"x", "-", 
        RowBox[{"9", "/", "3"}]}]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Get\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"eqn1", "\[Equal]", "0"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"eqn2", "\[Equal]", "0"}], "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3989685975*^9, 3.39896859859375*^9}}]
}, Closed]],

Cell[TextData[{
 "\tIf Cardano could get any value of x that solved a depressed cubic, he \
could easily get a corresponding solution to ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["z", "3"], "+", 
    RowBox[{
     SubscriptBox["a", "2"], " ", 
     SuperscriptBox["z", "2"]}], "+", 
    RowBox[{
     SubscriptBox["a", "1"], " ", "z"}], " ", "+", " ", 
    SubscriptBox["a", "0"]}], " ", "=", " ", "0"}]]],
 " from the identity ",
 Cell[BoxData[
  RowBox[{"z", " ", "=", " ", 
   RowBox[{"x", "-", 
    RowBox[{
     FractionBox["1", "3"], 
     SubscriptBox["a", "2"]}]}]}]]],
 ". Happily, Cardano knew how to solve a depressed cubic.  The technique had \
been communicated to him by Niccolo Fontana who, unfortunately, came to be \
known as ",
 StyleBox[ButtonBox["Tartaglia",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Tartaglia.\
html"], None}],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[0, 0, 1]],
 " (the stammerer) due to a speaking disorder.  The procedure was also \
independently discovered some 30 years earlier by Scipione del Ferro of \
Bologna.  Ferro and Tartaglia showed that one of the solutions to the \
depressed cubic equation is\n\n\t\t",
 Cell[BoxData[
  RowBox[{"x", " ", "=", " ", 
   RowBox[{
    RadicalBox[
     RowBox[{
      FractionBox[
       RowBox[{"-", "c"}], "2"], " ", "+", " ", 
      SqrtBox[
       RowBox[{
        FractionBox[
         SuperscriptBox["c", "2"], "4"], "+", 
        FractionBox[
         SuperscriptBox["b", "3"], "27"]}]]}], "3"], " ", "+", " ", 
    RadicalBox[
     RowBox[{
      RowBox[{"-", 
       FractionBox["c", "2"]}], " ", "-", " ", 
      SqrtBox[
       RowBox[{
        FractionBox[
         SuperscriptBox["c", "2"], "4"], "+", 
        FractionBox[
         SuperscriptBox["b", "3"], "27"]}]]}], "3"]}]}]],
  AspectRatioFixed->True],
 ".  "
}], "Text",
 CellChangeTimes->{{3.398967950421875*^9, 3.39896795578125*^9}}],

Cell[TextData[{
 "\tAlthough Cardano would not have reasoned in the following way, today we \
can take this value for x and use it to factor the depressed cubic into a \
linear and quadratic term.  The remaining roots can then be found with the \
quadratic formula. \n\n\tFor example, to solve  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["z", "3"], "+", 
    RowBox[{"9", 
     SuperscriptBox["z", "2"]}], "+", 
    RowBox[{"24", "z"}], "+", "20"}], " ", "=", " ", "0"}]]],
 ",  use the substitution  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{"x", "-", "3"}]}]]],
 "  to get  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["x", "3"], "-", 
    RowBox[{"3", " ", "x"}], "+", "2"}], " ", "=", " ", "0"}]]],
 ",  which is a depressed cubic equation.  Next, apply the \
\"Ferro-Tartaglia\" formula with ",
 Cell[BoxData[
  RowBox[{"b", "=", 
   RowBox[{"-", "3"}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{"c", "=", "2"}]]],
 " to get  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RadicalBox[
     RowBox[{
      FractionBox[
       RowBox[{"-", "2"}], "2"], " ", "+", " ", 
      SqrtBox[
       RowBox[{
        FractionBox[
         SuperscriptBox["2", "2"], "4"], "+", 
        FractionBox[
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"-", "3"}], ")"}], "3"], "27"]}]]}], "3"], " ", "+", " ", 
    RadicalBox[
     RowBox[{
      RowBox[{"-", 
       FractionBox["2", "2"]}], " ", "-", " ", 
      SqrtBox[
       RowBox[{
        FractionBox[
         SuperscriptBox["2", "2"], "4"], "+", 
        FractionBox[
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"-", "3"}], ")"}], "3"], "27"]}]]}], "3"]}], " ", "=", " ",
    
   RowBox[{
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], 
      RowBox[{"1", "/", "3"}]], "+", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], 
      RowBox[{"1", "/", "3"}]]}], " ", "=", " ", 
    RowBox[{"-", "2"}]}]}]]],
 ".  Since  ",
 Cell[BoxData[
  RowBox[{"x", "=", 
   RowBox[{"-", "2"}]}]]],
 "  is a root,   ",
 Cell[BoxData[
  RowBox[{"x", "+", "2"}]]],
 "  must be a factor of  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["x", "3"], "-", 
   RowBox[{"3", " ", "x"}], "+", "2"}]]],
 ".  Dividing   ",
 Cell[BoxData[
  RowBox[{"x", "+", "2"}]]],
 "  into  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["x", "3"], "-", 
   RowBox[{"3", " ", "x"}], "+", "2"}]]],
 "  gives  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["x", "2"], "-", 
   RowBox[{"2", " ", "x"}], "+", "1"}]]],
 ",  which yields the remaining (duplicate) roots of   ",
 Cell[BoxData[
  RowBox[{"x", "=", "1"}]]],
 ".  The solutions to  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["z", "3"], "+", 
    RowBox[{"9", 
     SuperscriptBox["z", "2"]}], "+", 
    RowBox[{"24", "z"}], "+", "20"}], " ", "=", " ", "0"}]]],
 "  are obtained by recalling  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{"x", "-", "3"}]}]]],
 ", which yields the three roots  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "2"}], "-", "3"}], "=", 
    RowBox[{"-", "5"}]}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "2"], " ", "=", " ", 
   RowBox[{
    SubscriptBox["z", "3"], "=", 
    RowBox[{
     RowBox[{"1", "-", "3"}], "=", 
     RowBox[{"-", "2"}]}]}]}]]],
 "."
}], "Text",
 CellChangeTimes->{3.3989679595625*^9}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration.",
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"eqn0", " ", "=", 
     RowBox[{
      SuperscriptBox["z", "3"], "+", 
      RowBox[{"9", 
       SuperscriptBox["z", "2"]}], "+", 
      RowBox[{"24", "z"}], "+", "20"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqn1", " ", "=", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{"eqn0", ",", " ", 
       RowBox[{"z", "\[Rule]", " ", 
        RowBox[{"x", "-", 
         RowBox[{"9", "/", "3"}]}]}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"eqn2", " ", "=", 
     RowBox[{"ExpandAll", "[", "eqn1", "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"eqn0", "\[Equal]", "0"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Substitute  \>\"", ",", 
      RowBox[{"z", "\[Rule]", " ", 
       RowBox[{"x", "-", 
        RowBox[{"9", "/", "3"}]}]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Get\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"eqn1", "\[Equal]", "0"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"eqn2", "\[Equal]", "0"}], "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39896860703125*^9, 3.39896862921875*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<Start with the Ferro-Tartaglia formula\>\"", "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<x = \!\(\*RadicalBox[\(\*FractionBox[\(-c\), \(2\)]\\\  + \\\ \
\*SqrtBox[\(\*FractionBox[SuperscriptBox[\(c\), \(2\)], \(4\)] + \
\*FractionBox[SuperscriptBox[\(b\), \(3\)], \(27\)]\)]\), \(3\)]\) + \
\!\(\*RadicalBox[\(\(-\*FractionBox[\(c\), \(2\)]\)\\\  - \\\ \
\*SqrtBox[\(\*FractionBox[SuperscriptBox[\(c\), \(2\)], \(4\)] + \
\*FractionBox[SuperscriptBox[\(b\), \(3\)], \(27\)]\)]\), \(3\)]\)\>\"", 
     "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<Substitute  b\[Rule]-3  and  c\[Rule]2  and  get\>\"", 
     "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<x = \>\"", ",", 
      RowBox[{"ReplaceAll", "[", " ", 
       RowBox[{
        RowBox[{
         RadicalBox[
          RowBox[{
           FractionBox[
            RowBox[{"-", "c"}], "2"], " ", "+", " ", 
           SqrtBox[
            RowBox[{
             FractionBox[
              SuperscriptBox["c", "2"], "4"], "+", 
             FractionBox[
              SuperscriptBox["b", "3"], "27"]}]]}], "3"], " ", "+", " ", 
         RadicalBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox["c", "2"]}], " ", "-", " ", 
           SqrtBox[
            RowBox[{
             FractionBox[
              SuperscriptBox["c", "2"], "4"], "+", 
             FractionBox[
              SuperscriptBox["b", "3"], "27"]}]]}], "3"]}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"b", "\[Rule]", "\"\<-3\>\""}], ",", 
          RowBox[{"c", "\[Rule]", "\"\<2\>\""}]}], "}"}]}], "]"}]}], "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Which simplifies\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<x = \>\"", ",", 
      RowBox[{"ReplaceAll", "[", " ", 
       RowBox[{
        RowBox[{
         RadicalBox[
          RowBox[{
           FractionBox[
            RowBox[{"-", "c"}], "2"], " ", "+", " ", 
           SqrtBox[
            RowBox[{
             FractionBox[
              SuperscriptBox["c", "2"], "4"], "+", 
             FractionBox[
              SuperscriptBox["b", "3"], "27"]}]]}], "3"], " ", "+", " ", 
         RadicalBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox["c", "2"]}], " ", "-", " ", 
           SqrtBox[
            RowBox[{
             FractionBox[
              SuperscriptBox["c", "2"], "4"], "+", 
             FractionBox[
              SuperscriptBox["b", "3"], "27"]}]]}], "3"]}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"b", "\[Rule]", 
           RowBox[{"-", "3"}]}], ",", 
          RowBox[{"c", "\[Rule]", "2"}]}], "}"}]}], "]"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<And an answer is\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<x = -2\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.398968624*^9, 3.398968637890625*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<Now divide \!\(\*SuperscriptBox[\(x\), \(3\)]\)-3 x+2 by x+2\>\"", 
     "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Q", "[", "x_", "]"}], "=", 
     RowBox[{"PolynomialQuotient", "[", 
      RowBox[{
       RowBox[{
        SuperscriptBox["x", "3"], "-", 
        RowBox[{"3", " ", "x"}], "+", "2"}], ",", 
       RowBox[{"x", "+", "2"}], ",", "x"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Q[x] = \!\(\*FractionBox[\(\*SuperscriptBox[\(x\), \(3\)] - 3\\\ x \
+ 2\), \(x + 2\)]\) = \>\"", ",", 
      RowBox[{"Q", "[", "x", "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Solve\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"Q", "[", "x", "]"}], "\[Equal]", "0"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Get\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", " ", 
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Q", "[", "x", "]"}], "\[Equal]", "0"}], ",", "x"}], " ", 
      "]"}], "]"}], ";"}], "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.398968640984375*^9, 3.39896864715625*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", "\"\<The solutions to\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"eqn0", "\[Equal]", "0"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Are\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<    \!\(\*SubscriptBox[\(z\), \(1\)]\) = x-3 = -2 - 3 = -5\>\"", 
     "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<\!\(\*SubscriptBox[\(z\), \(2\)]\) = \!\(\*SubscriptBox[\(z\), \
\(3\)]\)= x-3 = 1 - 3 = -2\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.3989686090625*^9, 3.3989686500625*^9}]
}, Closed]],

Cell[TextData[{
 "\tSo, by using Tartaglia's work and a clever transformation technique, \
Cardano was able to crack what had seemed to be the impossible task of \
solving the general cubic equation.  Surprisingly, this development played a \
significant role in helping to establish the legitimacy of imaginary numbers. \
 Roots of negative numbers, of course, had come up earlier in the simplest of \
quadratic equations, such as  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["x", "2"], "+", "1"}], "=", "0"}]]],
 ".  The solutions we know today as  ",
 Cell[BoxData[
  RowBox[{"x", "=", 
   RowBox[{"\[PlusMinus]", 
    SqrtBox[
     RowBox[{"-", "1"}]]}]}]]],
 ", however, were easy for mathematicians to ignore.  In Cardano's time, \
negative numbers were still being treated with some suspicion, as it was \
difficult to conceive of any physical reality corresponding to them. Taking \
square roots of such quantities was surely all the more ludicrous. \
Nevertheless, Cardano made some genuine attempts to deal with ",
 Cell[BoxData[
  SqrtBox[
   RowBox[{"-", "1"}]]]],
 ".  Unfortunately, his geometric thinking made it hard to make much headway. \
 At one point he commented that the process of arithmetic that deals with \
quantities such as ",
 Cell[BoxData[
  SqrtBox[
   RowBox[{"-", "1"}]]]],
 " \"involves mental tortures and is truly sophisticated.\"  At another point \
he concluded that the process is \"as refined as it is useless.\" Many \
mathematicians held this view, but finally there was a breakthrough."
}], "Text",
 CellChangeTimes->{{3.398967978859375*^9, 3.398967984671875*^9}}],

Cell[TextData[{
 "\tIn his 1572 treatise L'Algebra, ",
 StyleBox[ButtonBox["Rafael Bombelli",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Bombelli.\
html"], None}],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[0, 0, 1]],
 " showed that roots of negative numbers have great utility indeed. Consider \
the depressed cubic ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["x", "3"], "-", 
    RowBox[{"15", "x"}], "-", "4"}], "=", "0"}]]],
 ".  Using ",
 Cell[BoxData[
  RowBox[{"b", "=", 
   RowBox[{"-", "15"}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{"c", "=", 
   RowBox[{"-", "4"}]}]]],
 " in the \"Ferro-Tartaglia\" formula for the depressed cubic, we compute ",
 Cell[BoxData[
  RowBox[{"x", "=", 
   RowBox[{
    RadicalBox[
     RowBox[{"2", "+", 
      SqrtBox[
       RowBox[{"-", "121"}]]}], "3"], "+", 
    RadicalBox[
     RowBox[{"2", "-", 
      SqrtBox[
       RowBox[{"-", "121"}]]}], "3"]}]}]]],
 ", or in a somewhat different form, ",
 Cell[BoxData[
  RowBox[{"x", "=", 
   RowBox[{
    RadicalBox[
     RowBox[{"2", "+", 
      RowBox[{"11", 
       SqrtBox[
        RowBox[{"-", "1"}]]}]}], "3"], "+", 
    RadicalBox[
     RowBox[{"2", "-", 
      RowBox[{"11", 
       SqrtBox[
        RowBox[{"-", "1"}]]}]}], "3"]}]}]]],
 ". "
}], "Text"],

Cell[TextData[{
 "\tSimplifying this expression would have been very difficult if Bombelli \
had not come up with what he called a \"wild thought.\"   He suspected that \
if the original depressed cubic had real solutions, then the two parts of x \
in the preceding equation could be written as  ",
 Cell[BoxData[
  RowBox[{"u", "+", 
   RowBox[{"v", 
    SqrtBox[
     RowBox[{"-", "1"}]]}]}]],
  AspectRatioFixed->True],
 "  and  ",
 Cell[BoxData[
  RowBox[{"u", "-", 
   RowBox[{"v", 
    SqrtBox[
     RowBox[{"-", "1"}]]}]}]],
  AspectRatioFixed->True],
 "  for some real numbers u and v.  That is, Bombeli believed  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"u", "+", 
    RowBox[{"v", 
     SqrtBox[
      RowBox[{"-", "1"}]]}]}], "=", 
   RadicalBox[
    RowBox[{"2", "+", 
     RowBox[{"11", 
      SqrtBox[
       RowBox[{"-", "1"}]]}]}], "3"]}]]],
 " and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"u", "-", 
    RowBox[{"v", 
     SqrtBox[
      RowBox[{"-", "1"}]]}]}], "=", 
   RadicalBox[
    RowBox[{"2", "-", 
     RowBox[{"11", 
      SqrtBox[
       RowBox[{"-", "1"}]]}]}], "3"]}]]],
 ",  which would mean  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"u", "+", 
      RowBox[{"v", 
       SqrtBox[
        RowBox[{"-", "1"}]]}]}], ")"}], "3"], "=", 
   RowBox[{"2", "+", 
    RowBox[{"11", 
     SqrtBox[
      RowBox[{"-", "1"}]]}]}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"u", "-", 
      RowBox[{"v", 
       SqrtBox[
        RowBox[{"-", "1"}]]}]}], ")"}], "3"], "=", 
   RowBox[{"2", "-", 
    RowBox[{"11", 
     SqrtBox[
      RowBox[{"-", "1"}]]}]}]}]]],
 ".  Then, using the well-known algebraic identity ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"a", "+", "b"}], ")"}], "3"], "=", 
   RowBox[{
    SuperscriptBox["a", "3"], "+", 
    RowBox[{"3", " ", 
     SuperscriptBox["a", "2"], " ", "b"}], "+", 
    RowBox[{"3", " ", "a", " ", 
     SuperscriptBox["b", "2"]}], "+", 
    SuperscriptBox["b", "3"]}]}]]],
 ", and (letting ",
 Cell[BoxData[
  RowBox[{"a", "=", "u"}]]],
 " and ",
 Cell[BoxData[
  RowBox[{"b", "=", 
   RowBox[{"v", " ", 
    SqrtBox[
     RowBox[{"-", "1"}]]}]}]]],
 "),  and assuming that roots of negative numbers obey the rules of algebra, \
he obtained  \n\t\n\t",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"u", "+", 
      RowBox[{"v", 
       SqrtBox[
        RowBox[{"-", "1"}]]}]}], ")"}], "3"], "="}]]],
 "  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["u", "3"], "+", 
   RowBox[{"3", 
    SuperscriptBox["u", "2"], 
    RowBox[{"(", 
     RowBox[{"v", 
      SqrtBox[
       RowBox[{"-", "1"}]]}], ")"}]}], "+", 
   RowBox[{"3", 
    RowBox[{"(", "u", ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"v", 
       SqrtBox[
        RowBox[{"-", "1"}]]}], ")"}], "2"]}], "+", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"v", 
      SqrtBox[
       RowBox[{"-", "1"}]]}], ")"}], "3"]}]]],
 "  \n\t",
 Cell[BoxData["           "]],
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{"=", " ", 
    RowBox[{
     SuperscriptBox["u", "3"], "+", 
     RowBox[{"3", 
      RowBox[{"(", "u", ")"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"v", 
         SqrtBox[
          RowBox[{"-", "1"}]]}], ")"}], "2"]}], "+", 
     RowBox[{"3", 
      SuperscriptBox["u", "2"], 
      RowBox[{"(", 
       RowBox[{"v", 
        SqrtBox[
         RowBox[{"-", "1"}]]}], ")"}]}], "+", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"v", 
        SqrtBox[
         RowBox[{"-", "1"}]]}], ")"}], "3"]}]}]}]]],
 "   \n\t                          ",
 Cell[BoxData[
  RowBox[{"=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["u", "3"], "-", 
      RowBox[{"3", "u", " ", 
       SuperscriptBox["v", "2"]}]}], ")"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", 
        SuperscriptBox["u", "2"], "v"}], "-", 
       SuperscriptBox["v", "3"]}], ")"}], 
     SqrtBox[
      RowBox[{"-", "1"}]]}]}]}]]],
 "  \n\t                          ",
 Cell[BoxData[
  RowBox[{"=", " ", 
   RowBox[{
    RowBox[{"u", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["u", "2"], "-", 
       RowBox[{"3", " ", 
        SuperscriptBox["v", "2"]}]}], ")"}]}], "+", 
    RowBox[{"v", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", 
        SuperscriptBox["u", "2"]}], "-", 
       SuperscriptBox["v", "2"]}], ")"}], 
     SqrtBox[
      RowBox[{"-", "1"}]]}]}]}]]],
 "  \n\t                          ",
 Cell[BoxData[
  RowBox[{"=", " ", 
   RowBox[{"2", " ", "+", " ", 
    RowBox[{"11", 
     SqrtBox[
      RowBox[{"-", "1"}]]}]}]}]],
  AspectRatioFixed->True],
 ".  "
}], "Text",
 Evaluatable->False,
 CellChangeTimes->{{3.39896762759375*^9, 3.398967636140625*^9}, 
   3.398967990828125*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "\tBy equating like parts, Bombelli reasoned that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"u", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["u", "2"], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["v", "2"]}]}], ")"}]}], "=", "2"}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"v", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", 
       SuperscriptBox["u", "2"]}], "-", 
      SuperscriptBox["v", "2"]}], ")"}]}], "=", "11"}]]],
 ".  Perhaps thinking even more wildly, Bombelli then supposed that u and v \
were integers.  The only integer factors of 2 are 2 and 1, so the equation  \
",
 Cell[BoxData[
  RowBox[{
   RowBox[{"u", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["u", "2"], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["v", "2"]}]}], ")"}]}], "=", "2"}]]],
 "   led Bombelli to conclude that  ",
 Cell[BoxData[
  RowBox[{"u", "=", "2"}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["u", "2"], "-", 
    RowBox[{"3", " ", 
     SuperscriptBox["v", "2"]}]}], "=", "1"}]]],
 ".  From this conclusion it follows that  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["v", "2"], "=", "1"}]]],
 ", or  ",
 Cell[BoxData[
  RowBox[{"v", "=", 
   RowBox[{"\[PlusMinus]", "1"}]}]]],
 ". Amazingly, ",
 Cell[BoxData[
  RowBox[{"u", "=", "2"}]]],
 " and ",
 Cell[BoxData[
  RowBox[{"v", "=", "1"}]]],
 "  solve the second equation ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"v", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", 
       SuperscriptBox["u", "2"]}], "-", 
      SuperscriptBox["v", "2"]}], ")"}]}], "=", "11"}]]],
 ", so Bombelli declared the values for ",
 StyleBox["u",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["v",
  FontFamily->"Courier New"],
 " to be  ",
 Cell[BoxData[
  RowBox[{"u", "=", "2"}]]],
 " and ",
 Cell[BoxData[
  RowBox[{"v", "=", "1"}]]],
 ",  respectively."
}], "Text",
 CellChangeTimes->{{3.398968012640625*^9, 3.39896804475*^9}}],

Cell[TextData[{
 "\tSince ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"2", "+", 
      SqrtBox[
       RowBox[{"-", "1"}]]}], ")"}], "3"], "=", 
   RowBox[{"2", "+", 
    RowBox[{"11", 
     SqrtBox[
      RowBox[{"-", "1"}]]}]}]}]]],
 ", we clearly have ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"2", "+", 
    SqrtBox[
     RowBox[{"-", "1"}]]}], "=", 
   RadicalBox[
    RowBox[{"2", "+", 
     RowBox[{"11", 
      SqrtBox[
       RowBox[{"-", "1"}]]}]}], "3"]}]]],
 ".  Similarly, Bombelli showed that ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"2", "-", 
    SqrtBox[
     RowBox[{"-", "1"}]]}], "=", 
   RadicalBox[
    RowBox[{"2", "-", 
     RowBox[{"11", 
      SqrtBox[
       RowBox[{"-", "1"}]]}]}], "3"]}]]],
 ".  But this means that\n\n\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RadicalBox[
     RowBox[{"2", "+", 
      RowBox[{"11", 
       SqrtBox[
        RowBox[{"-", "1"}]]}]}], "3"], "+", 
    RadicalBox[
     RowBox[{"2", "-", 
      RowBox[{"11", 
       SqrtBox[
        RowBox[{"-", "1"}]]}]}], "3"]}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"2", "+", 
       SqrtBox[
        RowBox[{"-", "1"}]]}], ")"}], "+", 
     RowBox[{"(", 
      RowBox[{"2", "-", 
       SqrtBox[
        RowBox[{"-", "1"}]]}], ")"}]}], "=", "4"}]}]]],
 ", "
}], "Text",
 CellChangeTimes->{3.398968090828125*^9}],

Cell[TextData[{
 "which was a proverbial bombshell.  Prior to Bombelli, mathematicians could \
easily scoff at imaginary numbers when they arose as solutions to quadratic \
equations.  With cubic equations, they no longer had this luxury.  That ",
 Cell[BoxData[
  RowBox[{"x", "=", "4"}]]],
 " was a correct solution to the equation  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["x", "3"], "-", 
    RowBox[{"15", "x"}], "-", "4"}], "=", "0"}]]],
 "  was indisputable, as it could be checked easily.  However, to arrive at \
this very real solution, mathematicians had to take a detour through the \
uncharted territory of \"imaginary numbers.\"  Thus, whatever else might have \
been said about these numbers (which, today, we call complex numbers), their \
utility could no longer be ignored."
}], "Text",
 CellChangeTimes->{3.398968096859375*^9}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration.",
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell["Enter the cubic equation.", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"b", ",", "c", ",", "r", ",", "x", ",", "z"}], "]"}], ";"}], " ",
    "\n", 
   RowBox[{
    RowBox[{"eqn", " ", "=", " ", 
     RowBox[{
      RowBox[{
       SuperscriptBox["x", "3"], " ", "-", " ", 
       RowBox[{"15", " ", "x"}], " ", "-", " ", "4"}], " ", "\[Equal]", " ", 
      "0"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"solset", " ", "=", " ", 
     RowBox[{"Solve", "[", 
      RowBox[{"eqn", ",", " ", "x"}], " ", "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", "eqn", "\[IndentingNewLine]", 
   RowBox[{"MapAll", "[", 
    RowBox[{"Factor", ",", "eqn"}], "]"}], "\n", "solset", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39896866034375*^9, 3.398968662453125*^9}}],

Cell["Enter the solution for the cubic equation.", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"z", " ", "=", " ", 
    RowBox[{
     RadicalBox[
      RowBox[{
       FractionBox[
        RowBox[{"-", "c"}], "2"], " ", "+", " ", 
       SqrtBox[
        RowBox[{
         FractionBox[
          SuperscriptBox["c", "2"], "4"], "+", 
         FractionBox[
          SuperscriptBox["b", "3"], "27"]}]]}], "3"], " ", "+", " ", 
     RadicalBox[
      RowBox[{
       RowBox[{"-", 
        FractionBox["c", "2"]}], " ", "-", " ", 
       SqrtBox[
        RowBox[{
         FractionBox[
          SuperscriptBox["c", "2"], "4"], "+", 
         FractionBox[
          SuperscriptBox["b", "3"], "27"]}]]}], "3"]}]}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39896868140625*^9, 3.3989686825*^9}}],

Cell[TextData[{
 "\nUse the Ferro-Tartaglia formula  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{
    RadicalBox[
     RowBox[{
      FractionBox[
       RowBox[{"-", "c"}], "2"], "+", 
      SqrtBox[
       RowBox[{
        FractionBox[
         SuperscriptBox["c", "2"], "4"], "+", 
        FractionBox[
         SuperscriptBox["b", "3"], "27"]}]]}], "3"], "-", 
    RadicalBox[
     RowBox[{
      FractionBox["c", "2"], "+", 
      SqrtBox[
       RowBox[{
        FractionBox[
         SuperscriptBox["c", "2"], "4"], "+", 
        FractionBox[
         SuperscriptBox["b", "3"], "27"]}]]}], "3"]}]}]],
  AspectRatioFixed->True],
 "  and verify that  z  it is a solution."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", "z", "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"b", " ", "=", " ", 
     RowBox[{"-", " ", "15"}]}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"c", " ", "=", " ", 
     RowBox[{"-", " ", "4"}]}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Solve  \>\"", ",", "0", ",", "\"\< = \>\"", ",", 
      RowBox[{
       SuperscriptBox["z", "3"], " ", "+", " ", 
       RowBox[{"b", " ", "z"}], " ", "+", " ", "c"}]}], "]"}], ";"}], "  ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Use the `Ferro-Tartaglia formula.`\>\"", "]"}],
     ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<0 = \!\(\*SuperscriptBox[\(z\), \(3\)]\) + b z + c\>\"", "]"}], 
    ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"z", " ", "=", " ", 
     RowBox[{
      RadicalBox[
       RowBox[{
        FractionBox[
         RowBox[{"-", "c"}], "2"], " ", "+", " ", 
        SqrtBox[
         RowBox[{
          FractionBox[
           SuperscriptBox["c", "2"], "4"], "+", 
          FractionBox[
           SuperscriptBox["b", "3"], "27"]}]]}], "3"], " ", "+", " ", 
      RadicalBox[
       RowBox[{
        RowBox[{"-", 
         FractionBox["c", "2"]}], " ", "-", " ", 
        SqrtBox[
         RowBox[{
          FractionBox[
           SuperscriptBox["c", "2"], "4"], "+", 
          FractionBox[
           SuperscriptBox["b", "3"], "27"]}]]}], "3"]}]}], ";"}], "  ", "\n", 
   
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<z = \!\(\*RadicalBox[\(\*FractionBox[\(-c\), \(2\)] + \\\ \
\*SqrtBox[\(\*FractionBox[SuperscriptBox[\(c\), \(2\)], \(4\)] + \
\*FractionBox[SuperscriptBox[\(b\), \(3\)], \(27\)]\)]\), \(3\)]\) + \
\!\(\*RadicalBox[\(\(-\*FractionBox[\(c\), \(2\)]\) - \\\ \
\*SqrtBox[\(\*FractionBox[SuperscriptBox[\(c\), \(2\)], \(4\)] + \
\*FractionBox[SuperscriptBox[\(b\), \(3\)], \(27\)]\)]\), \(3\)]\)\>\"", 
     "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Substitute  b = \>\"", ",", "b", ",", "\"\<  and  c = \>\"", ",", 
      "c", ",", " ", "\"\<  and get\>\""}], "]"}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<    \!\(\*RadicalBox[\(\*FractionBox[\(-c\), \(2\)] + \\\ \
\*SqrtBox[\(\*FractionBox[SuperscriptBox[\(c\), \(2\)], \(4\)] + \
\*FractionBox[SuperscriptBox[\(b\), \(3\)], \(27\)]\)]\), \(3\)]\) = \>\"", 
      ",", " ", 
      RadicalBox[
       RowBox[{
        FractionBox[
         RowBox[{"-", "c"}], "2"], " ", "+", " ", 
        SqrtBox[
         RowBox[{
          FractionBox[
           SuperscriptBox["c", "2"], "4"], "+", 
          FractionBox[
           SuperscriptBox["b", "3"], "27"]}]]}], "3"]}], "]"}], ";"}], "  ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<    \!\(\*RadicalBox[\(\(-\*FractionBox[\(c\), \(2\)]\) - \\\ \
\*SqrtBox[\(\*FractionBox[SuperscriptBox[\(c\), \(2\)], \(4\)] + \
\*FractionBox[SuperscriptBox[\(b\), \(3\)], \(27\)]\)]\), \(3\)]\) = \>\"", 
      ",", "  ", 
      RadicalBox[
       RowBox[{
        RowBox[{"-", 
         FractionBox["c", "2"]}], " ", "-", " ", 
        SqrtBox[
         RowBox[{
          FractionBox[
           SuperscriptBox["c", "2"], "4"], "+", 
          FractionBox[
           SuperscriptBox["b", "3"], "27"]}]]}], "3"]}], "]"}], ";"}], "  ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The details are\>\"", "]"}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<z = \!\(\*RadicalBox[\(2 + \*SqrtBox[\(-121\)]\), \(3\)]\)+ \
\!\(\*RadicalBox[\(2 + \*SqrtBox[\(-121\)]\), \(3\)]\)\>\"", "]"}], ";"}], 
   "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<z = \!\(\*RadicalBox[\(2 + 11 \*SqrtBox[\(-1\)]\), \(3\)]\)+ \
\!\(\*RadicalBox[\(2 + 11 \*SqrtBox[\(-1\)]\), \(3\)]\)\>\"", "]"}], ";"}], 
   "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<    \!\(\*RadicalBox[\(2 + 11 \*SqrtBox[\(-1\)]\), \(3\)]\) = \>\"",
       ",", 
      RadicalBox[
       RowBox[{"2", "+", 
        RowBox[{"11", 
         SqrtBox[
          RowBox[{"-", "1"}]]}]}], "3"]}], "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<    \!\(\*RadicalBox[\(2 - 11 \*SqrtBox[\(-1\)]\), \(3\)]\) = \>\"",
       ",", 
      RadicalBox[
       RowBox[{"2", "-", 
        RowBox[{"11", 
         SqrtBox[
          RowBox[{"-", "1"}]]}]}], "3"]}], "]"}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Add these quantities and obtain\>\"", "]"}], 
    ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<z = \>\"", ",", " ", 
      RadicalBox[
       RowBox[{"2", "+", 
        RowBox[{"11", 
         SqrtBox[
          RowBox[{"-", "1"}]]}]}], "3"], ",", "\"\< + \>\"", ",", 
      RadicalBox[
       RowBox[{"2", "-", 
        RowBox[{"11", 
         SqrtBox[
          RowBox[{"-", "1"}]]}]}], "3"]}], "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<z = \>\"", ",", 
      RowBox[{
       RadicalBox[
        RowBox[{"2", "+", 
         RowBox[{"11", 
          SqrtBox[
           RowBox[{"-", "1"}]]}]}], "3"], "+", 
       RadicalBox[
        RowBox[{"2", "-", 
         RowBox[{"11", 
          SqrtBox[
           RowBox[{"-", "1"}]]}]}], "3"]}]}], "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<z = \>\"", " ", ",", " ", "z", ",", " ", 
      "\"\<, using the `Ferro-Tartaglia formula.`\>\""}], "]"}], ";"}], "  ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39896868565625*^9},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 "\tAdmittedly, Bombelli's technique applies only to a few specialized cases, \
and lots of work remained to be done even if Bombelli's results could be \
extended.  After all, today we represent real numbers geometrically on the \
number line.  What possible representation could complex numbers have?  In \
1673 ",
 StyleBox[ButtonBox["John Wallis",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Wallis.\
html"], None}],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[0, 0, 1]],
 " made a stab at a geometric picture of complex numbers that comes close to \
what we use today.  He was interested in representing solutions to general \
quadratic equations, which we can write as ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["x", "2"], "+", 
    RowBox[{"2", "b", " ", "x"}], " ", "+", 
    SuperscriptBox["c", "2"]}], " ", "=", "0"}]]],
 " to make the following discussion easier to follow.  When we use the \
quadratic formula with this equation, we get\n\n\t\t",
 Cell[BoxData[
  RowBox[{"x", "=", 
   RowBox[{
    RowBox[{"-", "b"}], "-", 
    SqrtBox[
     RowBox[{
      SuperscriptBox["b", "2"], "-", 
      SuperscriptBox["c", "2"]}]]}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{"x", "=", 
   RowBox[{
    RowBox[{"-", "b"}], "+", 
    SqrtBox[
     RowBox[{
      SuperscriptBox["b", "2"], "-", 
      SuperscriptBox["c", "2"]}]]}]}]]],
 ". "
}], "Text"],

Cell[TextData[{
 "\tWallis imagined these solutions as displacements to the left and right \
from the point ",
 Cell[BoxData[
  RowBox[{"-", "b"}]]],
 ". He saw each displacement, whose value is ",
 Cell[BoxData[
  SqrtBox[
   RowBox[{
    SuperscriptBox["b", "2"], "-", 
    SuperscriptBox["c", "2"]}]]]],
 ", as the length of the sides of the right triangles shown in Figure 1.1. \
The points ",
 Cell[BoxData[
  SubscriptBox["P", "1"]],
  CellChangeTimes->{{3.398967837046875*^9, 3.3989678503125*^9}}],
 " and ",
 Cell[BoxData[
  SubscriptBox["P", "2"]],
  CellChangeTimes->{{3.398967837046875*^9, 3.3989678503125*^9}}],
 " represent the solutions to our equation, which is clearly correct if  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["b", "2"], "-", 
    SuperscriptBox["c", "2"]}], "\[GreaterEqual]", "0"}]]],
 ".  But how should we picture ",
 Cell[BoxData[
  SubscriptBox["P", "1"]],
  CellChangeTimes->{{3.398967837046875*^9, 3.3989678503125*^9}}],
 " and ",
 Cell[BoxData[
  SubscriptBox["P", "2"]],
  CellChangeTimes->{{3.398967837046875*^9, 3.3989678503125*^9}}],
 " when negative roots arise (i.e., when ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["b", "2"], "-", 
    SuperscriptBox["c", "2"]}], "<", "0"}]]],
 ")?  Wallis reasoned that, with negative roots, b would be less than c, so \
the lines of length b in Figure 1.1 would no longer be able to reach all the \
way to the x axis.  Instead, they would stop somewhere above it, as Figure \
1.2 shows.  Wallis argued that ",
 Cell[BoxData[
  SubscriptBox["P", "1"]],
  CellChangeTimes->{{3.398967837046875*^9, 3.3989678503125*^9}}],
 " and ",
 Cell[BoxData[
  SubscriptBox["P", "2"]],
  CellChangeTimes->{{3.398967837046875*^9, 3.3989678503125*^9}}],
 " should represent the geometric locations of the solutions  ",
 Cell[BoxData[
  RowBox[{"x", "=", 
   RowBox[{
    RowBox[{"-", "b"}], "-", 
    SqrtBox[
     RowBox[{
      SuperscriptBox["b", "2"], "-", 
      SuperscriptBox["c", "2"]}]]}]}]]],
 "  and   ",
 Cell[BoxData[
  RowBox[{"x", "=", 
   RowBox[{
    RowBox[{"-", "b"}], "+", 
    SqrtBox[
     RowBox[{
      SuperscriptBox["b", "2"], "-", 
      SuperscriptBox["c", "2"]}]]}]}]]],
 "  when  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["b", "2"], "-", 
    SuperscriptBox["c", "2"]}], "<", "0"}]]],
 ".  He evidently thought that, because b is shorter than c, it could no \
longer be the hypotenuse of the right triangle as it had been earlier.  The \
side of length c would now have to take that role."
}], "Text",
 CellChangeTimes->{{3.3989678549375*^9, 3.3989678715625*^9}, {
  3.398968148125*^9, 3.398968158953125*^9}}],

Cell[TextData[{
 "\t\t\t\t",
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .65385 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.961538 0.384615 0.0769231 0.384615 [
[ 0 0 0 0 ]
[ 1 .65385 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .07692 m
1 .07692 L
s
.96154 0 m
.96154 .65385 L
s
0 0 m
1 0 L
1 .65385 L
0 .65385 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.41761 .07692 m
.41761 .46154 L
s
1 0 0 r
.03299 .07692 m
.41761 .46154 L
.80223 .07692 L
s
0 0 1 r
.02 w
.96154 .07692 Mdot
.41761 .07692 Mdot
1 0 0 r
.03299 .07692 Mdot
.80223 .07692 Mdot
0 g
gsave
.03299 .03846 -66.5938 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(P) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.80223 .03846 -66.5938 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(P) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.05223 .02308 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.82146 .02308 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.41761 .03846 -84.5625 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(H) show
70.188 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
77.375 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
91.750 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
98.938 12.813 moveto
(L) show
106.125 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.20607 .30769 -66.5938 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.62915 .30769 -66.5938 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.44838 .25 -66.5938 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 188.25},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
  ImageRangeCache->{{{0, 287}, {187.25, 0}} -> {-2, 0, 0, 0}}],
 "   \n\t\t\t\t",
 StyleBox["Figure 1.1",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Wallis's representation of real roots of quadratics.  "
}], "Text",
 CellChangeTimes->{{3.3996720124375*^9, 3.39967201425*^9}, {
  3.400231313671875*^9, 3.400231314390625*^9}}],

Cell[TextData[{
 "\t\t\t\t",
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .65385 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.961538 0.384615 0.0769231 0.384615 [
[ 0 0 0 0 ]
[ 1 .65385 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .07692 m
1 .07692 L
s
.96154 0 m
.96154 .65385 L
s
0 0 m
1 0 L
1 .65385 L
0 .65385 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.57692 .07692 m
.57692 .62085 L
s
1 0 0 r
.30496 .34889 m
.57692 .62085 L
.84889 .34889 L
s
0 1 0 r
.30496 .34889 m
.57692 .07692 L
.84889 .34889 L
s
0 0 1 r
.02 w
.96154 .07692 Mdot
.57692 .07692 Mdot
1 0 0 r
.30496 .34889 Mdot
.84889 .34889 Mdot
0 g
gsave
.28573 .31043 -66.5938 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(P) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.86812 .31043 -66.5938 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(P) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.30496 .29504 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.88735 .29504 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.57692 .03846 -84.5625 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(H) show
70.188 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
77.375 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
91.750 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
98.938 12.813 moveto
(L) show
106.125 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.40248 .49283 -66.5938 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.75137 .49283 -66.5938 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.60769 .32169 -66.5938 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 188.25},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
  ImageRangeCache->{{{0, 287}, {187.25, 0}} -> {-2, 0, 0, 0}}],
 "   \n\t\t\t\t",
 StyleBox["Figure 1.2",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Wallis's representation of nonreal roots of quadratics.  "
}], "Text",
 CellChangeTimes->{{3.39967201553125*^9, 3.399672016890625*^9}, {
  3.40023131840625*^9, 3.4002313199375*^9}}],

Cell[TextData[{
 "\tWallis's method has the undesirable consequence that  ",
 Cell[BoxData[
  RowBox[{"-", 
   SqrtBox[
    RowBox[{"-", "1"}]]}]]],
 "  is represented by the same point as is  ",
 Cell[BoxData[
  SqrtBox[
   RowBox[{"-", "1"}]]]],
 ".  Nevertheless, this interpretation helped set the stage for thinking of \
complex numbers as \"points on the plane.\" By 1732, the great Swiss \
mathematician  ",
 StyleBox[ButtonBox["Leonhard Euler",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Euler.\
html"], None}],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[0, 0, 1]],
 "  (pronounced \"oiler\") adopted this view concerning the n solutions to \
the equation  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["x", "n"], "-", "1"}], "=", "0"}]]],
 ".  You will learn shortly that these solutions can be expressed as  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"cos", 
    RowBox[{"(", "\[Theta]", ")"}]}], "+", 
   RowBox[{
    SqrtBox[
     RowBox[{"-", "1"}]], "sin", 
    RowBox[{"(", "\[Theta]", ")"}]}]}]]],
 "  for various values of  ",
 Cell[BoxData["\[Theta]"]],
 ";  Euler thought of them as being located at the vertices of a regular \
polygon in the plane.  Euler was also the first to use the symbol ",
 Cell[BoxData["\[ImaginaryI]"]],
 " for ",
 Cell[BoxData[
  SqrtBox[
   RowBox[{"-", "1"}]]]],
 ".  Today, this notation is still the most popular, although some electrical \
engineers prefer the symbol ",
 Cell[BoxData["j"]],
 " instead so that they can use ",
 Cell[BoxData["\[ImaginaryI]"]],
 " to represent current."
}], "Text",
 CellChangeTimes->{{3.398968163359375*^9, 3.398968173265625*^9}}],

Cell[TextData[{
 "\tIs it possible to modify slightly Wallis's picture of complex numbers so \
that it is consistent with the representation used today?  To help you answer \
this question, refer to the article by Alec Norton and Benjamin Lotto, \"",
 StyleBox[ButtonBox["Complex Roots Made Visible",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://links.jstor.org/sici?sici=0746-8342%28198406%2915%3A3%3C248%\
3ACRMV%3E2.0.CO%3B2-8"], None}],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[0, 0, 1]],
 ",\" The College Mathematics Journal, 15(3), June 1984, pp. 248--249, Jstor. \
"
}], "Text"],

Cell[TextData[{
 "\tTwo additional mathematicians deserve mention. The Frenchman ",
 StyleBox[ButtonBox["Augustin-Louis Cauchy",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Cauchy.\
html"], None}],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[0, 0, 1]],
 " (1789-1857) formulated many of the classic theorems that are now part of \
the corpus of complex analysis.  The German ",
 StyleBox[ButtonBox["Carl Friedrich Gauss",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Gauss.\
html"], None}],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[0, 0, 1]],
 " (1777--1855) reinforced the utility of complex numbers by using them in \
his several proofs of the fundamental theorem of algebra (see Chapter 6).  In \
an 1831 paper, he produced a clear geometric representation of x+iy by \
identifying it with the point (x, y) in the coordinate plane.  He also \
described how to perform arithmetic operations with these new numbers."
}], "Text",
 CellChangeTimes->{{3.39896818575*^9, 3.398968190625*^9}}],

Cell[TextData[{
 "\tIt would be a mistake, however, to conclude that in 1831 complex numbers \
were transformed into legitimacy.  In that same year the prolific logician ",
 StyleBox[ButtonBox["Augustus De Morgan",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/De_Morgan.\
html"], None}],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[0, 0, 1]],
 " commented in his book, On the Study and Difficulties of Mathematics, \"We \
have shown the symbol ",
 Cell[BoxData[
  SqrtBox[
   RowBox[{"-", "a"}]]]],
 " to be void of meaning, or rather self-contradictory and absurd. \
Nevertheless, by means of such symbols, a part of algebra is established \
which is of great utility.\""
}], "Text",
 CellChangeTimes->{3.398968198859375*^9}],

Cell[TextData[{
 "\tThere are, indeed, genuine logical problems associated with complex \
numbers.  For example, with real numbers  ",
 Cell[BoxData[
  RowBox[{
   SqrtBox["ab"], "=", 
   RowBox[{
    SqrtBox["a"], 
    SqrtBox["b"]}]}]]],
 "  so long as both sides of the equation are defined.  Applying this \
identity to complex numbers leads to  ",
 Cell[BoxData[
  RowBox[{"1", "=", 
   RowBox[{
    SqrtBox["1"], "=", 
    RowBox[{
     SqrtBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], 
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}]}]], "=", 
     RowBox[{
      RowBox[{
       SqrtBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}]], 
       SqrtBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}]]}], "=", 
      RowBox[{
       RowBox[{"\[ImaginaryI]", "*", "\[ImaginaryI]"}], "=", 
       RowBox[{"-", "1"}]}]}]}]}]}]],
  CellChangeTimes->{{3.398967650859375*^9, 3.398967652265625*^9}, {
   3.39896773903125*^9, 3.3989677949375*^9}}],
 ".  Plausible answers to these problems can be given, however, and you will \
learn how to resolve this apparent contradiction in ",
 StyleBox[ButtonBox["Section 2.4",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/ComplexFunBranchMod.html"], 
    None}],
  FontVariations->{"Underline"->True}],
 ".  De Morgan's remark illustrates that many factors are needed to persuade \
mathematicians to adopt new theories.  In this case, as always, a firm \
logical foundation was crucial, but so, too, was a willingness to modify some \
ideas concerning certain well-established properties of numbers."
}], "Text",
 CellChangeTimes->{{3.39896780171875*^9, 3.398967813421875*^9}, {
  3.39896820609375*^9, 3.39896821690625*^9}, {3.398968483515625*^9, 
  3.3989684976875*^9}}],

Cell["\<\
\tAs time passed, mathematicians gradually refined their thinking, and by the \
end of the nineteenth century complex numbers were firmly entrenched.  Thus, \
as it is with many new mathematical or scientific innovations, the theory of \
complex numbers evolved by way of a very intricate process.  But what is the \
theory that Tartaglia, Ferro, Cardano, Bombelli, Wallis, Euler, Cauchy, \
Gauss, and so many others helped produce?  That is, how do we now think of \
complex numbers?  We explore this question in the remainder of this chapter.\
\>", "Text",
 CellChangeTimes->{{3.39896822465625*^9, 3.398968229375*^9}, 
   3.39896850290625*^9}],

Cell[TextData[{
 StyleBox["The solution of the cubic equations.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " can construct the solutions to the general cubic equation. However they \
are quite formidable."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration.",
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell["Enter the depressed cubic equation.", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"a", ",", "b", ",", "c", ",", "z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"eqn", " ", "=", " ", 
     RowBox[{
      RowBox[{
       SuperscriptBox["z", "3"], "+", 
       RowBox[{"b", " ", "z"}], " ", "+", " ", "c"}], " ", "\[Equal]", " ", 
      "0"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"solset", " ", "=", " ", 
     RowBox[{"Solve", "[", 
      RowBox[{"eqn", ",", " ", "z"}], " ", "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "1"], "=", 
     SubscriptBox["solset", 
      RowBox[{"\[LeftDoubleBracket]", 
       RowBox[{"1", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "2"], "=", 
     SubscriptBox["solset", 
      RowBox[{"\[LeftDoubleBracket]", 
       RowBox[{"2", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "3"], "=", 
     SubscriptBox["solset", 
      RowBox[{"\[LeftDoubleBracket]", 
       RowBox[{"3", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]]}], ";"}],
    " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<The depressed cubic equation \>\"", ",", "eqn"}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Mathematica can find the roots\>\"", ",", "\"\<\\n\>\""}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["z", "1"]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(2\)]\) = \>\"", ",", 
      SubscriptBox["z", "2"]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(3\)]\) = \>\"", ",", 
      SubscriptBox["z", "3"]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input"],

Cell["Enter the general cubic equation.", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"a", ",", "b", ",", "c", ",", "z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"eqn", " ", "=", " ", 
     RowBox[{
      RowBox[{
       SuperscriptBox["z", "3"], "+", 
       RowBox[{"a", " ", 
        SuperscriptBox["z", "2"]}], "+", 
       RowBox[{"b", " ", "z"}], " ", "+", " ", "c"}], " ", "\[Equal]", " ", 
      "0"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"solset", " ", "=", " ", 
     RowBox[{"Solve", "[", 
      RowBox[{"eqn", ",", " ", "z"}], " ", "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "1"], "=", 
     SubscriptBox["solset", 
      RowBox[{"\[LeftDoubleBracket]", 
       RowBox[{"1", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "2"], "=", 
     SubscriptBox["solset", 
      RowBox[{"\[LeftDoubleBracket]", 
       RowBox[{"2", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "3"], "=", 
     SubscriptBox["solset", 
      RowBox[{"\[LeftDoubleBracket]", 
       RowBox[{"3", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]]}], ";"}],
    " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<The general cubic equation \>\"", ",", "eqn"}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Mathematica can find the roots\>\"", ",", "\"\<\\n\>\""}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["z", "1"]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(2\)]\) = \>\"", ",", 
      SubscriptBox["z", "2"]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(3\)]\) = \>\"", ",", 
      SubscriptBox["z", "3"]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input"],

Cell[TextData[{
 "\nThe formulas for the roots ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   SubscriptBox["z", "2"], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "  ", 
   RowBox[{
    StyleBox["and",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], "  ", 
    SubscriptBox["z", "3"]}]}]]],
 " are complicated.  Hopefully this text will promote their understanding."
}], "Text"]
}, Closed]],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["History of Complex Numbers",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/HistoryComplexBib.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Complex Numbers",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/ComplexNumbersBib.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/complex.html"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2008 John H. Mathews, Russell W. \
Howell",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/"], None}],
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[0, 1, 0]]], "Text",
 CellChangeTimes->{{3.398968514046875*^9, 3.398968527421875*^9}}]
},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{1019, 643},
WindowMargins->{{Automatic, 0}, {Automatic, 0}},
CellLabelAutoDelete->True,
Magnification->1,
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "CHAPTER 1"->{
  Cell[568, 21, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"],
  Cell[905, 32, 184, 5, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"CHAPTER 1", 84934, 2809}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"],
Cell[905, 32, 184, 5, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"],
Cell[1092, 39, 96, 2, 29, "Text"],
Cell[1191, 43, 624, 9, 65, "Text"],
Cell[1818, 54, 130, 2, 29, "Text"],
Cell[1951, 58, 1047, 25, 85, "Text"],
Cell[3001, 85, 647, 10, 65, "Text"],
Cell[3651, 97, 977, 29, 83, "Text",
 Evaluatable->False],
Cell[4631, 128, 1766, 57, 149, "Text"],
Cell[CellGroupData[{
Cell[6422, 189, 138, 3, 29, "Text"],
Cell[6563, 194, 2480, 67, 315, "Input"]
}, Closed]],
Cell[9058, 264, 1147, 42, 50, "Text"],
Cell[CellGroupData[{
Cell[10230, 310, 138, 3, 29, "Text"],
Cell[10371, 315, 1380, 40, 212, "Input"]
}, Closed]],
Cell[11766, 358, 1995, 60, 158, "Text"],
Cell[13764, 420, 3451, 129, 173, "Text"],
Cell[CellGroupData[{
Cell[17240, 553, 138, 3, 29, "Text"],
Cell[17381, 558, 1384, 40, 212, "Input"],
Cell[18768, 600, 3280, 93, 335, "Input"],
Cell[22051, 695, 1432, 42, 215, "Input"],
Cell[23486, 739, 807, 23, 152, "Input"]
}, Closed]],
Cell[24308, 765, 1623, 35, 140, "Text"],
Cell[25934, 802, 1353, 51, 81, "Text"],
Cell[27290, 855, 4916, 195, 254, "Text",
 Evaluatable->False],
Cell[32209, 1052, 1963, 77, 74, "Text"],
Cell[34175, 1131, 1374, 61, 91, "Text"],
Cell[35552, 1194, 865, 18, 83, "Text"],
Cell[CellGroupData[{
Cell[36442, 1216, 185, 5, 29, "Text",
 Evaluatable->False],
Cell[36630, 1223, 41, 0, 29, "Text"],
Cell[36674, 1225, 815, 22, 172, "Input"],
Cell[37492, 1249, 58, 0, 29, "Text"],
Cell[37553, 1251, 785, 26, 113, "Input"],
Cell[38341, 1279, 741, 28, 83, "Text",
 Evaluatable->False],
Cell[39085, 1309, 5832, 175, 703, "Input"]
}, Closed]],
Cell[44932, 1487, 1470, 42, 125, "Text"],
Cell[46405, 1531, 2655, 80, 146, "Text"],
Cell[49063, 1613, 10171, 373, 224, "Text"],
Cell[59237, 1988, 10733, 386, 224, "Text"],
Cell[69973, 2376, 1710, 51, 107, "Text"],
Cell[71686, 2429, 619, 13, 47, "Text"],
Cell[72308, 2444, 1156, 24, 83, "Text"],
Cell[73467, 2470, 808, 19, 67, "Text"],
Cell[74278, 2491, 1816, 50, 87, "Text"],
Cell[76097, 2543, 655, 10, 65, "Text"],
Cell[76755, 2555, 334, 11, 29, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[77114, 2570, 185, 5, 29, "Text",
 Evaluatable->False],
Cell[77302, 2577, 51, 0, 29, "Text"],
Cell[77356, 2579, 2289, 63, 312, "Input"],
Cell[79648, 2644, 49, 0, 29, "Text"],
Cell[79700, 2646, 2452, 68, 332, "Input"],
Cell[82155, 2716, 947, 33, 47, "Text"]
}, Closed]],
Cell[83117, 2752, 281, 7, 26, "Text"],
Cell[83401, 2761, 288, 7, 29, "Text"],
Cell[83692, 2770, 277, 7, 29, "Text"],
Cell[83972, 2779, 249, 5, 29, "Text"],
Cell[84224, 2786, 320, 7, 29, "Text"]
}
]
*)

(* End of internal cache information *)
