(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     78396,       2259]
NotebookOptionsPosition[     75917,       2174]
NotebookOutlinePosition[     76440,       2198]
CellTagsIndexPosition[     76367,       2193]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"],

Cell[TextData[{
 StyleBox["1.3",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[" The Geometry of Complex Numbers",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]
}], "Text"],

Cell["\<\
\tComplex numbers are ordered pairs of real numbers, so they can be \
represented by points in the plane.  In this section we show the effect that \
algebraic operations on complex numbers have on their geometric \
representations.\
\>", "Text",
 CellChangeTimes->{3.398969633703125*^9}],

Cell[TextData[{
 "\tWe can represent the number  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{
    RowBox[{"x", "+", 
     RowBox[{"\[ImaginaryI]", " ", "y"}]}], "=", 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}]}]]],
 "  by a position vector in the xy plane whose tail is at the origin and \
whose head is at the point  ",
 Cell[BoxData[
  RowBox[{"(", 
   RowBox[{"x", ",", "y"}], ")"}]]],
 ".  When the xy plane is used for displaying complex numbers, it is called \
the ",
 StyleBox[ButtonBox["complex plane",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/ComplexPlane.html"], None}],
  FontVariations->{"Underline"->True}],
 ", or more simply, the ",
 Cell[BoxData["z"]],
 " plane.  Recall that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Re", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    RowBox[{"x", "  ", 
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", "Im", 
     RowBox[{"(", "z", ")"}]}], "=", "y"}]}]]],
 ".  Geometrically,  ",
 Cell[BoxData[
  RowBox[{"Re", 
   RowBox[{"(", "z", ")"}]}]]],
 "  is the projection of  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{"(", 
    RowBox[{"x", ",", "y"}], ")"}]}]]],
 "  onto the ",
 Cell[BoxData["x"]],
 " axis, and  ",
 Cell[BoxData[
  RowBox[{"Im", 
   RowBox[{"(", "z", ")"}]}]]],
 "  is the projection of ",
 Cell[BoxData["z"]],
 " onto the ",
 Cell[BoxData["y"]],
 " axis.  It makes sense, then, to call the ",
 Cell[BoxData["x"]],
 " axis the real axis and the ",
 Cell[BoxData["y"]],
 " axis the imaginary axis, as Figure 1.3 illustrates."
}], "Text",
 CellChangeTimes->{3.3989696429375*^9}],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{406, 168},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 "\tAddition of complex numbers is analogous to addition of vectors in the \
plane.  As we saw in Section 1.2, the sum of ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], "=", 
   RowBox[{
    RowBox[{
     SubscriptBox["x", "1"], "+", 
     RowBox[{"\[ImaginaryI]", " ", 
      SubscriptBox["y", "1"]}]}], "=", 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["x", "1"], ",", 
      SubscriptBox["y", "1"]}], ")"}]}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "2"], "=", 
   RowBox[{
    RowBox[{
     SubscriptBox["x", "2"], "+", 
     RowBox[{"\[ImaginaryI]", " ", 
      SubscriptBox["y", "2"]}]}], "=", 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["x", "2"], ",", 
      SubscriptBox["y", "2"]}], ")"}]}]}]]],
 "is ",
 Cell[BoxData[
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     SubscriptBox["x", "1"], "+", 
     SubscriptBox["x", "2"]}], ",", 
    RowBox[{
     SubscriptBox["y", "1"], "+", 
     SubscriptBox["y", "2"]}]}], ")"}]]],
 ".  Hence, ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], " ", "+", 
   SubscriptBox["z", "2"]}]]],
 " can be obtained vectorially by using the \"parallelogram law,\" where the \
vector sum is the vector represented by the diagonal of the parallelogram \
formed by the two original vectors.  Figure 1.4 illustrates this notion."
}], "Text",
 CellChangeTimes->{3.398969653140625*^9}],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{403, 197},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 "\tThe difference  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], " ", "-", 
   SubscriptBox["z", "2"]}]]],
 "  can be represented by the displacement vector from the point  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "2"], "=", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["x", "2"], ",", 
     SubscriptBox["y", "2"]}], ")"}]}]]],
 "  to the point  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], "=", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["x", "1"], ",", 
     SubscriptBox["y", "1"]}], ")"}]}]]],
 ",  as Figure 1.5 shows."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{406, 255},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 StyleBox["Definition 1.8, (",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Modulus",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/ModulusComplexNumber.html"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 StyleBox[" or Absolute Value).",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["  ",
  FontColor->RGBColor[0, 0, 1]],
 "The modulus, or absolute value, of the complex number  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{"x", "+", 
    RowBox[{"\[ImaginaryI]", " ", "y"}]}]}]]],
 "  is a nonnegative real number denoted by  ",
 Cell[BoxData[
  RowBox[{"|", "z", "|"}]]],
 "  and is given by the equation  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", "z", "|"}], "=", 
   SqrtBox[
    RowBox[{
     SuperscriptBox["x", "2"], "+", 
     SuperscriptBox["y", "2"]}]]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "\tThe number  ",
 Cell[BoxData[
  RowBox[{"|", "z", "|"}]]],
 "  is the distance between the origin and the point  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{"(", 
    RowBox[{"x", ",", "y"}], ")"}]}]]],
 ".  The only complex number with modulus zero is the number ",
 Cell[BoxData["0"]],
 ".  The number  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{"3", "+", 
    RowBox[{"4", "\[ImaginaryI]"}]}]}]]],
 "  has modulus  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", 
    RowBox[{"4", "+", 
     RowBox[{"3", "\[ImaginaryI]"}]}], "|"}], "=", 
   RowBox[{
    SqrtBox[
     RowBox[{
      SuperscriptBox["4", "2"], "+", 
      SuperscriptBox["3", "2"]}]], "=", 
    RowBox[{
     SqrtBox["25"], "=", "5"}]}]}]]],
 ",  and is depicted in Figure 1.6.  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{410, 248},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 "\tThe numbers  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Re", 
    RowBox[{"(", "z", ")"}]}], ",", 
   RowBox[{
    RowBox[{"Im", 
     RowBox[{"(", "z", ")"}], "  ", 
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]]}], "  ", "|", "z", "|"}]}]]],
 "  are the lengths of the sides of the right triangle OPQ shown in Figure \
1.7.  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{406, 248},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 "\tThe inequality ",
 Cell[BoxData[
  RowBox[{"|", 
   SubscriptBox["z", "1"], "|", 
   RowBox[{"<", 
    RowBox[{"|", 
     SubscriptBox["z", "2"], "|"}]}]}]]],
 " means that the point ",
 Cell[BoxData[
  SubscriptBox["z", "1"]]],
 " is closer to the origin than the point ",
 Cell[BoxData[
  SubscriptBox["z", "2"]]],
 ".  Although obvious from Figure 1.7, it is still profitable to work out \
algebraically the standard results that\t\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", "x", "|"}], "=", 
   RowBox[{"|", 
    RowBox[{"Re", 
     RowBox[{"(", "z", ")"}]}], "|", 
    RowBox[{"\[LessEqual]", 
     RowBox[{"|", "z", "|"}]}]}]}]]],
 " and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", "y", "|"}], "=", 
   RowBox[{"|", 
    RowBox[{"Im", 
     RowBox[{"(", "z", ")"}]}], "|", 
    RowBox[{"\[LessEqual]", 
     RowBox[{"|", "z", "|"}]}]}]}]]],
 ".\n\t\t\t\nwhich we leave as an exercise for the reader. "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "\tThe difference ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], " ", "-", 
   SubscriptBox["z", "2"]}]]],
 " represents the displacement vector from ",
 Cell[BoxData[
  SubscriptBox["z", "2"]]],
 " to ",
 Cell[BoxData[
  SubscriptBox["z", "1"]]],
 ", so the distance between ",
 Cell[BoxData[
  SubscriptBox["z", "1"]]],
 " and ",
 Cell[BoxData[
  SubscriptBox["z", "2"]]],
 " is given by",
 Cell[BoxData[
  RowBox[{"|", 
   RowBox[{
    SubscriptBox["z", "1"], " ", "-", 
    SubscriptBox["z", "2"]}], "|"}]]],
 ".  We can obtain this distance by using Definitions (1.2) and (1-3) to \
obtain the familiar formula \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    StyleBox["dist",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["z", "1"], ",", 
      SubscriptBox["z", "2"]}], ")"}]}], "=", 
   RowBox[{"|", 
    RowBox[{
     SubscriptBox["z", "2"], "-", 
     SubscriptBox["z", "1"]}], "|"}]}]]],
 Cell[BoxData[
  RowBox[{"=", 
   SqrtBox[
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["x", "1"], "-", 
        SubscriptBox["x", "2"]}], ")"}], "2"], "+", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["y", "1"], "-", 
        SubscriptBox["y", "2"]}], ")"}], "2"]}]]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "\tIf  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}], "=", 
    RowBox[{"x", "+", 
     RowBox[{"\[ImaginaryI]", " ", "y"}]}]}]}]]],
 ",  then  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"-", "z"}], "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "x"}], ",", 
      RowBox[{"-", "y"}]}], ")"}], "=", 
    RowBox[{
     RowBox[{"-", "x"}], "-", 
     RowBox[{"\[ImaginaryI]", " ", "y"}]}]}]}]]],
 "  is the reflection of ",
 Cell[BoxData["z"]],
 ", through the origin, and  ",
 Cell[BoxData[
  RowBox[{
   OverscriptBox[
    RowBox[{"z", " "}], "_"], "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"x", ",", 
      RowBox[{"-", "y"}]}], ")"}], "=", 
    RowBox[{"x", "-", 
     RowBox[{"\[ImaginaryI]", " ", "y"}]}]}]}]]],
 "  is the reflection of ",
 Cell[BoxData["z"]],
 " through the ",
 Cell[BoxData["x"]],
 " axis, as illustrated in Figure 1.8."
}], "Text"],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{432, 197},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 "\tWe can use an important algebraic relationship to establish properties of \
the absolute value that have geometric applications.  Its proof is rather \
straightforward, and we ask you to give it in the exercises for this section. \
\n\t\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", "z", 
    SuperscriptBox["|", "2"]}], "=", 
   RowBox[{"z", " ", 
    OverscriptBox[
     RowBox[{"z", " "}], "_"]}]}]]],
 ".  "
}], "Text"],

Cell["\<\
\tA beautiful and important application of the above identity is its use in \
establishing the triangle inequality, which states that the sum of the \
lengths of two sides of a triangle is greater than or equal to the length of \
the third side. Figure 1.9 illustrates this inequality.\
\>", "Text"],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{403, 197},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 StyleBox["Theorem 1.2, (",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Triangle Inequality",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/TriangleInequality.html"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 StyleBox["). ",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  If  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], " ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], " ", 
   SubscriptBox["z", "2"]}]]],
 " are arbitrary complex numbers, then  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"|", 
   RowBox[{
    SubscriptBox["z", "1"], "+", 
    SubscriptBox["z", "2"]}], "|", 
   RowBox[{"\[LessEqual]", 
    RowBox[{"|", 
     SubscriptBox["z", "1"], "|", 
     RowBox[{"+", 
      RowBox[{"|", 
       SubscriptBox["z", "2"], "|"}]}]}]}]}]]],
 ".  \n\t\t\t"
}], "Text"],

Cell[TextData[{
 StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 "  We appeal to basic results:  \n\n\t\t\t",
 Cell[BoxData[GridBox[{
    {
     RowBox[{"|", 
      RowBox[{
       SubscriptBox["z", "1"], "+", 
       SubscriptBox["z", "2"]}], 
      SuperscriptBox["|", "2"]}], "=", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["z", "1"], "+", 
         SubscriptBox["z", "2"]}], ")"}], 
       OverscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["z", "1"], "+", 
          SubscriptBox["z", "2"]}], ")"}], "_"]}], "                     ", 
      "\[IndentingNewLine]"}], 
     RowBox[{
      RowBox[{"(", 
       StyleBox[
        RowBox[{"by", " ", "Identity", 
         RowBox[{" ", 
          StyleBox[" ",
           FontColor->RGBColor[0, 0, 1]]}], 
         StyleBox[
          RowBox[{"(", 
           RowBox[{"1", "-", "22"}], ")"}],
          FontColor->RGBColor[0, 0, 1]]}],
        FontFamily->"Times New Roman",
        FontWeight->"Plain"], ")"}], 
      "                                           "}]},
    {" ", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["z", "1"], "+", 
         SubscriptBox["z", "2"]}], ")"}], 
       RowBox[{"(", 
        RowBox[{
         OverscriptBox[
          SubscriptBox["z", "1"], "_"], "+", 
         OverscriptBox[
          SubscriptBox["z", "2"], "_"]}], ")"}]}], "                     ", 
      "\[IndentingNewLine]"}], 
     RowBox[{
      RowBox[{"(", 
       StyleBox[
        RowBox[{
         StyleBox["by",
          FontColor->GrayLevel[0]], 
         StyleBox[" ",
          FontColor->GrayLevel[0]], 
         StyleBox["Identity",
          FontColor->GrayLevel[0]], 
         StyleBox["  ",
          FontColor->GrayLevel[0]], 
         StyleBox[
          RowBox[{"(", 
           RowBox[{"1", "-", "13"}], ")"}],
          FontColor->RGBColor[0, 0, 1]]}],
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False}], ")"}], 
      "                                            "}]},
    {" ", "=", 
     RowBox[{
      RowBox[{
       RowBox[{
        SubscriptBox["z", "1"], 
        OverscriptBox[
         SubscriptBox["z", "1"], "_"]}], "+", 
       RowBox[{
        SubscriptBox["z", "1"], 
        OverscriptBox[
         SubscriptBox["z", "2"], "_"]}], "+", 
       RowBox[{
        SubscriptBox["z", "2"], 
        OverscriptBox[
         SubscriptBox["z", "1"], "_"]}], "+", 
       RowBox[{
        SubscriptBox["z", "2"], 
        OverscriptBox[
         SubscriptBox["z", "2"], "_"]}]}], "       ", "\[IndentingNewLine]"}],
      
     RowBox[{
      RowBox[{"(", 
       StyleBox[
        RowBox[{"by", " ", "the", " ", "distributive", " ", "law"}],
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], ")"}], 
      "                                         "}]},
    {" ", "=", 
     RowBox[{"|", 
      SubscriptBox["z", "1"], 
      SuperscriptBox["|", "2"], 
      RowBox[{
       RowBox[{
        RowBox[{"+", 
         SubscriptBox["z", "1"]}], 
        OverscriptBox[
         SubscriptBox["z", "2"], "_"]}], "+", 
       RowBox[{
        OverscriptBox[
         SubscriptBox["z", "1"], "_"], 
        SubscriptBox["z", "2"]}], "+"}], "|", 
      SubscriptBox["z", "2"], 
      SuperscriptBox["|", "2"], "\[IndentingNewLine]"}], 
     RowBox[{
      RowBox[{"(", 
       StyleBox[
        RowBox[{"by", " ", "the", " ", "commutative", " ", "law"}],
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], ")"}], 
      "                                       "}]},
    {" ", "=", 
     RowBox[{"|", 
      SubscriptBox["z", "1"], 
      SuperscriptBox["|", "2"], 
      RowBox[{
       RowBox[{
        RowBox[{"+", 
         SubscriptBox["z", "1"]}], 
        OverscriptBox[
         SubscriptBox["z", "2"], "_"]}], "+", 
       OverscriptBox[
        RowBox[{
         SubscriptBox["z", "1"], 
         OverscriptBox[
          SubscriptBox["z", "2"], "_"]}], "_"], "+"}], "|", 
      SubscriptBox["z", "2"], 
      SuperscriptBox["|", "2"], "\[IndentingNewLine]"}], 
     RowBox[{
      RowBox[{"(", 
       StyleBox[
        RowBox[{
         StyleBox["by",
          FontColor->GrayLevel[0]], 
         StyleBox["  ",
          FontColor->GrayLevel[0]], 
         StyleBox[
          RowBox[{"(", 
           RowBox[{"1", "-", "12"}], ")"}],
          FontColor->RGBColor[0, 0, 1]]}],
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False}], ")"}], 
      "                                                          "}]},
    {" ", "=", 
     RowBox[{"|", 
      SubscriptBox["z", "1"], 
      SuperscriptBox["|", "2"], 
      RowBox[{
       RowBox[{
        RowBox[{"+", "2"}], "Re", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["z", "1"], 
          OverscriptBox[
           SubscriptBox["z", "2"], "_"]}], ")"}]}], "+"}], "|", 
      SubscriptBox["z", "2"], 
      SuperscriptBox["|", "2"], "\[IndentingNewLine]"}], 
     RowBox[{
      RowBox[{"(", 
       StyleBox[
        RowBox[{
         StyleBox["by",
          FontColor->GrayLevel[0]], 
         StyleBox[" ",
          FontColor->GrayLevel[0]], 
         StyleBox["Identity",
          FontColor->GrayLevel[0]], 
         StyleBox["  ",
          FontColor->GrayLevel[0]], 
         StyleBox[
          RowBox[{"(", 
           RowBox[{"1", "-", "16"}], ")"}],
          FontColor->RGBColor[0, 0, 1]]}],
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False}], ")"}], 
      "                                            "}]},
    {" ", "\[LessEqual]", 
     RowBox[{"|", 
      SubscriptBox["z", "1"], 
      SuperscriptBox["|", "2"], 
      RowBox[{"+", "2"}], "|", 
      RowBox[{
       SubscriptBox["z", "1"], 
       OverscriptBox[
        SubscriptBox["z", "2"], "_"]}], "|", 
      RowBox[{"+", 
       RowBox[{"|", 
        SubscriptBox["z", "2"], 
        SuperscriptBox["|", "2"], "   ", "\[IndentingNewLine]"}]}]}], 
     RowBox[{
      RowBox[{"(", 
       StyleBox[
        RowBox[{"by", " ", "Identity", 
         RowBox[{" ", 
          StyleBox[" ",
           FontColor->RGBColor[0, 0, 1]]}], 
         StyleBox[
          RowBox[{"(", 
           RowBox[{"1", "-", "22"}], ")"}],
          FontColor->RGBColor[0, 0, 1]]}],
        FontFamily->"Times New Roman",
        FontWeight->"Plain"], ")"}], 
      "                                           "}]},
    {" ", "=", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"|", 
         SubscriptBox["z", "1"], "|", 
         RowBox[{"+", 
          RowBox[{"|", 
           SubscriptBox["z", "2"], "|"}]}]}], ")"}], "2"], 
      "                         "}], " "}
   }]]],
 "   \n\nTaking square roots yields the desired inequality.  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Example  1.5.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  To produce an example of which Figure 1.9 is a reasonable illustration, \
we let  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], "=", 
   RowBox[{
    RowBox[{"7", "+", 
     RowBox[{"\[ImaginaryI]", "  ", "and", "  ", 
      SubscriptBox["z", "2"]}]}], "=", 
    RowBox[{"3", "+", 
     RowBox[{"5", "\[ImaginaryI]"}]}]}]}]]],
 ".  Then  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", 
    SubscriptBox["z", "1"], "|"}], "=", 
   RowBox[{
    SqrtBox[
     RowBox[{"49", "+", "1"}]], "=", 
    SqrtBox["50"]}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", 
    SubscriptBox["z", "2"], "|"}], "=", 
   RowBox[{
    SqrtBox[
     RowBox[{"9", "+", "25"}]], "=", 
    SqrtBox["34"]}]}]]],
 ".  Clearly,  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["z", "1"], "+", 
    SubscriptBox["z", "2"]}], "=", 
   RowBox[{"10", "+", 
    RowBox[{"6", "\[ImaginaryI]"}]}]}]]],
 ";  hence  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", 
    RowBox[{
     SubscriptBox["z", "1"], "+", 
     SubscriptBox["z", "2"]}], "|"}], "=", 
   RowBox[{
    SqrtBox[
     RowBox[{"100", "+", "36"}]], "=", 
    SqrtBox["136"]}]}]]],
 ".  In this case, we can verify the triangle inequality without recourse to \
computation of square roots because  \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", 
    RowBox[{
     SubscriptBox["z", "1"], "+", 
     SubscriptBox["z", "2"]}], "|"}], "=", 
   RowBox[{
    SqrtBox[
     RowBox[{"100", "+", "36"}]], "=", 
    RowBox[{
     SqrtBox["136"], "=", 
     RowBox[{
      RowBox[{"2", " ", 
       SqrtBox["34"]}], "=", 
      RowBox[{
       RowBox[{
        RowBox[{
         SqrtBox["34"], "+", " ", 
         SqrtBox["34"]}], "<", 
        RowBox[{
         SqrtBox["50"], "+", " ", 
         SqrtBox["34"]}]}], "=", 
       RowBox[{"|", 
        SubscriptBox["z", "1"], "|", 
        RowBox[{"+", 
         RowBox[{"|", 
          SubscriptBox["z", "2"], "|"}]}]}]}]}]}]}]}]]],
 ",  \nthus \n\t\t\t",
 Cell[BoxData[
  RowBox[{"|", 
   RowBox[{
    SubscriptBox["z", "1"], "+", 
    SubscriptBox["z", "2"]}], "|", 
   RowBox[{"\[LessEqual]", 
    RowBox[{"|", 
     SubscriptBox["z", "1"], "|", 
     RowBox[{"+", 
      RowBox[{"|", 
       SubscriptBox["z", "2"], "|"}]}]}]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 1.5.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "Compute ",
 Cell[BoxData[
  RowBox[{"|", 
   RowBox[{
    SubscriptBox["z", "1"], "+", 
    SubscriptBox["z", "2"]}], "|", "  ", "and", "  ", "|", 
   SubscriptBox["z", "1"], "|", 
   RowBox[{"+", 
    RowBox[{"|", 
     SubscriptBox["z", "2"], "|"}]}]}]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", "z", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "1"], "=", 
     RowBox[{"7", "+", "\[ImaginaryI]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "2"], "=", 
     RowBox[{"3", "+", 
      RowBox[{"5", "\[ImaginaryI]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["w", "1"], "=", 
     RowBox[{
      SubscriptBox["z", "1"], "+", 
      SubscriptBox["z", "2"]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["V", "1"], " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Magenta", ",", 
        RowBox[{"Arrowheads", "[", 
         RowBox[{"{", 
          RowBox[{"0.0", ",", "0.06"}], "}"}], "]"}], ",", 
        RowBox[{"Thickness", "[", "0.006", "]"}], ",", 
        RowBox[{"Arrow", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["z", "1"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["z", "1"], "]"}]}], "}"}]}], "}"}], "]"}]}], "}"}],
       "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["V", "2"], " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Green", ",", 
        RowBox[{"Arrowheads", "[", 
         RowBox[{"{", 
          RowBox[{"0.0", ",", "0.06"}], "}"}], "]"}], ",", 
        RowBox[{"Thickness", "[", "0.006", "]"}], ",", 
        RowBox[{"Arrow", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["z", "2"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["z", "2"], "]"}]}], "}"}]}], "}"}], "]"}]}], "}"}],
       "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["V", "3"], " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"Arrowheads", "[", 
         RowBox[{"{", 
          RowBox[{"0.0", ",", "0.06"}], "}"}], "]"}], ",", 
        RowBox[{"Thickness", "[", "0.006", "]"}], ",", 
        RowBox[{"Arrow", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["z", "1"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["z", "1"], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["w", "1"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["w", "1"], "]"}]}], "}"}]}], "}"}], "]"}]}], "}"}],
       "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["V", "4"], " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", 
        RowBox[{"Arrowheads", "[", 
         RowBox[{"{", 
          RowBox[{"0.0", ",", "0.06"}], "}"}], "]"}], ",", 
        RowBox[{"Thickness", "[", "0.006", "]"}], ",", 
        RowBox[{"Arrow", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["w", "1"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["w", "1"], "]"}]}], "}"}]}], "}"}], "]"}]}], "}"}],
       "]"}]}], ";"}], " ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{
     SubscriptBox["V", "1"], ",", 
     SubscriptBox["V", "2"], ",", 
     SubscriptBox["V", "3"], ",", 
     SubscriptBox["V", "4"], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "10"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "6"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "10", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "6", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["6", "10"]}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<          \!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", " ", ",", 
      SubscriptBox["z", "1"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<          \!\(\*SubscriptBox[\(z\), \(2\)]\) = \>\"", " ", ",", 
      SubscriptBox["z", "2"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<     \!\(\*SubscriptBox[\(z\), \(1\)]\) + \!\(\*SubscriptBox[\(z\), \
\(2\)]\) = \>\"", " ", ",", 
      RowBox[{
       SubscriptBox["z", "1"], "+", 
       SubscriptBox["z", "2"]}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<        |\!\(\*SubscriptBox[\(z\), \(1\)]\)| = \>\"", ",", 
      RowBox[{"Abs", "[", 
       SubscriptBox["z", "1"], "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<        |\!\(\*SubscriptBox[\(z\), \(2\)]\)| = \>\"", ",", 
      RowBox[{"Abs", "[", 
       SubscriptBox["z", "2"], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<   |\!\(\*SubscriptBox[\(z\), \(1\)]\) + \!\(\*SubscriptBox[\(z\), \
\(2\)]\)| = \>\"", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{
        SubscriptBox["z", "1"], "+", 
        SubscriptBox["z", "2"]}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Is |\!\(\*SubscriptBox[\(z\), \(1\)]\) + \!\(\*SubscriptBox[\(z\), \
\(2\)]\)| \[LessEqual]  |\!\(\*SubscriptBox[\(z\), \(1\)]\)| + \
|\!\(\*SubscriptBox[\(z\), \(2\)]\)| ?  \>\"", ",", 
      RowBox[{
       RowBox[{"Abs", "[", 
        RowBox[{
         SubscriptBox["z", "1"], "+", 
         SubscriptBox["z", "2"]}], "]"}], "\[LessEqual]", 
       RowBox[{
        RowBox[{"Abs", "[", 
         SubscriptBox["z", "1"], "]"}], "+", 
        RowBox[{"Abs", "[", 
         SubscriptBox["z", "2"], "]"}]}]}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<   |\!\(\*SubscriptBox[\(z\), \(1\)]\) + \!\(\*SubscriptBox[\(z\), \
\(2\)]\)| = \>\"", ",", 
      RowBox[{"N", "[", 
       RowBox[{"Abs", "[", 
        RowBox[{
         SubscriptBox["z", "1"], "+", 
         SubscriptBox["z", "2"]}], "]"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< |\!\(\*SubscriptBox[\(z\), \(1\)]\)| + |\!\(\*SubscriptBox[\(z\), \
\(2\)]\)| = \>\"", ",", 
      RowBox[{"N", "[", 
       RowBox[{
        RowBox[{"Abs", "[", 
         SubscriptBox["z", "1"], "]"}], "+", 
        RowBox[{"Abs", "[", 
         SubscriptBox["z", "2"], "]"}]}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Is |\!\(\*SubscriptBox[\(z\), \(1\)]\) + \!\(\*SubscriptBox[\(z\), \
\(2\)]\)| \[LessEqual]  |\!\(\*SubscriptBox[\(z\), \(1\)]\)| + \
|\!\(\*SubscriptBox[\(z\), \(2\)]\)| ?  \>\"", ",", 
      RowBox[{
       RowBox[{"Abs", "[", 
        RowBox[{
         SubscriptBox["z", "1"], "+", 
         SubscriptBox["z", "2"]}], "]"}], "\[LessEqual]", 
       RowBox[{
        RowBox[{"Abs", "[", 
         SubscriptBox["z", "1"], "]"}], "+", 
        RowBox[{"Abs", "[", 
         SubscriptBox["z", "2"], "]"}]}]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Is    \>\"", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{
        SubscriptBox["z", "1"], "+", 
        SubscriptBox["z", "2"]}], "]"}], ",", "\"\< \[LessEqual] \>\"", ",", 
      RowBox[{
       RowBox[{"Abs", "[", 
        SubscriptBox["z", "1"], "]"}], "+", 
       RowBox[{"Abs", "[", 
        SubscriptBox["z", "2"], "]"}]}], ",", "\"\< ?  \>\"", ",", 
      RowBox[{
       RowBox[{"Abs", "[", 
        RowBox[{
         SubscriptBox["z", "1"], "+", 
         SubscriptBox["z", "2"]}], "]"}], "\[LessEqual]", 
       RowBox[{
        RowBox[{"Abs", "[", 
         SubscriptBox["z", "1"], "]"}], "+", 
        RowBox[{"Abs", "[", 
         SubscriptBox["z", "2"], "]"}]}]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Is  \>\"", ",", 
      RowBox[{"N", "[", 
       RowBox[{"Abs", "[", 
        RowBox[{
         SubscriptBox["z", "1"], "+", 
         SubscriptBox["z", "2"]}], "]"}], "]"}], ",", 
      "\"\< \[LessEqual] \>\"", ",", 
      RowBox[{"N", "[", 
       RowBox[{
        RowBox[{"Abs", "[", 
         SubscriptBox["z", "1"], "]"}], "+", 
        RowBox[{"Abs", "[", 
         SubscriptBox["z", "2"], "]"}]}], "]"}], ",", "\"\< ?  \>\"", ",", 
      RowBox[{
       RowBox[{"Abs", "[", 
        RowBox[{
         SubscriptBox["z", "1"], "+", 
         SubscriptBox["z", "2"]}], "]"}], "\[LessEqual]", 
       RowBox[{
        RowBox[{"Abs", "[", 
         SubscriptBox["z", "1"], "]"}], "+", 
        RowBox[{"Abs", "[", 
         SubscriptBox["z", "2"], "]"}]}]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.398969715734375*^9, 3.39896971878125*^9}, {
  3.39970896884375*^9, 3.399708997484375*^9}, {3.39970904403125*^9, 
  3.3997091058125*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 "\t",
 "We can also establish other important identities by means of the triangle \
inequality. Note that",
 "  \n\t\n\t\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", 
    SubscriptBox["z", "1"], "|"}], "=", 
   RowBox[{"|", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["z", "1"], "+", 
       SubscriptBox["z", "2"]}], ")"}], "+", 
     RowBox[{"(", 
      RowBox[{"-", 
       SubscriptBox["z", "2"]}], ")"}]}], "|"}]}]]],
 "  \n\t\t\t\t",
 Cell[BoxData[
  RowBox[{"            ", 
   RowBox[{"\[LessEqual]", 
    RowBox[{"|", 
     RowBox[{
      SubscriptBox["z", "1"], "+", 
      SubscriptBox["z", "2"]}], "|", 
     RowBox[{"+", 
      RowBox[{"|", 
       RowBox[{"-", 
        SubscriptBox["z", "2"]}], "|"}]}]}]}]}]]],
 "  \n\t\t\t\t",
 Cell[BoxData[
  RowBox[{"            ", 
   RowBox[{"\[LessEqual]", 
    RowBox[{"|", 
     RowBox[{
      SubscriptBox["z", "1"], "+", 
      SubscriptBox["z", "2"]}], "|", 
     RowBox[{"+", 
      RowBox[{"|", 
       SubscriptBox["z", "2"], "|"}]}]}]}]}]]],
 ".  \n\nSubtracting ",
 Cell[BoxData[
  RowBox[{"|", 
   SubscriptBox["z", "2"], "|"}]]],
 " from the left and right sides of this string of inequalities gives an \
important relationship that will be used in determining lower bounds of sums \
of complex numbers: \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"|", 
   RowBox[{
    SubscriptBox["z", "1"], "+", 
    SubscriptBox["z", "2"]}], "|", 
   RowBox[{"\[GreaterEqual]", 
    RowBox[{"|", 
     SubscriptBox["z", "1"], "|", 
     RowBox[{"-", 
      RowBox[{"|", 
       SubscriptBox["z", "2"], "|"}]}]}]}]}]]],
 ".  \n"
}], "Text"],

Cell[TextData[{
 "Using the identity  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", "z", 
    SuperscriptBox["|", "2"]}], "=", 
   RowBox[{"z", " ", 
    OverscriptBox[
     RowBox[{"z", " "}], "_"]}]}]]],
 "  and the commutative and associative laws it follows that  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", 
    RowBox[{
     SubscriptBox["z", "1"], 
     SubscriptBox["z", "2"]}], 
    SuperscriptBox["|", "2"]}], "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["z", "1"], 
      SubscriptBox["z", "2"]}], ")"}], " ", 
    OverscriptBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["z", "1"], 
        SubscriptBox["z", "2"]}], ")"}], " "}], "_"]}]}]]],
 "  \n\t\t\t",
 Cell[BoxData[
  RowBox[{"                   ", 
   RowBox[{"=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["z", "1"], " ", 
       OverscriptBox[
        RowBox[{
         SubscriptBox["z", "1"], " "}], "_"]}], ")"}], 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["z", "2"], " ", 
       OverscriptBox[
        RowBox[{
         SubscriptBox["z", "2"], " "}], "_"]}], ")"}]}]}]}]]],
 "  \n\t\t\t",
 Cell[BoxData[
  RowBox[{"                   ", 
   RowBox[{"=", 
    RowBox[{"|", 
     SubscriptBox["z", "1"], 
     SuperscriptBox["|", "2"], "|", 
     SubscriptBox["z", "2"], 
     SuperscriptBox["|", "2"]}]}]}]]],
 "  \n\nTaking square roots of the terms on the left and right establishes \
another important identity  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", 
    RowBox[{
     SubscriptBox["z", "1"], 
     SubscriptBox["z", "2"]}], "|"}], "=", 
   RowBox[{"|", 
    RowBox[{
     SubscriptBox["z", "1"], "||", 
     SubscriptBox["z", "2"]}], "|"}]}]]],
 ".  \n\nAs an exercise, we ask you to show\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", 
    FractionBox[
     SubscriptBox["z", "1"], 
     SubscriptBox["z", "2"]], "|"}], "=", 
   FractionBox[
    RowBox[{"|", 
     SubscriptBox["z", "1"], "|"}], 
    RowBox[{"|", 
     SubscriptBox["z", "2"], "|"}]]}]]],
 ", provided   ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "2"], "\[NotEqual]", "0"}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 StyleBox["Example  1.6.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Use the values  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], "=", 
   RowBox[{
    RowBox[{"1", "+", 
     RowBox[{"2", "\[ImaginaryI]", "  ", "and", "  ", 
      SubscriptBox["z", "2"]}]}], "=", 
    RowBox[{"3", "+", 
     RowBox[{"2", "\[ImaginaryI]"}]}]}]}]]],
 ",  then  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", 
    SubscriptBox["z", "1"], "|"}], "=", 
   RowBox[{
    SqrtBox[
     RowBox[{"1", "+", "4"}]], "=", 
    SqrtBox["5"]}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", 
    SubscriptBox["z", "2"], "|"}], "=", 
   RowBox[{
    SqrtBox[
     RowBox[{"9", "+", "4"}]], "=", 
    SqrtBox["13"]}]}]]],
 ".  Also  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["z", "1"], 
    SubscriptBox["z", "2"]}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{"2", "\[ImaginaryI]"}]}], ")"}], 
     RowBox[{"(", 
      RowBox[{"3", "+", 
       RowBox[{"2", "\[ImaginaryI]"}]}], ")"}]}], "=", 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     RowBox[{"8", " ", "\[ImaginaryI]"}]}]}]}]]],
 ";  hence  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", 
    RowBox[{
     SubscriptBox["z", "1"], 
     SubscriptBox["z", "2"]}], "|"}], "=", 
   RowBox[{
    SqrtBox[
     RowBox[{"1", "+", "64"}]], "=", 
    RowBox[{
     SqrtBox["65"], "=", 
     RowBox[{
      RowBox[{
       SqrtBox["5"], 
       SqrtBox["13"]}], "=", 
      RowBox[{"|", 
       RowBox[{
        SubscriptBox["z", "1"], "||", 
        SubscriptBox["z", "2"]}], "|"}]}]}]}]}]]],
 ",  \nthus \n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", 
    RowBox[{
     SubscriptBox["z", "1"], 
     SubscriptBox["z", "2"]}], "|"}], "=", 
   RowBox[{"|", 
    RowBox[{
     SubscriptBox["z", "1"], "||", 
     SubscriptBox["z", "2"]}], "|"}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "\tFigure 1.10 illustrates the multiplication shown in Example1.6.  The \
length of the ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], 
   SubscriptBox["z", "2"]}]]],
 " vector apparently equals the product of the lengths of ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], "  ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "  ", 
   SubscriptBox["z", "2"]}]]],
 ", confirming that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", 
    RowBox[{
     SubscriptBox["z", "1"], 
     SubscriptBox["z", "2"]}], "|"}], "=", 
   RowBox[{"|", 
    RowBox[{
     SubscriptBox["z", "1"], "||", 
     SubscriptBox["z", "2"]}], "|"}]}]]],
 ",  but why is it located in the second quadrant when both ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], "  ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "  ", 
   SubscriptBox["z", "2"]}]]],
 "are in the first quadrant?  The answer to this question will become \
apparent to you in Section 1.4.."
}], "Text"],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{326, 312},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 1.6.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "Compute ",
 Cell[BoxData[
  RowBox[{"|", 
   RowBox[{
    SubscriptBox["z", "1"], 
    SubscriptBox["z", "2"]}], "|", "  ", "and", "  ", "|", 
   RowBox[{
    SubscriptBox["z", "1"], "||", 
    SubscriptBox["z", "2"]}], "|"}]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", "z", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "1"], " ", "=", " ", 
     RowBox[{"1", " ", "+", " ", 
      RowBox[{"2", "\[ImaginaryI]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "2"], " ", "=", " ", 
     RowBox[{"3", " ", "+", " ", 
      RowBox[{"2", "\[ImaginaryI]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "3"], " ", "=", " ", 
     RowBox[{
      SubscriptBox["z", "1"], " ", 
      SubscriptBox["z", "2"]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["V", "1"], " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"Arrowheads", "[", 
         RowBox[{"{", 
          RowBox[{"0.0", ",", "0.1"}], "}"}], "]"}], ",", 
        RowBox[{"Thickness", "[", "0.01", "]"}], ",", 
        RowBox[{"Arrow", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["z", "1"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["z", "1"], "]"}]}], "}"}]}], "}"}], "]"}]}], "}"}],
       "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["V", "2"], " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Green", ",", 
        RowBox[{"Arrowheads", "[", 
         RowBox[{"{", 
          RowBox[{"0.0", ",", "0.1"}], "}"}], "]"}], ",", 
        RowBox[{"Thickness", "[", "0.01", "]"}], ",", 
        RowBox[{"Arrow", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["z", "2"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["z", "2"], "]"}]}], "}"}]}], "}"}], "]"}]}], "}"}],
       "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["V", "3"], " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", 
        RowBox[{"Arrowheads", "[", 
         RowBox[{"{", 
          RowBox[{"0.0", ",", "0.1"}], "}"}], "]"}], ",", 
        RowBox[{"Thickness", "[", "0.01", "]"}], ",", 
        RowBox[{"Arrow", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["z", "3"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["z", "3"], "]"}]}], "}"}]}], "}"}], "]"}]}], "}"}],
       "]"}]}], ";"}], " ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{
     SubscriptBox["V", "1"], ",", 
     SubscriptBox["V", "2"], ",", 
     SubscriptBox["V", "3"], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "8"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "3", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "8", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "2"}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", " ", ",", " ", 
      SubscriptBox["z", "1"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(2\)]\) = \>\"", " ", ",", " ", 
      SubscriptBox["z", "2"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\) \!\(\*SubscriptBox[\(z\), \(2\)]\
\) = \>\"", " ", ",", " ", 
      SubscriptBox["z", "3"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<|\!\(\*SubscriptBox[\(z\), \(1\)]\)| = \>\"", " ", ",", " ", 
      RowBox[{"Abs", "[", 
       SubscriptBox["z", "1"], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<|\!\(\*SubscriptBox[\(z\), \(2\)]\)| = \>\"", " ", ",", " ", 
      RowBox[{"Abs", "[", 
       SubscriptBox["z", "2"], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< |\!\(\*SubscriptBox[\(z\), \(1\)]\) \!\(\*SubscriptBox[\(z\), \
\(2\)]\)| = \>\"", " ", ",", " ", 
      RowBox[{"Abs", "[", 
       RowBox[{
        SubscriptBox["z", "1"], " ", 
        SubscriptBox["z", "2"]}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<|\!\(\*SubscriptBox[\(z\), \(1\)]\)||\!\(\*SubscriptBox[\(z\), \
\(2\)]\)| = \>\"", ",", " ", 
      RowBox[{"Abs", "[", 
       SubscriptBox["z", "1"], "]"}], ",", 
      RowBox[{"Abs", "[", 
       SubscriptBox["z", "2"], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Is |\!\(\*SubscriptBox[\(z\), \(1\)]\) \!\(\*SubscriptBox[\(z\), \
\(2\)]\)| = |\!\(\*SubscriptBox[\(z\), \(1\)]\)||\!\(\*SubscriptBox[\(z\), \
\(2\)]\)| ?  \>\"", ",", "\n", "  ", 
      RowBox[{
       RowBox[{"Abs", "[", 
        RowBox[{
         SubscriptBox["z", "1"], " ", 
         SubscriptBox["z", "2"]}], "]"}], " ", "\[Equal]", " ", 
       RowBox[{
        RowBox[{"Abs", "[", 
         SubscriptBox["z", "1"], "]"}], " ", 
        RowBox[{"Abs", "[", 
         SubscriptBox["z", "2"], "]"}]}]}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< |\!\(\*SubscriptBox[\(z\), \(1\)]\) \!\(\*SubscriptBox[\(z\), \
\(2\)]\)| = \>\"", ",", " ", 
      RowBox[{"N", "[", 
       RowBox[{"Abs", "[", 
        RowBox[{
         SubscriptBox["z", "1"], " ", 
         SubscriptBox["z", "2"]}], "]"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<|\!\(\*SubscriptBox[\(z\), \(1\)]\)||\!\(\*SubscriptBox[\(z\), \
\(2\)]\)| = \>\"", ",", " ", 
      RowBox[{"N", "[", 
       RowBox[{
        RowBox[{"Abs", "[", 
         SubscriptBox["z", "1"], "]"}], 
        RowBox[{"Abs", "[", 
         SubscriptBox["z", "2"], "]"}]}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Is |\!\(\*SubscriptBox[\(z\), \(1\)]\) \!\(\*SubscriptBox[\(z\), \
\(2\)]\)| = |\!\(\*SubscriptBox[\(z\), \(1\)]\)||\!\(\*SubscriptBox[\(z\), \
\(2\)]\)| ?  \>\"", ",", "\n", "  ", 
      RowBox[{
       RowBox[{"Abs", "[", 
        RowBox[{
         SubscriptBox["z", "1"], " ", 
         SubscriptBox["z", "2"]}], "]"}], " ", "\[Equal]", " ", 
       RowBox[{
        RowBox[{"Abs", "[", 
         SubscriptBox["z", "1"], "]"}], " ", 
        RowBox[{"Abs", "[", 
         SubscriptBox["z", "2"], "]"}]}]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.398969735875*^9, 3.398969738203125*^9}, {
  3.3997091285*^9, 3.39970916215625*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Complex Numbers",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/ComplexNumbersBib.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox[ButtonBox["History of Complex Numbers",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/HistoryComplexBib.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/complex.html"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2008 John H. Mathews, Russell W. \
Howell",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/"], None}],
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[0, 1, 0]]], "Text",
 CellChangeTimes->{{3.398969695765625*^9, 3.3989696965*^9}}]
},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{988, 617},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "CHAPTER 1"->{
  Cell[568, 21, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"CHAPTER 1", 76257, 2186}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"],
Cell[905, 32, 199, 7, 29, "Text"],
Cell[1107, 41, 297, 6, 47, "Text"],
Cell[1407, 49, 1811, 64, 83, "Text"],
Cell[3221, 115, 2652, 46, 182, "Text",
 Evaluatable->False],
Cell[5876, 163, 1385, 47, 65, "Text"],
Cell[7264, 212, 2884, 50, 211, "Text",
 Evaluatable->False],
Cell[10151, 264, 640, 25, 29, "Text",
 Evaluatable->False],
Cell[10794, 291, 3303, 57, 269, "Text",
 Evaluatable->False],
Cell[14100, 350, 978, 34, 92, "Text",
 Evaluatable->False],
Cell[15081, 386, 837, 32, 56, "Text",
 Evaluatable->False],
Cell[15921, 420, 3567, 61, 262, "Text",
 Evaluatable->False],
Cell[19491, 483, 593, 21, 29, "Text",
 Evaluatable->False],
Cell[20087, 506, 3401, 59, 262, "Text",
 Evaluatable->False],
Cell[23491, 567, 998, 36, 119, "Text",
 Evaluatable->False],
Cell[24492, 605, 1517, 60, 92, "Text"],
Cell[26012, 667, 957, 39, 47, "Text"],
Cell[26972, 708, 3750, 64, 211, "Text",
 Evaluatable->False],
Cell[30725, 774, 449, 13, 83, "Text"],
Cell[31177, 789, 309, 5, 47, "Text"],
Cell[31489, 796, 3478, 60, 211, "Text",
 Evaluatable->False],
Cell[34970, 858, 1079, 39, 83, "Text"],
Cell[36052, 899, 7576, 249, 379, "Text",
 Evaluatable->False],
Cell[43631, 1150, 2407, 96, 143, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[46063, 1250, 156, 4, 29, "Text",
 Evaluatable->False],
Cell[46222, 1256, 292, 12, 29, "Text"],
Cell[46517, 1270, 10028, 287, 553, "Input"]
}, Closed]],
Cell[56560, 1560, 1635, 60, 188, "Text"],
Cell[58198, 1622, 2174, 83, 259, "Text"],
Cell[60375, 1707, 1963, 83, 123, "Text",
 Evaluatable->False],
Cell[62341, 1792, 1334, 46, 65, "Text"],
Cell[63678, 1840, 2640, 46, 326, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[66343, 1890, 156, 4, 29, "Text",
 Evaluatable->False],
Cell[66502, 1896, 263, 11, 29, "Text"],
Cell[66768, 1909, 7708, 219, 532, "Input"]
}, Closed]],
Cell[74491, 2131, 281, 7, 26, "Text"],
Cell[74775, 2140, 277, 7, 29, "Text"],
Cell[75055, 2149, 288, 7, 29, "Text"],
Cell[75346, 2158, 249, 5, 29, "Text"],
Cell[75598, 2165, 315, 7, 29, "Text"]
}
]
*)

(* End of internal cache information *)
