(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    149679,       4552]
NotebookOptionsPosition[    145284,       4411]
NotebookOutlinePosition[    145810,       4435]
CellTagsIndexPosition[    145736,       4430]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["1.4 The Geometry of Complex Numbers, Continued",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
 "\tIn Secion 1.3 we saw that a complex number  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{"x", "+", 
    RowBox[{"\[ImaginaryI]", " ", "y"}]}]}]]],
 "  could be viewed as a vector in the xy-plane whose tail is at the origin \
and whose head is at the point ",
 StyleBox["(x,y)",
  FontFamily->"Courier New"],
 ".  A vector can be uniquely specified by giving its magnitude (i.e., its \
length) and direction (i.e., the angle it makes with the positive x-axis).  \
In this section, we focus on these two geometric aspects of complex numbers."
}], "Text",
 Evaluatable->False,
 CellChangeTimes->{3.398971522828125*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "\t\tLet ",
 StyleBox["r",
  FontFamily->"Courier New"],
 " be the modulus of ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " (i.e., ",
 StyleBox["r = |z|",
  FontFamily->"Courier New"],
 "), and let  ",
 Cell[BoxData["\[Theta]"]],
 "  be the angle that the line from the origin to the complex number ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " makes with the positive ",
 StyleBox["x",
  FontFamily->"Courier New"],
 "-axis. (Note: The number  ",
 Cell[BoxData["\[Theta]"]],
 "  is undefined if ",
 StyleBox["z=0",
  FontFamily->"Courier New"],
 ").  We make the following definition."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Definition 1.9, (Polar Representation).",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[" ",
  FontColor->RGBColor[0, 0, 1]],
 " The identity \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"z", " ", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"r", " ", "cos", " ", "\[Theta]"}], ",", 
      RowBox[{"r", " ", "sin", " ", "\[Theta]"}]}], ")"}], "=", " ", 
    RowBox[{"r", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"cos", " ", "\[Theta]"}], " ", "+", " ", 
       RowBox[{"i", " ", "sin", " ", "\[Theta]"}]}], ")"}]}]}]}]]],
 "  \n\nis known as a polar representation of ",
 StyleBox["z",
  FontFamily->"Courier New"],
 ", and the values ",
 StyleBox["r",
  FontFamily->"Courier New"],
 " and  ",
 Cell[BoxData["\[Theta]"]],
 "  are called polar coordinates of ",
 StyleBox["z",
  FontFamily->"Courier New"],
 ", and is illustrated in Figure 1.11 (a)."
}], "Text"],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{613, 287},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 "\tAs Figure 1.11(b) shows, the angle ",
 Cell[BoxData["\[Theta]"]],
 "  can",
 " be any val",
 "ue for which the identities  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"cos", " ", "\[Theta]"}], "=", 
   RowBox[{
    RowBox[{
     FractionBox["x", "r"], " ", "and", " ", "sin", " ", "\[Theta]"}], "=", 
    FractionBox["y", "r"]}]}]]],
 "  hold true.  Given ",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{"z", "\[NotEqual]", "0"}]}]]],
 ",  the collection of all values of  ",
 Cell[BoxData["\[Theta]"]],
 " for which  ",
 Cell[BoxData[
  RowBox[{"z", " ", "=", 
   RowBox[{"r", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"cos", " ", "\[Theta]"}], " ", "+", " ", 
      RowBox[{"i", " ", "sin", " ", "\[Theta]"}]}], ")"}]}]}]]],
 "  is denoted by  ",
 Cell[BoxData[
  RowBox[{"arg", " ", "z"}]]],
 ".  Formally, ",
 "we have the following definitions."
}], "Text"],

Cell[TextData[{
 StyleBox["Example 1.7.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  If  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{"1", "+", "\[ImaginaryI]"}]}]]],
 ",  then  ",
 Cell[BoxData[
  RowBox[{"r", "=", 
   RowBox[{
    SqrtBox[
     RowBox[{"1", "+", "1"}]], "=", 
    SqrtBox["2"]}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SqrtBox["2"], "cos", 
       FractionBox["\[Pi]", "4"]}], ",", " ", 
      RowBox[{
       SqrtBox["2"], "sin", 
       FractionBox["\[Pi]", "4"]}]}], ")"}], "=", " ", 
    RowBox[{
     SqrtBox["2"], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"cos", 
        FractionBox["\[Pi]", "4"]}], "+", 
       RowBox[{"\[ImaginaryI]", " ", "sin", 
        FractionBox["\[Pi]", "4"]}]}], ")"}]}]}]}]]],
 "  is a polar representation of ",
 StyleBox["z",
  FontFamily->"Courier New"],
 ".  The polar coordinates in this case are ",
 Cell[BoxData[
  RowBox[{"r", "=", 
   SqrtBox["2"]}]]],
 ", and ",
 Cell[BoxData[
  RowBox[{"\[Theta]", "=", 
   FractionBox["\[Pi]", "4"]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 1.7.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", "z", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"z", "=", " ", 
     RowBox[{"1", "+", " ", "\[ImaginaryI]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"r", "=", 
     RowBox[{"Abs", "[", "z", "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"\[Theta]", "=", 
     RowBox[{"Arg", "[", "z", "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["V", "1"], " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", 
        RowBox[{"Arrowheads", "[", 
         RowBox[{"{", 
          RowBox[{"0.0", ",", "0.06"}], "}"}], "]"}], ",", 
        RowBox[{"Thickness", "[", "0.006", "]"}], ",", 
        RowBox[{"Arrow", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", "z", "]"}], ",", 
             RowBox[{"Im", "[", "z", "]"}]}], "}"}]}], "}"}], "]"}]}], "}"}], 
      "]"}]}], ";"}], " ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{
     SubscriptBox["V", "1"], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "1.1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "1.1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "2", ",", 
          FractionBox["1", "2"]}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "1", ",", 
          FractionBox["1", "2"]}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<         z = \>\"", ",", "z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<r = Abs[z] = \>\"", ",", "r"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Theta] = Arg[z] = \>\"", ",", "\[Theta]"}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\\n\>\"", ",", "\"\<Verify it\>\""}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<z = \!\(\*SqrtBox[\(2\)]\)(Cos[\!\(\*FractionBox[\(\[Pi]\), \
\(4\)]\)] + \[ImaginaryI] Sin[\!\(\*FractionBox[\(\[Pi]\), \(4\)]\)])\>\"", 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<z = \>\"", ",", 
      SqrtBox["2"], ",", "\"\<(\>\"", ",", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Cos", "[", 
         FractionBox["\[Pi]", "4"], "]"}], "+", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"Sin", "[", 
          FractionBox["\[Pi]", "4"], "]"}]}]}], ")"}], ",", "\"\<)\>\""}], 
     " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<z = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{
        SqrtBox["2"], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Cos", "[", 
           FractionBox["\[Pi]", "4"], "]"}], "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           RowBox[{"Sin", "[", 
            FractionBox["\[Pi]", "4"], "]"}]}]}], ")"}]}], "]"}]}], "  ", 
     "]"}], ";"}], "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.398971618296875*^9, 3.398971623421875*^9}, {
  3.399709324296875*^9, 3.399709355859375*^9}, {3.40023657559375*^9, 
  3.400236576515625*^9}, {3.400236622296875*^9, 3.400236622828125*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Definition 1.10, (",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Argument",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/ArgumentComplexNumber.html"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 StyleBox[", arg z).",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[" ",
  FontColor->RGBColor[0, 0, 1]],
 " If  ",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{"z", "\[NotEqual]", "0"}]}]]],
 ",  we denote  ",
 Cell[BoxData[
  RowBox[{"arg", " ", "z"}]]],
 "  by  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"arg", " ", "z"}], " ", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Theta]", ":", " ", "z"}], "=", 
     RowBox[{"r", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"cos", " ", "\[Theta]"}], " ", "+", 
        RowBox[{"\[ImaginaryI]", " ", "sin", " ", "\[Theta]"}]}], ")"}]}]}], 
    "}"}]}]]],
 ".  \n\nIf  ",
 Cell[BoxData[
  RowBox[{"\[Theta]", " ", "\[Element]", 
   RowBox[{"arg", " ", "z"}]}]]],
 ",  we say that ",
 Cell[BoxData["\[Theta]"]],
 " is an argument of ",
 StyleBox["z",
  FontFamily->"Courier New"],
 ". "
}], "Text"],

Cell[TextData[{
 "\tNotice that we write  ",
 Cell[BoxData[
  RowBox[{"\[Theta]", " ", "\[Element]", 
   RowBox[{"arg", " ", "z"}]}]]],
 "  as opposed to  ",
 Cell[BoxData[
  RowBox[{"\[Theta]", " ", "=", 
   RowBox[{"arg", " ", "z"}]}]]],
 ".  This is because  ",
 Cell[BoxData[
  RowBox[{"arg", " ", "z"}]]],
 "  is a set, and the designation ",
 Cell[BoxData[
  RowBox[{"\[Theta]", " ", "\[Element]", 
   RowBox[{"arg", " ", "z"}]}]]],
 " indicates that ",
 Cell[BoxData["\[Theta]"]],
 " belongs to that set.  Notice also that, if  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["\[Theta]", "1"], "\[Element]", 
   RowBox[{"arg", " ", "z", "  ", 
    StyleBox["and",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], "  ", 
    SubscriptBox["\[Theta]", "2"]}], "\[Element]", 
   RowBox[{"arg", " ", "z"}]}]]],
 ",  then there exists some integer ",
 StyleBox["n",
  FontFamily->"Courier New"],
 " such that  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["\[Theta]", "2"], " ", "=", " ", 
   RowBox[{
    SubscriptBox["\[Theta]", "1"], " ", "+", " ", 
    RowBox[{"2", "n", " ", "\[Pi]"}]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 StyleBox["Example 1.8.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Since ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"1", "+", "\[ImaginaryI]"}], "=", 
   RowBox[{
    SqrtBox["2"], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Cos", "[", 
       FractionBox["\[Pi]", "4"], "]"}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"Sin", "[", 
        FractionBox["\[Pi]", "4"], "]"}]}]}], ")"}]}]}]]],
 ", we have \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{"arg", 
    RowBox[{"(", 
     RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}]}], "=", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["\[Pi]", "4"], "+", 
     RowBox[{"2", "n", " ", 
      RowBox[{"\[Pi]", ":", " ", 
       RowBox[{"n", " ", 
        StyleBox["an",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], 
        StyleBox[" ",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], 
        StyleBox["integer",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]]}]}]}]}], "}"}]}], "\[IndentingNewLine]", 
  RowBox[{"                      ", 
   RowBox[{"=", 
    RowBox[{"{", 
     RowBox[{"...", ",", 
      FractionBox[
       RowBox[{
        RowBox[{"-", "15"}], "\[Pi]"}], "4"], ",", 
      FractionBox[
       RowBox[{
        RowBox[{"-", "7"}], "\[Pi]"}], "4"], ",", 
      FractionBox["\[Pi]", "4"], ",", 
      FractionBox[
       RowBox[{"9", "\[Pi]"}], "4"], ",", 
      FractionBox[
       RowBox[{"17", "\[Pi]"}], "4"], ",", 
      FractionBox[
       RowBox[{"25", "\[Pi]"}], "4"], ",", "..."}], "}"}]}]}]}]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 1.8.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "Enter several values  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"arg", 
    RowBox[{"(", 
     RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}]}], "=", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["\[Pi]", "4"], "+", 
     RowBox[{"2", "n", " ", 
      RowBox[{"\[Pi]", ":", " ", 
       RowBox[{"n", " ", 
        StyleBox["an",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], 
        StyleBox[" ",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], 
        StyleBox["integer",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]]}]}]}]}], "}"}]}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", "z", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "1"], "=", " ", 
     RowBox[{"1", "+", " ", "\[ImaginaryI]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "2"], " ", "=", " ", 
     RowBox[{
      SqrtBox["2"], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"\[Pi]", "/", "4"}]}]]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "3"], " ", "=", " ", 
     RowBox[{
      SqrtBox["2"], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", "9", " ", 
        RowBox[{"\[Pi]", "/", "4"}]}]]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "4"], " ", "=", " ", 
     RowBox[{
      SqrtBox["2"], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", " ", "\[ImaginaryI]"}], " ", "7", " ", 
        RowBox[{"\[Pi]", "/", "4"}]}]]}]}], ";"}], " ", "\[IndentingNewLine]",
    
   RowBox[{
    RowBox[{
     SubscriptBox["z", "5"], " ", "=", " ", 
     RowBox[{
      SqrtBox["2"], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", "17", 
        RowBox[{"\[Pi]", "/", "4"}]}]]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"r", "=", 
     RowBox[{"Abs", "[", 
      SubscriptBox["z", "1"], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"\[Theta]", "=", 
     RowBox[{"Arg", "[", 
      SubscriptBox["z", "1"], "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["V", "1"], " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"Arrowheads", "[", 
         RowBox[{"{", 
          RowBox[{"0.0", ",", "0.06"}], "}"}], "]"}], ",", 
        RowBox[{"Thickness", "[", "0.006", "]"}], ",", 
        RowBox[{"Arrow", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["z", "1"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["z", "1"], "]"}]}], "}"}]}], "}"}], "]"}]}], "}"}],
       "]"}]}], ";"}], " ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{
     SubscriptBox["V", "1"], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "1.1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "1.1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "2", ",", 
          FractionBox["1", "2"]}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "1", ",", 
          FractionBox["1", "2"]}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["z", "1"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<r = \>\"", ",", "r"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Theta] = \>\"", ",", "\[Theta]"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(z\), \(2\)]\) = \!\(\*SqrtBox[\(2\)]\) \
\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\"\<\[ImaginaryI]\>\" \
\[Pi]/4\)]\)    = \>\"", ",", 
      SubscriptBox["z", "2"], ",", "\"\< = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       SubscriptBox["z", "2"], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(z\), \(3\)]\) = \!\(\*SqrtBox[\(2\)]\) \
\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\"\<\[ImaginaryI]\>\" 13  \[Pi]/4\
\)]\)  = \>\"", ",", 
      SubscriptBox["z", "3"], ",", "\"\< = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       SubscriptBox["z", "3"], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(z\), \(4\)]\) = \!\(\*SqrtBox[\(2\)]\) \
\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\"\<-\[ImaginaryI]\>\" 11  \
\[Pi]/4\)]\) = \>\"", ",", 
      SubscriptBox["z", "4"], ",", "\"\< = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       SubscriptBox["z", "4"], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(z\), \(5\)]\) = \!\(\*SqrtBox[\(2\)]\) \
\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\"\<\[ImaginaryI]\>\" 25  \[Pi]/4\
\)]\)  = \>\"", ",", 
      SubscriptBox["z", "5"], ",", "\"\< = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       SubscriptBox["z", "5"], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39897164425*^9, 3.398971649875*^9}, {
  3.39970937446875*^9, 3.39970940240625*^9}, {3.400236642*^9, 
  3.4002366428125*^9}}],

Cell["Here is another way to look at it.", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"n", ",", "w"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"w", " ", "=", " ", 
     RowBox[{
      SqrtBox["2"], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"\[Pi]", "/", "4"}]}], "+", " ", 
        RowBox[{"\[ImaginaryI]", " ", "2", "\[Pi]", " ", "n"}]}]]}]}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = \>\"", ",", "w"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<w = \!\(\*SqrtBox[\(2\)]\)\!\(\*SuperscriptBox[\(\[ExponentialE]\), \
\(\[ImaginaryI]\\\ \[Pi]/4\)]\) \!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\
\[ImaginaryI]\\\ 2  \[Pi]\\\ n\)]\)\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"w", " ", "=", " ", 
     RowBox[{"Simplify", "[", "w", "]"}]}], ";"}], " ", "\[IndentingNewLine]",
    
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = \>\"", ",", "w"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = (\>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{
        SqrtBox["2"], " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"\[Pi]", "/", "4"}]}]]}], "]"}], ",", "\"\<)(\>\"", ",", 
      RowBox[{"Simplify", "[", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{" ", 
          RowBox[{"\[ImaginaryI]", " ", "2", "\[Pi]", " ", "n"}]}]], ",", 
        RowBox[{"Element", "[", 
         RowBox[{"n", ",", "Integers"}], "]"}]}], "]"}], ",", "\"\<)\>\""}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"w", " ", "=", " ", 
     RowBox[{"Simplify", "[", 
      RowBox[{"w", ",", 
       RowBox[{"Element", "[", 
        RowBox[{"n", ",", "Integers"}], "]"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = \>\"", ",", "w"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.398971655796875*^9}]
}, Closed]],

Cell[TextData[{
 "\tMathematicians have agreed to single out a special choice of  ",
 Cell[BoxData[
  RowBox[{"\[Theta]", " ", "\[Element]", 
   RowBox[{"arg", " ", "z"}]}]]],
 ".  It is that value of ",
 Cell[BoxData["\[Theta]"]],
 " for which ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"-", "\[Pi]"}], "<", "\[Theta]", "\[LessEqual]", "\[Pi]"}]]],
 " as the following definition indicates."
}], "Text"],

Cell[TextData[{
 StyleBox["Definition 1.11, (The principal value of argument, Arg z).",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[" ",
  FontColor->RGBColor[0, 0, 1]],
 " Let  ",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{"z", "\[NotEqual]", "0"}]}]]],
 ",  be a complex number.  Then \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Arg", " ", "z"}], " ", "=", "\[Theta]"}]]],
 ",    provided ",
 Cell[BoxData[
  RowBox[{"z", " ", "=", 
   RowBox[{"r", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"cos", " ", "\[Theta]"}], " ", "+", " ", 
      RowBox[{"i", " ", "sin", " ", "\[Theta]"}]}], ")"}]}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"-", "\[Pi]"}], "<", "\[Theta]", "\[LessEqual]", "\[Pi]"}]]],
 ".  \n\nIf  ",
 Cell[BoxData[
  RowBox[{"\[Theta]", " ", "=", 
   RowBox[{"Arg", " ", "z"}]}]]],
 ",  we call ",
 Cell[BoxData["\[Theta]"]],
 " the argument of ",
 StyleBox["z",
  FontFamily->"Courier New"],
 ". "
}], "Text"],

Cell[TextData[{
 StyleBox["Example 1.9.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Arg", 
    RowBox[{"(", 
     RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}]}], "=", 
   FractionBox["\[Pi]", "4"]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 1.9.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"z", "=", 
     RowBox[{"1", "+", "\[ImaginaryI]"}]}], ";"}], " ", "\[IndentingNewLine]",
    
   RowBox[{
    RowBox[{"\[Theta]", "=", 
     RowBox[{"Arg", "[", "z", "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<z = \>\"", ",", "z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\[Theta] = Arg[1+\[ImaginaryI]]\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\[Theta] = ArcTan[\!\(\*FractionBox[\(1\), \(1\)]\)] = \>\"", ",", 
      RowBox[{"ArcTan", "[", 
       FractionBox["1", "1"], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Theta] = ArcTan[1,1] = \>\"", ",", 
      RowBox[{"ArcTan", "[", 
       RowBox[{"1", ",", "1"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Theta] = \>\"", ",", "\[Theta]"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.398971666796875*^9, 3.398971668140625*^9}}]
}, Closed]],

Cell[TextData[{
 StyleBox["Remark.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  Clearly if ",
 Cell[BoxData[
  RowBox[{"z", " ", "=", 
   RowBox[{
    RowBox[{"x", "+", 
     RowBox[{"\[ImaginaryI]", " ", "y"}]}], "=", 
    RowBox[{"r", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"cos", " ", "\[Theta]"}], " ", "+", " ", 
       RowBox[{"i", " ", "sin", " ", "\[Theta]"}]}], ")"}]}]}]}]]],
 ", where ",
 Cell[BoxData[
  RowBox[{"x", "\[NotEqual]", "0"}]]],
 ", then  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"arg", " ", "z"}], "  ", "\[Subset]", " ", 
   RowBox[{"arctan", " ", 
    FractionBox["y", "x"]}]}]]],
 ".  \n\nwhere  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"arctan", " ", 
    FractionBox["y", "x"]}], " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Theta]", ":", "  ", 
      RowBox[{"tan", " ", "\[Theta]"}]}], " ", "=", " ", 
     FractionBox["y", "x"]}], "}"}]}]]],
 ".  Note that, as with ",
 StyleBox["arg",
  FontFamily->"Courier New"],
 ", ",
 StyleBox["arctan",
  FontFamily->"Courier New"],
 " is a set (as opposed to ",
 StyleBox["Arctan",
  FontFamily->"Courier New"],
 ", which is a number).  We specifically identify ",
 Cell[BoxData[
  RowBox[{"arg", " ", "z"}]]],
 " as a proper subset of ",
 Cell[BoxData[
  RowBox[{"arctan", " ", 
   FractionBox["y", "x"]}]]],
 " because ",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{"tan", " ", "\[Theta]", " "}]}]]],
 " has period ",
 Cell[BoxData["\[Pi]"]],
 ", whereas ",
 StyleBox["cos",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["sin",
  FontFamily->"Courier New"],
 " have period  ",
 Cell[BoxData[
  RowBox[{"2", "\[Pi]"}]]],
 ".  In selecting the proper values for  ",
 Cell[BoxData[
  RowBox[{"arg", " ", "z"}]]],
 " , we must be careful in specifying the choices of ",
 Cell[BoxData[
  RowBox[{"arctan", " ", 
   FractionBox["y", "x"]}]]],
 " so that the poin ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " associated with ",
 StyleBox["r",
  FontFamily->"Courier New"],
 " and ",
 Cell[BoxData["\[Theta]"]],
 " lies in the appropriate quadrant."
}], "Text"],

Cell[TextData[{
 StyleBox["Example 1.10.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  If  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SqrtBox["3"]}], "-", "\[ImaginaryI]"}], "=", 
    RowBox[{"r", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"cos", " ", "\[Theta]"}], " ", "+", " ", 
       RowBox[{"i", " ", "sin", " ", "\[Theta]"}]}], ")"}]}]}]}]]],
 ",  then  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"r", "=", 
   RowBox[{
    RowBox[{"|", "z", "|"}], "=", 
    RowBox[{
     RowBox[{"|", 
      RowBox[{
       RowBox[{"-", 
        SqrtBox["3"]}], "-", "\[ImaginaryI]"}], "|"}], "=", 
     RowBox[{
      SqrtBox[
       RowBox[{"3", "+", "1"}]], "=", "2"}]}]}]}]]],
 "   and  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Theta]", " ", "\[Element]", " ", 
    RowBox[{"arctan", " ", 
     FractionBox["y", "x"]}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"arctan", " ", 
     FractionBox[
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       SqrtBox["3"]}]]}], " ", "=", 
    RowBox[{"{", 
     RowBox[{
      FractionBox["\[Pi]", "6"], "+", 
      RowBox[{"n", " ", 
       RowBox[{"\[Pi]", ":", "  ", 
        RowBox[{"n", "   ", 
         StyleBox["is",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontVariations->{"StrikeThrough"->False,
          "Underline"->False},
          FontColor->GrayLevel[0]], 
         StyleBox[" ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontVariations->{"StrikeThrough"->False,
          "Underline"->False},
          FontColor->GrayLevel[0]], 
         StyleBox["an",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontVariations->{"StrikeThrough"->False,
          "Underline"->False},
          FontColor->GrayLevel[0]], 
         StyleBox[" ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontVariations->{"StrikeThrough"->False,
          "Underline"->False},
          FontColor->GrayLevel[0]], 
         StyleBox["integer",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontVariations->{"StrikeThrough"->False,
          "Underline"->False},
          FontColor->GrayLevel[0]]}]}]}]}], "}"}]}]}]]],
 ".  \n\nIt would be a mistake to use ",
 Cell[BoxData[
  FractionBox["\[Pi]", "6"]]],
 " as an acceptable value for ",
 Cell[BoxData[
  RowBox[{"\[Theta]", " "}]]],
 ", as the point z associated with ",
 Cell[BoxData[
  RowBox[{"r", "=", "2"}]]],
 " and ",
 Cell[BoxData[
  RowBox[{"\[Theta]", "=", 
   FractionBox["\[Pi]", "6"]}]]],
 " is in the first quadrant, whereas ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{
    RowBox[{"-", 
     SqrtBox["3"]}], "-", "\[ImaginaryI]"}]}]]],
 " is in the third quadrant.  A correct choice for ",
 Cell[BoxData[
  RowBox[{"\[Theta]", " "}]]],
 " is ",
 Cell[BoxData[
  RowBox[{"\[Theta]", "=", 
   RowBox[{
    RowBox[{
     FractionBox["\[Pi]", "6"], "-", "\[Pi]"}], "=", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"5", "\[Pi]"}], "6"]}]}]}]]],
 ".  Thus\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SqrtBox["3"], "-", "\[ImaginaryI]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{"2", 
     RowBox[{"Cos", "[", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"5", "\[Pi]"}], "6"]}], "]"}]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", "2", 
     RowBox[{"Sin", "[", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"5", "\[Pi]"}], "6"]}], "]"}]}]}]}]]],
 ",  and \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     SqrtBox["3"]}], "-", "\[ImaginaryI]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{"2", 
     RowBox[{"Cos", "[", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"5", "\[Pi]"}], "6"]}], "+", 
       RowBox[{"2", "n", " ", "\[Pi]"}]}], "]"}]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", "2", 
     RowBox[{"Sin", "[", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"5", "\[Pi]"}], "6"]}], "+", 
       RowBox[{"2", "n", " ", "\[Pi]"}]}], "]"}]}]}]}]]],
 ", \n\t\t\t\nwhere ",
 StyleBox["n",
  FontFamily->"Courier New"],
 " is any integer.  In this case,\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Arg", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SqrtBox["3"]}], "-", "\[ImaginaryI]"}], ")"}]}], "=", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"5", "\[Pi]"}], "6"]}]}]]],
 ",  and \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"arg", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SqrtBox["3"]}], "-", "\[ImaginaryI]"}], ")"}]}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"5", "\[Pi]"}], "6"]}], "+", 
     RowBox[{"2", "n", " ", 
      RowBox[{"\[Pi]", ":", "  ", 
       RowBox[{"n", "  ", 
        StyleBox["is",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], 
        StyleBox[" ",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], 
        StyleBox["an",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], 
        StyleBox[" ",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], 
        StyleBox["integer",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]]}]}]}]}], "}"}]}]]],
 ". \n\n",
 StyleBox["Remark.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  Note that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"arg", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SqrtBox["3"]}], "-", "\[ImaginaryI]"}], ")"}]}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"5", "\[Pi]"}], "6"]}], "+", 
     RowBox[{"2", "n", " ", 
      RowBox[{"\[Pi]", ":", "  ", 
       RowBox[{"n", "  ", 
        StyleBox["is",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], 
        StyleBox[" ",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], 
        StyleBox["an",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], 
        StyleBox[" ",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], 
        StyleBox["integer",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]]}]}]}]}], "}"}]}]]],
 "  is indeed a proper subset of  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"arctan", " ", 
    FractionBox[
     RowBox[{"-", "1"}], 
     RowBox[{"-", 
      SqrtBox["3"]}]]}], " ", "=", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["\[Pi]", "6"], "+", 
     RowBox[{"n", " ", 
      RowBox[{"\[Pi]", ":", "  ", 
       RowBox[{"n", "  ", 
        StyleBox["is",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], 
        StyleBox[" ",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], 
        StyleBox["an",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], 
        StyleBox[" ",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], 
        StyleBox["integer",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]]}]}]}]}], "}"}]}]]],
 "."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 1.10.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "Enter  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], "=", " ", 
   RowBox[{
    RowBox[{"-", 
     SqrtBox["3"]}], "-", "\[ImaginaryI]"}]}]],
  AspectRatioFixed->True],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "2"], ",", 
   SubscriptBox["z", "3"], ",", 
   SubscriptBox["z", "4"], ",", 
   SubscriptBox["z", "5"]}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", "z", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "1"], "=", " ", 
     RowBox[{
      RowBox[{"-", 
       SqrtBox["3"]}], " ", "-", " ", "\[ImaginaryI]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "2"], " ", "=", " ", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", "5", 
        RowBox[{"\[Pi]", "/", "6"}]}]]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "3"], " ", "=", " ", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", "7", 
        RowBox[{"\[Pi]", "/", "6"}]}]]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "4"], " ", "=", " ", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", " ", "\[ImaginaryI]"}], " ", "17", " ", 
        RowBox[{"\[Pi]", "/", "6"}]}]]}]}], ";"}], " ", "\[IndentingNewLine]",
    
   RowBox[{
    RowBox[{
     SubscriptBox["z", "5"], " ", "=", " ", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", "19", 
        RowBox[{"\[Pi]", "/", "6"}]}]]}]}], ";"}], " ", "\[IndentingNewLine]",
    
   RowBox[{
    RowBox[{
     SubscriptBox["V", "1"], " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", 
        RowBox[{"Arrowheads", "[", 
         RowBox[{"{", 
          RowBox[{"0.0", ",", "0.06"}], "}"}], "]"}], ",", 
        RowBox[{"Thickness", "[", "0.006", "]"}], ",", 
        RowBox[{"Arrow", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["z", "1"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["z", "1"], "]"}]}], "}"}]}], "}"}], "]"}]}], "}"}],
       "]"}]}], ";"}], " ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{
     SubscriptBox["V", "1"], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", 
          FractionBox["1", "2"]}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          FractionBox[
           RowBox[{"-", "1"}], "2"], ",", "1", ",", 
          FractionBox["1", "2"]}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["z", "1"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(z\), \(2\)]\) = 2 \!\(\*SuperscriptBox[\(\
\[ExponentialE]\), \(\"\<-\[ImaginaryI]\>\" 5  \[Pi]/6\)]\) = \>\"", ",", 
      SubscriptBox["z", "2"], ",", "\"\< = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       SubscriptBox["z", "2"], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(z\), \(3\)]\) = 2 \!\(\*SuperscriptBox[\(\
\[ExponentialE]\), \(\"\<\[ImaginaryI]\>\" 7  \[Pi]/6\)]\)  = \>\"", ",", 
      SubscriptBox["z", "3"], ",", "\"\< = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       SubscriptBox["z", "3"], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(z\), \(4\)]\) = 2 \!\(\*SuperscriptBox[\(\
\[ExponentialE]\), \(\"\<-\[ImaginaryI]\>\" 17  \[Pi]/6\)]\) = \>\"", ",", 
      SubscriptBox["z", "4"], ",", "\"\< = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       SubscriptBox["z", "4"], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(z\), \(5\)]\) = 2 \!\(\*SuperscriptBox[\(\
\[ExponentialE]\), \(\"\<\[ImaginaryI]\>\" 19  \[Pi]/6\)]\)  = \>\"", ",", 
      SubscriptBox["z", "5"], ",", "\"\< = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       SubscriptBox["z", "5"], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{
  3.3989716765625*^9, {3.399709429359375*^9, 3.3997094688125*^9}, {
   3.400236691453125*^9, 3.40023669253125*^9}},
 AspectRatioFixed->True],

Cell["Here is another way to look at it.", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"n", ",", "w"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"w", " ", "=", " ", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "5", 
         RowBox[{"\[Pi]", "/", "6"}]}], "+", " ", 
        RowBox[{"\[ImaginaryI]", " ", "2", "\[Pi]", " ", "n"}]}]]}]}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = \>\"", ",", "w"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<w = 2 \!\(\*SuperscriptBox[\(\[ExponentialE]\), \
\(\(-\[ImaginaryI]\)\\\ 5  \[Pi]/6\)]\) \
\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\[ImaginaryI]\\\ 2  \[Pi]\\\ n\)]\
\)\>\"", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"w", " ", "=", " ", 
     RowBox[{"Simplify", "[", 
      RowBox[{"w", ",", 
       RowBox[{"Element", "[", 
        RowBox[{"n", ",", "Integers"}], "]"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = \>\"", ",", "w"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = (\>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"2", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", "5", 
          RowBox[{"\[Pi]", "/", "6"}]}]]}], "]"}], ",", "\"\<)(\>\"", ",", 
      " ", 
      RowBox[{"Simplify", "[", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{" ", 
          RowBox[{"\[ImaginaryI]", " ", "2", "\[Pi]", " ", "n"}]}]], ",", 
        RowBox[{"Element", "[", 
         RowBox[{"n", ",", "Integers"}], "]"}]}], "]"}], ",", "\"\<)\>\""}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"w", " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", "w", "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = \>\"", ",", "w"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.398971683703125*^9}]
}, Closed]],

Cell[TextData[{
 "\tIf  ",
 Cell[BoxData[
  RowBox[{"z", "\[NotEqual]", "0"}]]],
 "  is on the ",
 StyleBox["y",
  FontFamily->"Courier New"],
 "-axis, it would be a mistake to attempt to find  ",
 Cell[BoxData[
  RowBox[{"Arg", " ", "z"}]]],
 "  by looking at  ",
 Cell[BoxData[
  RowBox[{"arctan", " ", 
   FractionBox["y", "x"]}]]],
 ",  as ",
 Cell[BoxData[
  RowBox[{"x", "=", "0"}]]],
 ",  so ",
 Cell[BoxData[
  FractionBox["y", "x"]]],
 " is undefined.  We emphasize these special cases:\n\n\t\t\tIf  ",
 Cell[BoxData[
  RowBox[{GridBox[{
     {"y", ">"}
    }], "0"}]]],
 ",  then  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Arg", 
    RowBox[{"(", 
     RowBox[{"0", "+", 
      RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], " ", "=", " ", 
   FractionBox["\[Pi]", "2"]}]]],
 ",  and \n\n\t\t\tIf  ",
 Cell[BoxData[
  RowBox[{GridBox[{
     {"y", "<"}
    }], "0"}]]],
 ",  then  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Arg", " ", 
    RowBox[{"(", 
     RowBox[{"0", "+", 
      RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], " ", "=", " ", 
   RowBox[{"-", 
    FractionBox["\[Pi]", "2"]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 StyleBox["Example 1.11.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  If  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{
    RowBox[{"x", "+", 
     RowBox[{"\[ImaginaryI]", " ", "y"}]}], "=", 
    RowBox[{"0", "+", 
     RowBox[{"4", "\[ImaginaryI]"}]}]}]}]]],
 ", it would be a mistake to attempt to find  ",
 Cell[BoxData[
  RowBox[{"arg", " ", "z"}]]],
 "  by looking at  ",
 Cell[BoxData[
  RowBox[{"arctan", " ", 
   FractionBox["y", "x"]}]]],
 ",  as ",
 Cell[BoxData[
  RowBox[{"x", "=", "0"}]]],
 ",  so ",
 Cell[BoxData[
  RowBox[{
   FractionBox["y", "x"], "=", 
   FractionBox["4", "0"]}]]],
 " is undefined.  In this case  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Arg", 
    RowBox[{"(", 
     RowBox[{"4", " ", "\[ImaginaryI]"}], ")"}]}], "=", 
   RowBox[{
    RowBox[{"Arg", 
     RowBox[{"(", 
      RowBox[{"0", "+", 
       RowBox[{"4", " ", "\[ImaginaryI]"}]}], ")"}]}], "=", 
    FractionBox["\[Pi]", "2"]}]}]]],
 ",   and   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"arg", 
    RowBox[{"(", 
     RowBox[{"4", "\[ImaginaryI]"}], ")"}]}], "=", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["\[Pi]", "2"], "+", 
     RowBox[{"2", "n", " ", 
      RowBox[{"\[Pi]", ":", " ", 
       RowBox[{"n", " ", 
        StyleBox["is",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], 
        StyleBox[" ",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], 
        StyleBox["an",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], 
        StyleBox[" ",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], 
        StyleBox["integer",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]]}]}]}]}], "}"}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "\tAs we shall see in Chapter 2, ",
 Cell[BoxData[
  RowBox[{"Arg", " ", "z", " "}]]],
 " is a discontinuous function of z because it \"jumps'' by an amount of ",
 Cell[BoxData[
  RowBox[{"2", "\[Pi]"}]]],
 " as ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " crosses the negative real axis."
}], "Text"],

Cell[TextData[{
 "\tIn Chapter 5 we define ",
 Cell[BoxData[
  SuperscriptBox["\[ExponentialE]", "z"]]],
 " for any complex number ",
 StyleBox["z",
  FontFamily->"Courier New"],
 ".  You will see that this complex exponential has all the properties of \
real exponentials that you studied in earlier mathematics courses.  That is,  \
",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     SubscriptBox["z", "1"]], 
    SuperscriptBox["\[ExponentialE]", 
     SubscriptBox["z", "2"]]}], "=", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     SubscriptBox["z", "1"], "+", 
     SubscriptBox["z", "2"]}]]}]]],
 ",  and so forth. You will also see, amazingly, that if ",
 Cell[BoxData[
  RowBox[{"z", " ", "=", 
   RowBox[{"x", "+", 
    RowBox[{"\[ImaginaryI]", " ", "y"}]}]}]]],
 ", then  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[ExponentialE]", "z"], " ", "=", " ", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"x", "+", 
      RowBox[{"\[ImaginaryI]", " ", "y"}]}]], " ", "=", " ", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", "x"], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"cos", " ", "y"}], " ", "+", " ", 
       RowBox[{"\[ImaginaryI]", " ", "sin", " ", "y"}]}], ")"}]}]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "\tWe will establish this result rigorously in Chapter 5, but there is a \
plausible explanation we can give now.  \n\nIf  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[ExponentialE]", "z"], " "}]]],
 "  has the normal properties of an exponential, it must be that  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"x", "+", 
     RowBox[{"\[ImaginaryI]", " ", "y"}]}]], "=", " ", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", "x"], "=", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", "y"}]]}]}]]],
 ".  Now, recall from Calculus the values of three infinite series: \n\n\t",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[ExponentialE]", "x"], "=", " ", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"k", "=", "0"}], "\[Infinity]"], 
    RowBox[{
     FractionBox["1", 
      RowBox[{"k", "!"}]], 
     SuperscriptBox["x", "k"]}]}]}]]],
 ",    ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"cos", " ", "x"}], " ", "=", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"k", "=", "0"}], "\[Infinity]"], 
    RowBox[{
     FractionBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], "k"], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"2", "k"}], ")"}], "!"}]], 
     SuperscriptBox["x", 
      RowBox[{"2", "k"}]]}]}]}]]],
 ",   and   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Sin", "[", "x", "]"}], " ", "=", " ", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"k", "=", "0"}], "\[Infinity]"], 
    RowBox[{
     FractionBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], "k"], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", "k"}], "+", "1"}], ")"}], "!"}]], 
     SuperscriptBox["x", 
      RowBox[{
       RowBox[{"2", "k"}], "+", "1"}]]}]}]}]]],
 ".  \n"
}], "Text"],

Cell[TextData[{
 "Substituting ",
 Cell[BoxData[
  RowBox[{"\[ImaginaryI]", " ", "y"}]]],
 " for ",
 Cell[BoxData["x"]],
 " in the infinite series for  ",
 Cell[BoxData[
  SuperscriptBox["\[ExponentialE]", "x"]]],
 "  gives  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[ImaginaryI]", " ", "y"}]], " ", "=", "  ", 
   RowBox[{
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"k", "=", "0"}], "\[Infinity]"], 
     RowBox[{
      FractionBox["1", 
       RowBox[{"k", "!"}]], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"\[ImaginaryI]", " ", "y"}], ")"}], "k"]}]}], " ", "+", " ", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"k", "=", "0"}], "\[Infinity]"], 
     RowBox[{
      FractionBox["1", 
       RowBox[{"k", "!"}]], 
      SuperscriptBox["\[ImaginaryI]", "k"], 
      SuperscriptBox["y", "k"]}]}]}]}]]],
 ".  At this point, our argument loses rigor because we have not talked about \
infinite series of complex numbers, let alone whether such series converge.  \
Nevertheless, if we merely take the last series as a formal expression and \
split it into two series according to whether the index ",
 StyleBox["k",
  FontFamily->"Courier New"],
 " is even (",
 StyleBox["k=2n",
  FontFamily->"Courier New"],
 ") or odd (",
 StyleBox["k=2n+1",
  FontFamily->"Courier New"],
 "), we get  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", "y"}]], " ", "=", "  ", 
      RowBox[{
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"k", " ", "is", " ", "even"}], "\[Infinity]"], 
        RowBox[{
         FractionBox["1", 
          RowBox[{"k", "!"}]], 
         SuperscriptBox["\[ImaginaryI]", "k"], 
         SuperscriptBox["y", "k"]}]}], " ", "+", " ", 
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"k", " ", "is", " ", "odd"}], "\[Infinity]"], 
        RowBox[{
         FractionBox["1", 
          RowBox[{"k", "!"}]], 
         SuperscriptBox["\[ImaginaryI]", "k"], 
         SuperscriptBox["y", "k"]}]}]}]}], " ", "\[IndentingNewLine]"}], 
    "\[IndentingNewLine]", "        ", 
    RowBox[{
     RowBox[{"=", " ", 
      RowBox[{
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"n", "=", "0"}], "\[Infinity]"], 
        RowBox[{
         FractionBox["1", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"2", "n"}], ")"}], "!"}]], 
         SuperscriptBox["\[ImaginaryI]", 
          RowBox[{"2", "n"}]], 
         SuperscriptBox["y", 
          RowBox[{"2", "n"}]]}]}], " ", "+", " ", 
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"n", "=", "0"}], "\[Infinity]"], 
        RowBox[{
         FractionBox["1", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", "n"}], "+", "1"}], ")"}], "!"}]], 
         SuperscriptBox["\[ImaginaryI]", 
          RowBox[{
           RowBox[{"2", "n"}], "+", "1"}]], 
         SuperscriptBox["y", 
          RowBox[{
           RowBox[{"2", "n"}], "+", "1"}]]}]}]}]}], " ", 
     "\[IndentingNewLine]"}], "\[IndentingNewLine]", "        ", 
    RowBox[{
     RowBox[{"=", " ", 
      RowBox[{
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"n", "=", "0"}], "\[Infinity]"], 
        RowBox[{
         FractionBox["1", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"2", "n"}], ")"}], "!"}]], 
         SuperscriptBox[
          RowBox[{"(", 
           SuperscriptBox["\[ImaginaryI]", "2"], ")"}], "n"], 
         SuperscriptBox["y", 
          RowBox[{"2", "n"}]]}]}], " ", "+", " ", 
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"n", "=", "0"}], "\[Infinity]"], 
        RowBox[{
         FractionBox["1", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", "n"}], "+", "1"}], ")"}], "!"}]], 
         SuperscriptBox[
          RowBox[{"(", 
           SuperscriptBox["\[ImaginaryI]", "2"], ")"}], "n"], "\[ImaginaryI]",
          " ", 
         SuperscriptBox["y", 
          RowBox[{
           RowBox[{"2", "n"}], "+", "1"}]]}]}]}]}], " ", 
     "\[IndentingNewLine]"}], "\[IndentingNewLine]", "        ", 
    RowBox[{
     RowBox[{"=", " ", 
      RowBox[{
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"n", "=", "0"}], "\[Infinity]"], 
        RowBox[{
         FractionBox["1", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"2", "n"}], ")"}], "!"}]], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"-", "1"}], ")"}], "n"], 
         SuperscriptBox["y", 
          RowBox[{"2", "n"}]]}]}], " ", "+", " ", 
       RowBox[{"\[ImaginaryI]", 
        RowBox[{
         UnderoverscriptBox["\[Sum]", 
          RowBox[{"n", "=", "0"}], "\[Infinity]"], 
         RowBox[{
          FractionBox["1", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", "n"}], "+", "1"}], ")"}], "!"}]], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], "n"], " ", 
          SuperscriptBox["y", 
           RowBox[{
            RowBox[{"2", "n"}], "+", "1"}]]}]}]}]}]}], "\[IndentingNewLine]", 
     " "}], "\[IndentingNewLine]", "        ", 
    RowBox[{"=", " ", 
     RowBox[{
      RowBox[{"cos", " ", "y"}], "  ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", "sin", " ", "y"}]}]}]}]}]]]
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["\[ExponentialE]", "x"], "  ", "\[Equal]", "  ", 
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"k", "=", "0"}], "\[Infinity]"], 
   RowBox[{
    FractionBox["1", 
     RowBox[{"k", "!"}]], 
    SuperscriptBox["x", "k"]}]}]}]], "Input",
 CellChangeTimes->{{3.398971695234375*^9, 3.398971696625*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", "y"}]], " ", "\[Equal]", " ", 
    RowBox[{
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "0"}], "\[Infinity]"], 
      RowBox[{
       FractionBox["1", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"2", "n"}], ")"}], "!"}]], 
       SuperscriptBox["\[ImaginaryI]", 
        RowBox[{"2", "n"}]], 
       SuperscriptBox["y", 
        RowBox[{"2", "n"}]]}]}], " ", "+", " ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "0"}], "\[Infinity]"], 
      RowBox[{
       FractionBox["1", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", "n"}], "+", "1"}], ")"}], "!"}]], 
       SuperscriptBox["\[ImaginaryI]", 
        RowBox[{
         RowBox[{"2", "n"}], "+", "1"}]], 
       SuperscriptBox["y", 
        RowBox[{
         RowBox[{"2", "n"}], "+", "1"}]]}]}]}]}], "    ", "//", 
   "ComplexExpand"}]}]], "Input",
 CellChangeTimes->{3.39897174965625*^9, 3.400236712046875*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", "y"}]], " ", "\[Equal]", " ", 
    RowBox[{
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "0"}], "\[Infinity]"], 
      RowBox[{
       FractionBox["1", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"2", "n"}], ")"}], "!"}]], 
       SuperscriptBox["\[ImaginaryI]", 
        RowBox[{"2", "n"}]], 
       SuperscriptBox["y", 
        RowBox[{"2", "n"}]]}]}], " ", "+", " ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "0"}], "\[Infinity]"], 
      RowBox[{
       FractionBox["1", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", "n"}], "+", "1"}], ")"}], "!"}]], 
       SuperscriptBox["\[ImaginaryI]", 
        RowBox[{
         RowBox[{"2", "n"}], "+", "1"}]], 
       SuperscriptBox["y", 
        RowBox[{
         RowBox[{"2", "n"}], "+", "1"}]]}]}]}]}], "     ", "//", 
   "ComplexExpand"}]}]], "Input",
 CellChangeTimes->{3.3989717565625*^9, 3.400236713203125*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", "y"}]], " ", "\[Equal]", 
    RowBox[{
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "0"}], "\[Infinity]"], 
      RowBox[{
       FractionBox["1", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"2", "n"}], ")"}], "!"}]], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], "n"], 
       SuperscriptBox["y", 
        RowBox[{"2", "n"}]]}]}], " ", "+", 
     RowBox[{"\[ImaginaryI]", 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"n", "=", "0"}], "\[Infinity]"], 
       RowBox[{
        FractionBox["1", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", "n"}], "+", "1"}], ")"}], "!"}]], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"-", "1"}], ")"}], "n"], " ", 
        SuperscriptBox["y", 
         RowBox[{
          RowBox[{"2", "n"}], "+", "1"}]]}]}]}]}]}], "     ", "//", 
   "ComplexExpand"}]}]], "Input",
 CellChangeTimes->{3.39897176*^9, 3.40023671425*^9}]
}, Closed]],

Cell[TextData[{
 "\tThus, it seems the only possible value for ",
 Cell[BoxData[
  SuperscriptBox["\[ExponentialE]", "z"]]],
 " is  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[ExponentialE]", "z"], " ", "=", " ", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", "x"], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"cos", " ", "y"}], " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", "sin", " ", "y"}]}], ")"}]}]}]]],
 ".  We will use this result freely from now on, and, as stated, supply a \
rigorous proof in Chapter 5."
}], "Text"],

Cell[TextData[{
 "If we set ",
 StyleBox["x=0",
  FontFamily->"Courier New"],
 " and let ",
 Cell[BoxData["\[Theta]"]],
 " take the role of ",
 StyleBox["y",
  FontFamily->"Courier New"],
 " in the above equation, we get a famous result known as ",
 StyleBox[ButtonBox["Euler Formula",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/EulerFormula.html"], None}],
  FontVariations->{"Underline"->True}],
 ": \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["e", "\[ImaginaryI]\[Theta]"], " ", "=", "  ", 
   RowBox[{
    RowBox[{
     RowBox[{"cos", " ", "\[Theta]"}], " ", "+", " ", 
     RowBox[{"i", " ", "sin", " ", "\[Theta]"}]}], " ", "=", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"cos", " ", "\[Theta]"}], " ", ",", 
      RowBox[{"sin", " ", "\[Theta]"}]}], ")"}]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "\tIf ",
 Cell[BoxData["\[Theta]"]],
 " is a real number, ",
 Cell[BoxData[
  SuperscriptBox["e", "\[ImaginaryI]\[Theta]"]]],
 " will be located somewhere on the circle with radius ",
 StyleBox["1",
  FontFamily->"Courier New"],
 " centered at the origin.  This assertion is easy to verify because   \n\n\t\
\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", 
    SuperscriptBox["e", "\[ImaginaryI]\[Theta]"], "|"}], " ", "=", " ", 
   RowBox[{
    SqrtBox[
     RowBox[{
      RowBox[{
       SuperscriptBox["cos", "2"], " ", "\[Theta]"}], " ", "+", " ", 
      RowBox[{
       SuperscriptBox["sin", "2"], " ", "\[Theta]"}]}]], " ", "=", " ", 
    "1"}]}]]],
 ".  \n\nFigure 1.12 illustrates the location of the points ",
 Cell[BoxData[
  SuperscriptBox["e", "\[ImaginaryI]\[Theta]"]]],
 " for various values of ",
 Cell[BoxData["\[Theta]"]],
 "."
}], "Text"],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{395, 312},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 "\tNotice that, when ",
 Cell[BoxData[
  RowBox[{"\[Theta]", "=", "\[Pi]"}]]],
 ", we get  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["e", "\[ImaginaryI]\[Pi]"], "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"cos", " ", "\[Pi]"}], " ", ",", 
      RowBox[{"sin", " ", "\[Pi]"}]}], ")"}], "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], " ", ",", "0"}], ")"}], "=", 
     RowBox[{"-", "1"}]}]}]}]]],
 ",  so\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["e", "\[ImaginaryI]\[Pi]"], "+", "1"}], "=", "0"}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "\t",
 StyleBox[ButtonBox["Euler",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Euler.\
html"], None}],
  FontVariations->{"Underline"->True}],
 " was the first to discover this relationship;  it is referred to as Euler's \
identity.  It has been labeled by many mathematicians as the most amazing \
relation in analysis---and with good reason.  Symbols with a rich history are \
miraculously woven together---the constant  used by Hippocrates as early as \
",
 StyleBox[ButtonBox["Hippocrates",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/\
Hippocrates.html"], None}],
  FontVariations->{"Underline"->True}],
 " as early as 400 B.C.;  ",
 Cell[BoxData["e"]],
 " the base of the natural logarithms;  the basic concepts of addition (+) \
and equality (=);  the foundational whole numbers 0 and 1;  and ",
 Cell[BoxData["\[ImaginaryI]"]],
 ", the number that is the central focus of this book."
}], "Text"],

Cell[TextData[{
 "\tEuler's formula is of tremendous use in establishing important algebraic \
and geometric properties of complex numbers.  You will see shortly that it \
enables you to multiply complex numbers with great ease. It also allows you \
to express a polar form of the complex number z in a more compact way.  \
Recall that if  ",
 Cell[BoxData[
  RowBox[{"r", " ", "=", 
   RowBox[{"|", "z", "|"}]}]]],
 " and  ",
 Cell[BoxData[
  RowBox[{"\[Theta]", " ", "\[Element]", 
   RowBox[{"arg", " ", "z"}]}]]],
 ",  then  ",
 Cell[BoxData[
  RowBox[{"z", " ", "=", 
   RowBox[{"r", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"cos", " ", "\[Theta]"}], " ", "+", " ", 
      RowBox[{"i", " ", "sin", " ", "\[Theta]"}]}], ")"}]}]}]]],
 ".  Using Euler's formula we can now write ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " in its",
 StyleBox[" ",
  FontSlant->"Italic"],
 StyleBox[ButtonBox["exponential form",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/Phasor.html"], None}],
  FontVariations->{"Underline"->True}],
 ":  \n\t\n\t\t\t",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{"r", " ", 
    SuperscriptBox["e", "\[ImaginaryI]\[Theta]"]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 StyleBox["Example 1.12.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  In example 1.10 we investigated the polar form of  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{
    RowBox[{"-", " ", 
     SqrtBox["3"]}], "-", "\[ImaginaryI]"}]}]],
  AspectRatioFixed->True],
 ",  and saw that ",
 Cell[BoxData[
  RowBox[{"r", "=", "2"}]]],
 "   and  ",
 Cell[BoxData[
  RowBox[{"\[Theta]", "=", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"5", "\[Pi]"}], "6"]}]}]]],
 ".  Now we have \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"z", " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"-", " ", 
      SqrtBox["3"]}], "-", "\[ImaginaryI]"}], " ", "=", " ", 
    RowBox[{
     RowBox[{"2", " ", 
      SuperscriptBox["e", 
       RowBox[{"\[ImaginaryI]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], 
          RowBox[{"\[Pi]", "/", "6"}]}], ")"}]}]]}], " ", "=", " ", 
     RowBox[{"2", " ", 
      SuperscriptBox["e", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], 
        FractionBox[
         RowBox[{"5", "  ", "\[Pi]"}], "6"]}]]}]}]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 1.12.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"e", ",", "\[Theta]", ",", "r", ",", "z"}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"z", " ", "=", " ", 
     RowBox[{
      RowBox[{"-", " ", 
       SqrtBox["3"]}], " ", "-", " ", "\[ImaginaryI]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"r", " ", "=", " ", 
     RowBox[{"Abs", "[", "z", "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"\[Theta]", "=", 
     RowBox[{"Arg", "[", "z", "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Z", "=", 
     RowBox[{"r", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", "+", " ", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], ")"}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"V", " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"Arrowheads", "[", 
         RowBox[{"{", 
          RowBox[{"0.0", ",", "0.06"}], "}"}], "]"}], ",", 
        RowBox[{"Thickness", "[", "0.006", "]"}], ",", 
        RowBox[{"Arrow", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", "z", "]"}], ",", 
             RowBox[{"Im", "[", "z", "]"}]}], "}"}]}], "}"}], "]"}]}], "}"}], 
      "]"}]}], ";"}], " ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{"V", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "0", ",", 
          FractionBox["1", "2"]}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "0", ",", 
          FractionBox["1", "2"]}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["1", "2"]}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<z = \>\"", ",", "z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<r = |z| = \>\"", ",", "r"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Theta] = Arg[z] = \>\"", ",", "\[Theta]"}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<z = r \!\(\*SuperscriptBox[\(e\), \(\"\<i\[Theta]\>\"\)]\)\>\"", 
     " ", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<z = \>\"", ",", "r", ",", "\"\< \>\"", ",", 
      SuperscriptBox["e", 
       RowBox[{"i", " ", "\[Theta]"}]]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<z = \>\"", ",", "Z"}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<z = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", "Z", "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.398971775171875*^9, 3.39897177665625*^9}, {
  3.3997094945*^9, 3.399709520859375*^9}, {3.400236737015625*^9, 
  3.4002367379375*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 "\tTogether with the rules for exponentiation that we will verify in Chapter \
5, the exponential form has interesting applications.  If ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], "=", 
   RowBox[{
    SubscriptBox["r", "1"], 
    SuperscriptBox["\[ExponentialE]", 
     SubscriptBox["\[ImaginaryI]\[Theta]", "1"]]}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "2"], "=", 
   RowBox[{
    SubscriptBox["r", "2"], 
    SuperscriptBox["\[ExponentialE]", 
     SubscriptBox["\[ImaginaryI]\[Theta]", "2"]]}]}]]],
 ", then  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["z", "1"], 
     SubscriptBox["z", "2"]}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      SubscriptBox["r", "1"], 
      SuperscriptBox["\[ExponentialE]", 
       SubscriptBox["\[ImaginaryI]\[Theta]", "1"]], 
      SubscriptBox["r", "2"], 
      SuperscriptBox["\[ExponentialE]", 
       SubscriptBox["\[ImaginaryI]\[Theta]", "2"]]}], " ", "=", "  ", 
     RowBox[{
      SubscriptBox["r", "1"], 
      SubscriptBox["r", "2"], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Theta]", "1"], "+", 
          SubscriptBox["\[Theta]", "2"]}], ")"}]}]]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"          ", 
   RowBox[{"=", 
    RowBox[{
     SubscriptBox["r", "1"], 
     SubscriptBox["r", "2"], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"cos", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Theta]", "1"], "+", 
          SubscriptBox["\[Theta]", "2"]}], ")"}]}], "+", 
       RowBox[{"\[ImaginaryI]", " ", "sin", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Theta]", "1"], "+", 
          SubscriptBox["\[Theta]", "2"]}], ")"}]}]}], ")"}]}]}]}]}]],
 "  \n\n Figure 1.13 illustrates the geometric significance of this \
equation."
}], "Text"],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{426, 221},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 "\tWe have already seen that the modulus of the product is the product of \
the moduli;  that is, ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", 
    RowBox[{
     SubscriptBox["z", "1"], 
     SubscriptBox["z", "2"]}], "|"}], "=", 
   RowBox[{"|", 
    RowBox[{
     SubscriptBox["z", "1"], "||", 
     SubscriptBox["z", "2"]}], "|"}]}]]],
 ".  The above identity establishes that an argument of  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], 
   SubscriptBox["z", "2"]}]]],
 "  is an argument of ",
 Cell[BoxData[
  SubscriptBox["z", "1"]]],
 " plus an argument of ",
 Cell[BoxData[
  SubscriptBox["z", "2"]]],
 ".  It also answers the question posed at the end of Section 1.3 regarding \
why the product ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], 
   SubscriptBox["z", "2"]}]]],
 " was in a different quadrant than either ",
 Cell[BoxData[
  SubscriptBox["z", "1"]]],
 " or ",
 Cell[BoxData[
  SubscriptBox["z", "2"]]],
 ".  It further offers an interesting explanation as to why the product of \
two negative real numbers is a positive real number.  The negative numbers, \
each of which has an angular displacement of ",
 Cell[BoxData["\[Pi]"]],
 " radians, combine to produce a product that is rotated to a point with an \
argument of  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Pi]", "+", "\[Pi]"}], "=", 
   RowBox[{"2", "\[Pi]"}]}]]],
 "  radians, coinciding with the positive real axis."
}], "Text"],

Cell[TextData[{
 "\tUsing exponential form, if ",
 Cell[BoxData[
  RowBox[{"z", "\[NotEqual]", "0"}]]],
 ", we can write  ",
 Cell[BoxData[
  RowBox[{"arg", " ", "z"}]]],
 ",  a little more compactly as \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"arg", " ", "z"}], " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Theta]", ":", " ", "z"}], "=", 
     RowBox[{"r", " ", 
      SuperscriptBox["\[ExponentialE]", "\[ImaginaryI]\[Theta]"]}]}], 
    "}"}]}]]],
 ".  \n\n",
 "Doing so enables us to see a nice relationship between the sets",
 " ",
 Cell[BoxData[
  RowBox[{"arg", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["z", "1"], 
     SubscriptBox["z", "2"]}], ")"}]}]]],
 ", ",
 Cell[BoxData[
  RowBox[{"arg", 
   RowBox[{"(", 
    SubscriptBox["z", "1"], ")"}]}]]],
 ", and ",
 Cell[BoxData[
  RowBox[{"arg", 
   RowBox[{"(", 
    SubscriptBox["z", "2"], ")"}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 StyleBox["Theorem 1.3.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  If  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], "=", 
   RowBox[{
    RowBox[{
     SubscriptBox["r", "1"], 
     SuperscriptBox["\[ExponentialE]", 
      SubscriptBox["\[ImaginaryI]\[Theta]", "1"]]}], "\[NotEqual]", 
    "0"}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "2"], "=", 
   RowBox[{
    RowBox[{
     SubscriptBox["r", "2"], 
     SuperscriptBox["\[ExponentialE]", 
      SubscriptBox["\[ImaginaryI]\[Theta]", "2"]]}], "\[NotEqual]", 
    "0"}]}]]],
 ",  then as sets,\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"arg", 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["z", "1"], 
      SubscriptBox["z", "2"]}], ")"}]}], "=", 
   RowBox[{
    RowBox[{"arg", 
     RowBox[{"(", 
      SubscriptBox["z", "1"], ")"}]}], "+", 
    RowBox[{"arg", 
     RowBox[{"(", 
      SubscriptBox["z", "2"], ")"}]}]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "\tBefore proceeding with the proof, we recall two important facts about \
sets.  First, to establish the equality of two sets, we must show that each \
is a subset of the other.  Second, the sum of two sets is the sum of all \
combinations of elements from the first and second sets, respectively.  In \
this case,  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"arg", 
     RowBox[{"(", 
      SubscriptBox["z", "1"], ")"}]}], "+", 
    RowBox[{"arg", 
     RowBox[{"(", 
      SubscriptBox["z", "2"], ")"}]}]}], " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["\[Theta]", "1"], "+", 
     RowBox[{
      SubscriptBox["\[Theta]", "2"], ":", " ", 
      RowBox[{
       SubscriptBox["\[Theta]", "1"], "\[Element]", 
       RowBox[{"arg", 
        RowBox[{"(", 
         SubscriptBox["z", "1"], ")"}], "  ", 
        StyleBox["and",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], "   ", 
        SubscriptBox["\[Theta]", "2"]}], "\[Element]", 
       RowBox[{"arg", 
        RowBox[{"(", 
         SubscriptBox["z", "2"], ")"}]}]}]}]}], "}"}]}]]],
 "."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Proof",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 "  Let  ",
 Cell[BoxData[
  RowBox[{"\[Theta]", "\[Element]", 
   RowBox[{"arg", 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["z", "1"], 
      SubscriptBox["z", "2"]}], ")"}]}]}]]],
 ".  Because  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["z", "1"], 
    SubscriptBox["z", "2"]}], "=", " ", 
   RowBox[{
    SubscriptBox["r", "1"], 
    SubscriptBox["r", "2"], 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["\[Theta]", "1"], "+", 
        SubscriptBox["\[Theta]", "2"]}], ")"}]}]]}]}]]],
 ",  it follows that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["\[Theta]", "1"], "+", 
    SubscriptBox["\[Theta]", "2"]}], "\[Element]", 
   RowBox[{"arg", 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["z", "1"], 
      SubscriptBox["z", "2"]}], ")"}]}]}]]],
 ".  Hence, there is some integer ",
 StyleBox["n",
  FontFamily->"Courier New"],
 " such that  ",
 Cell[BoxData[
  RowBox[{"\[Theta]", " ", "=", " ", 
   RowBox[{
    SubscriptBox["\[Theta]", "1"], "+", 
    SubscriptBox["\[Theta]", "2"], "+", 
    RowBox[{"2", "n", " ", "\[Pi]"}]}]}]]],
 ".  Further, as  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], "=", 
   RowBox[{
    SubscriptBox["r", "1"], 
    SuperscriptBox["\[ExponentialE]", 
     SubscriptBox["\[ImaginaryI]\[Theta]", "1"]]}]}]]],
 "  we have  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["\[Theta]", "1"], "\[Element]", 
   RowBox[{"arg", 
    RowBox[{"(", 
     SubscriptBox["z", "1"], ")"}]}]}]]],
 ".  Likewise,  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "2"], "=", 
   RowBox[{
    SubscriptBox["r", "2"], 
    SuperscriptBox["\[ExponentialE]", 
     SubscriptBox["\[ImaginaryI]\[Theta]", "2"]]}]}]]],
 "  gives  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["\[Theta]", "2"], "\[Element]", 
   RowBox[{"arg", 
    RowBox[{"(", 
     SubscriptBox["z", "2"], ")"}]}]}]]],
 ".  But if  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["\[Theta]", "2"], "\[Element]", 
   RowBox[{"arg", 
    RowBox[{"(", 
     SubscriptBox["z", "2"], ")"}]}]}]]],
 ",  then  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["\[Theta]", "2"], "+", 
    RowBox[{"2", "n", " ", "\[Pi]"}]}], "\[Element]", 
   RowBox[{"arg", 
    RowBox[{"(", 
     SubscriptBox["z", "2"], ")"}]}]}]]],
 ".  This result shows that  ",
 Cell[BoxData[
  RowBox[{"\[Theta]", " ", "=", " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Theta]", "1"], "+", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Theta]", "2"], "+", 
       RowBox[{"2", "n", " ", "\[Pi]"}]}], ")"}]}], "\[Element]", 
    RowBox[{
     RowBox[{"arg", 
      RowBox[{"(", 
       SubscriptBox["z", "1"], ")"}]}], "+", 
     RowBox[{"arg", 
      RowBox[{"(", 
       SubscriptBox["z", "1"], ")"}]}]}]}]}]]],
 ".  Thus,  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"arg", 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["z", "1"], 
      SubscriptBox["z", "2"]}], ")"}]}], " ", "\[Subset]", " ", 
   RowBox[{
    RowBox[{"arg", 
     RowBox[{"(", 
      SubscriptBox["z", "1"], ")"}]}], "+", 
    RowBox[{"arg", 
     RowBox[{"(", 
      SubscriptBox["z", "2"], ")"}]}]}]}]]],
 ".  The proof that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"arg", 
     RowBox[{"(", 
      SubscriptBox["z", "1"], ")"}]}], "+", 
    RowBox[{"arg", 
     RowBox[{"(", 
      SubscriptBox["z", "2"], ")"}]}]}], " ", "\[Subset]", " ", 
   RowBox[{"arg", 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["z", "1"], 
      SubscriptBox["z", "2"]}], ")"}]}]}]]],
 "  is left as an exercise."
}], "Text"],

Cell[TextData[{
 "\tUsing the exponential form,  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{"r", " ", 
    SuperscriptBox["e", "\[ImaginaryI]\[Theta]"]}]}]]],
 ",  we see that  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["z", 
    RowBox[{"-", "1"}]], "=", 
   RowBox[{
    FractionBox["1", "z"], "=", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"r", " ", 
       SuperscriptBox["e", "\[ImaginaryI]\[Theta]"]}]], "=", 
     RowBox[{
      FractionBox["1", "r"], 
      SuperscriptBox["e", 
       RowBox[{"-", "\[ImaginaryI]\[Theta]"}]]}]}]}]}]]],
 ".  In other words,\n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    SuperscriptBox["z", 
     RowBox[{"-", "1"}]], " ", "=", " ", 
    RowBox[{
     FractionBox["1", "r"], "[", 
     RowBox[{
      RowBox[{"cos", 
       RowBox[{"(", 
        RowBox[{"-", "\[Theta]"}], ")"}]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", "sin", " ", 
       RowBox[{"(", 
        RowBox[{"-", "\[Theta]"}], ")"}]}]}], "]"}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"       ", 
   RowBox[{"=", " ", 
    RowBox[{
     FractionBox["1", "r"], 
     SuperscriptBox["e", 
      RowBox[{"-", "\[ImaginaryI]\[Theta]"}]]}]}]}]}]],
 "    "
}], "Text"],

Cell[TextData[{
 "Recalling that ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"cos", 
    RowBox[{"(", 
     RowBox[{"-", "\[Theta]"}], ")"}]}], "=", 
   RowBox[{"cos", 
    RowBox[{"(", "\[Theta]", ")"}]}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"sin", 
    RowBox[{"(", 
     RowBox[{"-", "\[Theta]"}], ")"}]}], "=", 
   RowBox[{
    RowBox[{"-", "sin"}], 
    RowBox[{"(", "\[Theta]", ")"}]}]}]]],
 ", we also have  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    OverscriptBox[
     RowBox[{"z", " "}], "_"], "  ", "=", " ", 
    RowBox[{
     RowBox[{"r", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"cos", " ", "\[Theta]"}], " ", "-", " ", 
        RowBox[{"\[ImaginaryI]", " ", "sin", " ", "\[Theta]"}]}], ")"}]}], 
     " ", "=", "  ", 
     RowBox[{"r", "[", 
      RowBox[{
       RowBox[{"cos", " ", 
        RowBox[{"(", 
         RowBox[{"-", "\[Theta]"}], ")"}]}], " ", "+", " ", 
       RowBox[{"\[ImaginaryI]", " ", "sin", 
        RowBox[{"(", 
         RowBox[{"-", " ", "\[Theta]"}], ")"}]}]}], "]"}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"     ", 
   RowBox[{"=", " ", 
    RowBox[{"r", " ", 
     SuperscriptBox["e", 
      RowBox[{"-", "\[ImaginaryI]\[Theta]"}]]}]}]}]}]],
 "  \n\t\n\tand\n\n  \t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    FractionBox[
     SubscriptBox["z", "1"], 
     SubscriptBox["z", "2"]], " ", "=", " ", 
    RowBox[{
     FractionBox[
      SubscriptBox["r", "1"], 
      SubscriptBox["r", "2"]], "[", 
     RowBox[{
      RowBox[{"cos", " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Theta]", "1"], "-", 
         SubscriptBox["\[Theta]", "2"]}], ")"}]}], " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", "sin", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Theta]", "1"], "-", 
         SubscriptBox["\[Theta]", "2"]}], ")"}]}]}], "]"}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"       ", 
   RowBox[{"=", " ", 
    RowBox[{
     FractionBox[
      SubscriptBox["r", "1"], 
      SubscriptBox["r", "2"]], 
     SuperscriptBox["e", 
      RowBox[{"\[ImaginaryI]", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Theta]", "1"], "-", 
         SubscriptBox["\[Theta]", "2"]}], ")"}]}]]}]}]}]}]],
 "  "
}], "Text"],

Cell[TextData[{
 "If ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " is in the first quadrant, the positions of the numbers  ",
 Cell[BoxData[
  RowBox[{"z", ",", 
   OverscriptBox[
    RowBox[{"z", " "}], "_"], ",", 
   RowBox[{
    StyleBox["and",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], "  ", 
    SuperscriptBox["z", 
     RowBox[{"-", "1"}]]}]}]]],
 "  are as shown in Figure 1.14 when  ",
 Cell[BoxData[
  RowBox[{"|", "z", "|", 
   RowBox[{"<", "1"}]}]]],
 ".  Figure 1.15 depicts the situation when  ",
 Cell[BoxData[
  RowBox[{"|", "z", "|", 
   RowBox[{">", "1"}]}]]],
 ". "
}], "Text"],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{452, 272},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{462, 262},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 StyleBox["Example 1.13.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  If  ",
 Cell[BoxData[
  RowBox[{"z", " ", "=", " ", 
   RowBox[{"1", "+", "\[ImaginaryI]"}]}]]],
 ",  then  ",
 Cell[BoxData[
  RowBox[{"r", "=", 
   RowBox[{
    RowBox[{"|", 
     RowBox[{"1", "+", "\[ImaginaryI]"}], "|"}], "=", 
    RowBox[{
     SqrtBox[
      RowBox[{"1", "+", "1"}]], "=", 
     SqrtBox["2"]}]}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{"\[Theta]", "=", 
   RowBox[{
    RowBox[{"Arg", 
     RowBox[{"(", "z", ")"}]}], "=", 
    RowBox[{
     RowBox[{"Arg", 
      RowBox[{"(", 
       RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}]}], "=", 
     FractionBox["\[Pi]", "4"]}]}]}]]],
 ".  Therefore  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    SuperscriptBox["z", 
     RowBox[{"-", "1"}]], "=", " ", 
    RowBox[{
     FractionBox["1", "r"], 
     SuperscriptBox["e", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", 
       RowBox[{"\[Pi]", "/", "4"}]}]]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"      ", 
   RowBox[{"=", " ", 
    RowBox[{
     FractionBox["1", 
      SqrtBox["2"]], "[", 
     RowBox[{
      RowBox[{"cos", 
       RowBox[{"(", 
        RowBox[{"-", 
         FractionBox["\[Pi]", "4"]}], ")"}]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", "sin", " ", 
       RowBox[{"(", 
        RowBox[{"-", 
         FractionBox["\[Pi]", "4"]}], ")"}]}]}], 
     "]"}]}]}], "\[IndentingNewLine]", 
  RowBox[{"      ", 
   RowBox[{
    RowBox[{"=", " ", 
     RowBox[{
      FractionBox["1", 
       SqrtBox["2"]], 
      RowBox[{"(", " ", 
       RowBox[{
        FractionBox[
         SqrtBox["2"], "2"], "-", 
        RowBox[{"\[ImaginaryI]", 
         FractionBox[
          SqrtBox["2"], "2"]}]}], ")"}]}]}], " ", 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"      ", 
   RowBox[{"=", " ", 
    RowBox[{
     FractionBox["1", "2"], "-", 
     FractionBox["\[ImaginaryI]", "2"]}]}]}]}]],
 "\n\nthe modulus is  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", 
    SuperscriptBox["z", 
     RowBox[{"-", "1"}]], "|"}], "=", 
   RowBox[{
    SqrtBox[
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        FractionBox["1", "2"], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        FractionBox["1", "2"], ")"}], "2"]}]], "=", 
    RowBox[{
     FractionBox[
      SqrtBox["2"], "2"], "=", 
     RowBox[{
      FractionBox["1", 
       SqrtBox["2"]], "=", 
      FractionBox["1", 
       RowBox[{"|", "z", "|"}]]}]}]}]}]]],
 ",  and the argument is  ",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{
    RowBox[{"Arg", 
     RowBox[{"(", 
      SuperscriptBox["z", 
       RowBox[{"-", "1"}]], ")"}]}], "=", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["\[Pi]", "4"]}], "=", 
     RowBox[{
      RowBox[{"-", "Arg"}], 
      RowBox[{"(", "z", ")"}]}]}]}]}]]],
 "."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 1.13.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "Enter  ",
 Cell[BoxData[
  RowBox[{"z", " ", "=", " ", 
   RowBox[{"1", " ", "+", "\[ImaginaryI]"}]}]]],
 "  and compute ",
 Cell[BoxData[
  FractionBox["1", "z"]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"r", ",", "w", ",", "z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"z", " ", "=", " ", 
     RowBox[{"1", "+", "\[ImaginaryI]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"r", " ", "=", " ", 
     RowBox[{"Abs", "[", "z", "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "1"], " ", "=", " ", 
     RowBox[{"Conjugate", "[", "z", "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "2"], " ", "=", " ", 
     FractionBox[
      RowBox[{"Conjugate", "[", "z", "]"}], "r"]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "3"], " ", "=", " ", 
     RowBox[{
      FractionBox["1", "r"], " ", 
      FractionBox[
       RowBox[{"Conjugate", "[", "z", "]"}], "r"]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"w", "=", 
     RowBox[{"ComplexExpand", "[", 
      FractionBox["1", "z"], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["V", "1"], " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"Arrowheads", "[", 
         RowBox[{"{", 
          RowBox[{"0.0", ",", "0.06"}], "}"}], "]"}], ",", 
        RowBox[{"Thickness", "[", "0.006", "]"}], ",", 
        RowBox[{"Arrow", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", "z", "]"}], ",", 
             RowBox[{"Im", "[", "z", "]"}]}], "}"}]}], "}"}], "]"}]}], "}"}], 
      "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["V", "2"], " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", 
        RowBox[{"Arrowheads", "[", 
         RowBox[{"{", 
          RowBox[{"0.0", ",", "0.06"}], "}"}], "]"}], ",", 
        RowBox[{"Thickness", "[", "0.006", "]"}], ",", 
        RowBox[{"Arrow", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", "w", "]"}], ",", 
             RowBox[{"Im", "[", "w", "]"}]}], "}"}]}], "}"}], "]"}]}], "}"}], 
      "]"}]}], ";"}], " ", "\n", 
   RowBox[{"g1", "=", 
    RowBox[{"Show", "[", 
     RowBox[{
      SubscriptBox["V", "1"], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "0.1"}], ",", "1.1"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "0.1"}], ",", "1.1"}], "}"}]}], "}"}]}], ",", 
      RowBox[{"Ticks", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Range", "[", 
          RowBox[{"0", ",", "5", ",", "1"}], "]"}], ",", 
         RowBox[{"Range", "[", 
          RowBox[{"0", ",", "12", ",", "1"}], "]"}]}], "}"}]}], ",", 
      RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
      RowBox[{"Axes", "\[Rule]", "True"}], ",", 
      RowBox[{"AxesLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}]}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< z = \>\"", ",", "z"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< \!\(\*OverscriptBox[\(z\), \(_\)]\) = \>\"", ",", 
      SubscriptBox["z", "1"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< r = |z| = \>\"", ",", "r"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*FractionBox[OverscriptBox[\(z\), \(_\)], \(r\)]\) = \>\"", 
      ",", 
      SubscriptBox["z", "2"]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<  \!\(\*FractionBox[\(1\), \(z\)]\) = \!\(\*FractionBox[\(1\), \
\(r\)]\)\!\(\*FractionBox[OverscriptBox[\(z\), \(_\)], \(r\)]\)\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  \!\(\*FractionBox[\(1\), \(z\)]\) = \>\"", ",", 
      FractionBox["1", "r"], ",", 
      FractionBox[
       RowBox[{"Conjugate", "[", "z", "]"}], "r"]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  \!\(\*FractionBox[\(1\), \(z\)]\) = \>\"", ",", 
      SubscriptBox["z", "3"]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{"g2", "=", 
    RowBox[{"Show", "[", 
     RowBox[{
      SubscriptBox["V", "2"], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "0.1"}], ",", "1.1"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "1.1"}], ",", "0.1"}], "}"}]}], "}"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Ticks", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Range", "[", 
          RowBox[{"0", ",", "1", ",", 
           FractionBox["1", "2"]}], "]"}], ",", 
         RowBox[{"Range", "[", 
          RowBox[{
           RowBox[{"-", "1"}], ",", "0", ",", 
           FractionBox["1", "2"]}], "]"}]}], "}"}]}], ",", 
      RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
      RowBox[{"Axes", "\[Rule]", "True"}], ",", 
      RowBox[{"AxesLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}]}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{
  3.398971792234375*^9, {3.399709541703125*^9, 3.3997095820625*^9}, {
   3.399709618*^9, 3.39970962759375*^9}, {3.399709743015625*^9, 
   3.3997097634375*^9}, {3.400236748234375*^9, 3.400236749359375*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Show", "[", 
    RowBox[{"g1", ",", "g2", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0"}], ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.5"}], ",", "1"}], "}"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "1", ",", 
          FractionBox["1", "2"]}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "0", ",", 
          FractionBox["1", "2"]}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["3", "2"]}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  z  =  \>\"", ",", "z", ",", "\"\<\\n\>\""}], "]"}], ";"}],
    " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< \!\(\*FractionBox[\(1\), \(z\)]\)  =  \>\"", ",", 
      SubscriptBox["z", "3"]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39970979484375*^9, 3.39970997021875*^9}, {
  3.40023677178125*^9, 3.400236779609375*^9}}]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 1.14.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Given  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], "=", 
   RowBox[{
    RowBox[{"8", "\[ImaginaryI]", "  ", "and", "  ", 
     SubscriptBox["z", "2"]}], "=", 
    RowBox[{"1", "+", 
     RowBox[{"\[ImaginaryI]", " ", 
      SqrtBox["3"]}]}]}]}]]],
 ",  compute  ",
 Cell[BoxData[
  FractionBox[
   SubscriptBox["z", "1"], 
   SubscriptBox["z", "2"]]]],
 "  using polar computations.\n\nIf  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], "=", 
   RowBox[{"8", "\[ImaginaryI]"}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "2"], "=", 
   RowBox[{"1", "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     SqrtBox["3"]}]}]}]]],
 ",  then representative polar forms for these numbers are  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], "=", 
   RowBox[{"8", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"cos", 
       FractionBox["\[Pi]", "2"]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", "sin", 
       FractionBox["\[Pi]", "2"]}]}], ")"}]}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "2"], "=", 
   RowBox[{"2", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"cos", 
       FractionBox["\[Pi]", "3"]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", "sin", 
       FractionBox["\[Pi]", "3"]}]}], ")"}]}]}]]],
 ".  Hence  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    FractionBox[
     SubscriptBox["z", "1"], 
     SubscriptBox["z", "2"]], "=", " ", 
    RowBox[{
     FractionBox["8", "2"], 
     SuperscriptBox["e", 
      RowBox[{"\[ImaginaryI]", 
       RowBox[{"(", 
        RowBox[{
         FractionBox["\[Pi]", "2"], "-", 
         FractionBox["\[Pi]", "3"]}], ")"}]}]]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"      ", 
   RowBox[{
    RowBox[{"=", " ", 
     RowBox[{
      FractionBox["8", "2"], "[", 
      RowBox[{
       RowBox[{"cos", " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox["\[Pi]", "2"], "-", 
          FractionBox["\[Pi]", "3"]}], ")"}]}], " ", "+", " ", 
       RowBox[{"\[ImaginaryI]", " ", "sin", 
        RowBox[{"(", 
         RowBox[{
          FractionBox["\[Pi]", "2"], "-", 
          FractionBox["\[Pi]", "3"]}], ")"}]}]}], "]"}]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"      ", 
   RowBox[{
    RowBox[{"=", " ", 
     RowBox[{"4", "[", 
      RowBox[{
       RowBox[{"cos", " ", 
        RowBox[{"(", 
         FractionBox["\[Pi]", "6"], ")"}]}], " ", "+", " ", 
       RowBox[{"\[ImaginaryI]", " ", "sin", 
        RowBox[{"(", 
         FractionBox["\[Pi]", "6"], ")"}]}]}], "]"}]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"      ", 
   RowBox[{"=", " ", 
    RowBox[{
     RowBox[{"2", " ", 
      SqrtBox["3"]}], "+", 
     RowBox[{"2", " ", "\[ImaginaryI]"}]}]}]}]}]],
 "    \n\nthe modulus is  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", 
    FractionBox[
     SubscriptBox["z", "1"], 
     SubscriptBox["z", "2"]], "|"}], "=", 
   RowBox[{
    FractionBox["8", "2"], "=", 
    FractionBox[
     RowBox[{"|", 
      SubscriptBox["z", "1"], "|"}], 
     RowBox[{"|", 
      SubscriptBox["z", "2"], "|"}]]}]}]]],
 ",  and the argument is ",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{
    RowBox[{"Arg", 
     RowBox[{"(", 
      FractionBox[
       SubscriptBox["z", "1"], 
       SubscriptBox["z", "2"]], ")"}]}], "=", 
    RowBox[{
     FractionBox["\[Pi]", "6"], "=", 
     RowBox[{
      RowBox[{
       FractionBox["\[Pi]", "2"], "-", 
       FractionBox["\[Pi]", "3"]}], "=", 
      RowBox[{
       RowBox[{"Arg", 
        RowBox[{"(", 
         SubscriptBox["z", "1"], ")"}]}], "-", 
       RowBox[{"Arg", 
        RowBox[{"(", 
         SubscriptBox["z", "2"], ")"}]}]}]}]}]}]}]]],
 ". "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Caveat.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]],
 "  The formula  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Arg", 
    RowBox[{"(", 
     FractionBox[
      SubscriptBox["z", "1"], 
      SubscriptBox["z", "2"]], ")"}]}], "=", 
   RowBox[{
    RowBox[{"Arg", 
     RowBox[{"(", 
      SubscriptBox["z", "1"], ")"}]}], "-", 
    RowBox[{"Arg", 
     RowBox[{"(", 
      SubscriptBox["z", "2"], ")"}]}]}]}]]],
 " does not hold for all complex numbers ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], "  ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "  ", 
   SubscriptBox["z", "2"]}]]],
 ".  Whereas, the formula  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"arg", 
    RowBox[{"(", 
     FractionBox[
      SubscriptBox["z", "1"], 
      SubscriptBox["z", "2"]], ")"}]}], "=", 
   RowBox[{
    RowBox[{"arg", 
     RowBox[{"(", 
      SubscriptBox["z", "1"], ")"}]}], "-", 
    RowBox[{"arg", 
     RowBox[{"(", 
      SubscriptBox["z", "2"], ")"}]}]}]}]]],
 "  does hold for all complex numbers ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], "  ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "  ", 
   SubscriptBox["z", "2"]}]]],
 ", and is left for the reader to verify. "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 1.14.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "Enter  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], "=", 
   RowBox[{
    RowBox[{"8", "\[ImaginaryI]", "  ", "and", "  ", 
     SubscriptBox["z", "2"]}], "=", 
    RowBox[{"1", "+", 
     RowBox[{"\[ImaginaryI]", " ", 
      SqrtBox["3"]}]}]}]}]]],
 "   and compute ",
 Cell[BoxData[
  FractionBox[
   SubscriptBox["z", "1"], 
   SubscriptBox["z", "2"]]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"\[Theta]", ",", "r", ",", "w", ",", "z"}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "1"], "=", 
     RowBox[{"8", "\[ImaginaryI]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "2"], "=", 
     RowBox[{"1", "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SqrtBox["3"]}]}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["w", "3"], "=", 
     RowBox[{"ComplexExpand", "[", 
      FractionBox[
       SubscriptBox["z", "1"], 
       SubscriptBox["z", "2"]], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"v1", " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"Arrowheads", "[", 
         RowBox[{"{", 
          RowBox[{"0.0", ",", "0.1"}], "}"}], "]"}], ",", 
        RowBox[{"Thickness", "[", "0.016", "]"}], ",", 
        RowBox[{"Arrow", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["z", "1"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["z", "1"], "]"}]}], "}"}]}], "}"}], "]"}]}], "}"}],
       "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"v2", " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Green", ",", 
        RowBox[{"Arrowheads", "[", 
         RowBox[{"{", 
          RowBox[{"0.0", ",", "0.1"}], "}"}], "]"}], ",", 
        RowBox[{"Thickness", "[", "0.01", "]"}], ",", 
        RowBox[{"Arrow", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["z", "2"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["z", "2"], "]"}]}], "}"}]}], "}"}], "]"}]}], "}"}],
       "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"v3", " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", 
        RowBox[{"Arrowheads", "[", 
         RowBox[{"{", 
          RowBox[{"0.0", ",", "0.1"}], "}"}], "]"}], ",", 
        RowBox[{"Thickness", "[", "0.01", "]"}], ",", 
        RowBox[{"Arrow", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["w", "3"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["w", "3"], "]"}]}], "}"}]}], "}"}], "]"}]}], "}"}],
       "]"}]}], ";"}], " ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{"v1", ",", "v2", ",", "v3", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.5"}], ",", "3.5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.5"}], ",", "8.5"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "3", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "8", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["9", "4"]}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", " ", ",", " ", 
      SubscriptBox["z", "1"], ",", 
      "\"\<,  \!\(\*SubscriptBox[\(z\), \(2\)]\) = \>\"", " ", ",", " ", 
      SubscriptBox["z", "2"]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*FractionBox[SubscriptBox[\(z\), \(1\)], SubscriptBox[\(z\), \
\(2\)]]\) = \>\"", " ", ",", " ", 
      FractionBox[
       SubscriptBox["z", "1"], 
       SubscriptBox["z", "2"]]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*FractionBox[SubscriptBox[\(z\), \(1\)], SubscriptBox[\(z\), \
\(2\)]]\) = \>\"", " ", ",", " ", 
      FractionBox[
       SubscriptBox["z", "1"], 
       SubscriptBox["z", "2"]], ",", 
      "\"\<\!\(\*FractionBox[\(1 - \[ImaginaryI]\\\ \*SqrtBox[\(3\)]\), \(1 - \
\[ImaginaryI]\\\ \*SqrtBox[\(3\)]\)]\)\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*FractionBox[SubscriptBox[\(z\), \(1\)], SubscriptBox[\(z\), \
\(2\)]]\) = \>\"", " ", ",", " ", 
      FractionBox[
       RowBox[{"ComplexExpand", "[", 
        RowBox[{
         SubscriptBox["z", "1"], 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{"\[ImaginaryI]", " ", 
            SqrtBox["3"]}]}], ")"}]}], "]"}], 
       RowBox[{"ComplexExpand", "[", 
        RowBox[{
         SubscriptBox["z", "2"], 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{"\[ImaginaryI]", " ", 
            SqrtBox["3"]}]}], ")"}]}], "]"}]]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*FractionBox[SubscriptBox[\(z\), \(1\)], SubscriptBox[\(z\), \
\(2\)]]\) = \>\"", " ", ",", " ", 
      SubscriptBox["w", "3"]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["r", "1"], "=", 
     RowBox[{"Abs", "[", 
      SubscriptBox["z", "1"], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Theta]", "1"], "=", 
     RowBox[{"Arg", "[", 
      SubscriptBox["z", "1"], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["z", "1"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(r\), \(1\)]\) = |\!\(\*SubscriptBox[\(z\), \(1\
\)]\)| = \>\"", ",", 
      SubscriptBox["r", "1"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(\[Theta]\), \(1\)]\) = Arg[\!\(\*SubscriptBox[\
\(z\), \(1\)]\)] = \>\"", ",", 
      SubscriptBox["\[Theta]", "1"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["r", "2"], "=", 
     RowBox[{"Abs", "[", 
      SubscriptBox["z", "2"], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Theta]", "2"], "=", 
     RowBox[{"Arg", "[", 
      SubscriptBox["z", "2"], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(2\)]\) = \>\"", ",", 
      SubscriptBox["z", "2"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(r\), \(2\)]\) = |\!\(\*SubscriptBox[\(z\), \(2\
\)]\)| = \>\"", ",", 
      SubscriptBox["r", "2"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(\[Theta]\), \(2\)]\) = Arg[\!\(\*SubscriptBox[\
\(z\), \(2\)]\)] = \>\"", ",", 
      SubscriptBox["\[Theta]", "2"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["w", "1"], "=", 
     FractionBox[
      SubscriptBox["z", "1"], 
      SubscriptBox["z", "2"]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["w", "2"], "=", 
     RowBox[{
      FractionBox[
       SubscriptBox["r", "1"], 
       SubscriptBox["r", "2"]], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Theta]", "1"], "-", 
          SubscriptBox["\[Theta]", "2"]}], ")"}]}]]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*FractionBox[SubscriptBox[\(z\), \(1\)], SubscriptBox[\(z\), \
\(2\)]]\) = \>\"", ",", 
      FractionBox[
       SubscriptBox["z", "1"], 
       SubscriptBox["z", "2"]]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<\!\(\*FractionBox[SubscriptBox[\(z\), \(1\)], SubscriptBox[\(z\), \
\(2\)]]\) = \!\(\*FractionBox[SubscriptBox[\(r\), \(1\)], SubscriptBox[\(r\), \
\(2\)]]\)\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\[ImaginaryI] \
\((\*SubscriptBox[\(\[Theta]\), \(1\)] - \*SubscriptBox[\(\[Theta]\), \(2\)])\
\)\)]\)\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*FractionBox[SubscriptBox[\(z\), \(1\)], SubscriptBox[\(z\), \
\(2\)]]\) = (\>\"", ",", 
      SubscriptBox["r", "1"], ",", "\"\</\>\"", ",", 
      SubscriptBox["r", "2"], ",", "\"\<)(\>\"", ",", 
      SuperscriptBox[
       "\"\<\!\(\*SuperscriptBox[\(\[ExponentialE]\), \
\(\[ImaginaryI]\)]\)\>\"", 
       SubscriptBox["\[Theta]", "1"]], ",", "\"\< \>\"", ",", 
      SuperscriptBox["\"\<\>\"", 
       SubscriptBox["\[Theta]", "2"]], ",", "\"\<)\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*FractionBox[SubscriptBox[\(z\), \(1\)], SubscriptBox[\(z\), \
\(2\)]]\) = (\>\"", ",", 
      FractionBox[
       SubscriptBox["r", "1"], 
       SubscriptBox["r", "2"]], ",", "\"\<)(\>\"", ",", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Theta]", "1"], "-", 
          SubscriptBox["\[Theta]", "2"]}], ")"}]}]], ",", "\"\<)\>\""}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*FractionBox[SubscriptBox[\(z\), \(1\)], SubscriptBox[\(z\), \
\(2\)]]\) = (\>\"", ",", 
      FractionBox[
       SubscriptBox["r", "1"], 
       SubscriptBox["r", "2"]], ",", "\"\<)(\>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[Theta]", "1"], "-", 
           SubscriptBox["\[Theta]", "2"]}], ")"}]}]], "]"}], ",", 
      "\"\<)\>\""}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*FractionBox[SubscriptBox[\(z\), \(1\)], SubscriptBox[\(z\), \
\(2\)]]\) = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{
        FractionBox[
         SubscriptBox["r", "1"], 
         SubscriptBox["r", "2"]], 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", 
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["\[Theta]", "1"], "-", 
            SubscriptBox["\[Theta]", "2"]}], ")"}]}]]}], "]"}]}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{
  3.3989718086875*^9, {3.399709656421875*^9, 3.399709719046875*^9}, {
   3.400236791453125*^9, 3.40023679221875*^9}}]
}, Closed]],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Complex Numbers",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/ComplexNumbersBib.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox[ButtonBox["History of Complex Numbers",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/HistoryComplexBib.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/complex.html"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2008 John H. Mathews, Russell W. \
Howell",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/"], None}],
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[0, 1, 0]]], "Text",
 CellChangeTimes->{{3.398971607625*^9, 3.398971607703125*^9}}]
},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{996, 621},
WindowMargins->{{-2, Automatic}, {Automatic, 10}},
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "CHAPTER 1"->{
  Cell[568, 21, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"CHAPTER 1", 145626, 4423}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"],
Cell[905, 32, 134, 2, 29, "Text"],
Cell[1042, 36, 665, 16, 65, "Text",
 Evaluatable->False],
Cell[1710, 54, 671, 26, 47, "Text",
 Evaluatable->False],
Cell[2384, 82, 928, 31, 101, "Text"],
Cell[3315, 115, 6422, 108, 301, "Text",
 Evaluatable->False],
Cell[9740, 225, 880, 32, 53, "Text"],
Cell[10623, 259, 1176, 49, 63, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[11824, 312, 156, 4, 29, "Text",
 Evaluatable->False],
Cell[11983, 318, 3870, 107, 389, "Input"]
}, Closed]],
Cell[15868, 428, 1197, 45, 98, "Text"],
Cell[17068, 475, 1282, 44, 83, "Text"],
Cell[18353, 521, 2157, 73, 104, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[20535, 598, 156, 4, 29, "Text",
 Evaluatable->False],
Cell[20694, 604, 1143, 38, 35, "Text"],
Cell[21840, 644, 5378, 149, 477, "Input"],
Cell[27221, 795, 50, 0, 29, "Text"],
Cell[27274, 797, 2262, 63, 251, "Input"]
}, Closed]],
Cell[29551, 863, 401, 12, 26, "Text"],
Cell[29955, 877, 965, 36, 101, "Text"],
Cell[30923, 915, 322, 14, 35, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[31270, 933, 156, 4, 29, "Text",
 Evaluatable->False],
Cell[31429, 939, 1208, 33, 206, "Input"]
}, Closed]],
Cell[32652, 975, 2089, 81, 152, "Text"],
Cell[34744, 1058, 9979, 342, 454, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[44748, 1404, 157, 4, 29, "Text",
 Evaluatable->False],
Cell[44908, 1410, 383, 17, 31, "Text"],
Cell[45294, 1429, 4927, 135, 368, "Input"],
Cell[50224, 1566, 50, 0, 29, "Text"],
Cell[50277, 1568, 2292, 64, 239, "Input"]
}, Closed]],
Cell[52584, 1635, 1127, 48, 116, "Text"],
Cell[53714, 1685, 2656, 94, 77, "Text",
 Evaluatable->False],
Cell[56373, 1781, 324, 11, 29, "Text"],
Cell[56700, 1794, 1294, 41, 83, "Text"],
Cell[57997, 1837, 1888, 64, 132, "Text"],
Cell[59888, 1903, 5540, 171, 289, "Text"],
Cell[CellGroupData[{
Cell[65453, 2078, 99, 2, 29, "Text"],
Cell[65555, 2082, 350, 10, 52, "Input"],
Cell[65908, 2094, 1123, 35, 73, "Input"],
Cell[67034, 2131, 1123, 35, 73, "Input"],
Cell[68160, 2168, 1163, 37, 73, "Input"]
}, Closed]],
Cell[69338, 2208, 545, 16, 26, "Text"],
Cell[69886, 2226, 847, 28, 65, "Text"],
Cell[70736, 2256, 875, 29, 111, "Text"],
Cell[71614, 2287, 6394, 108, 326, "Text",
 Evaluatable->False],
Cell[78011, 2397, 619, 24, 65, "Text"],
Cell[78633, 2423, 1052, 25, 65, "Text"],
Cell[79688, 2450, 1221, 38, 101, "Text"],
Cell[80912, 2490, 1173, 44, 80, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[82110, 2538, 157, 4, 29, "Text",
 Evaluatable->False],
Cell[82270, 2544, 3799, 109, 401, "Input"]
}, Closed]],
Cell[86084, 2656, 1964, 62, 137, "Text"],
Cell[88051, 2720, 4743, 81, 235, "Text",
 Evaluatable->False],
Cell[92797, 2803, 1447, 47, 83, "Text"],
Cell[94247, 2852, 911, 37, 104, "Text"],
Cell[95161, 2891, 1026, 42, 65, "Text",
 Evaluatable->False],
Cell[96190, 2935, 1340, 40, 65, "Text",
 Evaluatable->False],
Cell[97533, 2977, 3693, 142, 65, "Text"],
Cell[101229, 3121, 1223, 44, 124, "Text"],
Cell[102455, 3167, 2303, 81, 232, "Text"],
Cell[104761, 3250, 768, 29, 29, "Text"],
Cell[105532, 3281, 4889, 83, 286, "Text",
 Evaluatable->False],
Cell[110424, 3366, 4812, 82, 276, "Text",
 Evaluatable->False],
Cell[115239, 3450, 2949, 116, 283, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[118213, 3570, 157, 4, 29, "Text",
 Evaluatable->False],
Cell[118373, 3576, 202, 9, 35, "Text"],
Cell[118578, 3587, 6237, 176, 654, "Input"],
Cell[124818, 3765, 1505, 42, 167, "Input"]
}, Closed]],
Cell[126338, 3810, 3873, 143, 311, "Text",
 Evaluatable->False],
Cell[130214, 3955, 1596, 61, 61, "Text"],
Cell[CellGroupData[{
Cell[131835, 4020, 157, 4, 29, "Text",
 Evaluatable->False],
Cell[131995, 4026, 405, 17, 40, "Text"],
Cell[132403, 4045, 11438, 320, 1003, "Input"]
}, Closed]],
Cell[143856, 4368, 281, 7, 26, "Text"],
Cell[144140, 4377, 277, 7, 29, "Text"],
Cell[144420, 4386, 288, 7, 29, "Text"],
Cell[144711, 4395, 249, 5, 29, "Text"],
Cell[144963, 4402, 317, 7, 29, "Text"]
}
]
*)

(* End of internal cache information *)
