(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    187135,       6513]
NotebookOptionsPosition[    183268,       6387]
NotebookOutlinePosition[    183764,       6410]
CellTagsIndexPosition[    183690,       6405]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["1.5 The Algebra of Complex Numbers, Revisited",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
 "\tThe real numbers are deficient in the sense that not all algebraic \
operations on them produce real numbers.  Thus, for ",
 Cell[BoxData[
  SqrtBox[
   RowBox[{"-", "1"}]]]],
 " to make sense, we must consider the domain of complex numbers.  Do complex \
numbers have this same deficiency?  That is, if we are to make sense of \
expressions such as ",
 Cell[BoxData[
  SqrtBox[
   RowBox[{"1", "+", "\[ImaginaryI]"}]]]],
 ", must we appeal to yet another new number system?  The answer to this \
question is no. In other words, any reasonable algebraic operation performed \
on complex numbers gives complex numbers.  Later we show how to evaluate \
intriguing expressions such as ",
 Cell[BoxData[
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{"-", "1"}], ")"}], "\[ImaginaryI]"]]],
 ".  ",
 "For now we only look at integral powers and roots of complex numbers."
}], "Text",
 CellChangeTimes->{{3.398971896890625*^9, 3.398971908625*^9}}],

Cell[TextData[{
 "\tThe important players in this regard are the exponential and polar forms \
of a non-zero complex number   ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{
    RowBox[{"r", " ", 
     SuperscriptBox["\[ExponentialE]", "\[ImaginaryI]\[Theta]"]}], "=", 
    RowBox[{"r", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"cos", " ", "\[Theta]"}], " ", "+", " ", 
       RowBox[{"\[ImaginaryI]", " ", "sin", " ", "\[Theta]"}]}], 
      ")"}]}]}]}]]],
 ".  By the laws of exponents (which, you recall, we have promised to prove \
in Chapter 5) we have  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["z", "n"], "=", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"r", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]]}], ")"}], "n"], "=", 
    RowBox[{
     SuperscriptBox["r", "n"], 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "n", " ", "\[Theta]"}]]}]}]}]]],
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{"=", 
    RowBox[{
     SuperscriptBox["r", "n"], "[", 
     RowBox[{
      RowBox[{"cos", " ", 
       RowBox[{"(", "n\[Theta]", ")"}]}], " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", "sin", " ", 
       RowBox[{"(", "n\[Theta]", ")"}]}]}], "]"}]}]}]]],
 ",  \n\t\tand\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["z", 
    RowBox[{"-", "n"}]], "=", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"r", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]]}], ")"}], 
     RowBox[{"-", "n"}]], "=", 
    RowBox[{
     RowBox[{
      SuperscriptBox["r", 
       RowBox[{"-", "n"}]], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", "n", " ", "\[Theta]"}]]}], "=", 
     RowBox[{
      SuperscriptBox["r", 
       RowBox[{"-", "n"}]], "[", 
      RowBox[{
       RowBox[{"cos", " ", 
        RowBox[{"(", 
         RowBox[{"-", "n\[Theta]"}], ")"}]}], " ", "+", " ", 
       RowBox[{"\[ImaginaryI]", " ", "sin", " ", 
        RowBox[{"(", 
         RowBox[{"-", "n\[Theta]"}], ")"}]}]}], "]"}]}]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 StyleBox["Example 1.15.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Show that  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SqrtBox["3"]}], "-", "\[ImaginaryI]"}], ")"}], "3"], "=", 
   RowBox[{
    RowBox[{"-", "8"}], "\[ImaginaryI]"}]}]]],
 "  in two ways.\n\nSolution.  (Method 1):  The binomial formula (Exercise 14 \
of Section 1.2) gives  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        SqrtBox["3"]}], "-", "\[ImaginaryI]"}], ")"}], "3"], "=", 
    RowBox[{
     RowBox[{"1", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", 
         SqrtBox["3"]}], ")"}], "3"]}], "+", 
     RowBox[{"3", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", 
         SqrtBox["3"]}], ")"}], "2"], 
      RowBox[{"(", 
       RowBox[{"-", "\[ImaginaryI]"}], ")"}]}], "+", 
     RowBox[{"3", 
      RowBox[{"(", 
       RowBox[{"-", 
        SqrtBox["3"]}], ")"}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "\[ImaginaryI]"}], ")"}], "2"]}], "+", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "\[ImaginaryI]"}], ")"}], "3"]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                        ", 
   RowBox[{
    RowBox[{"=", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "3"}], " ", 
       SqrtBox["3"]}], "+", 
      RowBox[{
       RowBox[{"-", "9"}], " ", "\[ImaginaryI]"}], "+", 
      RowBox[{"3", " ", 
       SqrtBox["3"]}], "+", "\[ImaginaryI]"}]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                        ", 
   RowBox[{"=", 
    RowBox[{
     RowBox[{"-", "8"}], "\[ImaginaryI]"}]}]}]}]],
 "   "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "(Method 2):  Using iIdentity stated above and Example 1.12 yields  \n\n\t\t\
\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        SqrtBox["3"]}], "-", "\[ImaginaryI]"}], ")"}], "3"], "=", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"2", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "5"}], 
           RowBox[{"\[Pi]", "/", "6"}]}], ")"}]}]]}], ")"}], "3"]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                       ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", "2", ")"}], "3"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "5"}], 
            RowBox[{"\[Pi]", "/", "6"}]}], ")"}]}]], ")"}], "3"]}]}], " ", 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                       ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{"8", 
      RowBox[{"(", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "15"}], 
           RowBox[{"\[Pi]", "/", "6"}]}], ")"}]}]], ")"}]}]}], " ", 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                       ", 
   RowBox[{
    RowBox[{"=", 
     RowBox[{"8", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Cos", "[", 
         FractionBox[
          RowBox[{
           RowBox[{"-", "15"}], " ", "\[Pi]"}], "6"], "]"}], "+", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"Sin", "[", 
          FractionBox[
           RowBox[{
            RowBox[{"-", "15"}], " ", "\[Pi]"}], "6"], "]"}]}]}], ")"}]}]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                       ", 
   RowBox[{"=", 
    RowBox[{
     RowBox[{"-", "8"}], " ", "\[ImaginaryI]"}]}]}]}]],
 "  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 1.15.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "Enter  ",
 Cell[BoxData[
  RowBox[{"z", " ", "=", 
   RowBox[{
    RowBox[{"-", " ", 
     SqrtBox["3"]}], "-", "\[ImaginaryI]"}]}]]],
 "  and compute  ",
 Cell[BoxData[
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      SqrtBox["3"]}], "-", "\[ImaginaryI]"}], ")"}], "3"]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"e", ",", "\[Theta]", ",", "r", ",", "z", ",", "Z"}], "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"z", " ", "=", " ", 
     RowBox[{
      RowBox[{"-", " ", 
       SqrtBox["3"]}], " ", "-", " ", "\[ImaginaryI]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"r", " ", "=", " ", 
     RowBox[{"Abs", "[", "z", "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"\[Theta]", " ", "=", " ", 
     RowBox[{"Arg", "[", "z", "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Z", " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"r", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["V", "1"], " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", 
        RowBox[{"Arrowheads", "[", 
         RowBox[{"{", 
          RowBox[{"0.0", ",", "0.15"}], "}"}], "]"}], ",", 
        RowBox[{"Thickness", "[", "0.015", "]"}], ",", 
        RowBox[{"Arrow", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", "z", "]"}], ",", 
             RowBox[{"Im", "[", "z", "]"}]}], "}"}]}], "}"}], "]"}]}], "}"}], 
      "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["V", "2"], " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"Arrowheads", "[", 
         RowBox[{"{", 
          RowBox[{"0.0", ",", "0.15"}], "}"}], "]"}], ",", 
        RowBox[{"Thickness", "[", "0.02", "]"}], ",", 
        RowBox[{"Thickness", "[", "0.02", "]"}], ",", 
        RowBox[{"Arrow", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SuperscriptBox["z", "3"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SuperscriptBox["z", "3"], "]"}]}], "}"}]}], "}"}], "]"}]}], 
       "}"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{
     SubscriptBox["V", "1"], ",", 
     SubscriptBox["V", "2"], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "0.5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "8"}], ",", "0.5"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "0", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "8"}], ",", "0", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["8.5", "2.5"]}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<z = \>\"", ",", "z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<r = |z| = \>\"", ",", "r"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Theta] = Arg[z] = \>\"", ",", "\[Theta]"}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<z = \!\(\*SuperscriptBox[\(r\[ExponentialE]\), \(\[ImaginaryI]\
\[Theta]\)]\) = \>\"", ",", "r", ",", 
      SuperscriptBox["e", 
       RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]]}], "]"}], ";"}], " ", "\n",
    
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<z = \!\(\*SuperscriptBox[\(r\[ExponentialE]\), \(\[ImaginaryI]\
\[Theta]\)]\) = \>\"", ",", "Z"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SuperscriptBox[\(z\), \(3\)]\) = \>\"", ",", " ", 
      SuperscriptBox["z", "3"]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SuperscriptBox[\(z\), \(3\)]\) = (\>\"", ",", " ", "z", ",", 
      "\"\<)\>\"", ",", 
      SuperscriptBox["z", "2"]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SuperscriptBox[\(z\), \(3\)]\) = (\>\"", ",", " ", "z", ",", 
      "\"\<)\>\"", ",", "\"\<(\>\"", ",", 
      RowBox[{"Expand", "[", 
       SuperscriptBox["z", "2"], "]"}], ",", "\"\<)\>\""}], "]"}], ";"}], " ",
    "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SuperscriptBox[\(z\), \(3\)]\) = \>\"", ",", " ", 
      RowBox[{"Expand", "[", 
       SuperscriptBox["z", "3"], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SuperscriptBox[\(z\), \(3\)]\) = \!\(\*SuperscriptBox[\(r\), \
\(3\)]\)\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\[ImaginaryI]3\[Theta]\)]\
\) = \>\"", ",", " ", 
      SuperscriptBox["r", "3"], " ", ",", 
      SuperscriptBox["e", 
       RowBox[{"\[ImaginaryI]", " ", "3", "\[Theta]"}]]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SuperscriptBox[\(z\), \(3\)]\) = \!\(\*SuperscriptBox[\(r\), \
\(3\)]\)\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\[ImaginaryI]3\[Theta]\)]\
\) = \>\"", ",", " ", 
      SuperscriptBox["r", "3"], " ", ",", "\"\<(Cos[\>\"", ",", 
      RowBox[{"3", "\[Theta]"}], ",", "\"\<]+ \[ImaginaryI] Sin[\>\"", ",", 
      RowBox[{"3", "\[Theta]"}], ",", "\"\<])\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SuperscriptBox[\(z\), \(3\)]\) = \!\(\*SuperscriptBox[\(r\), \
\(3\)]\)\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\[ImaginaryI]3\[Theta]\)]\
\) = \>\"", ",", " ", 
      SuperscriptBox["r", "3"], " ", ",", "\"\<(\>\"", ",", 
      RowBox[{
       RowBox[{"Cos", "[", 
        RowBox[{"3", " ", "\[Theta]"}], "]"}], "+", " ", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"3", " ", "\[Theta]"}], "]"}]}]}], ",", "\"\<)\>\""}], "]"}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SuperscriptBox[\(z\), \(3\)]\) = \!\(\*SuperscriptBox[\(r\), \
\(3\)]\)\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\[ImaginaryI]3\[Theta]\)]\
\) = \>\"", ",", " ", 
      RowBox[{
       SuperscriptBox["r", "3"], " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "3", " ", "\[Theta]"}]]}]}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.398972324046875*^9, 3.39897237646875*^9}, {
  3.399710134484375*^9, 3.399710187390625*^9}, {3.40023789165625*^9, 
  3.400237892796875*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 "\tWhich method would you use if you were asked to compute ",
 Cell[BoxData[
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      SqrtBox["3"]}], "-", "\[ImaginaryI]"}], ")"}], "30"]]],
 "? "
}], "Text"],

Cell[TextData[{
 StyleBox["Example 1.16.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Evaluate  ",
 Cell[BoxData[
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      SqrtBox["3"]}], "-", "\[ImaginaryI]"}], ")"}], "30"]]],
 ".\n\nSolution.\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        SqrtBox["3"]}], "-", "\[ImaginaryI]"}], ")"}], "30"], "=", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"2", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "5"}], 
           RowBox[{"\[Pi]", "/", "6"}]}], ")"}]}]]}], ")"}], "30"]}], " ", 
   "\[IndentingNewLine]"}], "\n", 
  RowBox[{"                       ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      SuperscriptBox["2", "30"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "5"}], 
            RowBox[{"\[Pi]", "/", "6"}]}], ")"}]}]], ")"}], "30"]}]}], " ", 
    "\[IndentingNewLine]"}]}], "\n", 
  RowBox[{"                       ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      SuperscriptBox["2", "30"], 
      RowBox[{"(", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "150"}], 
           RowBox[{"\[Pi]", "/", "6"}]}], ")"}]}]], ")"}]}]}], " ", 
    "\[IndentingNewLine]"}]}], "\n", 
  RowBox[{"                       ", 
   RowBox[{
    RowBox[{"=", 
     RowBox[{
      SuperscriptBox["2", "30"], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Cos", "[", 
         FractionBox[
          RowBox[{
           RowBox[{"-", "150"}], " ", "\[Pi]"}], "6"], "]"}], "+", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"Sin", "[", 
          FractionBox[
           RowBox[{
            RowBox[{"-", "150"}], " ", "\[Pi]"}], "6"], "]"}]}]}], ")"}]}]}], 
    "\[IndentingNewLine]"}]}], "\n", 
  RowBox[{"                       ", 
   RowBox[{
    RowBox[{"=", 
     RowBox[{
      SuperscriptBox["2", "30"], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{
          RowBox[{"-", "25"}], " ", "\[Pi]"}], "]"}], "+", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"Sin", "[", 
          RowBox[{
           RowBox[{"-", "25"}], " ", "\[Pi]"}], "]"}]}]}], ")"}]}]}], 
    "\[IndentingNewLine]"}]}], "\n", 
  RowBox[{"                       ", 
   RowBox[{"=", 
    RowBox[{"-", " ", 
     SuperscriptBox["2", "30"]}]}]}]}]],
 "  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 1.16.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "Enter  ",
 Cell[BoxData[
  RowBox[{"z", " ", "=", 
   RowBox[{
    RowBox[{"-", " ", 
     SqrtBox["3"]}], "-", "\[ImaginaryI]"}]}]]],
 "  and compute  ",
 Cell[BoxData[
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      SqrtBox["3"]}], "-", "\[ImaginaryI]"}], ")"}], "30"]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"e", ",", "\[Theta]", ",", "r", ",", "z", ",", "Z"}], "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"z", " ", "=", " ", 
     RowBox[{
      RowBox[{"-", " ", 
       SqrtBox["3"]}], " ", "-", " ", "\[ImaginaryI]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"r", " ", "=", " ", 
     RowBox[{"Abs", "[", "z", "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"\[Theta]", " ", "=", " ", 
     RowBox[{"Arg", "[", "z", "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Z", " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"r", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<z = \>\"", ",", "z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<r = |z| = \>\"", ",", "r"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Theta] = Arg[z] = \>\"", ",", "\[Theta]"}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<z = \!\(\*SuperscriptBox[\(r\[ExponentialE]\), \(\[ImaginaryI]\
\[Theta]\)]\) = \>\"", ",", "r", ",", 
      SuperscriptBox["e", 
       RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]]}], "]"}], ";"}], " ", "\n",
    
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<z = \!\(\*SuperscriptBox[\(r\[ExponentialE]\), \(\[ImaginaryI]\
\[Theta]\)]\) = \>\"", ",", "Z"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SuperscriptBox[\(z\), \(30\)]\) = \!\(\*SuperscriptBox[\(r\), \
\(30\)]\)\!\(\*SuperscriptBox[\(\[ExponentialE]\), \
\(\[ImaginaryI]30\[Theta]\)]\) = \>\"", ",", " ", 
      SuperscriptBox["r", "30"], " ", ",", 
      SuperscriptBox["e", 
       RowBox[{"\[ImaginaryI]", " ", "30", "\[Theta]"}]]}], "]"}], ";"}], " ",
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SuperscriptBox[\(z\), \(30\)]\) = \!\(\*SuperscriptBox[\(r\), \
\(30\)]\)\!\(\*SuperscriptBox[\(\[ExponentialE]\), \
\(\[ImaginaryI]30\[Theta]\)]\) = \>\"", ",", " ", 
      SuperscriptBox["r", "30"], " ", ",", "\"\<(Cos[\>\"", ",", 
      RowBox[{"30", "\[Theta]"}], ",", "\"\<]+ \[ImaginaryI] Sin[\>\"", ",", 
      RowBox[{"30", "\[Theta]"}], ",", "\"\<])\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SuperscriptBox[\(z\), \(30\)]\) = \!\(\*SuperscriptBox[\(r\), \
\(30\)]\)\!\(\*SuperscriptBox[\(\[ExponentialE]\), \
\(\[ImaginaryI]30\[Theta]\)]\) = \>\"", ",", " ", 
      SuperscriptBox["r", "30"], " ", ",", "\"\<(\>\"", ",", 
      RowBox[{
       RowBox[{"Cos", "[", 
        RowBox[{"30", " ", "\[Theta]"}], "]"}], "+", " ", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"30", " ", "\[Theta]"}], "]"}]}]}], ",", "\"\<)\>\""}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SuperscriptBox[\(z\), \(30\)]\) = \!\(\*SuperscriptBox[\(r\), \
\(30\)]\)\!\(\*SuperscriptBox[\(\[ExponentialE]\), \
\(\[ImaginaryI]30\[Theta]\)]\) = \>\"", ",", " ", 
      RowBox[{
       SuperscriptBox["r", "30"], " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "30", " ", "\[Theta]"}]]}]}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SuperscriptBox[\(z\), \(30\)]\) = -(\>\"", ",", " ", "r", 
      ",", "\"\<\!\(\*SuperscriptBox[\()\), \(30\)]\)\>\""}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Alternate solution\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SuperscriptBox[\(z\), \(30\)]\) = \>\"", ",", " ", 
      SuperscriptBox["z", "30"]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SuperscriptBox[\(z\), \(30\)]\) = \>\"", ",", " ", 
      RowBox[{"Expand", "[", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", " ", 
           SqrtBox["3"]}], " ", "-", " ", "i"}], ")"}], "30"], "]"}]}], "]"}],
     ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Which can be simplified.\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SuperscriptBox[\(z\), \(30\)]\) = \>\"", ",", " ", 
      RowBox[{"Expand", "[", 
       SuperscriptBox["z", "30"], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SuperscriptBox[\(z\), \(30\)]\) = -(\>\"", ",", " ", "r", 
      ",", "\"\<\!\(\*SuperscriptBox[\()\), \(30\)]\)\>\""}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{
  3.398972391359375*^9, {3.400237792765625*^9, 3.400237814390625*^9}}]
}, Closed]],

Cell[TextData[{
 StyleBox["Extra Example.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Evaluate  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SqrtBox["3"]}], "-", "\[ImaginaryI]"}], ")"}], 
    RowBox[{"-", "6"}]], "=", 
   FractionBox[
    RowBox[{"-", " ", "1"}], "64"]}]]],
 "  in two ways."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Extra Solution.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "Enter  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{
    RowBox[{"-", " ", 
     SqrtBox["3"]}], "-", "\[ImaginaryI]"}]}]]],
 "  and compute ",
 Cell[BoxData[
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      SqrtBox["3"]}], "-", "\[ImaginaryI]"}], ")"}], 
   RowBox[{"-", "6"}]]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"e", ",", "\[Theta]", ",", "r", ",", "z", ",", "Z"}], "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"z", " ", "=", 
     RowBox[{
      RowBox[{"-", " ", 
       SqrtBox["3"]}], " ", "-", " ", "\[ImaginaryI]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"r", " ", "=", " ", 
     RowBox[{"Abs", "[", "z", "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"\[Theta]", " ", "=", " ", 
     RowBox[{"Arg", "[", "z", "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Z", " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"r", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["V", "1"], " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", 
        RowBox[{"Arrowheads", "[", 
         RowBox[{"{", 
          RowBox[{"0.0", ",", "0.05"}], "}"}], "]"}], ",", 
        RowBox[{"Thickness", "[", "0.005", "]"}], ",", 
        RowBox[{"Arrow", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", "z", "]"}], ",", 
             RowBox[{"Im", "[", "z", "]"}]}], "}"}]}], "}"}], "]"}]}], "}"}], 
      "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["V", "2"], " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"Arrowheads", "[", 
         RowBox[{"{", 
          RowBox[{"0.0", ",", "0.05"}], "}"}], "]"}], ",", 
        RowBox[{"Thickness", "[", "0.01", "]"}], ",", 
        RowBox[{"Arrow", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SuperscriptBox["z", 
               RowBox[{"-", "6"}]], "]"}], ",", 
             RowBox[{"Im", "[", 
              SuperscriptBox["z", 
               RowBox[{"-", "6"}]], "]"}]}], "}"}]}], "}"}], "]"}]}], "}"}], 
      "]"}]}], ";"}], " ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{
     SubscriptBox["V", "1"], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "0.1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "0.05"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", 
           SqrtBox["3"]}], ",", "0", ",", 
          SqrtBox["3"]}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "8"}], ",", "0", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["1", "2"]}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<z = \>\"", ",", "z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{
     SubscriptBox["V", "2"], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.05"}], ",", "0.01"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.03"}], ",", "0.03"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          FractionBox[
           RowBox[{"-", "3"}], "64"], ",", "0", ",", 
          FractionBox["1", "64"]}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          FractionBox[
           RowBox[{"-", "2"}], "100"], ",", 
          FractionBox["2", "100"], ",", 
          FractionBox["1", "100"]}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SuperscriptBox[\(z\), \(-6\)]\) = \>\"", ",", " ", 
      RowBox[{"ExpandAll", "[", 
       SuperscriptBox["z", 
        RowBox[{"-", "6"}]], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<z = \>\"", ",", "z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<r = |z| = \>\"", ",", "r"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Theta] = Arg[z] = \>\"", ",", "\[Theta]"}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<z = \!\(\*SuperscriptBox[\(r\[ExponentialE]\), \(\[ImaginaryI]\
\[Theta]\)]\) = \>\"", ",", "r", ",", 
      SuperscriptBox["e", 
       RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]]}], "]"}], ";"}], " ", "\n",
    
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<z = \!\(\*SuperscriptBox[\(r\[ExponentialE]\), \(\[ImaginaryI]\
\[Theta]\)]\) = \>\"", ",", "Z"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SuperscriptBox[\(z\), \(6\)]\) = \>\"", ",", 
      SuperscriptBox["z", "6"], ",", "\"\< = \>\"", ",", 
      RowBox[{"Expand", "[", 
       SuperscriptBox["z", "6"], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SuperscriptBox[\(z\), \(-6\)]\) = \>\"", ",", " ", 
      RowBox[{"Expand", "[", 
       SuperscriptBox["z", 
        RowBox[{"-", "6"}]], "]"}], ",", " ", "\"\< = \>\"", " ", ",", " ", 
      RowBox[{"ExpandAll", "[", 
       SuperscriptBox["z", 
        RowBox[{"-", "6"}]], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SuperscriptBox[\(z\), \(-6\)]\) = \!\(\*SuperscriptBox[\(r\), \
\(-6\)]\)\!\(\*SuperscriptBox[\(\[ExponentialE]\), \
\(-\[ImaginaryI]6\[Theta]\)]\) = \>\"", ",", " ", 
      SuperscriptBox["r", 
       RowBox[{"-", "6"}]], " ", ",", 
      SuperscriptBox["e", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", "6", " ", "\[Theta]"}]]}], "]"}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SuperscriptBox[\(z\), \(-6\)]\) = \!\(\*SuperscriptBox[\(r\), \
\(-6\)]\)\!\(\*SuperscriptBox[\(\[ExponentialE]\), \
\(-\[ImaginaryI]6\[Theta]\)]\) = \>\"", ",", " ", 
      SuperscriptBox["r", 
       RowBox[{"-", "6"}]], " ", ",", "\"\<(Cos[\>\"", ",", 
      RowBox[{
       RowBox[{"-", "6"}], "\[Theta]"}], ",", "\"\<]+ \[ImaginaryI] Sin[\>\"",
       ",", 
      RowBox[{
       RowBox[{"-", "6"}], "\[Theta]"}], ",", "\"\<])\>\""}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SuperscriptBox[\(z\), \(-6\)]\) = \!\(\*SuperscriptBox[\(r\), \
\(-6\)]\)\!\(\*SuperscriptBox[\(\[ExponentialE]\), \
\(-\[ImaginaryI]6\[Theta]\)]\) = \>\"", ",", " ", 
      SuperscriptBox["r", 
       RowBox[{"-", "6"}]], " ", ",", "\"\<(\>\"", ",", 
      RowBox[{
       RowBox[{"Cos", "[", 
        RowBox[{
         RowBox[{"-", "6"}], " ", "\[Theta]"}], "]"}], "+", " ", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"Sin", "[", 
         RowBox[{
          RowBox[{"-", "6"}], " ", "\[Theta]"}], "]"}]}]}], ",", 
      "\"\<)\>\""}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SuperscriptBox[\(z\), \(-6\)]\) = \!\(\*SuperscriptBox[\(r\), \
\(-6\)]\)\!\(\*SuperscriptBox[\(\[ExponentialE]\), \
\(-\[ImaginaryI]6\[Theta]\)]\) = \>\"", ",", " ", 
      RowBox[{
       SuperscriptBox["r", 
        RowBox[{"-", "6"}]], " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "6", " ", "\[Theta]"}]]}]}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.398972403375*^9, 3.398972409953125*^9}, {
  3.399710212484375*^9, 3.399710278921875*^9}, {3.400237900390625*^9, 
  3.4002379031875*^9}}]
}, Closed]],

Cell[TextData[{
 "\tAn interesting application of the laws of exponents comes from putting \
the equation ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]], ")"}], "n"], "=", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[ImaginaryI]", " ", "n", " ", "\[Theta]"}]]}]]],
 " into its polar form.  Doing so gives\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"cos", " ", "\[Theta]"}], " ", "+", 
      RowBox[{"i", " ", "sin", " ", "\[Theta]"}]}], ")"}], "n"], " ", "=", 
   " ", 
   RowBox[{
    RowBox[{"cos", 
     RowBox[{"(", 
      RowBox[{"n", " ", "\[Theta]"}], ")"}]}], " ", "+", 
    RowBox[{"i", " ", "sin", " ", 
     RowBox[{"(", 
      RowBox[{"n", " ", "\[Theta]"}], ")"}]}]}]}]]],
 ", \n\t\n\twhich is known as ",
 StyleBox[ButtonBox["De Moivre's Formula",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/deMoivresIdentity.html"], None}],
  FontVariations->{"Underline"->True}],
 ", in honor of the French mathematician ",
 StyleBox[ButtonBox["Abraham de Moivre",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/De_Moivre.\
html"], None}],
  FontVariations->{"Underline"->True}],
 " (1667--1754)."
}], "Text"],

Cell[TextData[{
 StyleBox["Example 1.17.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Use DeMoivre's formula to show that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"cos", 
    RowBox[{"(", 
     RowBox[{"5", " ", "\[Theta]"}], ")"}]}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["cos", "5"], 
     RowBox[{"(", "\[Theta]", ")"}]}], "-", 
    RowBox[{"10", " ", 
     SuperscriptBox["cos", "3"], 
     RowBox[{"(", "\[Theta]", ")"}], " ", 
     SuperscriptBox["sin", "2"], 
     RowBox[{"(", "\[Theta]", ")"}]}], "+", 
    RowBox[{"5", " ", 
     RowBox[{"cos", "[", "\[Theta]", "]"}], 
     RowBox[{"(", "\[Theta]", ")"}], " ", 
     SuperscriptBox["sin", "4"], 
     RowBox[{"(", "\[Theta]", ")"}]}]}]}]]],
 ".  \n\nSolution.  If we let ",
 StyleBox["n=5",
  FontFamily->"Courier New"],
 " and use the binomial formula to expand the left side of De Moivre's \
formula, we obtain  \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"cos", " ", "\[Theta]"}], "+", 
      RowBox[{"\[ImaginaryI]", " ", "sin", " ", "\[Theta]"}]}], ")"}], "5"], 
   "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["cos", "5"], "\[Theta]"}], "+", 
    RowBox[{"\[ImaginaryI]", " ", "5", " ", 
     SuperscriptBox["cos", "4"], "\[Theta]", " ", "sin", " ", "\[Theta]"}], 
    "-", 
    RowBox[{"10", " ", 
     SuperscriptBox["cos", "3"], "\[Theta]", " ", 
     SuperscriptBox["sin", "2"], "\[Theta]"}], "-", 
    RowBox[{"10", "\[ImaginaryI]", " ", 
     SuperscriptBox["cos", "2"], "\[Theta]", " ", 
     SuperscriptBox["sin", "3"], "\[Theta]"}], "+", 
    RowBox[{"5", " ", "cos", " ", "\[Theta]", " ", 
     SuperscriptBox["sin", "4"], "\[Theta]"}], "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["sin", "5"], "\[Theta]"}]}]}]]],
 "  \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"cos", " ", "\[Theta]"}], "+", 
      RowBox[{"\[ImaginaryI]", " ", "sin", " ", "\[Theta]"}]}], ")"}], "5"], 
   "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["cos", "5"], "\[Theta]"}], "-", 
    RowBox[{"10", " ", 
     SuperscriptBox["cos", "3"], "\[Theta]", " ", 
     SuperscriptBox["sin", "2"], "\[Theta]"}], "+", 
    RowBox[{"5", " ", "cos", " ", "\[Theta]", " ", 
     SuperscriptBox["sin", "4"], "\[Theta]"}], "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"5", " ", 
        SuperscriptBox["cos", "4"], "\[Theta]", " ", "sin", " ", "\[Theta]"}],
        "-", 
       RowBox[{"10", " ", 
        SuperscriptBox["cos", "2"], "\[Theta]", " ", 
        SuperscriptBox["sin", "3"], "\[Theta]"}], "+", 
       RowBox[{
        SuperscriptBox["sin", "5"], "\[Theta]"}]}], ")"}]}]}]}]]],
 "\n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"cos", 
     RowBox[{"(", 
      RowBox[{"5", " ", "\[Theta]"}], ")"}]}], " ", "+", 
    RowBox[{"\[ImaginaryI]", " ", "sin", " ", 
     RowBox[{"(", 
      RowBox[{"5", " ", "\[Theta]"}], ")"}]}]}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["cos", "5"], "\[Theta]"}], "-", 
    RowBox[{"10", " ", 
     SuperscriptBox["cos", "3"], "\[Theta]", " ", 
     SuperscriptBox["sin", "2"], "\[Theta]"}], "+", 
    RowBox[{"5", " ", "cos", " ", "\[Theta]", " ", 
     SuperscriptBox["sin", "4"], "\[Theta]"}], "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"5", " ", 
        SuperscriptBox["cos", "4"], "\[Theta]", " ", "sin", " ", "\[Theta]"}],
        "-", 
       RowBox[{"10", " ", 
        SuperscriptBox["cos", "2"], "\[Theta]", " ", 
        SuperscriptBox["sin", "3"], "\[Theta]"}], "+", 
       RowBox[{
        SuperscriptBox["sin", "5"], "\[Theta]"}]}], ")"}]}]}]}]]],
 "\n\nThe real part of right side of this expression is  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["cos", "5"], "\[Theta]"}], "-", 
   RowBox[{"10", " ", 
    SuperscriptBox["cos", "3"], "\[Theta]", " ", 
    SuperscriptBox["sin", "2"], "\[Theta]"}], "+", 
   RowBox[{"5", " ", "cos", " ", "\[Theta]", " ", 
    SuperscriptBox["sin", "4"], "\[Theta]"}]}]]],
 ".  Equating it to the real part of  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"cos", 
    RowBox[{"(", 
     RowBox[{"5", " ", "\[Theta]"}], ")"}]}], " ", "+", 
   RowBox[{"\[ImaginaryI]", " ", "sin", " ", 
    RowBox[{"(", 
     RowBox[{"5", " ", "\[Theta]"}], ")"}]}]}]]],
 "  establishes the desired result.  Furthermore, it can be shown that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"sin", " ", 
    RowBox[{"(", 
     RowBox[{"5", " ", "\[Theta]"}], ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"5", " ", 
     SuperscriptBox["cos", "4"], "\[Theta]", " ", "sin", " ", "\[Theta]"}], 
    "-", 
    RowBox[{"10", " ", 
     SuperscriptBox["cos", "2"], "\[Theta]", " ", 
     SuperscriptBox["sin", "3"], "\[Theta]"}], "+", 
    RowBox[{
     SuperscriptBox["sin", "5"], "\[Theta]"}]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 1.17.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "Enter  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], "=", 
   RowBox[{
    RowBox[{"Cos", "[", 
     RowBox[{"n", " ", "\[Theta]"}], "]"}], "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"n", " ", "\[Theta]"}], "]"}]}]}]}]],
  AspectRatioFixed->True],
 "  and compute  ",
 Cell[BoxData[
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", "+", " ", 
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], ")"}], "n"]],
  AspectRatioFixed->True],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"\[Theta]", ",", "z"}], "]"}], ";"}], " ", "\[IndentingNewLine]",
    
   RowBox[{
    RowBox[{"Clear", "[", "n", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"n", "=", "5"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "1"], "=", 
     RowBox[{
      RowBox[{"Cos", "[", 
       RowBox[{"n", " ", "\[Theta]"}], "]"}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{"n", " ", "\[Theta]"}], "]"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "2"], " ", "=", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", "+", " ", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], ")"}], "n"]}], ";"}], " ",
    "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "3"], " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      SubscriptBox["z", "2"], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      SubscriptBox["z", "1"], ",", "\"\< = \>\"", ",", 
      SubscriptBox["z", "2"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      SubscriptBox["z", "1"], ",", "\"\< = \>\"", ",", 
      SubscriptBox["z", "3"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<Take the real part of both sides and obtain\>\"", 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"Re", "[", 
        SubscriptBox["z", "1"], "]"}], "]"}], " ", "\[Equal]", " ", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"Re", "[", 
        SubscriptBox["z", "3"], "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<Take the imaginary part of both sides and obtain\>\"", 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"Im", "[", 
        SubscriptBox["z", "1"], "]"}], "]"}], " ", "\[Equal]", " ", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"Im", "[", 
        SubscriptBox["z", "3"], "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39897243328125*^9},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 "\tA key aid in determining roots of complex numbers is a corollary to the \
",
 StyleBox[ButtonBox["Fundamental Theorem of Algebra",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/FundamentalTheoremofAlgebra.html"], 
    None}],
  FontVariations->{"Underline"->True}],
 ".  We prove this theorem in Chapter 6.  Our proofs must be independent of \
the conclusions we derive here because we are going to make use of the \
corollary now."
}], "Text"],

Cell[TextData[{
 StyleBox["Theorem 1.4  (",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Fundamental Theorem of Algebra",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/FundamentalTheoremofAlgebra.html"], 
    None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 StyleBox[").",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  If  ",
 StyleBox["P(z)",
  FontFamily->"Courier New"],
 "  is a polynomial of degree  ",
 StyleBox["n",
  FontFamily->"Courier New"],
 "  (",
 Cell[BoxData[
  RowBox[{"n", ">", "0"}]]],
 ")  with complex coefficients, then the equation  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"P", 
    RowBox[{"(", "z", ")"}]}], "=", "0"}]]],
 "  has precisely  ",
 StyleBox["n",
  FontFamily->"Courier New"],
 "  (not necessarily distinct) solutions."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 "   Refer to Chapter 6. "
}], "Text"],

Cell[TextData[{
 StyleBox["Example 1.18.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Let  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"P", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    SuperscriptBox["z", "3"], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"2", "-", 
       RowBox[{"2", "\[ImaginaryI]"}]}], ")"}], " ", 
     SuperscriptBox["z", "2"]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "-", 
       RowBox[{"4", "\[ImaginaryI]"}]}], ")"}], "z"}], "-", "2"}]}]],
  AspectRatioFixed->True],
 ".    and find its zeros.  This polynomial of degree 3 can be written as  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"P", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"z", "-", "\[ImaginaryI]"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{"z", "+", "2"}], ")"}]}]}]]],
 ".  Hence the equation  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"P", 
    RowBox[{"(", "z", ")"}]}], "=", "0"}]]],
 "  has solutions  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], "=", 
   RowBox[{
    SubscriptBox["z", "2"], "=", "\[ImaginaryI]"}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "3"], "=", 
   RowBox[{"-", "2"}]}]]],
 ".  Thus, in accordance with the Fundamental Theorem of Algebra, we have \
three solutions, with  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], "  ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "  ", 
   SubscriptBox["z", "2"]}]]],
 "  being repeated roots."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 1.18.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "Enter the polynomial  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"P", "[", "z", "]"}], "=", 
   RowBox[{
    SuperscriptBox["z", "3"], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"2", "-", 
       RowBox[{"2", "\[ImaginaryI]"}]}], ")"}], " ", 
     SuperscriptBox["z", "2"]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "-", 
       RowBox[{"4", "\[ImaginaryI]"}]}], ")"}], "z"}], "-", "2"}]}]],
  AspectRatioFixed->True],
 "  and factor it."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"P", ",", "z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"P", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{
      SuperscriptBox["z", "3"], " ", "+", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"2", "-", 
         RowBox[{"2", "\[ImaginaryI]"}]}], ")"}], " ", 
       SuperscriptBox["z", "2"]}], " ", "+", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "-", 
         RowBox[{"4", "\[ImaginaryI]"}]}], ")"}], " ", "z"}], " ", "-", " ", 
      "2"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"solset", "=", 
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"P", "[", "z", "]"}], "\[Equal]", "0"}], ",", "z"}], "]"}]}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<P[z] = \>\"", ",", 
      RowBox[{"P", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<P[z] = \>\"", ",", 
      RowBox[{"Factor", "[", 
       RowBox[{"P", "[", "z", "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<And we can find the roots of P[z]\>\"", "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Solve \>\"", ",", 
      RowBox[{"P", "[", "z", "]"}], " ", ",", "\"\< = 0\>\""}], "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "solset", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["solset", 
       RowBox[{"\[LeftDoubleBracket]", 
        RowBox[{"2", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]]}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(2\)]\) = \>\"", ",", 
      SubscriptBox["solset", 
       RowBox[{"\[LeftDoubleBracket]", 
        RowBox[{"3", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]]}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(3\)]\) = \>\"", ",", 
      SubscriptBox["solset", 
       RowBox[{"\[LeftDoubleBracket]", 
        RowBox[{"1", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]]}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.398972441953125*^9},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 "\tThe corollary implies that if we can find ",
 StyleBox["n distinct",
  FontSlant->"Italic"],
 " solutions to the equation ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["z", "n"], "=", "c"}]]],
 "  (or ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["z", "n"], "-", "c"}], "=", "0"}]]],
 ") , we will have found ",
 StyleBox["all",
  FontSlant->"Italic"],
 " the solutions.  We begin our search for these solutions by looking at the \
simpler equation ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["z", "n"], "=", "1"}]]],
 ".  ",
 "Solving this equation will enable us to handle the more general one quite \
easily."
}], "Text"],

Cell[TextData[{
 "\tTo solve  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["z", "n"], "=", "1"}]]],
 " we first note an important condition that determines when two nonzero \
complex numbers are equal.  If we let  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], " ", "=", " ", 
   RowBox[{
    SubscriptBox["r", "1"], 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", 
      SubscriptBox["\[Theta]", "1"]}]]}]}]]],
 "  and   ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "2"], " ", "=", " ", 
   RowBox[{
    SubscriptBox["r", "2"], 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", 
      SubscriptBox["\[Theta]", "2"]}]]}]}]]],
 ",  then  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], " ", "=", 
   SubscriptBox["z", "2"]}]]],
 "   (i.e., ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["r", "1"], 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", 
      SubscriptBox["\[Theta]", "1"]}]]}], "=", 
   RowBox[{
    SubscriptBox["r", "2"], 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", 
      SubscriptBox["\[Theta]", "2"]}]]}]}]]],
 ")    iff    ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["r", "1"], "=", 
   SubscriptBox["r", "2"]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["\[Theta]", "1"], "=", 
   RowBox[{
    SubscriptBox["\[Theta]", "2"], "+", 
    RowBox[{"2", "\[Pi]", " ", "k"}]}]}]]],
 ",\n\t\t\t\nwhere ",
 StyleBox["k",
  FontFamily->"Courier New"],
 " is an integer.  That is, two complex numbers are equal iff their moduli \
agree and an argument of one equals an argument of the other to within an \
integral multiple of ",
 Cell[BoxData[
  RowBox[{"2", "\[Pi]"}]]],
 "."
}], "Text"],

Cell[TextData[{
 "\tWe now find all solutions to  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["z", "n"], "=", "1"}]]],
 "  in two stages, with each stage corresponding to one direction in the iff \
part of the above relation.  First, we show that if we have a solution to ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["z", "n"], "=", "1"}]]],
 ", then the solution must have a certain form.  Second, we show that any \
quantity with that form is indeed a solution."
}], "Text"],

Cell[TextData[{
 "\tFor the first stage, suppose that  ",
 Cell[BoxData[
  RowBox[{"z", " ", "=", " ", 
   RowBox[{"r", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]]}]}]]],
 "  is a solution to  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["z", "n"], "=", "1"}]]],
 ".  Putting the latter equation in exponential form gives  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["r", "n"], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", "n", " ", "\[Theta]"}]]}], "=", 
   RowBox[{"1", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"0", "\[ImaginaryI]"}]]}]}]]],
 ",  so we must have  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["r", "n"], "=", "1"}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"n", " ", "\[Theta]"}], "=", 
   RowBox[{"0", "+", 
    RowBox[{"2", "\[Pi]", " ", "k"}]}]}]]],
 ".   In other words,  ",
 Cell[BoxData[
  RowBox[{"r", "=", "1"}]]],
 "   and   ",
 Cell[BoxData[
  RowBox[{"\[Theta]", "=", 
   FractionBox[
    RowBox[{"2", "\[Pi]", " ", "k"}], "n"]}]]],
 ",  where ",
 StyleBox["k",
  FontFamily->"Courier New"],
 " is an integer."
}], "Text"],

Cell[TextData[{
 "\tSo, if ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{"r", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]]}]}]]],
 " is a solution to ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["z", "n"], "=", "1"}]]],
 ", then ",
 Cell[BoxData[
  RowBox[{"r", "=", "1"}]]],
 " and ",
 Cell[BoxData[
  RowBox[{"\[Theta]", "=", 
   FractionBox[
    RowBox[{"2", "\[Pi]", " ", "k"}], "n"]}]]],
 " must be true.  This observation completes the first stage of our solution \
strategy.  For the second stage, we note that if ",
 Cell[BoxData[
  RowBox[{"r", "=", "1"}]]],
 ", and ",
 Cell[BoxData[
  RowBox[{"\[Theta]", "=", 
   FractionBox[
    RowBox[{"2", "\[Pi]", " ", "k"}], "n"]}]]],
 ", then ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{
    RowBox[{"r", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]]}], "=", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", "2", "\[Pi]", " ", 
      RowBox[{"k", "/", "n"}]}]]}]}]]],
 " is indeed a solution to ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["z", "n"], "=", "1"}]]],
 " because  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["z", "n"], "=", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", "2", "\[Pi]", " ", 
        RowBox[{"k", "/", "n"}]}]], ")"}], "n"], "=", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "2", "\[Pi]", " ", "k"}]], "=", 
     "1"}]}]}]]],
 ".  For example, if n=7 and k=3, then  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[ImaginaryI]", " ", "6", 
     RowBox[{"\[Pi]", " ", "/", "7"}]}]]}]]],
 "  is a solution to   ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["z", "7"], "=", "1"}]]],
 "  because ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "6", 
       RowBox[{"\[Pi]", " ", "/", "7"}]}]], ")"}], "7"], "=", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", "6", "\[Pi]"}]], "=", "1"}]}]]],
 "."
}], "Text"],

Cell[TextData[{
 "\tFurthermore, it is easy to verify that we get n distinct solutions to ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["z", "n"], "=", "1"}]]],
 " (and, therefore, all solutions) by setting  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"k", "=", "0"}], 
   StyleBox[",",
    FontFamily->"Times New Roman"], "1", 
   StyleBox[",",
    FontFamily->"Times New Roman"], "2", 
   StyleBox[",",
    FontFamily->"Times New Roman"], "...", 
   StyleBox[",",
    FontFamily->"Times New Roman"], 
   RowBox[{"n", "-", "1"}]}]],
  CellChangeTimes->{3.39897197109375*^9}],
 ".  The solutions for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"k", "=", "n"}], 
   StyleBox[",",
    FontFamily->"Times New Roman"], 
   RowBox[{"n", "+", "1"}], 
   StyleBox[",",
    FontFamily->"Times New Roman"], "..."}]],
  CellChangeTimes->{3.39897197109375*^9}],
 "  merely repeat those for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"k", "=", "0"}], 
   StyleBox[",",
    FontFamily->"Times New Roman"], "1", 
   StyleBox[",",
    FontFamily->"Times New Roman"], "2", 
   StyleBox[",",
    FontFamily->"Times New Roman"], "...", 
   StyleBox[",",
    FontFamily->"Times New Roman"], 
   RowBox[{"n", "-", "1"}]}]],
  CellChangeTimes->{3.39897197109375*^9}],
 ",  because the arguments so generated agree to within an integral multiple \
of ",
 Cell[BoxData[
  RowBox[{"2", "\[Pi]"}]]],
 ".  As we stated in Section 1.1, the n solutions can be expressed as\n\n\t\t\
\t",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", 
    StyleBox["k",
     FontSize->10]], "=", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     StyleBox[
      RowBox[{"\[ImaginaryI]", " ", "2", 
       RowBox[{"k\[Pi]", "/", "n"}]}],
      FontSize->10]], " ", "=", " ", 
    RowBox[{
     RowBox[{"cos", 
      FractionBox[
       RowBox[{"2", " ", "\[Pi]", " ", "k"}], "n"]}], "+", 
     RowBox[{"\[ImaginaryI]", " ", "sin", 
      FractionBox[
       RowBox[{"2", " ", "\[Pi]", " ", "k"}], "n"]}]}]}]}]]],
 "   for   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"k", "=", "0"}], ",", "1", ",", "\[CenterEllipsis]", ",", 
   RowBox[{"n", "-", "1"}]}]]],
 ".\n\nThey are called the ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["n", "th"], TraditionalForm]],
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[" roots of unity",
  FontColor->RGBColor[0, 0, 1]],
 "."
}], "Text",
 CellChangeTimes->{{3.3989719775625*^9, 3.39897215171875*^9}}],

Cell[TextData[{
 "    When ",
 StyleBox["k=0",
  FontFamily->"Courier New"],
 " in the above equation, we get  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "0"], "=", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     StyleBox[
      RowBox[{"\[ImaginaryI]", " ", "2", "*", "0", "*", 
       RowBox[{"\[Pi]", "/", "n"}]}],
      FontSize->10]], "=", "1"}]}]]],
 ",  which is a rather trivial result.  The first interesting root of unity \
occurs when  ",
 StyleBox["k=1",
  FontFamily->"Courier New"],
 ",  giving  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], "=", 
   SuperscriptBox["\[ExponentialE]", 
    StyleBox[
     RowBox[{"\[ImaginaryI]", " ", "2", 
      RowBox[{"\[Pi]", "/", "n"}]}],
     FontSize->10]]}]]],
 ".  This particular value shows up so often that mathematicians have given \
it a special symbol."
}], "Text",
 CellChangeTimes->{{3.398972161234375*^9, 3.398972164171875*^9}}],

Cell[TextData[{
 StyleBox["Definition 1.9 (",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Primitive nth Root of Unity",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/RootofUnity.html"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 StyleBox[").",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[" ",
  FontColor->RGBColor[0, 0, 1]],
 " For any natural number n, the value ",
 Cell[BoxData[
  SubscriptBox["\[Omega]", 
   StyleBox["n",
    FontSize->10]]]],
 " given by  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["\[Omega]", 
    StyleBox["n",
     FontSize->10]], "=", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     StyleBox[
      RowBox[{"\[ImaginaryI]2", " ", 
       RowBox[{"\[Pi]", "/", "n"}]}],
      FontSize->10]], "=", 
    RowBox[{
     RowBox[{"cos", 
      FractionBox[
       RowBox[{"2", " ", "\[Pi]"}], "n"]}], "+", 
     RowBox[{"\[ImaginaryI]", " ", "sin", 
      FractionBox[
       RowBox[{"2", " ", "\[Pi]"}], "n"]}]}]}]}]]],
 "\n\nis called the ",
 StyleBox["primitive ",
  FontColor->RGBColor[0, 0, 1]],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["n", "th"], TraditionalForm]],
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[" root of unity",
  FontColor->RGBColor[0, 0, 1]],
 ". "
}], "Text"],

Cell[TextData[{
 "\tBy De Moivre's formula, the ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["n", "th"], TraditionalForm]]],
 " roots of unity can be expressed as  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"1", ",", 
   SubscriptBox["\[Omega]", "n"], ",", 
   SubsuperscriptBox["\[Omega]", "n", "2"], ",", 
   SubsuperscriptBox["\[Omega]", "n", "3"], ",", "...", ",", 
   SubsuperscriptBox["\[Omega]", "n", 
    RowBox[{"n", "-", "1"}]]}]]],
 ".  \n\nGeometrically, the ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["n", "th"], TraditionalForm]]],
 " roots of unity are equally spaced points that lie on the unit circle ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["C", "1"], 
    RowBox[{"(", "0", ")"}]}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"z", ":", " ", 
      RowBox[{"|", "z", "|"}]}], "=", "1"}], "}"}]}]]],
 " and form the vertices of a regular polygon with ",
 StyleBox["n",
  FontFamily->"Courier New"],
 " sides."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Example 1.19.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  The solutions to the equation  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["z", "8"], "=", "1"}]]],
 " are given by the eight values  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", 
    StyleBox["k",
     FontSize->10]], " ", "=", " ", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     StyleBox[
      RowBox[{"\[ImaginaryI]", 
       FractionBox[
        RowBox[{"2", " ", "\[Pi]", " ", "k"}], "8"]}],
      FontSize->10]], " ", "=", " ", 
    RowBox[{
     RowBox[{"cos", 
      FractionBox[
       RowBox[{"2", " ", "\[Pi]", " ", "k"}], "8"]}], "+", 
     RowBox[{"\[ImaginaryI]", " ", "sin", 
      FractionBox[
       RowBox[{"2", " ", "\[Pi]", " ", "k"}], "8"]}]}]}]}]]],
 "   for   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"k", "=", "0"}], ",", "1", ",", "2", ",", "...", ",", "7"}]]],
 ".\n\nIn Cartesian form, these solutions are  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[PlusMinus]", "1"}], ",", 
   RowBox[{"\[PlusMinus]", "\[ImaginaryI]"}], ",", 
   RowBox[{"\[PlusMinus]", 
    FractionBox[
     RowBox[{
      SqrtBox["2"], "+", 
      RowBox[{"\[ImaginaryI]", 
       SqrtBox["2"]}]}], "2"]}], ",", 
   RowBox[{"\[PlusMinus]", 
    FractionBox[
     RowBox[{
      SqrtBox["2"], "-", 
      RowBox[{"\[ImaginaryI]", 
       SqrtBox["2"]}]}], "2"]}]}]]],
 ".  The primitive ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["8", "th"], TraditionalForm]]],
 " root of unity is \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["\[Omega]", 
    StyleBox["n",
     FontSize->10]], " ", "=", " ", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     StyleBox[
      RowBox[{"\[ImaginaryI]", 
       FractionBox[
        RowBox[{"2", " ", "\[Pi]"}], "8"]}],
      FontSize->10]], " ", "=", " ", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      StyleBox[
       RowBox[{"\[ImaginaryI]", 
        FractionBox["\[Pi]", "4"]}],
       FontSize->10]], " ", "=", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"cos", 
        FractionBox["\[Pi]", "4"]}], "+", 
       RowBox[{"\[ImaginaryI]", " ", "sin", 
        FractionBox["\[Pi]", "4"]}]}], " ", "=", " ", 
      FractionBox[
       RowBox[{
        SqrtBox["2"], "+", 
        RowBox[{"\[ImaginaryI]", 
         SqrtBox["2"]}]}], "2"]}]}]}]}]]],
 ".\n\n",
 "Figure 1.18 illustrates this result."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "\t\t\t",
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.09091 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.454545 0.545455 0.454545 [
[ 0 0 0 0 ]
[ 1 1.09091 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.09091 L
0 1.09091 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto fill
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto
-0.05 0.0125 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
1 1 0 r
.5 Mabswid
[ ] 0 setdash
newpath
.5 .54545 .45455 0 365.73 arc
s
1 0 0 r
.5 .54545 m
.95455 .54545 L
s
% Start of user PostScript
0 0 1. 0 MAarrowhead1
% End of user PostScript
0 0 1 r
.5 .54545 m
.82141 .86687 L
s
% Start of user PostScript
0 0 0.707107 0.707107 MAarrowhead1
% End of user PostScript
0 1 0 r
.5 .54545 m
.5 1 L
s
% Start of user PostScript
0 0 0 1. MAarrowhead1
% End of user PostScript
.5 .165 .165 r
.5 .54545 m
.17859 .86687 L
s
% Start of user PostScript
0 0 -0.707107 0.707107 MAarrowhead1
% End of user PostScript
1 0 1 r
.5 .54545 m
.04545 .54545 L
s
% Start of user PostScript
0 0 -1. 0 MAarrowhead1
% End of user PostScript
1 .753 .796 r
.5 .54545 m
.17859 .22404 L
s
% Start of user PostScript
0 0 -0.707107 -0.707107 MAarrowhead1
% End of user PostScript
0 1 1 r
.5 .54545 m
.5 .09091 L
s
% Start of user PostScript
0 0 0 -1. MAarrowhead1
% End of user PostScript
1 .5 0 r
.5 .54545 m
.82141 .22404 L
s
% Start of user PostScript
0 0 0.707107 -0.707107 MAarrowhead1
% End of user PostScript
1 0 0 r
.025 w
.95455 .54545 Mdot
0 0 1 r
.82141 .86687 Mdot
0 1 0 r
.5 1 Mdot
.5 .165 .165 r
.17859 .86687 Mdot
1 0 1 r
.04545 .54545 Mdot
1 .753 .796 r
.17859 .22404 Mdot
0 1 1 r
.5 .09091 Mdot
1 .5 0 r
.82141 .22404 Mdot
0 g
gsave
.86364 .59091 -81.7188 -11.4688 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22.9375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 15.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.188 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\343) show
70.188 10.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
86.063 15.188 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.250 15.188 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
100.438 15.188 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.84414 .92141 -98.0938 -18.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 37.375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 19.938 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 19.938 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\343) show
70.188 15.375 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
80.438 15.375 moveto
(\\220) show
85.563 15.375 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
91.188 19.938 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
102.125 12.938 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
112.188 12.938 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
122.250 12.938 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344) show
100.500 19.938 moveto
(\\200\\200\\200\\200\\200\\200\\200\\200) show
121.500 19.938 moveto
(\\200\\200) show
126.750 19.938 moveto
(\\200) show
128.188 19.938 moveto
(\\200) show
0.000 0.000 0.000 setrgbcolor
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
106.000 24.000 moveto
(\\217) show
115.875 24.000 moveto
(!) show
118.563 24.000 moveto
(!) show
121.250 24.000 moveto
(!) show
121.938 24.000 moveto
(!) show
116.313 30.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
133.188 19.938 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 1.03636 -84.2813 -11.4688 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22.9375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 15.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.188 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\343) show
70.188 10.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
80.438 10.625 moveto
(\\220) show
85.563 10.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
91.188 15.188 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
98.375 15.188 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344) show
105.563 15.188 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.02859 .92141 -61 -18.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 37.375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 19.938 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 19.938 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\343) show
70.188 15.375 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
85.563 15.375 moveto
(\\220) show
90.688 15.375 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
96.313 19.938 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.250 12.938 moveto
(-) show
115.188 12.938 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
125.250 12.938 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
135.313 12.938 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344) show
105.625 19.938 moveto
(\\200\\200\\200\\200\\200\\200\\200\\200) show
126.625 19.938 moveto
(\\200\\200\\200\\200) show
137.125 19.938 moveto
(\\200\\200) show
141.250 19.938 moveto
(\\200) show
0.000 0.000 0.000 setrgbcolor
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.063 24.000 moveto
(\\217) show
124.938 24.000 moveto
(!) show
127.625 24.000 moveto
(!) show
130.313 24.000 moveto
(!) show
131.000 24.000 moveto
(!) show
125.375 30.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
146.250 19.938 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.13636 .59091 -82.75 -11.4688 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22.9375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 15.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.188 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
70.188 15.188 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
77.375 15.188 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
84.563 15.188 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\343) show
91.750 10.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344p) show
102.500 15.188 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.02859 .13313 -61 -18.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 37.375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 19.938 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 19.938 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\343) show
70.188 15.375 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
85.563 15.375 moveto
(\\220) show
90.688 15.375 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
96.313 19.938 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.250 12.938 moveto
(-) show
115.188 12.938 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
125.250 12.938 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
135.313 12.938 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344) show
105.625 19.938 moveto
(\\200\\200\\200\\200\\200\\200\\200\\200) show
126.625 19.938 moveto
(\\200\\200\\200\\200) show
137.125 19.938 moveto
(\\200\\200) show
141.250 19.938 moveto
(\\200) show
0.000 0.000 0.000 setrgbcolor
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.063 24.000 moveto
(\\217) show
124.938 24.000 moveto
(!) show
127.625 24.000 moveto
(!) show
130.313 24.000 moveto
(!) show
131.000 24.000 moveto
(!) show
125.375 30.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
146.250 19.938 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .02273 -90.4375 -11.4688 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22.9375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 15.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.188 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\343) show
70.188 10.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
85.563 10.625 moveto
(\\220) show
90.688 10.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
96.313 15.188 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
103.500 15.188 moveto
(-) show
110.688 15.188 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344) show
117.875 15.188 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.8305 .13313 -100.656 -18.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 37.375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 19.938 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 19.938 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\343) show
70.188 15.375 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
85.563 15.375 moveto
(\\220) show
90.688 15.375 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
96.313 19.938 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.250 12.938 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
117.313 12.938 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
127.375 12.938 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344) show
105.625 19.938 moveto
(\\200\\200\\200\\200\\200\\200\\200\\200) show
126.625 19.938 moveto
(\\200\\200) show
131.875 19.938 moveto
(\\200) show
133.313 19.938 moveto
(\\200) show
0.000 0.000 0.000 setrgbcolor
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
111.125 24.000 moveto
(\\217) show
121.000 24.000 moveto
(!) show
123.688 24.000 moveto
(!) show
126.375 24.000 moveto
(!) show
127.063 24.000 moveto
(!) show
121.438 30.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
138.313 19.938 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{269.563, 294.063},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
  ImageRangeCache->{{{0, 268.563}, {293.063, 0}} -> {-1, -1, 0, 0}}],
 StyleBox["   \n\t\t\tFigure 1.18",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  The eight eighth roots of unity."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 1.19.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "Enter the polynomial  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"P", "[", "z", "]"}], "=", 
   RowBox[{
    SuperscriptBox["z", "8"], "-", "1"}]}]],
  AspectRatioFixed->True],
 "  and find its zeros."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "k", ",", "list", ",", "set", ",", "solset", ",", "values", ",", "xx", 
      ",", "yy", ",", "z"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"P", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{
      SuperscriptBox["z", "8"], " ", "-", " ", "1"}]}], " ", ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"solset", "=", 
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"P", "[", "z", "]"}], "\[Equal]", "0"}], ",", "z"}], "]"}]}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"values", " ", "=", " ", 
     RowBox[{"solset", "[", 
      RowBox[{"[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{"k", ",", 
          RowBox[{"{", 
           RowBox[{"k", ",", 
            RowBox[{"Length", "[", "solset", "]"}]}], "}"}]}], "]"}], ",", 
        "1", ",", "2"}], "]"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"set", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"solset", "[", 
       RowBox[{"[", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{"k", ",", 
           RowBox[{"{", 
            RowBox[{"k", ",", 
             RowBox[{"Length", "[", "solset", "]"}]}], "}"}]}], "]"}], ",", 
         "1", ",", "2"}], "]"}], "]"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"set", " ", "=", "  ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{"set", ",", 
       RowBox[{"xx_Real", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"xx", ",", "0"}], "}"}]}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"list", " ", "=", "  ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{"set", ",", 
       RowBox[{
        RowBox[{"Complex", "[", 
         RowBox[{"xx_", ",", "yy_"}], "]"}], "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"xx", ",", "yy"}], "}"}]}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"list", ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"PointSize", "[", "0.025", "]"}], ",", "Red"}], "}"}]}], ",", 
     
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", 
          FractionBox[
           RowBox[{"-", "1"}], 
           SqrtBox["2"]], ",", 
          FractionBox["1", 
           SqrtBox["2"]], ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", 
          FractionBox[
           RowBox[{"-", "1"}], 
           SqrtBox["2"]], ",", 
          FractionBox["1", 
           SqrtBox["2"]], ",", "1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.1"}], ",", "1.1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.1"}], ",", "1.1"}], "}"}]}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"k", "=", "0"}], ",", 
      RowBox[{"k", "\[LessEqual]", "7"}], ",", 
      RowBox[{"k", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{
        SubscriptBox["\"\<z\>\"", "k"], ",", "\"\< = Cos[\>\"", ",", 
        FractionBox[
         RowBox[{" ", 
          RowBox[{"2", " ", "\[Pi]", " ", "k"}]}], "8"], ",", 
        "\"\<] + \[ImaginaryI] Sin[\>\"", ",", 
        FractionBox[
         RowBox[{" ", 
          RowBox[{"2", " ", "\[Pi]", " ", "k"}]}], "8"], ",", "\"\<] = \>\"", 
        ",", 
        RowBox[{
         RowBox[{"Cos", "[", 
          FractionBox[
           RowBox[{" ", 
            RowBox[{"2", " ", "\[Pi]", " ", "k"}]}], "8"], "]"}], "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"Sin", "[", 
           FractionBox[
            RowBox[{" ", 
             RowBox[{"2", " ", "\[Pi]", " ", "k"}]}], "8"], "]"}]}]}]}], 
       "]"}]}], " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<P[z] = \>\"", ",", 
      RowBox[{"P", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Solve \>\"", ",", 
      RowBox[{
       RowBox[{"P", "[", "z", "]"}], "\[Equal]", "0"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The roots of  \!\(\*SuperscriptBox[\(z\), \(8\)]\) = 1  are\>\"", 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SuperscriptBox[\(1\), FractionBox[\(1\), \(8\)]]\) = \>\"", 
      ",", "values"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The expanded form of the roots are\>\"", "]"}],
     ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SuperscriptBox[\(1\), FractionBox[\(1\), \(8\)]]\) = \>\"", 
      ",", 
      RowBox[{"ComplexExpand", "[", "values", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.398972453046875*^9, 3.398972489203125*^9}, {
  3.399193909046875*^9, 3.399193943328125*^9}, {3.399710497109375*^9, 
  3.3997105109375*^9}, {3.400237943171875*^9, 3.400237945171875*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 "\tThe procedure for solving  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["z", "n"], "=", "1"}]]],
 "  is easy to generalize in solving  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["z", "n"], "=", "c"}]]],
 "  for any nonzero complex number ",
 StyleBox["c",
  FontFamily->"Courier New"],
 ".  If  ",
 Cell[BoxData[
  RowBox[{"c", "=", 
   RowBox[{
    RowBox[{"\[Rho]", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       StyleBox["\[ImaginaryI]",
        FontSize->10], 
       StyleBox[" ",
        FontSize->10], "\[Phi]"}]]}], " ", "=", 
    RowBox[{"\[Rho]", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"cos", " ", "\[Phi]"}], "+", 
       RowBox[{"\[ImaginaryI]", " ", "sin", " ", "\[Phi]"}]}], ")"}]}]}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{"r", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      StyleBox["\[ImaginaryI]",
       FontSize->10], 
      StyleBox[" ",
       FontSize->10], "\[Theta]"}]]}]}]]],
 ",  then  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["z", "n"], "=", "c"}]]],
 "  iff  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["r", "n"], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      StyleBox["\[ImaginaryI]",
       FontSize->10], 
      StyleBox[" ",
       FontSize->10], 
      StyleBox["n",
       FontSize->10], 
      StyleBox[" ",
       FontSize->10], "\[Theta]"}]]}], "=", 
   RowBox[{"\[Rho]", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      StyleBox["\[ImaginaryI]",
       FontSize->10], 
      StyleBox[" ",
       FontSize->10], "\[Phi]"}]]}]}]]],
 ".  But this last equation is satisfied iff\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["r", "n"], " ", "=", " ", "\[Rho]"}]]],
 ",   and   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"n", " ", "\[Theta]"}], " ", "=", " ", 
   RowBox[{"\[Phi]", " ", "+", " ", 
    RowBox[{"2", " ", "k", " ", "\[Pi]"}]}]}]]],
 ",   where ",
 StyleBox["k",
  FontFamily->"Courier New"],
 " is an integer.\n\nAs before, we get ",
 StyleBox["n",
  FontFamily->"Courier New"],
 " distinct solutions given by  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", 
    StyleBox["k",
     FontSize->10]], " ", "=", "  ", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Rho]", 
      FractionBox["1", "n"]], 
     SuperscriptBox["\[ExponentialE]", 
      StyleBox[
       RowBox[{"\[ImaginaryI]", " ", 
        FractionBox[
         RowBox[{"\[Phi]", " ", "+", " ", 
          RowBox[{"2", " ", "\[Pi]", " ", "k"}]}], "n"]}],
       FontSize->10]]}], " ", "=", " ", 
    RowBox[{
     SuperscriptBox["\[Rho]", 
      FractionBox["1", "n"]], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"cos", 
        FractionBox[
         RowBox[{"\[Phi]", " ", "+", " ", 
          RowBox[{"2", " ", "\[Pi]", " ", "k"}]}], "n"]}], "+", 
       RowBox[{"\[ImaginaryI]", " ", "sin", 
        FractionBox[
         RowBox[{"\[Phi]", " ", "+", " ", 
          RowBox[{"2", " ", "\[Pi]", " ", "k"}]}], "n"]}]}], ")"}]}]}]}]]],
 "   for   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"k", "=", "0"}], ",", "1", ",", "\[CenterEllipsis]", ",", 
   RowBox[{"n", "-", "1"}]}]]],
 ".   \n\n\tEach of the above solutions can be considered an ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["n", "th"], TraditionalForm]]],
 " root of ",
 StyleBox["c",
  FontFamily->"Courier New"],
 ".  Geometrically, the ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["n", "th"], TraditionalForm]]],
 " roots of ",
 StyleBox["c",
  FontFamily->"Courier New"],
 " are equally spaced points that lie on the circle  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["C", 
    SuperscriptBox["\[Rho]", 
     FractionBox["1", "n"]]], " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"z", ":", "  ", 
      RowBox[{"|", "z", "|"}]}], "=", 
     SuperscriptBox["\[Rho]", 
      FractionBox["1", "n"]]}], "}"}]}]]],
 "  and form the vertices of a regular polygon with ",
 StyleBox["n",
  FontFamily->"Courier New"],
 " sides.  Figure 1.19 illustrates the case for ",
 StyleBox["n=5",
  FontFamily->"Courier New"],
 "."
}], "Text",
 CellChangeTimes->{{3.398972201125*^9, 3.39897226025*^9}}],

Cell[TextData[{
 "\t\t\t",
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.15385 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.461538 0.384615 0.384615 0.384615 [
[1.025 .38462 0 -6.28125 ]
[1.025 .38462 10 6.28125 ]
[.46154 1.17885 -5 0 ]
[.46154 1.17885 5 12.5625 ]
[ 0 0 0 0 ]
[ 1 1.15385 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .38462 m
1 .38462 L
s
gsave
1.025 .38462 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.46154 0 m
.46154 1.15385 L
s
gsave
.46154 1.17885 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.15385 L
0 1.15385 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto fill
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto
-0.05 0.0125 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
1 0 1 r
.5 Mabswid
newpath
.46154 .38462 .51923 0 73.125 arc
s
1 0 0 r
newpath
.46154 .38462 .30769 0 14.625 arc
s
1 0 1 r
.46154 .38462 m
.68483 1.12072 L
s
% Start of user PostScript
0 0 0.580569 1.91388 MAarrowhead1
% End of user PostScript
1 0 0 r
.46154 .38462 m
.88903 .49617 L
s
% Start of user PostScript
0 0 1.11148 0.290037 MAarrowhead1
% End of user PostScript
0 0 1 r
.46154 .38462 m
.48755 .82566 L
s
% Start of user PostScript
0 0 0.0676248 1.14671 MAarrowhead1
% End of user PostScript
0 1 0 r
.46154 .38462 m
.05012 .54564 L
s
% Start of user PostScript
0 0 -1.06969 0.418667 MAarrowhead1
% End of user PostScript
1 .5 0 r
.46154 .38462 m
.18126 .04309 L
s
% Start of user PostScript
0 0 -0.728727 -0.887956 MAarrowhead1
% End of user PostScript
0 1 1 r
.46154 .38462 m
.69973 .01252 L
s
% Start of user PostScript
0 0 0.619307 -0.967454 MAarrowhead1
% End of user PostScript
1 0 1 r
.025 w
.68483 1.12072 Mdot
1 0 0 r
.88903 .49617 Mdot
0 0 1 r
.48755 .82566 Mdot
0 1 0 r
.05012 .54564 Mdot
1 .5 0 r
.18126 .04309 Mdot
0 1 1 r
.69973 .01252 Mdot
0 g
gsave
.83868 1.08226 -93.625 -11.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.875 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 16.125 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.125 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
70.188 11.563 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
75.813 16.125 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
83.000 16.125 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
90.188 16.125 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
97.375 16.125 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r\\343) show
111.750 11.563 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344f) show
124.250 16.125 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.89288 .53463 -69.4063 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
70.188 14.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
75.813 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.50678 .87181 -69.4063 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
70.188 14.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
75.813 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.05012 .59179 -69.4063 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
70.188 14.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
75.813 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.09664 .08925 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
70.188 14.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
75.813 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.75358 .05098 -69.4063 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
70.188 14.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
75.813 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.58615 .65385 -66.5938 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
70.188 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.73077 .48077 -74.5313 -11.3438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22.6875 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 14.938 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.938 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
70.188 10.375 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.313 10.375 moveto
(\\220) show
80.438 10.375 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
86.063 14.938 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.92308 .69231 -66.5938 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
70.188 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.83462 .41154 -73.7813 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
70.188 12.813 moveto
(\\220) show
77.375 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
84.563 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{249.563, 287.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
  ImageRangeCache->{{{0, 248.563}, {286.938, 0}} -> {-1, -1, 0, 0}}],
 StyleBox["   \n\t\t\tFigure 1.19",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  The five solutions to the equation  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["z", "5"], "=", "c"}]]],
 "."
}], "Text"],

Cell[TextData[{
 "\tIt is interesting to note that if  ",
 Cell[BoxData["\[Zeta]"]],
 "  is any particular solution to the equation ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["z", "n"], "=", "c"}]]],
 ", then ",
 StyleBox["all",
  FontSlant->"Italic"],
 " solutions can be generated by multiplying by the various ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["n", "th"], TraditionalForm]]],
 " roots of unity.  That is, the solution set is  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   SubsuperscriptBox[
    RowBox[{"{", 
     RowBox[{"\[Zeta]", " ", 
      SubsuperscriptBox["\[Omega]", "n", 
       RowBox[{" ", "j"}]]}], "}"}], 
    RowBox[{"j", "=", "0"}], 
    RowBox[{"n", "-", "1"}]], " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"\[Zeta]", ",", 
     RowBox[{"\[Zeta]", " ", 
      SubscriptBox["\[Omega]", 
       StyleBox["n",
        FontSize->10]]}], ",", 
     RowBox[{"\[Zeta]", " ", 
      SubsuperscriptBox["\[Omega]", "n", 
       RowBox[{" ", "2"}]]}], ",", "...", ",", 
     RowBox[{"\[Zeta]", " ", 
      SubsuperscriptBox["\[Omega]", "n", 
       RowBox[{" ", 
        RowBox[{"n", "-", "1"}]}]]}]}], "}"}]}]]],
 ".  \n\n\tThe reason for this is that if  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[Zeta]", 
    RowBox[{" ", "n"}]], "=", "c"}]]],
 ",  then for any  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"j", "=", "0"}], ",", "1", ",", "\[CenterEllipsis]", ",", 
   RowBox[{"n", "-", "1"}]}]]],
 "  we have \n\t\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"\[Zeta]", " ", 
      SubsuperscriptBox["\[Omega]", "n", 
       RowBox[{" ", "j"}]]}], ")"}], "n"], " ", "=", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Zeta]", 
      RowBox[{" ", "n"}]], 
     SuperscriptBox[
      RowBox[{"(", 
       SubsuperscriptBox["\[Omega]", "n", 
        RowBox[{" ", "j"}]], ")"}], "n"]}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[Zeta]", 
       RowBox[{" ", "n"}]], 
      SuperscriptBox[
       RowBox[{"(", 
        SubsuperscriptBox["\[Omega]", "n", 
         RowBox[{" ", "n"}]], ")"}], "j"]}], " ", "=", " ", 
     RowBox[{
      RowBox[{
       SuperscriptBox["\[Zeta]", 
        RowBox[{" ", "n"}]], 
       RowBox[{"(", "1", ")"}]}], " ", "=", " ", "c"}]}]}]}]]],
 ",  \n\t\nand that multiplying a number by  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["\[Omega]", 
    StyleBox["n",
     FontSize->10]], "=", " ", 
   SuperscriptBox["\[ExponentialE]", 
    StyleBox[
     RowBox[{"\[ImaginaryI]", " ", 
      FractionBox[
       RowBox[{"2", " ", "\[Pi]"}], "n"]}],
     FontSize->10]]}]]],
 "  increases an argument of that number by ",
 Cell[BoxData[
  FractionBox[
   RowBox[{"2", " ", "\[Pi]"}], "n"]]],
 ",  so that  ",
 Cell[BoxData[
  SubsuperscriptBox[
   RowBox[{"{", 
    RowBox[{"\[Zeta]", " ", 
     SubsuperscriptBox["\[Omega]", "n", 
      RowBox[{" ", "j"}]]}], "}"}], 
   RowBox[{"j", "=", "0"}], 
   RowBox[{"n", "-", "1"}]]]],
 "  contain ",
 StyleBox["n",
  FontFamily->"Courier New"],
 " distinct values."
}], "Text"],

Cell[TextData[{
 StyleBox["Example 1.20.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Find all the cube roots of  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"8", "\[ImaginaryI]"}], "=", 
   RowBox[{"8", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"cos", 
       FractionBox["\[Pi]", "2"]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", "sin", 
       FractionBox["\[Pi]", "2"]}]}], ")"}]}]}]]],
 ",  i.e. find all solutions to the equation  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["z", "3"], "=", 
   RowBox[{"8", "\[ImaginaryI]"}]}]]],
 ".  \n\nSolution.\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    SubscriptBox["z", 
     StyleBox["k",
      FontSize->10]], " ", "=", "  ", 
    RowBox[{
     SuperscriptBox["8", 
      FractionBox["1", "3"]], 
     SuperscriptBox["\[ExponentialE]", 
      StyleBox[
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           FractionBox["\[Pi]", "2"], " ", "+", " ", 
           RowBox[{"2", " ", "\[Pi]", " ", "k"}]}], ")"}], "/", "3"}]}],
       FontSize->10]]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"      ", 
   RowBox[{"=", " ", 
    RowBox[{"2", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"cos", 
        FractionBox[
         RowBox[{
          FractionBox["\[Pi]", "2"], " ", "+", " ", 
          RowBox[{"2", " ", "\[Pi]", " ", "k"}]}], "3"]}], "+", 
       RowBox[{"\[ImaginaryI]", " ", "sin", 
        FractionBox[
         RowBox[{
          FractionBox["\[Pi]", "2"], " ", "+", " ", 
          RowBox[{"2", " ", "\[Pi]", " ", "k"}]}], "3"]}]}], ")"}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"      ", 
   RowBox[{"=", " ", 
    RowBox[{"2", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"cos", 
        RowBox[{"(", " ", 
         RowBox[{
          FractionBox["\[Pi]", "6"], " ", "+", 
          FractionBox[
           RowBox[{"2", " ", "k", " ", "\[Pi]"}], "3"]}], ")"}]}], "+", 
       RowBox[{"\[ImaginaryI]", " ", "sin", 
        RowBox[{"(", " ", 
         RowBox[{
          FractionBox["\[Pi]", "6"], " ", "+", 
          FractionBox[
           RowBox[{"2", " ", "k", " ", "\[Pi]"}], "3"]}], ")"}]}]}], 
      ")"}]}]}]}]}]],
 "   \n\nfor  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"k", "=", "0"}], 
   StyleBox[",",
    FontFamily->"Times New Roman"], "1", 
   StyleBox[",",
    FontFamily->"Times New Roman"], "2", 
   StyleBox[",",
    FontFamily->"Times New Roman"], "...", 
   StyleBox[",",
    FontFamily->"Times New Roman"], 
   RowBox[{"n", "-", "1"}]}]],
  CellChangeTimes->{3.39897197109375*^9}],
 ".  The Cartesian forms of the solutions (shown in Figure 1.20) are  \n\n\t\t\
\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["z", "0"], "=", 
    RowBox[{
     SqrtBox["3"], "+", "\[ImaginaryI]"}]}], ",", " ", 
   RowBox[{
    SubscriptBox["z", "1"], "=", 
    RowBox[{
     RowBox[{"-", 
      SqrtBox["3"]}], "+", "\[ImaginaryI]"}]}], ",", " ", 
   RowBox[{
    RowBox[{
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", 
     SubscriptBox["z", "2"]}], "=", 
    RowBox[{
     RowBox[{"-", "2"}], "\[ImaginaryI]"}]}]}]]],
 ". "
}], "Text",
 Evaluatable->False,
 CellChangeTimes->{{3.39897229190625*^9, 3.398972299921875*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "\t\t\t",
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.2625 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.25625 0.125 [
[1.025 .25625 0 -6.28125 ]
[1.025 .25625 10 6.28125 ]
[.5 1.2875 -5 0 ]
[.5 1.2875 5 12.5625 ]
[ 0 0 0 0 ]
[ 1 1.2625 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .25625 m
1 .25625 L
s
gsave
1.025 .25625 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.5 1.2625 L
s
gsave
.5 1.2875 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.2625 L
0 1.2625 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto fill
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto
-0.05 0.0125 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
1 0 1 r
.5 Mabswid
newpath
matrix currentmatrix
0.4375 0.4375 scale
1.14286 .58571 1 0 90 arc
setmatrix s
1 0 0 r
newpath
matrix currentmatrix
0.2375 0.2375 scale
2.10526 1.07895 1 0 30 arc
setmatrix s
0 1 0 r
newpath
matrix currentmatrix
0.15 0.15 scale
3.33333 1.70833 1 0 150 arc
setmatrix s
0 0 1 r
newpath
matrix currentmatrix
0.0875 0.0875 scale
5.71429 2.92857 1 0 270 arc
setmatrix s
1 0 1 r
.5 .25625 m
.5 1.25625 L
s
% Start of user PostScript
0 0 0 8. MAarrowhead1
% End of user PostScript
1 0 0 r
.5 .25625 m
.71651 .38125 L
s
% Start of user PostScript
0 0 1.73205 1. MAarrowhead1
% End of user PostScript
0 1 0 r
.5 .25625 m
.28349 .38125 L
s
% Start of user PostScript
0 0 -1.73205 1. MAarrowhead1
% End of user PostScript
0 0 1 r
.5 .25625 m
.5 .00625 L
s
% Start of user PostScript
0 0 0 -2. MAarrowhead1
% End of user PostScript
1 0 1 r
.025 w
.5 1.25625 Mdot
1 0 0 r
.71651 .38125 Mdot
0 1 0 r
.28349 .38125 Mdot
0 0 1 r
.5 .00625 Mdot
0 g
gsave
.55625 1.235 -61 -11.3438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22.6875 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 14.938 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.938 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
70.188 10.375 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
75.813 14.938 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
83.000 14.938 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
90.188 14.938 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344) show
97.375 14.938 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.76651 .40625 -69.4063 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
70.188 14.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
75.813 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.24599 .425 -69.4063 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
70.188 14.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
75.813 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5375 .025 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
70.188 14.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
75.813 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.525 .81875 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
70.188 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
77.375 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
84.563 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.8375 .59375 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
70.188 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
77.375 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
84.563 12.813 moveto
(\\220) show
91.750 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
98.938 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.78125 .3025 -70.3438 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 29.875 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
66.750 10.250 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
65.125 17.250 moveto
(\\200\\200) show
70.375 17.250 moveto
(\\200) show
72.688 17.250 moveto
(\\200) show
66.750 24.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
77.688 17.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.4125 .44375 -75.5 -16.0313 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.0625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 19.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
66.750 12.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
73.938 12.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
( ) show
77.063 12.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
65.125 19.438 moveto
(\\200\\200\\200\\200) show
75.625 19.438 moveto
(\\200\\200) show
80.875 19.438 moveto
(\\200) show
83.000 19.438 moveto
(\\200) show
71.875 27.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
88.000 19.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.4375 .11875 -75.5 -16.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 19.563 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
66.750 12.563 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
73.938 12.563 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
( ) show
77.063 12.563 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
65.125 19.563 moveto
(\\200\\200\\200\\200) show
75.625 19.563 moveto
(\\200\\200) show
80.875 19.563 moveto
(\\200) show
83.000 19.563 moveto
(\\200) show
71.875 27.125 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
88.000 19.563 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{249.563, 315.063},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
  ImageRangeCache->{{{0, 248.563}, {314.063, 0}} -> {-4, -2, 0, 0}}],
 StyleBox["   \n\t\tFigure 1.20",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  The point  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{"8", "\[ImaginaryI]"}]}]]],
 "  and its three cube roots  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "0"], ",", 
   SubscriptBox["z", "1"], ",", " ", 
   RowBox[{
    StyleBox["and",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], "  ", 
    SubscriptBox["z", "2"]}]}]]],
 ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 1.20.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "Enter the polynomial  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"P", "[", "z", "]"}], "=", 
   RowBox[{
    SuperscriptBox["z", "3"], "-", 
    RowBox[{"8", "\[ImaginaryI]"}]}]}]],
  AspectRatioFixed->True],
 "  and find its zeros."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "k", ",", "list", ",", "set", ",", "solset", ",", "values", ",", "xx", 
      ",", "yy", ",", "z"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"P", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{
      SuperscriptBox["z", "3"], "-", 
      RowBox[{"8", "\[ImaginaryI]"}]}]}], " ", ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"solset", "=", 
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"P", "[", "z", "]"}], "\[Equal]", "0"}], ",", "z"}], "]"}]}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"values", " ", "=", " ", 
     RowBox[{"solset", "[", 
      RowBox[{"[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{"k", ",", 
          RowBox[{"{", 
           RowBox[{"k", ",", 
            RowBox[{"Length", "[", "solset", "]"}]}], "}"}]}], "]"}], ",", 
        "1", ",", "2"}], "]"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"set", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"solset", "[", 
       RowBox[{"[", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{"k", ",", 
           RowBox[{"{", 
            RowBox[{"k", ",", 
             RowBox[{"Length", "[", "solset", "]"}]}], "}"}]}], "]"}], ",", 
         "1", ",", "2"}], "]"}], "]"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"set", " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{"set", ",", 
       RowBox[{"xx_Real", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"xx", ",", "0"}], "}"}]}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"list", " ", "=", "  ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{"set", ",", 
       RowBox[{
        RowBox[{"Complex", "[", 
         RowBox[{"xx_", ",", "yy_"}], "]"}], "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"xx", ",", "yy"}], "}"}]}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"list", ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"PointSize", "[", "0.025", "]"}], ",", "Red"}], "}"}]}], ",", 
     
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", 
           SqrtBox["3"]}], ",", 
          RowBox[{"-", "1"}], ",", "1", ",", 
          SqrtBox["3"]}], "}"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.1"}], ",", "2.1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.1"}], ",", "2.1"}], "}"}]}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"k", "=", "0"}], ",", 
      RowBox[{"k", "\[LessEqual]", "2"}], ",", 
      RowBox[{"k", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{
        SubscriptBox["\"\<z\>\"", "k"], ",", "\"\< = 2 Cos[\>\"", ",", " ", 
        RowBox[{
         FractionBox["\[Pi]", "6"], " ", "+", 
         FractionBox[
          RowBox[{"2", " ", "k", " ", "\[Pi]"}], "3"]}], ",", 
        "\"\<] + \[ImaginaryI] 2 Sin[\>\"", ",", " ", 
        RowBox[{
         FractionBox["\[Pi]", "6"], " ", "+", 
         FractionBox[
          RowBox[{"2", " ", "k", " ", "\[Pi]"}], "3"]}], ",", "\"\<] = \>\"", 
        ",", 
        RowBox[{
         RowBox[{"2", 
          RowBox[{"Cos", "[", " ", 
           RowBox[{
            FractionBox["\[Pi]", "6"], " ", "+", 
            FractionBox[
             RowBox[{"2", " ", "k", " ", "\[Pi]"}], "3"]}], "]"}]}], "+", 
         RowBox[{"\[ImaginaryI]", " ", "2", " ", 
          RowBox[{"Sin", "[", " ", 
           RowBox[{
            FractionBox["\[Pi]", "6"], " ", "+", 
            FractionBox[
             RowBox[{"2", " ", "k", " ", "\[Pi]"}], "3"]}], "]"}]}]}]}], 
       "]"}]}], " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<P[z] = \>\"", ",", 
      RowBox[{"P", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Solve \>\"", ",", 
      RowBox[{
       RowBox[{"P", "[", "z", "]"}], "\[Equal]", "0"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The cube roots of  8\[ImaginaryI]  are\>\"", "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<(8\[ImaginaryI]\!\(\*SuperscriptBox[\()\), FractionBox[\(1\), \
\(3\)]]\) = \>\"", ",", "values"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The expanded form of the cube roots are\>\"", "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<(8\[ImaginaryI]\!\(\*SuperscriptBox[\()\), FractionBox[\(1\), \
\(3\)]]\) = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", "values", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.398972563140625*^9, 3.39897256553125*^9}, {
  3.399193960328125*^9, 3.39919397340625*^9}, {3.400237955953125*^9, 
  3.40023795803125*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell["\<\
\tIs the quadratic formula valid in the complex domain?  The answer is yes, \
provided we are careful with our terms.\
\>", "Text"],

Cell[TextData[{
 StyleBox["Theorem 1.5  (",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Quadratic Formula",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/QuadraticEquation.html"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 StyleBox[").",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  If  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"a", " ", 
     SuperscriptBox["z", "2"]}], "+", " ", 
    RowBox[{"b", " ", "z"}], " ", "+", " ", "c"}], " ", "=", "  ", "0"}]]],
 ",  then the solution set for ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " is \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"{", 
   FractionBox[
    RowBox[{
     RowBox[{"-", "b"}], " ", "+", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"4", " ", "a", " ", "c"}]}], ")"}], 
      FractionBox["1", "2"]]}], 
    RowBox[{"2", " ", "a"}]], "}"}]]],
 ",  \n\nwhere by  ",
 Cell[BoxData[
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["b", "2"], "-", 
     RowBox[{"4", " ", "a", " ", "c"}]}], ")"}], 
   FractionBox["1", "2"]]]],
 "  we mean all distinct square roots of the number inside the parenthesis. "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Proof .",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 "  The proof is left as an exercise for the reader."
}], "Text"],

Cell[TextData[{
 StyleBox["Example 1.21.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Find all solutions to the equation  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["z", "2"], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}], "z"}], "+", 
    RowBox[{"5", "\[ImaginaryI]"}]}], "=", "0"}]],
  AspectRatioFixed->True],
 ".  \n\nSolution.  The quadratic formula gives  ",
 Cell[BoxData[
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}]}], " ", "+", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}], "2"], "-", 
        RowBox[{"4", " ", 
         RowBox[{"(", "1", ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"5", "\[ImaginaryI]"}], ")"}]}]}], ")"}], 
      FractionBox["1", "2"]]}], 
    RowBox[{"2", 
     RowBox[{"(", "1", ")"}]}]], " ", "=", " ", 
   FractionBox[
    RowBox[{
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}]}], " ", "+", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "18"}], " ", "\[ImaginaryI]"}], ")"}], 
      FractionBox["1", "2"]]}], "2"]}]]],
 ".  As  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"-", "18"}], " ", "\[ImaginaryI]"}], " ", "=", " ", 
   RowBox[{"18", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", 
      RowBox[{"(", 
       RowBox[{"-", 
        FractionBox["\[Pi]", "2"]}], ")"}]}]]}]}]]],
 ",  we compute  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "18"}], " ", "\[ImaginaryI]"}], ")"}], 
    FractionBox["1", "2"]], " ", "=", " ", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", "18", " ", ")"}], 
     FractionBox["1", "2"]], 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["\[Pi]", "2"]}], "+", 
         RowBox[{"2", "k", " ", "\[Pi]"}]}], ")"}], "/", "2"}]}]]}]}]]],
 "  for ",
 Cell[BoxData[
  RowBox[{"k", "=", "0"}]],
  AspectRatioFixed->True],
 " and ",
 Cell[BoxData[
  RowBox[{"k", "=", "1"}]],
  AspectRatioFixed->True],
 ".  In Cartesian form, this expression reduces to \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", "18", " ", ")"}], 
     FractionBox["1", "2"]], 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", 
      RowBox[{"(", 
       RowBox[{"-", 
        FractionBox["\[Pi]", "4"]}], ")"}]}]]}], "=", 
   RowBox[{
    RowBox[{"3", " ", 
     SqrtBox["2"], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"cos", 
        FractionBox[
         RowBox[{"-", "\[Pi]"}], "4"]}], "+", 
       RowBox[{"\[ImaginaryI]", " ", "sin", 
        FractionBox[
         RowBox[{"-", "\[Pi]"}], "4"]}]}], ")"}]}], "=", 
    RowBox[{
     RowBox[{"3", " ", 
      SqrtBox["2"], 
      RowBox[{"(", 
       FractionBox[
        RowBox[{"1", "-", "\[ImaginaryI]"}], 
        SqrtBox["2"]], ")"}]}], "=", " ", 
     RowBox[{"3", "-", 
      RowBox[{"3", " ", "\[ImaginaryI]"}]}]}]}]}]]],
 ",  \n\tand\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", "18", " ", ")"}], 
     FractionBox["1", "2"]], 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", 
      RowBox[{"(", 
       FractionBox[
        RowBox[{"3", " ", "\[Pi]"}], "4"], ")"}]}]]}], "=", 
   RowBox[{
    RowBox[{"3", " ", 
     SqrtBox["2"], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"cos", 
        FractionBox[
         RowBox[{"3", "\[Pi]"}], "4"]}], "+", 
       RowBox[{"\[ImaginaryI]", " ", "sin", 
        FractionBox[
         RowBox[{"3", "\[Pi]"}], "4"]}]}], ")"}]}], "=", 
    RowBox[{
     RowBox[{"3", " ", 
      SqrtBox["2"], 
      RowBox[{"(", 
       FractionBox[
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[ImaginaryI]"}], 
        SqrtBox["2"]], ")"}]}], "=", " ", 
     RowBox[{
      RowBox[{"-", "3"}], "+", 
      RowBox[{"3", " ", "\[ImaginaryI]"}]}]}]}]}]]],
 ".  \n\t\t\nThus, our solution set is  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}]}], " ", "+", " ", 
       RowBox[{"(", 
        RowBox[{"3", "-", 
         RowBox[{"3", " ", "\[ImaginaryI]"}]}], ")"}]}], "2"], ",", 
     FractionBox[
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}]}], " ", "+", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "3"}], "+", 
         RowBox[{"3", " ", "\[ImaginaryI]"}]}], ")"}]}], "2"]}], "}"}], " ", 
   "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", "-", 
      RowBox[{"2", " ", "\[ImaginaryI]"}]}], ",", " ", 
     RowBox[{
      RowBox[{"-", "2"}], "+", "\[ImaginaryI]"}]}], "}"}]}]]],
 ". "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 1.21.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "Enter the polynomial  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"P", "[", "z", "]"}], "=", 
   RowBox[{
    SuperscriptBox["z", "2"], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}], "z"}], "+", 
    RowBox[{"5", "\[ImaginaryI]"}]}]}]],
  AspectRatioFixed->True],
 "  and find its zeros."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "k", ",", "list", ",", "set", ",", "solset", ",", "values", ",", "xx", 
      ",", "yy", ",", "z"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"P", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{
      SuperscriptBox["z", "2"], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}], "z"}], "+", 
      RowBox[{"5", "\[ImaginaryI]"}]}]}], " ", ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"solset", "=", 
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"P", "[", "z", "]"}], "\[Equal]", "0"}], ",", "z"}], "]"}]}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"values", " ", "=", " ", 
     RowBox[{"solset", "[", 
      RowBox[{"[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{"k", ",", 
          RowBox[{"{", 
           RowBox[{"k", ",", 
            RowBox[{"Length", "[", "solset", "]"}]}], "}"}]}], "]"}], ",", 
        "1", ",", "2"}], "]"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"set", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"solset", "[", 
       RowBox[{"[", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{"k", ",", 
           RowBox[{"{", 
            RowBox[{"k", ",", 
             RowBox[{"Length", "[", "solset", "]"}]}], "}"}]}], "]"}], ",", 
         "1", ",", "2"}], "]"}], "]"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"set", " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{"set", ",", 
       RowBox[{"xx_Real", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"xx", ",", "0"}], "}"}]}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"list", " ", "=", "  ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{"set", ",", 
       RowBox[{
        RowBox[{"Complex", "[", 
         RowBox[{"xx_", ",", "yy_"}], "]"}], "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"xx", ",", "yy"}], "}"}]}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"list", ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"PointSize", "[", "0.025", "]"}], ",", "Red"}], "}"}]}], ",", 
     
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", 
           SqrtBox["3"]}], ",", 
          RowBox[{"-", "1"}], ",", "1", ",", 
          SqrtBox["3"]}], "}"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.1"}], ",", "2.1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.1"}], ",", "2.1"}], "}"}]}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<P[z] = \>\"", ",", 
      RowBox[{"P", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Solve \>\"", ",", 
      RowBox[{
       RowBox[{"P", "[", "z", "]"}], "\[Equal]", "0"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The solution set is \>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "values", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<Remark. The roots are not a conjugate pair.\>\"", 
     "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39897285096875*^9, 3.398972853765625*^9}, {
  3.3991939866875*^9, 3.399193997390625*^9}, {3.400237965390625*^9, 
  3.400238004140625*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell["\<\
\tIn Exercise 5 of Section 1.2 we asked you to show that a polynomial with \
nonreal coefficients must have some roots that do not occur in complex \
conjugate pairs.  This last example gives an illustration of such a \
phenomenon. \
\>", "Text"],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["DeMoivre's Theorem",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/DeMoivreBib.html"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Roots of Cubic Equations",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/CubicEquationBib.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Roots of Quartic Equations",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/QuarticEquationBib.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Complex Roots of Polynomials",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/PolyRootComplexBib.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Quaternions",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/QuaternionBib.html"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/complex.html"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2008 John H. Mathews, Russell W. \
Howell",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/"], None}],
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[0, 1, 0]]], "Text",
 CellChangeTimes->{{3.398972313359375*^9, 3.398972313484375*^9}}]
},
CellGrouping->Manual,
WindowSize->{994, 645},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "CHAPTER 1"->{
  Cell[568, 21, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"CHAPTER 1", 183580, 6398}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"],
Cell[905, 32, 133, 2, 29, "Text"],
Cell[1041, 36, 961, 23, 87, "Text"],
Cell[2005, 61, 2161, 68, 125, "Text"],
Cell[4169, 131, 1867, 67, 195, "Text",
 Evaluatable->False],
Cell[6039, 200, 2185, 71, 238, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[8249, 275, 157, 4, 29, "Text",
 Evaluatable->False],
Cell[8409, 281, 334, 15, 37, "Text"],
Cell[8746, 298, 7406, 197, 584, "Input"]
}, Closed]],
Cell[16167, 498, 240, 9, 34, "Text"],
Cell[16410, 509, 2787, 96, 284, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[19222, 609, 157, 4, 29, "Text",
 Evaluatable->False],
Cell[19382, 615, 335, 15, 37, "Text"],
Cell[19720, 632, 5377, 138, 550, "Input"]
}, Closed]],
Cell[25112, 773, 430, 18, 35, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[25567, 795, 158, 4, 29, "Text",
 Evaluatable->False],
Cell[25728, 801, 347, 16, 37, "Text"],
Cell[26078, 819, 8861, 245, 663, "Input"]
}, Closed]],
Cell[34954, 1067, 1386, 41, 101, "Text"],
Cell[36343, 1110, 4969, 147, 233, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[41337, 1261, 157, 4, 29, "Text",
 Evaluatable->False],
Cell[41497, 1267, 601, 22, 29, "Text"],
Cell[42101, 1291, 2882, 84, 392, "Input"]
}, Closed]],
Cell[44998, 1378, 498, 12, 44, "Text"],
Cell[45499, 1392, 914, 34, 47, "Text",
 Evaluatable->False],
Cell[46416, 1428, 129, 5, 29, "Text"],
Cell[46548, 1435, 1765, 66, 65, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[48338, 1505, 157, 4, 29, "Text",
 Evaluatable->False],
Cell[48498, 1511, 514, 19, 29, "Text"],
Cell[49015, 1532, 2674, 75, 292, "Input"]
}, Closed]],
Cell[51704, 1610, 662, 24, 44, "Text"],
Cell[52369, 1636, 1765, 63, 101, "Text"],
Cell[54137, 1701, 481, 12, 47, "Text"],
Cell[54621, 1715, 1178, 43, 53, "Text"],
Cell[55802, 1760, 2232, 78, 82, "Text"],
Cell[58037, 1840, 2387, 81, 143, "Text"],
Cell[60427, 1923, 920, 30, 47, "Text"],
Cell[61350, 1955, 1344, 49, 107, "Text"],
Cell[62697, 2006, 1008, 33, 101, "Text",
 Evaluatable->False],
Cell[63708, 2041, 2457, 87, 216, "Text",
 Evaluatable->False],
Cell[66168, 2130, 31795, 1165, 330, "Text"],
Cell[CellGroupData[{
Cell[97988, 3299, 157, 4, 29, "Text",
 Evaluatable->False],
Cell[98148, 3305, 228, 9, 29, "Text"],
Cell[98379, 3316, 5838, 170, 530, "Input"]
}, Closed]],
Cell[104232, 3489, 4163, 149, 238, "Text"],
Cell[108398, 3640, 24503, 932, 323, "Text"],
Cell[132904, 4574, 3046, 105, 213, "Text"],
Cell[135953, 4681, 3473, 118, 255, "Text",
 Evaluatable->False],
Cell[139429, 4801, 23378, 919, 351, "Text"],
Cell[CellGroupData[{
Cell[162832, 5724, 157, 4, 29, "Text",
 Evaluatable->False],
Cell[162992, 5730, 260, 10, 29, "Text"],
Cell[163255, 5742, 5860, 169, 514, "Input"]
}, Closed]],
Cell[169130, 5914, 141, 3, 26, "Text"],
Cell[169274, 5919, 1336, 47, 133, "Text",
 Evaluatable->False],
Cell[170613, 5968, 157, 5, 29, "Text"],
Cell[170773, 5975, 5120, 182, 268, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[175918, 6161, 157, 4, 29, "Text",
 Evaluatable->False],
Cell[176078, 6167, 355, 13, 29, "Text"],
Cell[176436, 6182, 4283, 127, 387, "Input"]
}, Closed]],
Cell[180734, 6312, 256, 5, 44, "Text"],
Cell[180993, 6319, 281, 7, 29, "Text"],
Cell[181277, 6328, 270, 6, 29, "Text"],
Cell[181550, 6336, 285, 7, 29, "Text"],
Cell[181838, 6345, 289, 7, 29, "Text"],
Cell[182130, 6354, 291, 7, 29, "Text"],
Cell[182424, 6363, 265, 6, 29, "Text"],
Cell[182692, 6371, 249, 5, 29, "Text"],
Cell[182944, 6378, 320, 7, 29, "Text"]
}
]
*)

(* End of internal cache information *)
