(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    143840,       4313]
NotebookOptionsPosition[    139172,       4165]
NotebookOutlinePosition[    139696,       4189]
CellTagsIndexPosition[    139622,       4184]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["1.6 The Topology of Complex Numbers",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
 "\tIn this section we investigate some basic ideas concerning sets of points \
in the plane.  The first concept is that of a curve. Intuitively, we think of \
a curve as a piece of string placed on a flat surface in some type of \
meandering pattern.  More formally, we define a curve to be the range of a \
continuous complex-valued function ",
 Cell[BoxData[
  RowBox[{"z", 
   RowBox[{"(", "t", ")"}]}]]],
 " defined on the interval ",
 Cell[BoxData[
  RowBox[{"[", 
   RowBox[{"a", ",", "b"}], "]"}]]],
 ".  That is, a curve C is the range of a function given by  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"z", 
    RowBox[{"(", "t", ")"}]}], "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"x", 
       RowBox[{"(", "t", ")"}]}], ",", 
      RowBox[{"y", 
       RowBox[{"(", "t", ")"}]}]}], ")"}], "=", 
    RowBox[{
     RowBox[{"x", 
      RowBox[{"(", "t", ")"}]}], "+", 
     RowBox[{"\[ImaginaryI]", " ", "y", 
      RowBox[{"(", "t", ")"}]}]}]}]}]]],
 ",  for ",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{"a", "\[LessEqual]", "t", "\[LessEqual]", "b"}]}]]],
 ",  where both ",
 Cell[BoxData[
  RowBox[{"x", 
   RowBox[{"(", "t", ")"}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{"y", 
   RowBox[{"(", "t", ")"}]}]]],
 " are continuous real-valued functions.  If both ",
 Cell[BoxData[
  RowBox[{"x", 
   RowBox[{"(", "t", ")"}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{"y", 
   RowBox[{"(", "t", ")"}]}]]],
 " are differentiable, we say that the curve is smooth.  A curve for which ",
 Cell[BoxData[
  RowBox[{"x", 
   RowBox[{"(", "t", ")"}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{"y", 
   RowBox[{"(", "t", ")"}]}]]],
 " are differentiable except for a finite number of points is called \
piecewise smooth.  "
}], "Text"],

Cell[TextData[{
 StyleBox["Definition  (",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Curve",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/Curve.html"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 StyleBox[").",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  \n\n\tWe specify a curve ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " as  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"C", ":", " ", 
    RowBox[{"z", 
     RowBox[{"(", "t", ")"}]}]}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"x", 
      RowBox[{"(", "t", ")"}]}], "+", 
     RowBox[{"\[ImaginaryI]", " ", "y", 
      RowBox[{"(", "t", ")"}], "   ", "for", "   ", "a"}]}], "\[LessEqual]", 
    "t", "\[LessEqual]", "b"}]}]]],
 ",  \n\nand say that ",
 Cell[BoxData[
  RowBox[{"z", 
   RowBox[{"(", "t", ")"}]}]]],
 " is a parametrization for the curve ",
 StyleBox["C",
  FontFamily->"Courier New"],
 ".  Notice that with this parametrization, we are specifying a direction the \
curve ",
 StyleBox["C",
  FontFamily->"Courier New"],
 ", and we say that ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " is a curve that goes from the initial point  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"z", 
    RowBox[{"(", "a", ")"}]}], "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"x", 
       RowBox[{"(", "a", ")"}]}], 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      RowBox[{"y", 
       RowBox[{"(", "a", ")"}]}]}], ")"}], "=", 
    RowBox[{
     RowBox[{"x", 
      RowBox[{"(", "a", ")"}]}], "+", 
     RowBox[{"\[ImaginaryI]", " ", "y", 
      RowBox[{"(", "a", ")"}]}]}]}]}]]],
 "  to the terminal point  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"z", 
    RowBox[{"(", "b", ")"}]}], "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"x", 
       RowBox[{"(", "b", ")"}]}], 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      RowBox[{"y", 
       RowBox[{"(", "b", ")"}]}]}], ")"}], "=", 
    RowBox[{
     RowBox[{"x", 
      RowBox[{"(", "b", ")"}]}], "+", 
     RowBox[{"\[ImaginaryI]", " ", "y", 
      RowBox[{"(", "b", ")"}]}]}]}]}]]],
 ".  If we had another function whose range was the same set of points as \
z(t) but whose initial and final points were reversed, we would indicate the \
curve this function defines by ",
 StyleBox["-C",
  FontFamily->"Courier New"],
 "."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Example 1.22.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Find parametrizations for ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["-C",
  FontFamily->"Courier New"],
 ", where ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " is the straight line segment beginning at ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "0"], "=", 
   RowBox[{
    SubscriptBox["x", "0"], "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["y", "0"]}]}]}]]],
 " and ending at ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], "=", 
   RowBox[{
    SubscriptBox["x", "1"], "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["y", "1"]}]}]}]]],
 ".  \n\nSolution.  Refer to Figure 1.21. The vector form of a line shows \
that the direction of ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " is ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], "-", 
   SubscriptBox["z", "0"]}]]],
 ".  As ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 " is a point on ",
 StyleBox["C",
  FontFamily->"Courier New"],
 ", its vector equation is\n\n",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      StyleBox[
       RowBox[{"(", 
        RowBox[{"1", "-", "48"}], ")"}],
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->RGBColor[0, 0, 0.996109]], "                      ", 
      RowBox[{"C", ":", " ", 
       RowBox[{"z", 
        RowBox[{"(", "t", ")"}]}]}]}], " ", "=", " ", 
     RowBox[{
      RowBox[{
       SubscriptBox["z", "0"], " ", "+", " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["z", "1"], "-", 
          SubscriptBox["z", "0"]}], ")"}], "t", "    ", 
        StyleBox["for",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], "    ", "0"}]}], "\[LessEqual]", "t", 
      "\[LessEqual]", "1"}]}], 
    StyleBox[",",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], 
    StyleBox["  ",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], 
    StyleBox["or",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]]}], "\n"}], "\n", 
  RowBox[{"                                   ", 
   RowBox[{
    RowBox[{"C", ":", " ", 
     RowBox[{"z", 
      RowBox[{"(", "t", ")"}]}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      RowBox[{
       StyleBox["(",
        FontSize->16], 
       RowBox[{
        SubscriptBox["x", "0"], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["x", "1"], "-", 
           SubscriptBox["x", "0"]}], ")"}], "t"}]}], 
       StyleBox[")",
        FontSize->16]}], " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", 
       RowBox[{
        StyleBox["(",
         FontSize->16], 
        RowBox[{
         SubscriptBox["y", "0"], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["y", "1"], "-", 
            SubscriptBox["y", "0"]}], ")"}], "t"}]}], 
        StyleBox[")",
         FontSize->16]}], "  ", 
       StyleBox["for",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "   ", "0"}]}], "\[LessEqual]", "t", 
     "\[LessEqual]", 
     RowBox[{"1", 
      StyleBox[" ",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox[".",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]]}]}]}]}]}]],
 "  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "Clearly one parametrization for  ",
 Cell[BoxData[
  RowBox[{"-", "C"}]]],
 "  is \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     RowBox[{"C", ":", " ", 
      RowBox[{"\[Gamma]", 
       RowBox[{"(", "t", ")"}]}]}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      SubscriptBox["z", "1"], " ", "+", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["z", "0"], "-", 
         SubscriptBox["z", "1"]}], ")"}], "t", "    ", 
       StyleBox["for",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "    ", "0"}]}], "\[LessEqual]", "t", 
     "\[LessEqual]", " ", "1"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   StyleBox["  ",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   StyleBox["or",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]]}]]],
 "\n\n",
 StyleBox["Remark.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]],
 "  Note that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Gamma]", 
    RowBox[{"(", "t", ")"}]}], " ", "=", " ", 
   RowBox[{"z", 
    RowBox[{"(", 
     RowBox[{"1", "-", "t"}], ")"}]}]}]]],
 ",  which illustrates a general principle:  If ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " is a curve parametrized by  ",
 Cell[BoxData[
  RowBox[{"z", 
   RowBox[{"(", "t", ")"}]}]]],
 "  for  ",
 Cell[BoxData[
  RowBox[{"0", "\[LessEqual]", "t", "\[LessEqual]", "1"}]]],
 ",  then one parametrization for  ",
 Cell[BoxData[
  RowBox[{"-", "C"}]]],
 "  will be  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Gamma]", 
    RowBox[{"(", "t", ")"}]}], " ", "=", " ", 
   RowBox[{"z", 
    RowBox[{"(", 
     RowBox[{"1", "-", "t"}], ")"}]}]}]]],
 ",  for  ",
 Cell[BoxData[
  RowBox[{"0", "\[LessEqual]", "t", "\[LessEqual]", "1"}]]],
 ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 1.22.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "Enter  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "0"], "  ", "and", "  ", 
   SubscriptBox["z", "1"]}]]],
 "  and construct the line segment."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "0"], "=", 
     RowBox[{
      SubscriptBox["x", "0"], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["y", "0"]}]}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "1"], "=", 
     RowBox[{
      SubscriptBox["x", "1"], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["y", "1"]}]}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"z", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{
      SubscriptBox["z", "0"], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["z", "1"], "-", 
         SubscriptBox["z", "0"]}], ")"}], "t"}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(0\)]\) = \>\"", ",", 
      SubscriptBox["z", "0"]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["z", "1"]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<z[t] = \!\(\*SubscriptBox[\(z\), \(0\)]\) + (\!\(\*SubscriptBox[\(z\
\), \(1\)]\)-\!\(\*SubscriptBox[\(z\), \(0\)]\))t\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<z[t] = \>\"", ",", 
      RowBox[{"z", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"z", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{
      SubscriptBox["x", "0"], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["x", "1"], "-", 
         SubscriptBox["x", "0"]}], ")"}], "t"}], "+", 
      RowBox[{"\[ImaginaryI]", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["y", "0"], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["y", "1"], "-", 
            SubscriptBox["y", "0"]}], ")"}], "t"}]}], ")"}]}]}]}], ";"}], " ",
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The equation of, C, a line segment\>\"", "]"}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<starting at \!\(\*SubscriptBox[\(z\), \(0\)]\) and ending at \
\!\(\*SubscriptBox[\(z\), \(1\)]\).\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<z[t] = \>\"", ",", 
      RowBox[{"z", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<       for  0 \[LessEqual] t \[LessEqual] 1\>\"", 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<z[0] = \>\"", ",", 
      RowBox[{"z", "[", "0", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<z[1] = \>\"", ",", 
      RowBox[{"z", "[", "1", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39897300309375*^9},
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "\[Gamma]"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "0"], "=", 
     RowBox[{
      SubscriptBox["x", "0"], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["y", "0"]}]}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "1"], "=", 
     RowBox[{
      SubscriptBox["x", "1"], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["y", "1"]}]}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Gamma]", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{
      SubscriptBox["z", "1"], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["z", "0"], "-", 
         SubscriptBox["z", "1"]}], ")"}], "t"}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(0\)]\) = \>\"", ",", 
      SubscriptBox["z", "0"]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["z", "1"]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<\[Gamma][t] = \!\(\*SubscriptBox[\(z\), \
\(1\)]\)+(\!\(\*SubscriptBox[\(z\), \(0\)]\)-\!\(\*SubscriptBox[\(z\), \(1\)]\
\))t\>\"", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Gamma][t] = \>\"", ",", 
      RowBox[{"\[Gamma]", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Gamma]", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{
      SubscriptBox["x", "1"], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["x", "0"], "-", 
         SubscriptBox["x", "1"]}], ")"}], "t"}], "+", 
      RowBox[{"\[ImaginaryI]", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["y", "1"], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["y", "0"], "-", 
            SubscriptBox["y", "1"]}], ")"}], "t"}]}], ")"}]}]}]}], ";"}], " ",
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The equation of, -C, a line segment\>\"", "]"}], ";"}],
    " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<starting at \!\(\*SubscriptBox[\(z\), \(1\)]\) and ending at \
\!\(\*SubscriptBox[\(z\), \(0\)]\).\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Gamma][t] = \>\"", ",", 
      RowBox[{"\[Gamma]", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<       for  0 \[LessEqual] t \[LessEqual] 1\>\"", 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Gamma][0] = \>\"", ",", 
      RowBox[{"\[Gamma]", "[", "0", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Gamma][1] = \>\"", ",", 
      RowBox[{"\[Gamma]", "[", "1", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<z[t] = \>\"", ",", 
      RowBox[{"z", "[", "t", "]"}], ",", 
      "\"\<       for  0 \[LessEqual] t \[LessEqual] 1\>\""}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<z[0] = \>\"", ",", 
      RowBox[{"z", "[", "0", "]"}], ",", "\"\<   z[1] = \>\"", ",", 
      RowBox[{"z", "[", "1", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Gamma][t] = \>\"", ",", 
      RowBox[{"\[Gamma]", "[", "t", "]"}], ",", 
      "\"\<,       for  0 \[LessEqual] t \[LessEqual] 1\>\""}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Gamma][0] = \>\"", ",", 
      RowBox[{"\[Gamma]", "[", "0", "]"}], ",", "\"\<,    \[Gamma][1] = \>\"",
       ",", 
      RowBox[{"\[Gamma]", "[", "1", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Note that\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<z[1-t] = \>\"", ",", 
      RowBox[{"z", "[", 
       RowBox[{"1", "-", "t"}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<z[1-t] = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"z", "[", 
        RowBox[{"1", "-", "t"}], "]"}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Does  z[1-t] = \[Gamma][t] ?  \>\"", ",", " ", 
      RowBox[{"ComplexExpand", "[", " ", 
       RowBox[{
        RowBox[{"z", "[", 
         RowBox[{"1", "-", "t"}], "]"}], "\[Equal]", 
        RowBox[{"\[Gamma]", "[", "t", "]"}]}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39897301415625*^9, 3.398973017046875*^9}}]
}, Closed]],

Cell[GraphicsData["CompressedBitmap", "\<\
eJztmclrU0Ecxyd5SffEWquW1m4urbXEbgdBcDlULagoCj14EGIpTQVR2oIH
Ea0L9eBBqAsKVTwI4sGDB8E/x4MbKC4HD16emXl537wkv9/MvDQqSEI7b/r7
fWZ+31neLM3R9EJm+lx6YXYq3XNoLn0hMzs133Pw/FzW5ESEiCwLIe71CJl3
s9lc4mZ/3LsykZa/nJ+TSVTqEI5nzn06A9C8yjvCk+sxXV7usnx8kYb6Ikj+
BivZQfgP2ESnCs5U/VV/1V/1/6f+FpnGpaWV8NYStiFDjVQ96wgbtYzvNNTd
BLUOV6PyxghvVOtNGSInVBorsEFGoblQYrzYJzgJtjaT1CRho7qrgbDF/6Cu
NXRfRdFXqqtWo6CCA0uJXaU6KyWqD5LaqVqpeJSNmieUzfSiDmrGmtJqWlT+
9TJp8o96rcsiYwZyWKY1khypGKl6r06SwwYy5Y+CHT4gUzmKrmMtpk+m0uTW
WpfZgjJN1h3ZDW3jBrID5ISB3AjyiEd+JyBqUxwkbK1o1HGvsm8ERO2ClLK1
qOykV9l7+dCvEQ7nHSBsCTR9MhAgxPal2+6oJYQSUQ8Rp7yyHwiIWoOpABRH
BY0j6Gkv6EeuQysYNIrxPBPsbqsNp9y4cuKrd3/aZgrpz0v96LQMP7mjlh25
FZVRJWbCvYq9qKyGr0z90YkxoI5CQbIdZMJAbkD0ZgPZApI6MQfJJMg2A9kI
nZsMZB3IbgMZQ/TNRjKb6eOhX/6M0m2xP1HTEA/9ADTGQ1/RxF089BnQbh76
BGgPD72Dpv089BbQOA/dIly2t7NRSJ3gAywVueSHCkBtTim04DAf4Ko/0iVL
gPw0wMuuqsrErmmqfcf48IvqUbKWUlqcIqX2+11Yfhs67gSv/BobqFB2I8FR
3RVWZH7xnORFXrcQCVuoa0xYuV2YDW2YNftCz4sQd72wAjsgsF1Tcq9BssWl
MKyw/Em3k/BqVrDHmkC6I+B6X77bGy7gE2J0/LGmTkLNaBm1FWkCvcFYUduT
puBrFEyVN8ivIHnEz+nwl8Av8tALQJd46Ll8qCPhFR56huYt8tBThLvBQyuA
qC0uBz0EdJuH7kPTHR5ayrUueK9Y5vGb8lEjcdye3Ad2eDZ9xJOqR+okuWID
5c9nwSDKWq+z5pubPwuK8r6s2+7PC3E2YKXuMZmA3/SPk9L7iCgor6KWrsNB
pN8fmeLv8WZCtjCXF5HfiNa5Dg==\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{403, 149},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 StyleBox["\t\t\tFigure 1.21",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  The straight-line segment ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " joining ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "0"], " ", 
   StyleBox["to",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], " ", 
   SubscriptBox["z", "1"]}]]],
 "."
}], "Text"],

Cell[TextData[{
 StyleBox["Extra Example 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Find the equation of the line segment with the initial point  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "0"], "=", 
   RowBox[{
    RowBox[{"-", "3"}], "+", 
    RowBox[{"2", "\[ImaginaryI]"}]}]}]],
  AspectRatioFixed->True],
 "  and the terminal point  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], "=", " ", 
   RowBox[{"1", " ", "+", " ", "\[ImaginaryI]"}]}]],
  AspectRatioFixed->True],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Extra Solution 1.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "Enter the initial point  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "0"], "=", 
   RowBox[{
    RowBox[{"-", "3"}], "+", 
    RowBox[{"2", "\[ImaginaryI]"}]}]}]],
  AspectRatioFixed->True],
 "  and the terminal point  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], "=", " ", 
   RowBox[{"1", " ", "+", " ", "\[ImaginaryI]"}]}]],
  AspectRatioFixed->True],
 "  and construct the line segment."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "0"], "=", 
     RowBox[{
      RowBox[{"-", "3"}], "+", 
      RowBox[{"2", "\[ImaginaryI]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "1"], "=", " ", 
     RowBox[{"1", " ", "+", " ", "\[ImaginaryI]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["x", "0"], "=", 
     RowBox[{"Re", "[", 
      SubscriptBox["z", "0"], "]"}]}], ";", "  ", 
    RowBox[{
     SubscriptBox["y", "0"], "=", 
     RowBox[{"Im", "[", 
      SubscriptBox["z", "0"], "]"}]}], ";", "  ", 
    RowBox[{
     SubscriptBox["x", "1"], "=", 
     RowBox[{"Re", "[", 
      SubscriptBox["z", "1"], "]"}]}], ";", "  ", 
    RowBox[{
     SubscriptBox["y", "1"], "=", 
     RowBox[{"Im", "[", 
      SubscriptBox["z", "1"], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"z", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{
      SubscriptBox["x", "0"], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["x", "1"], "-", 
         SubscriptBox["x", "0"]}], ")"}], "t"}], "+", 
      RowBox[{"\[ImaginaryI]", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["y", "0"], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["y", "1"], "-", 
            SubscriptBox["y", "0"]}], ")"}], "t"}]}], ")"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dot0", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"PointSize", "[", "0.03", "]"}], ",", "Green", ",", 
        RowBox[{"Point", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Re", "[", 
            SubscriptBox["z", "0"], "]"}], ",", 
           RowBox[{"Im", "[", 
            SubscriptBox["z", "0"], "]"}]}], "}"}], "]"}]}], "}"}], "]"}]}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dot1", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"PointSize", "[", "0.03", "]"}], ",", "Red", ",", 
        RowBox[{"Point", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Re", "[", 
            SubscriptBox["z", "1"], "]"}], ",", 
           RowBox[{"Im", "[", 
            SubscriptBox["z", "1"], "]"}]}], "}"}], "]"}]}], "}"}], "]"}]}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"gr", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"z", "[", "t", "]"}], "]"}], ",", 
         RowBox[{"Im", "[", 
          RowBox[{"z", "[", "t", "]"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", "0", ",", "1"}], "}"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "3.2"}], ",", "1.2"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "2.2"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "3"}], ",", "1", ",", "1"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "2", ",", "1"}], "]"}]}], "}"}]}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", 
        FractionBox["1", "2"]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Magenta"}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}]}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"gr", ",", "dot0", ",", "dot1"}], "]"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Equation of a line segment:\>\"", "]"}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<z[t] = \>\"", ",", 
      RowBox[{"z", "[", "t", "]"}], ",", 
      "\"\<  for  0 \[LessEqual] t \[LessEqual] 1\>\""}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Initial  point (green)  z[0] = \>\"", ",", " ", 
      RowBox[{"z", "[", "0", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Terminal point (red)    z[1] = \>\"", ",", " ", 
      RowBox[{"z", "[", "1", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.398973028578125*^9, 3.39897305565625*^9}, {
  3.39972045875*^9, 3.39972045915625*^9}, {3.400238103015625*^9, 
  3.400238113875*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 "\tA curve ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " having the property that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"z", 
    RowBox[{"(", "a", ")"}]}], "=", 
   RowBox[{"z", 
    RowBox[{"(", "b", ")"}]}]}]]],
 "  is said to be a closed curve.  The line segment",
 StyleBox[" (1-48)",
  FontColor->RGBColor[0, 0, 1]],
 " is not a closed curve.  The range of  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"z", 
    RowBox[{"(", "t", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"x", 
     RowBox[{"(", "t", ")"}]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", "y", 
     RowBox[{"(", "t", ")"}]}]}]}]]],
 ",  where  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"x", 
     RowBox[{"(", "t", ")"}]}], "=", 
    RowBox[{"sin", " ", "2", "t", " ", "cos", " ", "t"}]}], ",", " ", 
   RowBox[{
    RowBox[{
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", "y", 
     RowBox[{"(", "t", ")"}]}], "=", 
    RowBox[{"sin", " ", "2", "t", " ", "sin", " ", "t"}]}]}]]],
 "  for  ",
 Cell[BoxData[
  RowBox[{"0", "\[LessEqual]", "t", "\[LessEqual]", 
   RowBox[{"2", "\[Pi]"}]}]]],
 "  is a closed curve because  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"z", 
    RowBox[{"(", "0", ")"}]}], "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"0", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "0"}], ")"}], "=", 
    RowBox[{"z", 
     RowBox[{"(", 
      RowBox[{"2", "\[Pi]"}], ")"}]}]}]}]]],
 ".  The range of ",
 Cell[BoxData[
  RowBox[{"z", 
   RowBox[{"(", "t", ")"}]}]]],
 " is the four-leaved rose shown in Figure 1.22.  Note that, as ",
 StyleBox["t",
  FontFamily->"Courier New"],
 " goes from ",
 Cell[BoxData[
  RowBox[{"0", " ", 
   StyleBox["to",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   StyleBox[" ",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   FractionBox["\[Pi]", "2"]}]]],
 ", the point is on leaf  ",
 StyleBox["1",
  FontFamily->"Courier New"],
 " ;   from ",
 Cell[BoxData[
  RowBox[{
   FractionBox["\[Pi]", "2"], " ", 
   StyleBox["to",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   StyleBox[" ",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "\[Pi]"}]]],
 " to , it is on leaf  ",
 StyleBox["2",
  FontFamily->"Courier New"],
 " ;  between ",
 Cell[BoxData[
  RowBox[{"\[Pi]", " ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   StyleBox[" ",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   FractionBox[
    RowBox[{"3", "\[Pi]"}], "2"]}]]],
 ", it is on leaf ",
 StyleBox["3",
  FontFamily->"Courier New"],
 ";  and finally, for ",
 StyleBox["t",
  FontFamily->"Courier New"],
 " between ",
 Cell[BoxData[
  RowBox[{
   FractionBox[
    RowBox[{"3", "\[Pi]"}], "2"], " ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   StyleBox[" ",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "2", "\[Pi]"}]]],
 ", it is on leaf ",
 StyleBox["4",
  FontFamily->"Courier New"],
 ".  "
}], "Text"],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{353, 243},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 StyleBox["\t\tFigure 1.22",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  The curve ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"x", 
     RowBox[{"(", "t", ")"}]}], "=", 
    RowBox[{"sin", " ", "2", "t", " ", "cos", " ", "t"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], " ", 
   RowBox[{
    RowBox[{
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", "y", 
     RowBox[{"(", "t", ")"}]}], "=", 
    RowBox[{"sin", " ", "2", "t", " ", "sin", " ", "t"}]}]}]]],
 " for ",
 Cell[BoxData[
  RowBox[{"0", "\[LessEqual]", "t", "\[LessEqual]", 
   RowBox[{"2", "\[Pi]"}]}]]],
 ", which forms a four-leaved rose."
}], "Text"],

Cell[TextData[{
 "\tNote further, in Figure 1.22, that at the point ",
 Cell[BoxData[
  RowBox[{"(", 
   RowBox[{"0", 
    StyleBox[",",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], "0"}], ")"}]]],
 ", the curve has crossed over itself (at points other than those \
corresponding with   ",
 Cell[BoxData[
  RowBox[{"t", "=", 
   RowBox[{
    RowBox[{"0", " ", 
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], " ", "t"}], "=", 
    RowBox[{"2", "\[Pi]"}]}]}]]],
 ");  we want to be able to distinguish when a curve does not cross over \
itself in this way.  The curve ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " is called simple if it does not cross over itself, except possibly at its \
initial and terminal points.  In other words, the curve  ",
 Cell[BoxData[
  RowBox[{"C", ":", " ", 
   RowBox[{"z", 
    RowBox[{"(", "t", ")"}]}]}]]],
 ",  for  ",
 Cell[BoxData[
  RowBox[{"a", "\[LessEqual]", "t", "\[LessEqual]", "b"}]]],
 ",  is simple provided that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"z", 
    RowBox[{"(", 
     SubscriptBox["t", "1"], ")"}]}], "\[NotEqual]", 
   RowBox[{"z", 
    RowBox[{"(", 
     SubscriptBox["t", "2"], ")"}]}]}]]],
 "  whenever  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["t", "1"], "\[NotEqual]", 
   SubscriptBox["t", "2"]}]]],
 ",  except possibly when  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["t", "1"], "=", 
   RowBox[{
    RowBox[{"a", "  ", 
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", 
     SubscriptBox["t", "2"]}], "=", "b"}]}]]],
 "."
}], "Text"],

Cell[TextData[{
 StyleBox["Extra Example 2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  The curve  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"x", 
     RowBox[{"(", "t", ")"}]}], "=", 
    RowBox[{"sin", " ", "2", "t", " ", "cos", " ", "t"}]}], ",", " ", 
   RowBox[{
    RowBox[{
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", "y", 
     RowBox[{"(", "t", ")"}]}], "=", 
    RowBox[{"sin", " ", "2", "t", " ", "sin", " ", "t"}]}]}]]],
 "  for  ",
 Cell[BoxData[
  RowBox[{"0", "\[LessEqual]", "t", "\[LessEqual]", 
   RowBox[{"2", "\[Pi]"}]}]]],
 ".  \n",
 StyleBox["Remark.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 " The curve looks like a \"four leafed rose\"."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Explore ",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 StyleBox["Extra Solution 2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell["Enter the curve and plot it.", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"t", ",", "x", ",", "y"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "t_", "]"}], "=", 
     RowBox[{
      RowBox[{"Sin", "[", 
       RowBox[{"2", "t"}], "]"}], 
      RowBox[{"Cos", "[", "t", "]"}]}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"y", "[", "t_", "]"}], "=", 
     RowBox[{
      RowBox[{"Sin", "[", 
       RowBox[{"2", "t"}], "]"}], 
      RowBox[{"Sin", "[", "t", "]"}]}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{"ParametricPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "[", "t", "]"}], ",", 
       RowBox[{"y", "[", "t", "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", 
       RowBox[{"2", "\[Pi]"}]}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.8"}], ",", "0.8"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.8"}], ",", "0.8"}], "}"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "0.8"}], ",", "0.8", ",", "0.8"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "0.8"}], ",", "0.8", ",", "0.8"}], "]"}]}], "}"}]}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", "[", "0.01", "]"}], ",", "Green"}], "}"}]}], ",",
      
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<x = \>\"", ",", 
      RowBox[{"x", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y = \>\"", ",", " ", 
      RowBox[{"y", "[", "t", "]"}], ",", 
      "\"\<  for  0 \[LessEqual] t \[LessEqual] 2\[Pi]\>\""}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39897306525*^9, 3.39897306775*^9}, {
  3.399194125296875*^9, 3.3991941269375*^9}, {3.399720481859375*^9, 
  3.399720482296875*^9}}]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 1.23.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Show that the circle ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " with center ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "0"], "=", 
   RowBox[{
    SubscriptBox["x", "0"], "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["y", "0"]}]}]}]]],
 " and radius ",
 Cell[BoxData["R"]],
 " can be parameterized to form a simple closed curve.\n\nSolution.  Note \
that the required parametrization is \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"C", ":", " ", 
     RowBox[{"z", 
      RowBox[{"(", "t", ")"}]}]}], "  ", "=", "  ", 
    RowBox[{
     SubscriptBox["z", "0"], " ", "+", " ", 
     RowBox[{"R", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", "t"}]]}]}]}], 
   "\n"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"C", ":", " ", 
     RowBox[{"z", 
      RowBox[{"(", "t", ")"}]}]}], "  ", "=", "  ", 
    RowBox[{
     SubscriptBox["x", "0"], "+", 
     RowBox[{"\[ImaginaryI]", " ", 
      SubscriptBox["y", "0"]}], " ", "+", " ", 
     RowBox[{"R", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", "t"}]]}]}]}], 
   "\[IndentingNewLine]"}], "\n", 
  RowBox[{
   RowBox[{
    RowBox[{"C", ":", " ", 
     RowBox[{"z", 
      RowBox[{"(", "t", ")"}]}]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["x", "0"], "+", 
       RowBox[{"R", " ", "cos", " ", "t"}]}], ")"}], " ", "+", " ", 
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["y", "0"], "+", " ", 
        RowBox[{"R", " ", "sin", " ", "t"}]}], ")"}]}]}]}], 
   StyleBox[" ",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   StyleBox[" ",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "                            ", 
   RowBox[{
    RowBox[{
     StyleBox["for",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "   ", "0"}], "\[LessEqual]", "t", 
    "\[LessEqual]", 
    RowBox[{"2", 
     RowBox[{"\[Pi]", " ", 
      StyleBox[".",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]]}]}]}]}]}]],
 "  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "\tFigure 1.23 shows that, as t varies from ",
 Cell[BoxData[
  RowBox[{"0", 
   StyleBox["to",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], " ", "2", "\[Pi]"}]]],
 ", the circle is traversed counterclockwise.  If you were traveling around \
the circle in this manner, its interior would be on your left.  When a simple \
closed curve is parametrized in this fashion, we say that the curve has a \
positive orientation.  We will have more to say about this idea shortly."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Explore ",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 StyleBox["Solution 1.23.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "Enter  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "0"], "  ", "and", "  ", "R"}]]],
 "  and construct the standard parameterization for the circle.\nUse the \
complex exponential form ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"z", "[", "t", "]"}], "=", 
   RowBox[{
    SubscriptBox["z", "0"], "+", 
    RowBox[{"R", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "t"}]]}]}]}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "0"], "=", 
     RowBox[{"2", "+", "\[ImaginaryI]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"R", "=", "2"}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"z", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{
      SubscriptBox["z", "0"], "+", 
      RowBox[{"R", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "t"}]]}]}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "t_", "]"}], "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"Re", "[", 
       RowBox[{"z", "[", "t", "]"}], "]"}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"y", "[", "t_", "]"}], "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"Im", "[", 
       RowBox[{"z", "[", "t", "]"}], "]"}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{"ParametricPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "[", "t", "]"}], ",", 
       RowBox[{"y", "[", "t", "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", 
       RowBox[{"2", "\[Pi]"}]}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0.0", ",", "5.0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.5"}], ",", "3.5"}], "}"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0.0", ",", "5.0", ",", "1.0"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1.0"}], ",", "3.0", ",", "1.0"}], "]"}]}], "}"}]}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", "[", "0.01", "]"}], ",", "Blue"}], "}"}]}], ",", 
     
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The equation of, C, a circle\>\"", "]"}], 
    ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<with center \!\(\*SubscriptBox[\(z\), \(0\)]\) = \>\"", ",", 
      SubscriptBox["z", "0"], ",", "\"\< and radius R = \>\"", ",", "R"}], 
     "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<       for  0 \[LessEqual] t \[LessEqual] 2\[Pi]\>\"", 
     "]"}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<z[t] = \>\"", ",", 
      RowBox[{"z", "[", "t", "]"}]}], "]"}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<       for  0 \[LessEqual] t \[LessEqual] 2\[Pi]\>\"", 
     "]"}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<x = \>\"", ",", 
      RowBox[{"x", "[", "t", "]"}]}], " ", "]"}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y = \>\"", ",", " ", 
      RowBox[{"y", "[", "t", "]"}]}], " ", "]"}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<       for  0 \[LessEqual] t \[LessEqual] 2\[Pi]\>\"", 
     "]"}], ";"}], "  ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.398973076171875*^9, 3.398973080265625*^9}, {
  3.39919410415625*^9, 3.3991941138125*^9}, {3.3997204920625*^9, 
  3.39972049240625*^9}}]
}, Closed]],

Cell[GraphicsData["CompressedBitmap", "\<\
eJzNW+eTFEUUH27n0nKEgwNB0gEiYCInQUQRKJIkAckcOUqUIJYg2awgIkaC
mEMZylglYBlQ/KDlH6IfrNJPjttvZn69M7zX3bOAuHXb9/b17/36dZqZft0z
sWHziqVrGzavXNxQP2Zjw/oVKxdvqh+9bmNBlWvkeY0ueJ73Z72n5KAgRklQ
+At+VonSXEX5Y5WUKZ+8XKiOPnXhr23qH2n7qiRP2pwXViJEtypCFmXRV6W3
Mhl1FpvBLm5xhlOuXv5+lfpK870FlNL9IMMPMDoD+0FG950Mf5DRVVLqJ3SF
TzUD/VJm3sHoqtGnjZncL2SyTWjYHJPbhtF9LpNtZkYwR1um0ipmBFaopDxb
oZuYQv1Lr8tlbRiuy1pn6yhuPNVlGzh7MEi49iljdGdkst38WPZ59Tcy0V5G
l/bPQrGP0aV7zUJhqk65ks65tOsFGXSlr5A7QicKub/JoO0qrVCgX2UQ6aoU
6BcZtDFkKigISdJPMnyNShsrRV7BSfpWhi9TaS3gzZR0VoYvUSmByuE7Sc2V
7ivZsEGlNUrRGIYkNVW6z2TDBSG8oGiBJq0F2Sey4VyVVitFa3RYG+g+kg1n
o8SBgH8gw2cCNBSG78nw6QCNUFKlkt6V4dMAH4Vx8LYMnwrQOEhvyvDJAE2E
9IYMvxugKZBOy3DNeQ+kUzJ8PEAzIZ2U4VRBdcEI5kA6IcPHAjRfSer6ExyX
4WMAb4D0igwfDdBiSLjMBxr3vEwxKhylCh7ahEngLZUy6NcxmfEuSv0QH3ix
7UpAtdpGdSdjU6bS1VFXGat2R9QmEbzSAh8BzlXR3Aq8ozJ8ODjXAP6cDB8W
zajAWwdDA5ye+/MKtAFuHZHhQwDfBPizFnZyZks0KsPO8AJAnrFYp3qFmnmr
RPa0hYyGGVE8EP1UjyuF1ODFEG58YujvSA/C0FGDI4MxP3OaBrk7kPuUhYJq
vgeSAT4InHsBf1KGDwR8H6QnLHDiPAD44zJ8AEAHYWiA9wf8UcAfs8A1SBvy
8H5Jj3MWeN9ke5D0iAWuOydngfdJdr1uIwM8h8Hrowd4eG+ADiU7jIf3Avww
pP0WOHEegWSA3wLOI8nBZoAT51FIlw9+M1w4mpwoBjhxHoPkDvcxa3n4TQC9
kJzkBjiBXiwBTuXsluE3AvQSDG1wAr3sAr8B7O5wAr0K6eHLBu8JZ9zhBDoO
w10u8BOQLh+8B0An4cxOF/gpSP8D+Hgmd3o2inGpXPWZkY1ipJJonZ4OYziT
dUcn6CdUnWtiJqOHLMxU/Ggml6OdCQsn2jEOtOo7IxvtKL4d5pbAQl0zJ5vh
6SsFp0V36hF0UphRUE2FWYDliYGxltFVMLoqlVKcQK9XJ0HX1JGlI6OrYXR9
ZYebS85xxVNEZEIoedF6nHRcoRxLe0bHVbaP7HBVPMe88Mm7PJEbTxnfkFfJ
VMVX3UuE1YyUN+aSRHx+yrek57l4ULEx7UrYpmvIzORwFupoOeiFKhsGQHq7
wViuFOFNQv24zcL4R15l5S6hgVXbhnxcJPgSnU1Hzc2UTI+6FdPbMqJTHnAU
XAz7v21+Vw8yNH9q2JfQDFmaxtYL5rnrUICOOOtrS7ySiS5/DleKDO3X0kjk
srNTQls1Z/wLhCcu9eVuHh4NSUDiZUdxI9VETZoqxtPF8HkdrXbpThMyDLeh
S7nRU83jZVngdQCkKd+uZVL3djTguW1kw23A4VEouvMU1PGyLPA6gcrp8Ug/
n80AWc8kmfsj3kxQ9CiV4l5QdC+VYhYori+VYjYoupVKMQcUXTGuMlLMBUWX
pBfuC5p5oOjMVGSnC8V8UNRno+jBUHQqlWIBKDowzelEsRAU7eFFfTaKBlBc
Cy8yUiwCRVvGi10yRU+Gok2pFItB0ZqpiBPFElC0ghd0vaWLXVtnMj9J1hL+
hM/kF91zr4GRgVmHqZaCuRbM3G2hDSycol/LQNssSVsOH53I/CRZUzQlt1jT
VTfQ6nDhctDWwMcuyHUKUGqKxvCsC3INFDokugIU+SQF5TpFVVeCooqpiFPY
V1NUJClskWMdaF4FCh8UXZFri1X7SYqyJIUtOq5j76uLvCik1yHDKXLfEEvy
6ilyL+Z22kTwwX3xfK0EaTe44bTloX2tBoVuLBsFgRbyLmk+PYpsezw5A18e
fJ2d+cg/HCrwakCh7/AGCr2pdR8MO6Jsw/aW3jxbB8P2ILMZ+knDdiAz7L/1
A2g9DNuCzGboJw31FdCwn9ifMWwNLwzbnAMA2gDDOpDZDP2kYQvoDPuwAxnD
Wnhh2B4eBNBGGDYDmc3QTxo2gc6wfz2YMayBF4Z98iGMYR6GtrMF0VKG1jEe
jn0W3QrsFNFaKWFdAWvDGYWhaQeC6PyKrki0UI9zY9JDMukwI2lZ6JwXHaA4
nI2Hbgk0kuh0iOEIyW2S9XoX6+GMNZ3/WKsy6CCLwfPbVUoHbla7wEck4eRb
CwbHPdVtkWnpeFElaFO1oS7gQgrcc9n9llIqUAoVQj/z8ViRo1tiZHqzXB4d
uaKuSEUNlmNslkXcgdckRSB5kyH6ZXMth6Ht5TCp1XcZ/Eu3ulQUHzjK5NLI
WBcUU3jF5/FwGfe42HKEytoUY6JREa1rSWqH0hP09Jsb2oZBp08tzoPE7Uxl
nDH6cOgsSIazkxNQ9gzADQc59bnPaZBek+GTANLS6zJcn1mdAMlwxFWfiB0L
6S0Zrk+q0t40Hc99R4br07zDIRkO/+qzwkMgvS/DqXNoj6Ef4B/KcH3iuRec
MRyQXgA4rdQpQFkH3aey4SK41SRsrTieTEeyDW9WUGyADptj8yOcb6QznB5f
DhDZtFDS1zI84xl4mt45wOnSZXi/YBt8N5zadwI5vSTg9LoBpYZ3FmhZTBe8
Hy2glM7wpgH3OomBnXt15HwI/4f+XXRXisj+Zgz9sFE8/oIavUHyF5PF7Yif
DeG/o424Oye3mX8mNPwjlSVR5OJZyd7czhR54XDPNPhTckUyNhjXMdyt3FV3
zmU0bEXPp19CtIzu9HAtgm9n4BQRo3v4eZ6T/hdNu62828UQuiPnisZH/CHQ
5FBFcoYXYL1G/wIfU64g\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{459, 244},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 StyleBox["\t\tFigure 1.23",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  The simple closed curve  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"z", 
    RowBox[{"(", "t", ")"}]}], "  ", "=", "  ", 
   RowBox[{
    SubscriptBox["z", "0"], " ", "+", " ", 
    RowBox[{"R", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "t"}]]}]}]}]]],
 ",  for  ",
 Cell[BoxData[
  RowBox[{"0", "\[LessEqual]", "t", "\[LessEqual]", 
   RowBox[{"2", "\[Pi]"}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "\tWe need to develop some vocabulary that will help describe sets of points \
in the plane.  One fundamental idea is that of an ",
 Cell[BoxData["\[Epsilon]"]],
 " neighborhood of the point ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 ".  It is the open disk of radius ",
 Cell[BoxData[
  RowBox[{"\[Element]", 
   RowBox[{">", "0"}]}]]],
 " about ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 " shown in Figure 1.24.  Formally, it is the set of all points satisfying \
the inequality ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["D", "\[Epsilon]"], 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}], "=", 
   RowBox[{"{", 
    RowBox[{"z", ":", 
     RowBox[{"|", 
      RowBox[{"z", "-", 
       SubscriptBox["z", "0"]}], "|", 
      RowBox[{"<", "\[Element]"}]}]}], "}"}]}]]],
 "  and is denoted ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["D", "\[Epsilon]"], 
   RowBox[{"(", 
    SubscriptBox["z", "0"], ")"}]}]]],
 ".  That is,  \n\n",
 StyleBox["(1-49)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["D", "\[Epsilon]"], 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}], "  ", "=", "  ", 
   RowBox[{"{", 
    RowBox[{"z", ":", "  ", 
     RowBox[{"|", 
      RowBox[{"z", "-", 
       SubscriptBox["z", "0"]}], "|", 
      RowBox[{"<", "\[Element]"}]}]}], "}"}]}]]],
 ". "
}], "Text"],

Cell[GraphicsData["CompressedBitmap", "\<\
eJztmVtPE0EUx6ct5RbRlypUY2ykiEVjCOIlaqKRW0RQoYqKKDYEUxLxAhVB
UNF4jZoY0Tfjt/H78OyD656zs2eXdc/MtCpqspQ93cz8/ufMzqVzph0slIqT
04XS1EQh0zdTuFOcmpjN9N6esYsSMSFiK0KIrxkB95Z9K41l/1sfwUDJOt8v
golDO0TCKZZ/KR+0hPcJ4TTXYTY7dwvw9g0K6gIQXCkfFKj6rgkcpkHbFNVH
9VF9VP//1c+5ZZZX9oXHS2BrgP7MQ3fB1gNUJVat1dqQEO949S2wCRBWgWQj
3GFEhaYYCGFLRJMT2y56ywtvgMU4OwBHD294fJLwjAk+QXgr4K95sgA2CWQb
kC958jr53Afkcw0psCexY+C9Ha3c3WRnPeFdjIPtpEdVkNfAHiRymSevgj1M
5GOeHAN7hMhHPHk5ZPyPkvChmRBEcB0j4RIvvAQ2DtBxwhd5/KIzqW3ohBwB
/2p4wAtHSNgFQkWIEWpRD5A6n4GH7tZoLpD3PiAXNGTAe28FGowzz2vOgz0d
0pv3NJp+GrA5nsyDHSBS4dMj4xqfw2AHyyN10ZFsc3tBeN23M6RnZjV+cgE/
8NdM7S3x6nM0OzBsEuriIc6yIY2aMXGLrbC3E/8T/u4Y2ZBeZAMohsTz2GLg
Ea5mjcezgTb+1A+58hwkSaMYU0/T4EwBu7jLWFMHZDVo0nICCWu3sToJZD2o
Gx0/duEuY7Xc8yz52lCBH3f+yFcWbC1AWVoOisXkNQVHuwHUW2Q6UraLGplD
+Z+hxcQFzsMG50OkQnWOxq7VWDNsTA6ZfLQMgd0q00EhOow16ZCF1rmealxl
+zUrc4jGuTEk4gFjddPaHlLsLZ7mjDGJW9F9DYlLZkBD5n2ry33KfhMNtqO/
vO0+T806VUGekKBsB2MrGhiWvvTQ7q0QYibWS6Qi28EEsocao8ilkOwmnwoS
c9iTRCqyP48MnB0UmtGQTsHUWpfHowRJxdlglEg8ICzz5BUi8dChOMOMEXlI
Q+IZBg9hHb6JhZuOpT8mobCd+v0pj4/TzG+X69sQl8Pk9vteCvaMV+NpdQ/F
UZws8RjcKj/jLPGCJ+X5em0fweUdt1/xajzWY4jtgOu+AMBvCVJuhuQLZl/v
ee1NsNUg2EQP/4HHp6lRtU6WYt+t8DiuEPwa4hMP/e1vgaL6qD6qj+r/hXq8
/4O/MWI6hr/yYek2p3Sea1XarNVBPflP+6LKg7urDyCYiTse1v78+Cu9I2I/
AG8hqs0=\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{403, 197},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 StyleBox["\t\t\tFigure 1.24",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "   An ",
 Cell[BoxData["\[Element]"]],
 " neighborhood of the point ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 ". "
}], "Text"],

Cell[TextData[{
 StyleBox["Example 1.24.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  The solution sets of the inequalities  ",
 Cell[BoxData[
  RowBox[{"|", "z", "|", 
   RowBox[{"<", "1"}]}]]],
 ",  ",
 Cell[BoxData[
  RowBox[{"|", 
   RowBox[{"z", "-", "\[ImaginaryI]"}], "|", 
   RowBox[{"<", "2"}]}]]],
 ",  and  ",
 Cell[BoxData[
  RowBox[{"|", 
   RowBox[{"z", "+", "1", "+", 
    RowBox[{"2", "\[ImaginaryI]"}]}], "|", 
   RowBox[{"<", "3"}]}]]],
 "  are neighborhoods of the points  ",
 Cell[BoxData[
  RowBox[{"0", ",", "\[ImaginaryI]", ",", 
   RowBox[{
    StyleBox["and",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], " ", "-", "1", "-", 
    RowBox[{"2", "\[ImaginaryI]"}]}]}]]],
 ",  with radii  ",
 Cell[BoxData[
  RowBox[{"1", ",", "2", ",", 
   RowBox[{
    StyleBox["and",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], " ", "3"}]}]]],
 ",  respectively.  They can also be expressed as  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["D", "1"], 
   RowBox[{"(", "0", ")"}]}]]],
 ",  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["D", "2"], 
   RowBox[{"(", "\[ImaginaryI]", ")"}]}]]],
 ",  and  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["D", "3"], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "-", 
     RowBox[{"2", "\[ImaginaryI]"}]}], ")"}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "\tWe also define  ",
 Cell[BoxData[
  RowBox[{
   OverscriptBox[
    SubscriptBox["D", "\[Epsilon]"], "_"], 
   RowBox[{"(", 
    SubscriptBox["z", "0"], ")"}]}]]],
 ",  the closed disk of radius ",
 Cell[BoxData["\[Element]"]],
 " centered at ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 ", and  ",
 Cell[BoxData[
  RowBox[{
   SubsuperscriptBox["D", "\[Epsilon]", "*"], 
   RowBox[{"(", 
    SubscriptBox["z", "0"], ")"}]}]]],
 ",  the punctured disk of radius ",
 Cell[BoxData["\[Element]"]],
 " centered at ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 "as   \n\n",
 StyleBox["(1-50)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    OverscriptBox[
     SubscriptBox["D", "\[Epsilon]"], "_"], 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}], "  ", "=", "  ", 
   RowBox[{"{", 
    RowBox[{"z", ":", "  ", 
     RowBox[{"|", 
      RowBox[{"z", "-", 
       SubscriptBox["z", "0"]}], "|", 
      RowBox[{"\[LessEqual]", "\[Element]"}]}]}], "}"}]}]]],
 ",   and  \n\n",
 StyleBox["(1-51)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubsuperscriptBox["D", "\[Epsilon]", "*"], 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}], "  ", "=", "  ", 
   RowBox[{"{", 
    RowBox[{"z", ":", "  ", 
     RowBox[{
      RowBox[{"0", "<"}], "|", 
      RowBox[{"z", "-", 
       SubscriptBox["z", "0"]}], "|", 
      RowBox[{"<", "\[Element]"}]}]}], "}"}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 StyleBox["Definitions (Interior Point, Exterior Point, Boundary Point).",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  \n\n\tThe point ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 " is said to be an interior point of the set ",
 StyleBox["S",
  FontFamily->"Courier New"],
 " provided that there exists an ",
 Cell[BoxData["\[Epsilon]"]],
 " neighborhood of ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 " that contains only points of ",
 StyleBox["S",
  FontFamily->"Courier New"],
 ";  ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 " is called an exterior point of the set ",
 StyleBox["S",
  FontFamily->"Courier New"],
 " if there exists an ",
 Cell[BoxData["\[Epsilon]"]],
 " neighborhood of ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 " that contains no points of ",
 StyleBox["S",
  FontFamily->"Courier New"],
 ".  If ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 " is neither an interior point nor an exterior point of ",
 StyleBox["S",
  FontFamily->"Courier New"],
 ", then it is called a boundary point of ",
 StyleBox["S",
  FontFamily->"Courier New"],
 " and has the property that each ",
 Cell[BoxData["\[Element]"]],
 " neighborhood of ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 " contains both points in ",
 StyleBox["S",
  FontFamily->"Courier New"],
 " and points not in ",
 StyleBox["S",
  FontFamily->"Courier New"],
 ".  Figure 1.25 illustrates this situation."
}], "Text"],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{403, 149},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 StyleBox["\t\t\tFigure 1.25",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  The interior, exterior, and boundary of a set ",
 StyleBox["S",
  FontFamily->"Courier New"],
 ". "
}], "Text"],

Cell[TextData[{
 "\tThe boundary of  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["D", "R"], 
   RowBox[{"(", 
    SubscriptBox["z", "0"], ")"}]}]]],
 "  is the circle depicted in Figure 1.23.  We denote this circle  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["C", "R"], 
   RowBox[{"(", 
    SubscriptBox["z", "0"], ")"}]}]]],
 "  and refer to it as the circle of radius ",
 StyleBox["R",
  FontFamily->"Courier New"],
 " centered at ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 ".  Thus  \n\n",
 StyleBox["(1-52)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["C", "R"], 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}], "  ", "=", "  ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"z", ":", "  ", 
      RowBox[{"|", 
       RowBox[{"z", "-", 
        SubscriptBox["z", "0"]}], "|"}]}], "=", "R"}], "}"}]}]]],
 ". "
}], "Text"],

Cell[TextData[{
 "\tWe use the notation ",
 Cell[BoxData[
  RowBox[{
   SubsuperscriptBox["C", "R", "+"], 
   RowBox[{"(", 
    SubscriptBox["z", "0"], ")"}]}]]],
 " to indicate that the parametrization we chose for this simple closed curve \
resulted in a positive orientation;  ",
 Cell[BoxData[
  RowBox[{
   SubsuperscriptBox["C", "R", "-"], 
   RowBox[{"(", 
    SubscriptBox["z", "0"], ")"}]}]]],
 " denotes the same circle, but with a negative orientation.  (In both cases, \
counterclockwise denotes the positive direction.)  Using notation that we \
have already introduced, we get  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubsuperscriptBox["C", "R", "-"], 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}], "=", 
   RowBox[{
    RowBox[{"-", " ", 
     SubsuperscriptBox["C", "R", "+"]}], 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}]}]]],
 "."
}], "Text"],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{532, 201},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 StyleBox["\t\tFigure 1.C",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  The positively oriented curve ",
 Cell[BoxData[
  RowBox[{
   SubsuperscriptBox["C", "R", "+"], 
   RowBox[{"(", 
    SubscriptBox["z", "0"], ")"}]}]]],
 " and its opposite ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubsuperscriptBox["C", "R", "-"], 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}], "=", 
   RowBox[{
    RowBox[{"-", " ", 
     SubsuperscriptBox["C", "R", "+"]}], 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}]}]]],
 ". "
}], "Text"],

Cell[TextData[{
 StyleBox["Example 1.25.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Let  ",
 Cell[BoxData[
  RowBox[{"S", "=", 
   RowBox[{"{", 
    RowBox[{"z", ":", 
     RowBox[{"|", "z", "|", 
      RowBox[{"<", "1"}]}]}], "}"}]}]]],
 ".  ",
 StyleBox["(a)",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 " Find the interior of S.  ",
 StyleBox["(b)",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 " Find the exterior of S.  ",
 StyleBox["(c)",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 " Find boundary of  S."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "Solution.  We show that every point of ",
 StyleBox["S",
  FontFamily->"Courier New"],
 " is an interior point of ",
 StyleBox["S",
  FontFamily->"Courier New"],
 ".  Let ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 " be a point of S.  Then  ",
 Cell[BoxData[
  RowBox[{"|", 
   SubscriptBox["z", "0"], "|", 
   RowBox[{"<", " ", "1"}]}]]],
 ",  and we can choose  ",
 Cell[BoxData[
  RowBox[{"\[Epsilon]", " ", "=", " ", 
   RowBox[{
    RowBox[{"1", "-"}], "|", 
    SubscriptBox["z", "0"], "|", 
    RowBox[{">", " ", "0"}]}]}]]],
 ".  We claim that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["D", "\[Epsilon]"], 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}], "\[Subset]", "S"}]]],
 ".  If  ",
 Cell[BoxData[
  RowBox[{"z", "\[Element]", 
   RowBox[{
    SubscriptBox["D", "\[Epsilon]"], 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}]}]]],
 ",  then\n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{"|", "z", "|"}], " ", "=", " ", 
   RowBox[{"|", 
    RowBox[{"z", "-", 
     SubscriptBox["z", "0"], "+", 
     SubscriptBox["z", "0"]}], "|", " ", 
    RowBox[{"\[LessEqual]", " ", 
     RowBox[{"|", 
      RowBox[{"z", "-", 
       SubscriptBox["z", "0"]}], "|", 
      RowBox[{"+", 
       RowBox[{"|", 
        SubscriptBox["z", "0"], "|", 
        StyleBox["a",
         FontColor->GrayLevel[1]]}]}]}]}]}]}], "\[IndentingNewLine]", 
  RowBox[{"          ", 
   RowBox[{
    RowBox[{
     RowBox[{"<", "  ", 
      RowBox[{"\[Epsilon]", "+"}]}], "|", 
     SubscriptBox["z", "0"], "|"}], "=", "  ", 
    RowBox[{
     RowBox[{
      RowBox[{"1", "-"}], "|", 
      SubscriptBox["z", "0"], "|", 
      RowBox[{"+", 
       RowBox[{"|", 
        SubscriptBox["z", "0"], "|"}]}]}], " ", "=", " ", "1"}]}]}]}]],
 "\n\nHence the ",
 Cell[BoxData["\[Epsilon]"]],
 " neighborhood of ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 " is contained in ",
 StyleBox["S",
  FontFamily->"Courier New"],
 ", which shows that ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 " is an interior point of ",
 StyleBox["S",
  FontFamily->"Courier New"],
 ".  \nIt follows that the interior of ",
 StyleBox["S",
  FontFamily->"Courier New"],
 " is the set ",
 StyleBox["S",
  FontFamily->"Courier New"],
 " itself. "
}], "Text"],

Cell[TextData[{
 "\tSimilarly, it can be shown that the exterior of ",
 StyleBox["S",
  FontFamily->"Courier New"],
 " is the set ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{"z", ":", 
    RowBox[{"|", "z", "|", 
     RowBox[{">", "1"}]}]}], "}"}]]],
 ".  The boundary of ",
 StyleBox["S",
  FontFamily->"Courier New"],
 " is the unit circle  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["C", "1"], 
    RowBox[{"(", "0", ")"}]}], " ", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"z", ":", 
      RowBox[{"|", "z", "|"}]}], "=", "1"}], "}"}]}]]],
 ".  This condition is true because if  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "0"], "=", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["\[Theta]", "0"]}]]}]]],
 "  is any point on the circle, then any ",
 Cell[BoxData["\[Epsilon]"]],
 "-neighborhood of ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 " will contain the point  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "-", 
     FractionBox["\[Epsilon]", "2"]}], ")"}], 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["\[Theta]", "0"]}]]}]]],
 ",  which belongs to ",
 StyleBox["S",
  FontFamily->"Courier New"],
 ", and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "+", 
     FractionBox["\[Epsilon]", "2"]}], ")"}], 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["\[Theta]", "0"]}]]}]]],
 ",  which does not belong to ",
 StyleBox["S",
  FontFamily->"Courier New"],
 ".  We leave the details as an exercise."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Explore Solution 1.25 (a).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 "  Find the interior of ",
 StyleBox["S",
  FontFamily->"Courier New"],
 "."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "Let  ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 " be a point of  S.  Then  ",
 Cell[BoxData[
  RowBox[{"|", 
   SubscriptBox["z", "0"], "|", 
   RowBox[{"<", " ", "1"}]}]]],
 "  so that we can choose  ",
 Cell[BoxData[
  RowBox[{"\[Epsilon]", "=", 
   RowBox[{
    RowBox[{"1", "-"}], "|", 
    SubscriptBox["z", "0"], "|", 
    RowBox[{">", "0"}]}]}]]],
 ".  If  z  lies in the disk  ",
 Cell[BoxData[
  RowBox[{"|", 
   RowBox[{"z", "-", 
    SubscriptBox["z", "0"]}], "|", 
   RowBox[{"<", " ", "\[Epsilon]"}]}]]],
 ",  then  \n\n",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", "z", "|"}], "=", 
   RowBox[{"|", 
    RowBox[{
     SubscriptBox["z", "0"], "+", "z", "-", 
     SubscriptBox["z", "0"]}], "|", 
    RowBox[{"\[LessEqual]", " ", 
     RowBox[{"|", 
      SubscriptBox["z", "0"], "|", 
      RowBox[{"+", 
       RowBox[{"|", 
        RowBox[{"z", "-", 
         SubscriptBox["z", "0"]}], "|", 
        RowBox[{"<", " ", 
         RowBox[{"|", 
          SubscriptBox["z", "0"], "|", " ", 
          RowBox[{
           RowBox[{"+", " ", "\[Epsilon]"}], " ", "<", " ", 
           "1"}]}]}]}]}]}]}]}]}]]],
 ".  \n\nHence the ",
 Cell[BoxData["\[Epsilon]"]],
 "-neighborhood of  ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 "  is contained in  S,  and  ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 "  is an interior point of  S.  It follows that the interior of  S  is the \
open unit disk."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"dot", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
        RowBox[{"Point", "[", 
         RowBox[{"{", 
          RowBox[{"0.3", ",", "0.7"}], "}"}], "]"}]}], "}"}], "]"}]}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"r", "=", 
     RowBox[{"1", "-", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["0.3", "2"], "+", 
        SuperscriptBox["0.7", "2"]}]]}]}], ";"}], " ", "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"disk", " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Orange", ",", 
        RowBox[{"Disk", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0.3", ",", "0.7"}], "}"}], ",", "r"}], "]"}]}], "}"}], 
      "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"bdd", " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Green", ",", 
        RowBox[{"Circle", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}], ",", "1"}], "]"}]}], "}"}], 
      "]"}]}], ";"}], " ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{"bdd", ",", "disk", ",", "dot", ",", " ", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.5"}], ",", "1.5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.5"}], ",", "1.5"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1.5"}], ",", "1.5", ",", "0.5"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1.5"}], ",", "1.5", ",", "0.5"}], "]"}]}], "}"}]}], 
     ",", "\n", "          ", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The \[Epsilon]-neighborhood of \!\(\*SubscriptBox[\(z\), \(0\)]\) \
is contained in S = {z:|z|<1}.\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.398973092984375*^9, 3.398973096390625*^9}, {
  3.399720519328125*^9, 3.399720519609375*^9}, {3.399720659640625*^9, 
  3.39972066446875*^9}, {3.400238303375*^9, 3.400238304609375*^9}},
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"int", " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Orange", ",", 
        RowBox[{"Disk", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}], ",", "1"}], "]"}]}], "}"}], 
      "]"}]}], ";"}], " ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{"int", ",", " ", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.5"}], ",", "1.5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.5"}], ",", "1.5"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1.5"}], ",", "1.5", ",", "1.5"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1.5"}], ",", "1.5", ",", "1.5"}], "]"}]}], "}"}]}], 
     ",", "\n", "          ", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The interior of the set S is the unit disk {z: |z| < 1}.\>\"", 
     "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.398973102046875*^9, 3.398973103625*^9}, {
  3.399720646234375*^9, 3.399720647203125*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Explore Solution 1.25 (b). ",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 " Find the exterior of ",
 StyleBox["S",
  FontFamily->"Courier New"],
 "."
}], "Text"],

Cell[TextData[{
 "If  ",
 Cell[BoxData[
  RowBox[{"|", 
   SubscriptBox["z", "0"], "|", 
   RowBox[{">", " ", "1"}]}]]],
 " then a similar argument will produce an ",
 Cell[BoxData["\[Epsilon]"]],
 "-neighborhood of  ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 "  that lies entirely in the region  ",
 Cell[BoxData[
  RowBox[{"|", "z", "|", 
   RowBox[{">", " ", "1"}]}]]],
 ",  hence ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 "  is an exterior point of  S.  It follows that the exterior of  S  is the \
open region  ",
 Cell[BoxData[
  RowBox[{"|", "z", "|", 
   RowBox[{">", " ", "1"}]}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"dot", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
        RowBox[{"Point", "[", 
         RowBox[{"{", 
          RowBox[{"0.4", ",", "1.1"}], "}"}], "]"}]}], "}"}], "]"}]}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"r", "=", 
     RowBox[{
      SqrtBox[
       RowBox[{
        SuperscriptBox["0.4", "2"], "+", 
        SuperscriptBox["1.1", "2"]}]], "-", "1"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"disk", " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Cyan", ",", 
        RowBox[{"Disk", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0.4", ",", "1.1"}], "}"}], ",", "r"}], "]"}]}], "}"}], 
      "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"bdd", " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Green", ",", 
        RowBox[{"Circle", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}], ",", "1"}], "]"}]}], "}"}], 
      "]"}]}], ";"}], " ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{"bdd", ",", "disk", ",", "dot", ",", " ", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.5"}], ",", "1.5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.5"}], ",", "1.5"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1.5"}], ",", "1.5", ",", "0.5"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1.5"}], ",", "1.5", ",", "0.5"}], "]"}]}], "}"}]}], 
     ",", "\n", "          ", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The \[Epsilon]-neighborhood of \!\(\*SubscriptBox[\(z\), \(0\)]\) \
is contained in the region |z| > 1.\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39897311284375*^9, 3.39897311553125*^9}, {
  3.399720531265625*^9, 3.399720531515625*^9}, {3.4002383195*^9, 
  3.400238320703125*^9}},
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"ext", " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Cyan", ",", 
          RowBox[{"Disk", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", "0"}], "}"}], ",", "3"}], "]"}]}], "}"}], ",", 
        "\n", "                ", 
        RowBox[{"{", 
         RowBox[{"White", ",", 
          RowBox[{"Disk", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", "0"}], "}"}], ",", "1"}], "]"}]}], "}"}]}], 
       "}"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{"ext", ",", " ", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.5"}], ",", "1.5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.5"}], ",", "1.5"}], "}"}]}], "}"}]}], ",", "\n", 
     "          ", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The exterior of the set S is the open region {z: |z| > 1}.\>\"", 
     "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39897311846875*^9, 3.3989731211875*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Explore Solution 1.25 (c).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 "  Find the boundary of ",
 StyleBox["S",
  FontFamily->"Courier New"],
 "."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "If  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "0"], "=", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["\[Theta]", "0"]}]]}]]],
 " is any point on the unit circle, then any ",
 Cell[BoxData["\[Epsilon]"]],
 "-neighborhood of  ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 "  will contain the point  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "-", 
     FractionBox["\[Epsilon]", "2"]}], ")"}], 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["\[Theta]", "0"]}]]}]]],
 ", which belongs to  S,  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "+", 
     FractionBox["\[Epsilon]", "2"]}], ")"}], 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["\[Theta]", "0"]}]]}]]],
 "  which does not belong to  S.  It follows that the boundary of  S  is the \
unit circle  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", "z", "|"}], "=", " ", "1"}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"dot", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
        RowBox[{"Point", "[", 
         RowBox[{"{", 
          RowBox[{"0.4", ",", 
           SqrtBox[
            RowBox[{"1", "-", 
             SuperscriptBox["0.4", "2"]}]]}], "}"}], "]"}]}], "}"}], "]"}]}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"r", "=", "0.2"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"disk", " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Green", ",", 
        RowBox[{"Disk", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0.4", ",", 
            SqrtBox[
             RowBox[{"1", "-", 
              SuperscriptBox["0.4", "2"]}]]}], "}"}], ",", "r"}], "]"}]}], 
       "}"}], "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"bdd", " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Green", ",", 
        RowBox[{"Circle", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}], ",", "1"}], "]"}]}], "}"}], 
      "]"}]}], ";"}], " ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{"disk", ",", "bdd", ",", "dot", ",", " ", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.5"}], ",", "1.5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.5"}], ",", "1.5"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1.5"}], ",", "1.5", ",", "0.5"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1.5"}], ",", "1.5", ",", "0.5"}], "]"}]}], "}"}]}], 
     ",", "\n", "          ", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<Every \[Epsilon]-neighborhood of \!\(\*SubscriptBox[\(z\), \(0\)]\) \
contains points of S\>\"", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<and points that do not belong to S.\>\"", "]"}], ";"}],
    " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3989731275625*^9, 3.398973130875*^9}, {
  3.399720540328125*^9, 3.399720540546875*^9}, {3.39972060728125*^9, 
  3.399720608140625*^9}, {3.40023835740625*^9, 3.400238358734375*^9}},
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"bdd", " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Green", ",", 
        RowBox[{"Thickness", "[", "0.01", "]"}], ",", 
        RowBox[{"Circle", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}], ",", "1"}], "]"}]}], "}"}], 
      "]"}]}], ";"}], " ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{"bdd", ",", " ", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.5"}], ",", "1.5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.5"}], ",", "1.5"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1.5"}], ",", "1.5", ",", "0.5"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1.5"}], ",", "1.5", ",", "0.5"}], "]"}]}], "}"}]}], 
     ",", "\n", "          ", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The boundary of the set S = {z:|z|<1 is the unit circle {z: |z| = \
1}.\>\"", "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.398973133875*^9, 3.398973135296875*^9}, {
  3.39972062109375*^9, 3.3997206219375*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 "\tThe point ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 " is called an accumulation point of the set ",
 StyleBox["S",
  FontFamily->"Courier New"],
 " if, for each ",
 Cell[BoxData["\[Epsilon]"]],
 ", the punctured disk ",
 Cell[BoxData[
  RowBox[{
   SubsuperscriptBox["D", "\[Epsilon]", "*"], 
   RowBox[{"(", 
    SubscriptBox["z", "0"], ")"}]}]]],
 " contains at least one point of ",
 StyleBox["S",
  FontFamily->"Courier New"],
 ".  We ask you to show in the exercises that the set of accumulation points \
of ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["D", "1"], 
   RowBox[{"(", "0", ")"}]}]]],
 " is ",
 Cell[BoxData[
  RowBox[{
   OverscriptBox[
    SubscriptBox["D", "1"], "_"], 
   RowBox[{"(", "0", ")"}]}]]],
 ", and that there is only one accumulation point of ",
 Cell[BoxData[
  RowBox[{"S", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       FractionBox["\[ImaginaryI]", "n"], ":", " ", "n"}], "=", "1"}], 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "2", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], 
     StyleBox["...",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]]}], "}"}]}]]],
 ", namely, the point ",
 StyleBox["0",
  FontFamily->"Courier New"],
 ".  \nWe also ask you to prove that a set is closed if and only if it \
contains all of its accumulation points."
}], "Text"],

Cell[TextData[{
 "\tA set ",
 StyleBox["S",
  FontFamily->"Courier New"],
 " is called an open set if every point of ",
 StyleBox["S",
  FontFamily->"Courier New"],
 " is an interior point of  ",
 StyleBox["S",
  FontFamily->"Courier New"],
 ".  Thus, Example 1.25 shows that ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["D", "1"], 
   RowBox[{"(", "0", ")"}]}]]],
 " is open.  A set ",
 StyleBox["S",
  FontFamily->"Courier New"],
 " s called a closed set if it contains all its boundary points.  A set ",
 StyleBox["S",
  FontFamily->"Courier New"],
 " is said to be a connected set if every pair of points ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], " ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], " ", 
   SubscriptBox["z", "2"]}]]],
 " contained in ",
 StyleBox["S",
  FontFamily->"Courier New"],
 " can be joined by a curve that lies entirely in ",
 StyleBox["S",
  FontFamily->"Courier New"],
 ".  Roughly speaking, a connected set consists of a \"single piece.\"   The \
unit disk  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["D", "1"], 
    RowBox[{"(", "0", ")"}]}], "=", 
   RowBox[{"{", 
    RowBox[{"z", ":", 
     RowBox[{"|", 
      RowBox[{"z", "||", 
       RowBox[{"<", "1"}]}]}]}], "}"}]}]]],
 "  is a connected open set.  We ask you to verify in the exercises that, if \
",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], " ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], " ", 
   SubscriptBox["z", "2"]}]]],
 " lie in ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["D", "1"], 
   RowBox[{"(", "0", ")"}]}]]],
 ", then the straight-line segment joining them lies entirely in ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["D", "1"], 
   RowBox[{"(", "0", ")"}]}]]],
 ".  The annulus  ",
 Cell[BoxData[
  RowBox[{"A", "=", 
   RowBox[{"{", 
    RowBox[{"z", ":", " ", 
     RowBox[{
      RowBox[{"1", "<"}], "|", "z", "|", 
      RowBox[{"<", "2"}]}]}], "}"}]}]]],
 "  is a connected open set because any two points in A can be joined by a \
curve C that lies entirely in A, as shown in Figure 1.26.  The set  ",
 Cell[BoxData[
  RowBox[{"B", "=", 
   RowBox[{"{", 
    RowBox[{"z", ":", 
     RowBox[{"|", 
      RowBox[{"z", "+", "2"}], "|", 
      RowBox[{"<", 
       RowBox[{"1", "  ", 
        StyleBox["or",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]]}]}], " ", "|", 
      RowBox[{"z", "-", "2"}], "|", 
      RowBox[{"<", "1"}]}]}], "}"}]}]]],
 "  consists of two disjoint disks.  We leave it as an exercise for you to \
show that the set is not connected, as shown in Figure 1.27."
}], "Text"],

Cell[GraphicsData["CompressedBitmap", "\<\
eJztW2lvVFUYvrTTlqWU7ns703boMt0XuiOLCG6gcYlGjVoJCWgIBvig7AIi
ICgugBoNosQ9xmg0+sEYwyfj8gP8FfyDcd73PfPOndvndM60lNaESXvOzDnP
+zzvWe4555577tap/Tt37J7av2v7VGTL3qkXd+7avi+yec/eRFLuEs9bss3z
vH8jHn2PJ76aIJ74iz9AAaVk9/0fjnI9IeIc7/DtrOlZfySz4qmsHADPAbiX
hOJ3ipZSTp53I37DGNI3+ZUIOXevwH+jKIcSVgL4imSaT2ePGP5CUQWwKaXw
BQH9qOxVAMnWTL5D4D8ovAbAqynk3O0C/5aiPEqoA/BaCkOU+4zAvzGVRplU
IIrDwLARFPopofiaohZg00ShAX1J0WoAYsMnBPQ5RW0AxIaPC+iar5mT+cim
1aSZC4/jR+TXp4CiHVC0g0I/JBRXtVU6gWGHtoqBX1F4N4B3KvxBgX+k8F4A
71b4NoF/CMqDDHtBee7zUQwAmz4KtwroA4qGAKifwvsF9B5FwwA0SOG9ArpM
0QgAMfs9ArpE0SgAraHwbgFdpGgMgJIu+Nt/k/x6R6sXGY6CWtoohm+Dip4n
ijFAsUEoLqj7k8BwXHuHgb8JFJHhBFBclx3FJKC4QyjOq9PrgOFaddoP3wCQ
d1Bo3DpH0UYAYgnD9DpFYTOqejIoBeDrKVwr8LMU8UibR5Ac27gWSGNXJ30U
PNJ6oTRQ4pMLbCMgjUs1IXxnKKoHoNmQnaZIRvOCNJBxUGNUyjspHBei10Cf
KJdmTKSE5lb8TaAjDdt1yygMUUquthyabNq1G+TotwogtUakTtmk8imlCwh0
gDTUhcrtoq/a6tUqGpPSJz7VgHZIaE8C2kqtNjQrxXATZqlRYVgSQP5GC+fE
f4+7YA0QHBTBE1bBXBWk/z6glpx0PVkUuQuUAwF2vcCTHsgfU86USh1QGRCV
447F4GXO8iTYS/EUyOCaEkhaNGo3rwfy/T75KqAXpbAI6C3XwZyHY1NZr1BU
DXgiphLiXjEgK6SQ16TjLmSNSlYKyIrTp3ZTwcdsZA1KVg7ISkG7DAdpUcU1
gMpGAhW6DDJNcdTmKGq+CsBYqasvPyPyETFW2hjZxz5hPGJj5B5eByiqKVwT
pHC4rPjSbwCMtRQOghJ030yBAEE/0OsSvcOOVzA3bSPQqwMEfdnpofJxM0WA
Xr1eJzOoHHJUQVMCqtQGwNczd/kqQIHquNFRvlPkDzq2aSWgCAP5MODrvnXy
EUf5mF0eVX6FjqDN8yNaZhMNUCB5TkNN7NernKsA31abPnvANjiiFV8LYGxR
lxeIsRVQRCnsDlKgimOKtvmhWK0U5hJ52VYQ7jPtNopAB4vNPyMqJjN2AMZW
wKj3Fb62bvcJOFwzi1ovBvSkC5gt3MwDUamVYlHJtznW9m35LORLrN11Ucnz
bMGbE15qX9LmA98Ht8yPI9GUgqYl/mUrO5Rmnvi0LoATeWnmxhEz2EJP0BCE
emUWnvBeS8jWjrfWjRyQN3P/mIsnTJuj/ZQ9yNW0Qv2W7MbmUzY/3rSrD8E7
fvrIfbW3m6LrlLAUUPg9Q5NxaWrGBtoOI0aRS52ghUXJXJVbb6YAeuLVdltg
rgLcvWJAYDYT0rwLLK75Ht3zoinGKt+1EHqx7ARQfaIbsWkCaDXu2mBIgNO6
//cCXakrGgq4NvJNFUAlWA0Ept3nHnCsojIgEHUWQNvO7LL1dj7gErqL6sgg
wC6jWm4BAp2zEOB6QrXcDATQUGEEDs5YAlcBVIJYBgEuAWrGJscSLLgAXwxo
ayoCBGbYHjw0o4Dr/iMqQadPoMZWRQGbMNALOxbIrxeAu25HWne40WMKo4ce
G7jqWTf0Wa83OwG0aV0PBDiNn+TnydI+JYUe8aBRFz0dQA+pOA2dAsskisqH
RGuBKKc1afnQ8YjZyKdOBSLRGgrlwJ7TAY0CCmd4cocWpOyB9VlggKAZiGZy
5KijI3w11wBH+Lkm11ErqIob5qk9135/dpL8HLQKSFYAgihuh0Kf7rFsdNEj
3DItapt2teWgh5pexo/ea4EAPzJGz7FLVGAE0PZloE09hC8B3KtMGleMqQF0
vs6oHLeppM4NrAIqKylEx9f8ZyTqAC2fLOMtsxWAltMGkr0pHrAtsOudsBWj
RYuxDOjxbhV7M2T88uJLgcqATwWVql36SUqAjOk/pI2cTwmoBIb7pI0bHWGa
UMZ8wDjoYwz0BDRZoxO5k1odyGUjgI5eIYGYTcDgkrWFpIbsUqi50YGyCYDj
Rh4R7lN6NVqbNsA4Jp0qAeNhYVR40Ek75CM6fT0KcMsoHBPu047crYB7xMY9
budGNYFOCGbiPuPIHQXcwzZuczTzrCM3Oms/pC1YGGQMaxYyHAQC6A0H027n
lDFgEwHc/elOmSPLzHM+3TNk3efomZ+xCdg0AO4eVS6yM76hjIxEPN1AbyVg
NIeL+Rx1M7CpBdydqrwKMJrTzRdsjOhlkRjAofKvE+63QH9MNRkS6HAUWC8C
6Cw89wRmqAQCbSpfTN/85/kta0q4P+JjjKoe7//cJYzv2hhZG/EEcjcLz0XA
06KKxYAnrLl8z7lFeC4BHh6+Qnp1BXga1B+uR/O2xGWdGjpUZxmwrk1vBfPW
xvsUdaksepeK78DyKFfv08nStL3xgt8j6VVkcg1jWoo7TAH9rNdRwzgA31Ih
uyIK9TbC19OMIb9Q0w/87VEJ847LFfUtgOxSpHmB72PQJmjpgfZ8DMVVQIEW
F5z2sNh8ok2IkDy7PyrIa4pEcz7PrI8J8jNFovnW//bVF7YOjS6HQKENxVcU
ofkx+ZJG3HtSkPwuG5oaUncMTwvyO7A0RO+/1anhs2L4vS6YqwG8RuHPCfwn
rSg0OvEVu0uQP1PEhUGjRbGvergPJ0yeF8NfKSoBNrw0yyeT3YK8Hig0/fNr
jAHDfLliExn7xHCRvNi5+LP4xyzf77V9/8t0oeR9vfc30D+S0bWgFX2O+BSm
nxUwuX+ajukFn1TPsszekv8A4mb1HA==\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{334, 218},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 StyleBox["\t\tFigure 1.26",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  The annulus  ",
 Cell[BoxData[
  RowBox[{"A", "=", 
   RowBox[{"{", 
    RowBox[{"z", ":", " ", 
     RowBox[{
      RowBox[{"1", "<"}], "|", "z", "|", 
      RowBox[{"<", "2"}]}]}], "}"}]}]]],
 "  is a connected set."
}], "Text"],

Cell[GraphicsData["CompressedBitmap", "\<\
eJztWVtvG0UUntiO7RBeEJUgaZOa0qZx0iSksZ17Gzdp0lycJsA7iiqk9gGB
Sl8QT1wkSrmUQikqQgUJECC1QvDL8go8GJ9zxt/ujs/Y6zpIVIqV7KznfN93
zsycGc/OVvZuXH39jb0b167s5dau77119dqVt3Orb16vVSW7jOn6wxhzN2fo
vlq7tZdq7a/6J12opsP7JN8njShzlXl4aD+0d27/i4puMqT8oN/qpmpg6lXq
yoqEJrsWU+9Vcf+zY6KSv2Xpa4buvJ4TVLPiE8jQ1yzdWVc/UZGmih6zX91n
0wzVpXxdpNWVEVeWVHro7hVx8KPt76p5hkw1OgVDd/b/XEwfS4jUI7QrDn+Q
6KkyGYH00zWh9HoB/ZZW/C769I769C5JIA+oOEkgDnVB0Z6n6ymCsMK6EL91
NMnZEHTmFZ2ZpgzJPnNfZkatIg/TrCJWssNfNcOE47G7KBLfwDQKiRlFoqjg
JCfNPZjGnT4l87QiVkDc49LjQTz37MhVzRSZNPYU2GcJYqP42iLJb92/V+Is
JAoEWfZLFOla9Elo4AsidpeKOaooKOxJWGXam6+oWKCKKQX+EqxLAr9DxTnb
3fX1AEiHPREGh9N6wRVjsyYxHoUsCvELKpZQO6EQx6IQ6/E2FRdQO64Qz4Qm
QH1+ngdDpoz5DNmyjETSxEYx3mVIzLkSK0oPnVHERiC2DLHZjsTsBGhkyEw0
n8Ijg7QW5gFZJYht3CeoXaPaMYU4DMglgsyGPDq9v+qTyCvgtZAYR7FJFVoP
DMMahm9RxagPzlbbObeoqBwkvBIsG+ZjKraVoRlW2KcBDrMryJK8j1NB9paE
+L5NC2O6ockS/HvGm50BReworJmobBZ6MgTmXSp4RyC/d6mITn2jsA2B+jJj
PwnfXkKLSqvLRHsmrQchQ2Q+UAQ47MuIr6eDWNJRqaxvmhrzoRpIjbN9IIF0
YzForid5ZN7TOy0RU6WTqJqPV5C9SYUb5OJxxdsxWDMKNwOrzeOPANohkDbD
TkYhpSeCuKssOUfQeGc29sm3d6jg2mfp4o45ffrl7iYVO+hVbS07RdddQJ5X
IH3tiQWQ51o0pH3F4n9PHIquEgdCdH40K611HMZWbNmRmIqVUMbejM5Ar0QA
eRxi+Oe2MyK3xLtzaELkp5fN9oi3lM5b921yAonwXiTYGDkzXVsbGnYy7bM3
kC3hjeU6arXG56OQBqLjWxsxXYL3yjn7PGrMCdi92+QXFHBYjO2GARgRfjyr
fXLYanjlT8SiW4efI3oP4zgY2pZ5tFW8Ad3uim8r6XasVcQxHkC056yBVoE5
D52tQkwhIO3Z0htBCv4WQw542FtG6HXE9MEm9EHXIUfWrKuZMelzmGpF57bI
mZk8UbPDfiQ727VTgTHIO+DzInYHYvM+iQlA+DBiSYhfKiMyHcqnfXu24z2q
aMKt42yMfEwyo9g17UmAGWuj5WObkvNDqBzWlEAsh4hFEEsKkaMogGjPdvjQ
bNKmqE4sAmJPCph43yL3Q4dGwXmadlJVkpyN9j39j0B7JaTNOnlpUjAOdTHN
wXRrmg2eDzH57HAomCKKWADZEOJ3cPFikJ1R4hwgvApvCfEBsnNQyb4lRWce
OgNKn1VE9nunjWTqc+DyyGv0Y/nFmAJ2I8NO+dQ8qwT1NF3TWOm9LzLKPoFe
CFwWV784WUb/3Ce9dpkItSDkQHN60Sf1FJzuiNNfJTxj0Rklj7zvBfhRgM+0
+Y1DSrQbBV4WVw8xyJsxm7GBRHpNJP6JSbRvj/5GlNr7hP/Je7BD+xNgP6j3
6XHuu5C1v4dqE0qEj9pogcunzyPXa+PRUNQFfaKP/o/ZSabrX7Obobs=\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{433, 148},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 StyleBox["\t\tFigure 1.27",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  The set  ",
 Cell[BoxData[
  RowBox[{"B", "=", 
   RowBox[{"{", 
    RowBox[{"z", ":", 
     RowBox[{"|", 
      RowBox[{"z", "+", "2"}], "|", 
      RowBox[{"<", 
       RowBox[{"1", "  ", 
        StyleBox["or",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]]}]}], " ", "|", 
      RowBox[{"z", "-", "2"}], "|", 
      RowBox[{"<", "1"}]}]}], "}"}]}]]],
 "  is not a connected set."
}], "Text"],

Cell[TextData[{
 "\tWe call a connected open set a domain.  In the exercises we ask you to \
show that the open unit disk  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["D", "1"], 
    RowBox[{"(", "0", ")"}]}], "=", 
   RowBox[{"{", 
    RowBox[{"z", ":", 
     RowBox[{"|", 
      RowBox[{"z", "||", 
       RowBox[{"<", "1"}]}]}]}], "}"}]}]]],
 "  is a domain and that the closed unit disk  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    OverscriptBox[
     SubscriptBox["D", "1"], "_"], 
    RowBox[{"(", "0", ")"}]}], "=", 
   RowBox[{"{", 
    RowBox[{"z", ":", 
     RowBox[{"|", 
      RowBox[{"z", "||", 
       RowBox[{"\[LessEqual]", "1"}]}]}]}], "}"}]}]]],
 "  is not a domain.  The term domain is a noun and is a type of set.  In \
Chapter 2 we note that it also refers to the set of points on which a \
function is defined.  In the latter context, it does not necessarily mean a \
connected open set."
}], "Text"],

Cell[TextData[{
 StyleBox["Example 1.26.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Show that the right half-plane  ",
 Cell[BoxData[
  RowBox[{"H", "=", 
   RowBox[{"{", 
    RowBox[{"z", ":", " ", 
     RowBox[{
      RowBox[{"Re", 
       RowBox[{"(", "z", ")"}]}], ">", "0"}]}], "}"}]}]]],
 "  is a domain."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "Solution.  First we show that ",
 StyleBox["H",
  FontFamily->"Courier New"],
 " is connected. Let ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "0"], " ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], " ", 
   SubscriptBox["z", "1"]}]]],
 " be any two points in ",
 StyleBox["H",
  FontFamily->"Courier New"],
 ".  We claim the obvious, that the straight-line segment ",
 StyleBox[" ",
  FontFamily->"Courier New"],
 Cell[BoxData[
  RowBox[{
   RowBox[{"C", ":", " ", 
    RowBox[{"z", 
     RowBox[{"(", "t", ")"}]}]}], "=", " ", 
   RowBox[{
    SubscriptBox["z", "0"], " ", "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["z", "1"], "-", 
       SubscriptBox["z", "0"]}], ")"}], "t"}]}]}]]],
 ",  for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"0", "\[LessEqual]", "t", "\[LessEqual]", "1"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]]}]]],
 "  lies entirely within  ",
 StyleBox["H",
  FontFamily->"Courier New"],
 ".  To prove this claim, we let  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"z", 
    RowBox[{"(", 
     SuperscriptBox["t", "*"], ")"}]}], "=", " ", 
   RowBox[{
    SubscriptBox["z", "0"], " ", "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["z", "1"], "-", 
       SubscriptBox["z", "0"]}], ")"}], 
     SuperscriptBox["t", "*"]}]}]}]]],
 ",  for some  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["t", "*"], "\[Element]", 
   RowBox[{"[", 
    RowBox[{"0", ",", "1"}], "]"}]}]]],
 ",  be an arbitrary point on ",
 Cell[BoxData["C"]],
 ".  We must show that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Re", "[", 
    RowBox[{"z", 
     RowBox[{"(", 
      SuperscriptBox["t", "*"], ")"}]}], "]"}], ">", "0"}]]],
 ".  Now,  \n\t\t\n",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     StyleBox[
      RowBox[{"(", 
       RowBox[{"1", "-", "53"}], ")"}],
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->RGBColor[0, 0, 0.996109]], "                      ", 
     RowBox[{"Re", "[", 
      RowBox[{"z", 
       RowBox[{"(", 
        SuperscriptBox["t", "*"], ")"}]}], "]"}]}], " ", "=", "  ", 
    RowBox[{"Re", "[", 
     RowBox[{
      SubscriptBox["z", "0"], " ", "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["z", "1"], "-", 
         SubscriptBox["z", "0"]}], ")"}], 
       SuperscriptBox["t", "*"]}]}], "]"}]}], "\[IndentingNewLine]"}], "\n", 
  RowBox[{"                                                          ", 
   RowBox[{"=", "  ", 
    RowBox[{"Re", "[", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["t", "*"]}], ")"}], 
       SubscriptBox["z", "0"]}], " ", "+", " ", 
      RowBox[{
       SuperscriptBox["t", "*"], 
       SubscriptBox["z", "1"]}]}], "]"}]}], "\[IndentingNewLine]"}], "\n", 
  RowBox[{"                                                          ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{"Re", "[", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["t", "*"]}], ")"}], 
       SubscriptBox["z", "0"]}], "]"}], " ", "+", "   ", 
     RowBox[{"Re", "[", 
      RowBox[{
       SuperscriptBox["t", "*"], 
       SubscriptBox["z", "1"]}], "]"}]}]}], "\[IndentingNewLine]"}], "\n", 
  RowBox[{"                                                          ", 
   RowBox[{"=", "   ", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", 
        SuperscriptBox["t", "*"]}], ")"}], 
      RowBox[{"Re", "[", 
       SubscriptBox["z", "0"], "]"}]}], " ", "+", "   ", 
     RowBox[{
      SuperscriptBox["t", "*"], 
      RowBox[{"Re", "[", 
       SubscriptBox["z", "1"], "]"}]}]}]}]}]}]],
 "     "
}], "Text"],

Cell[TextData[{
 "If ",
 Cell[BoxData[
  RowBox[{"t", "=", "0"}]]],
 ", the last expression becomes ",
 Cell[BoxData[
  RowBox[{"Re", "[", 
   SubscriptBox["z", "0"], "]"}]]],
 ", which is greater than zero because ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "0"], "\[Element]", "H"}]]],
 ".  Likewise, if ",
 Cell[BoxData[
  RowBox[{"t", "=", "1"}]]],
 ", then Equation ",
 StyleBox["(1-53)",
  FontColor->RGBColor[0, 0, 1]],
 " becomes ",
 Cell[BoxData[
  RowBox[{"Re", "[", 
   SubscriptBox["z", "1"], "]"}]]],
 ", which also is positive.  Finally, if  ",
 Cell[BoxData[
  RowBox[{"0", "\[LessEqual]", "t", "\[LessEqual]", "1"}]]],
 ",  then each term in Equation ",
 StyleBox["(1-53)",
  FontColor->RGBColor[0, 0, 1]],
 " is positive, so in this case we also have  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Re", "[", 
    RowBox[{"z", 
     RowBox[{"(", 
      SuperscriptBox["t", "*"], ")"}]}], "]"}], ">", "0"}]]],
 ".\n\tTo show that ",
 StyleBox["H",
  FontFamily->"Courier New"],
 " is open, we suppose without loss of generality that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Re", "[", 
    SubscriptBox["z", "0"], "]"}], "<", 
   RowBox[{"Re", "[", 
    SubscriptBox["z", "1"], "]"}]}]]],
 ".  We claim that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["D", "\[Epsilon]"], 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}], "\[Subset]", "H"}]]],
 ",  where ",
 Cell[BoxData[
  RowBox[{"\[Element]", 
   RowBox[{"=", 
    RowBox[{"Re", "[", 
     SubscriptBox["z", "0"], "]"}]}]}]]],
 ".  We leave the proof of this claim as an exercise."
}], "Text"],

Cell[TextData[{
 "\tA domain, together with some, none, or all its boundary points, is called \
a region.  For example, the horizontal strip  ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{"z", ":", " ", 
    RowBox[{"1", "<", 
     RowBox[{"Im", 
      RowBox[{"(", "z", ")"}]}]}]}], "}"}]]],
 "  is a region.  A set formed by taking the union of a domain and its \
boundary is called a closed region; thus  ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{"z", ":", " ", 
    RowBox[{"1", "\[LessEqual]", 
     RowBox[{"Im", 
      RowBox[{"(", "z", ")"}]}], "\[LessEqual]", "2"}]}], "}"}]]],
 "  is a closed region.  A set ",
 StyleBox["S",
  FontFamily->"Courier New"],
 " is said to be a bounded set if it can be completely contained in some \
closed disk, that is, if there exists an  ",
 Cell[BoxData[
  RowBox[{"R", ">", "0"}]]],
 "  such that for each ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " in ",
 StyleBox["S",
  FontFamily->"Courier New"],
 " we have ",
 Cell[BoxData[
  RowBox[{"|", "z", "|", 
   RowBox[{"\[LessEqual]", " ", "R"}]}]]],
 ".  The rectangle given by  ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{"z", ":", 
    RowBox[{"|", "x", "|", 
     RowBox[{"\[LessEqual]", 
      RowBox[{"4", "  ", "and"}]}], "  ", "|", "y", "|", 
     RowBox[{"\[LessEqual]", "3"}]}]}], "}"}]]],
 " is bounded because it is contained inside the disk ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    OverscriptBox[
     SubscriptBox["D", "5"], "_"], 
    RowBox[{"(", "0", ")"}]}], "=", 
   RowBox[{"{", 
    RowBox[{"z", ":", " ", 
     RowBox[{"|", "z", "|", 
      RowBox[{"\[LessEqual]", " ", "5"}]}]}], "}"}]}]]],
 ".  A set that cannot be enclosed by any closed disk is called an unbounded \
set.  "
}], "Text"],

Cell[TextData[{
 "\tWe mentioned earlier that a simple closed curve is positively oriented if \
its interior is on the left when the curve is traversed.  How do we know, \
though, that any given simple closed curve will have an interior and \
exterior?  Theorem 1.6 guarantees that this is indeed the case.  It is due in \
part to the work of the French mathematician ",
 StyleBox[ButtonBox["Marie Ennemond Camille Jordan",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Jordan.\
html"], None}],
  FontVariations->{"Underline"->True}],
 " (1838--1922)."
}], "Text"],

Cell[TextData[{
 StyleBox["Theorem 1.6 (",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Jordan Curve Theorem",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/JordanCurveTheorem.html"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 StyleBox[").",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  The compliment of any simple closed curve ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " can be partitioned into two mutually exclusive domains ",
 StyleBox["I",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["E",
  FontFamily->"Courier New"],
 " in such a way that ",
 StyleBox["I",
  FontFamily->"Courier New"],
 " is bounded,  ",
 StyleBox["E",
  FontFamily->"Courier New"],
 " is unbounded, and ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " is the boundary for both ",
 StyleBox["I",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["E",
  FontFamily->"Courier New"],
 ".   In addition  ",
 Cell[BoxData[
  RowBox[{"I", "\[Union]", "E", "\[Union]", "C"}]]],
 "  is the entire complex plane.  The domain ",
 StyleBox["I",
  FontFamily->"Courier New"],
 " is called the interior of ",
 StyleBox["C",
  FontFamily->"Courier New"],
 ",  and  the domain ",
 StyleBox["E",
  FontFamily->"Courier New"],
 " is called the exterior of ",
 StyleBox["C",
  FontFamily->"Courier New"],
 "."
}], "Text"],

Cell[TextData[{
 "\tThe Jordan curve theorem is a classic example of a result in mathematics \
that seems obvious but is very hard to demonstrate, and its proof is beyond \
the scope of this book.  ",
 StyleBox[ButtonBox["Jordan's",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Jordan.\
html"], None}],
  FontVariations->{"Underline"->True}],
 " original argument, in fact, was inadequate, and not until 1905 was a \
correct version finally given by the American topologist ",
 StyleBox[ButtonBox["Oswald Veblen",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Veblen.\
html"], None}],
  FontVariations->{"Underline"->True}],
 " (1880-1960).  The difficulty lies in describing the interior and exterior \
of a simple closed curve analytically, and in showing that they are connected \
sets.  For example, in which domain (interior or exterior) do the two points \
depicted in Figure 1.28 lie?  If they are in the same domain, how, \
specifically, can they be connected with a curve?  If you appreciated the \
subtleties involved in showing that the right half-plane of Example 1.26 is \
connected, you can begin to appreciate the obstacles that Veblen had to \
navigate."
}], "Text"],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{409, 293},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 StyleBox["\t\tFigure 1.28",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Are the points ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["z", "1"], " ", 
    StyleBox[
     RowBox[{"(", "blue", ")"}],
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    StyleBox["and",
     FontFamily->"Times New Roman"], " ", 
    SubscriptBox["z", "2"], " ", 
    StyleBox[
     RowBox[{"(", "red", ")"}],
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]]}]}]]],
 " in the interior or exterior of this simple closed curve?"
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{406, 293},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell["\<\
\tAlthough an introductory treatment of complex analysis can be given without \
using this theorem, we think it is important for the well-informed student at \
least to be aware of it. \
\>", "Text"],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Complex Numbers",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/ComplexNumbersBib.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox[ButtonBox["History of Complex Numbers",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/HistoryComplexBib.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Quaternions",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/QuaternionBib.html"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/complex.html"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2008 John H. Mathews, Russell W. \
Howell",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/"], None}],
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[0, 1, 0]]], "Text",
 CellChangeTimes->{{3.39897299490625*^9, 3.39897299503125*^9}}]
},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{971, 648},
WindowMargins->{{3, Automatic}, {Automatic, 0}},
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "CHAPTER 1"->{
  Cell[568, 21, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"CHAPTER 1", 139512, 4177}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"],
Cell[905, 32, 123, 2, 29, "Text"],
Cell[1031, 36, 1762, 60, 101, "Text"],
Cell[2796, 98, 2852, 101, 173, "Text",
 Evaluatable->False],
Cell[5651, 201, 4659, 165, 140, "Text",
 Evaluatable->False],
Cell[10313, 368, 2427, 90, 119, "Text"],
Cell[CellGroupData[{
Cell[12765, 462, 157, 4, 29, "Text",
 Evaluatable->False],
Cell[12925, 468, 180, 7, 29, "Text"],
Cell[13108, 477, 3493, 104, 392, "Input"],
Cell[16604, 583, 3537, 104, 392, "Input"],
Cell[20144, 689, 2249, 59, 272, "Input"]
}, Closed]],
Cell[22408, 751, 1416, 26, 160, "Text",
 Evaluatable->False],
Cell[23827, 779, 526, 21, 29, "Text"],
Cell[24356, 802, 578, 21, 29, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[24959, 827, 160, 4, 29, "Text",
 Evaluatable->False],
Cell[25122, 833, 438, 16, 29, "Text"],
Cell[25563, 851, 4724, 139, 353, "Input"]
}, Closed]],
Cell[30302, 993, 4529, 171, 92, "Text"],
Cell[34834, 1166, 3807, 65, 257, "Text",
 Evaluatable->False],
Cell[38644, 1233, 1030, 36, 29, "Text"],
Cell[39677, 1271, 2063, 71, 65, "Text"],
Cell[41743, 1344, 963, 34, 47, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[42731, 1382, 236, 9, 29, "Text",
 Evaluatable->False],
Cell[42970, 1393, 44, 0, 29, "Text"],
Cell[43017, 1395, 2508, 73, 232, "Input"]
}, Closed]],
Cell[45540, 1471, 3162, 108, 213, "Text",
 Evaluatable->False],
Cell[48705, 1581, 703, 18, 47, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[49433, 1603, 233, 9, 29, "Text",
 Evaluatable->False],
Cell[49669, 1614, 456, 16, 47, "Text"],
Cell[50128, 1632, 4087, 116, 453, "Input"]
}, Closed]],
Cell[54230, 1751, 3299, 57, 255, "Text",
 Evaluatable->False],
Cell[57532, 1810, 525, 19, 29, "Text"],
Cell[58060, 1831, 1393, 51, 101, "Text"],
Cell[59456, 1884, 1457, 27, 211, "Text",
 Evaluatable->False],
Cell[60916, 1913, 235, 10, 29, "Text"],
Cell[61154, 1925, 1684, 65, 47, "Text",
 Evaluatable->False],
Cell[62841, 1992, 1487, 59, 101, "Text"],
Cell[64331, 2053, 1438, 53, 101, "Text"],
Cell[65772, 2108, 2648, 46, 163, "Text",
 Evaluatable->False],
Cell[68423, 2156, 217, 8, 29, "Text"],
Cell[68643, 2166, 895, 36, 65, "Text"],
Cell[69541, 2204, 887, 29, 47, "Text"],
Cell[70431, 2235, 2547, 45, 215, "Text",
 Evaluatable->False],
Cell[72981, 2282, 572, 23, 29, "Text"],
Cell[73556, 2307, 624, 26, 29, "Text",
 Evaluatable->False],
Cell[74183, 2335, 2267, 87, 157, "Text"],
Cell[76453, 2424, 1625, 60, 71, "Text"],
Cell[CellGroupData[{
Cell[78103, 2488, 247, 10, 29, "Text",
 Evaluatable->False],
Cell[78353, 2500, 1439, 53, 101, "Text"],
Cell[79795, 2555, 2645, 77, 200, "Input"],
Cell[82443, 2634, 1617, 47, 132, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[84097, 2686, 200, 8, 26, "Text"],
Cell[84300, 2696, 619, 24, 47, "Text"],
Cell[84922, 2722, 2599, 77, 200, "Input"],
Cell[87524, 2801, 1551, 46, 152, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[89112, 2852, 247, 10, 26, "Text",
 Evaluatable->False],
Cell[89362, 2864, 1053, 37, 53, "Text"],
Cell[90418, 2903, 2813, 80, 240, "Input"],
Cell[93234, 2985, 1679, 48, 132, "Input"]
}, Closed]],
Cell[94928, 3036, 1893, 67, 68, "Text"],
Cell[96824, 3105, 3098, 106, 119, "Text"],
Cell[99925, 3213, 3250, 56, 232, "Text",
 Evaluatable->False],
Cell[103178, 3271, 334, 13, 29, "Text"],
Cell[103515, 3286, 2054, 36, 162, "Text",
 Evaluatable->False],
Cell[105572, 3324, 688, 24, 29, "Text"],
Cell[106263, 3350, 937, 29, 65, "Text"],
Cell[107203, 3381, 387, 15, 29, "Text",
 Evaluatable->False],
Cell[107593, 3398, 4201, 146, 216, "Text"],
Cell[111797, 3546, 1585, 59, 83, "Text"],
Cell[113385, 3607, 1721, 55, 83, "Text"],
Cell[115109, 3664, 628, 13, 65, "Text"],
Cell[115740, 3679, 1401, 53, 65, "Text"],
Cell[117144, 3734, 1311, 26, 101, "Text"],
Cell[118458, 3762, 8476, 142, 307, "Text",
 Evaluatable->False],
Cell[126937, 3906, 1115, 40, 29, "Text"],
Cell[CellGroupData[{
Cell[128077, 3950, 99, 2, 29, "Text"],
Cell[128179, 3954, 9069, 151, 307, "Text",
 Evaluatable->False]
}, Closed]],
Cell[137263, 4108, 209, 4, 44, "Text"],
Cell[137475, 4114, 281, 7, 29, "Text"],
Cell[137759, 4123, 277, 7, 29, "Text"],
Cell[138039, 4132, 288, 7, 29, "Text"],
Cell[138330, 4141, 265, 6, 29, "Text"],
Cell[138598, 4149, 249, 5, 29, "Text"],
Cell[138850, 4156, 318, 7, 29, "Text"]
}
]
*)

(* End of internal cache information *)
