(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    259542,       7824]
NotebookOptionsPosition[    251226,       7573]
NotebookOutlinePosition[    251750,       7597]
CellTagsIndexPosition[    251676,       7592]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["Chapter 2  Complex Functions",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[StyleBox["Overview",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell["\<\
\tThe last chapter developed a basic theory of complex numbers.  For the next \
few chapters we turn our attention to functions of complex numbers.  They are \
defined in a similar way to functions of real numbers that you studied in \
calculus; the only difference is that they operate on complex numbers rather \
than real numbers.  This chapter focuses primarily on very basic functions, \
their representations, and properties associated with functions such as \
limits and continuity.  You will learn some interesting applications as well \
as some exciting new ideas. \
\>", "Text",
 CellChangeTimes->{{3.398976624625*^9, 3.3989766306875*^9}}],

Cell[TextData[StyleBox["2.1 Functions and Linear Mappings",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
 "\tA complex-valued function ",
 StyleBox["f",
  FontFamily->"Courier New"],
 " of the complex variable z is a rule that assigns to each complex number ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " in a set ",
 StyleBox["D",
  FontFamily->"Courier New"],
 " one and only one complex number ",
 StyleBox["w",
  FontFamily->"Courier New"],
 ".  We write  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}]}]]],
 "  and call ",
 StyleBox["w",
  FontFamily->"Courier New"],
 " the image of ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " under ",
 StyleBox["f",
  FontFamily->"Courier New"],
 ".   A simple example of a complex-valued function is given by the formula  \
",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "=", 
    SuperscriptBox["z", "4"]}]}]]],
 ".  The set ",
 StyleBox["D",
  FontFamily->"Courier New"],
 " is called the domain of ",
 StyleBox["f",
  FontFamily->"Courier New"],
 ", and the set of all images  ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{"w", "=", 
    RowBox[{
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], ":", 
     RowBox[{"z", "\[Element]", "D"}]}]}], "}"}]]],
 "  is called the range of ",
 StyleBox["f",
  FontFamily->"Courier New"],
 ".  When the context is obvious, we omit the phrase complex-valued, and \
simply refer to a function ",
 StyleBox["f",
  FontFamily->"Courier New"],
 ", or to a complex function ",
 StyleBox["f",
  FontFamily->"Courier New"],
 ". "
}], "Text"],

Cell[TextData[{
 "\tWe can define the domain to be any set that makes sense for a given rule, \
so for  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "=", 
    SuperscriptBox["z", "4"]}]}]]],
 ",  we could have the entire complex plane for the domain ",
 StyleBox["D",
  FontFamily->"Courier New"],
 ", or we might artificially restrict the domain to some set such as  ",
 Cell[BoxData[
  RowBox[{"D", "=", 
   RowBox[{
    RowBox[{
     SubscriptBox["D", "1"], 
     RowBox[{"(", "0", ")"}]}], "=", 
    RowBox[{"{", 
     RowBox[{"z", ":", " ", 
      RowBox[{"|", "z", "|", 
       RowBox[{"<", "1"}]}]}], "}"}]}]}]]],
 ".  Determining the range for a function defined by a formula is not always \
easy, but we will see plenty of examples later on.  In some contexts \
functions are referred to as mappings or transformations."
}], "Text"],

Cell["\<\
\tIn Section 1.6, we used the term domain to indicate a connected open set.  \
When speaking about the domain of a function, however, we mean only the set \
of points on which the function is defined.  This distinction is worth \
noting, and context will make clear the use intended.\
\>", "Text"],

Cell[TextData[{
 "\tJust as z can be expressed by its real and imaginary parts,  ",
 Cell[BoxData[
  RowBox[{"z", " ", "=", " ", 
   RowBox[{"x", "+", 
    RowBox[{"\[ImaginaryI]", " ", "y"}]}]}]]],
 ",  we write  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", " ", 
   RowBox[{"w", " ", "=", " ", 
    RowBox[{"v", "+", 
     RowBox[{"\[ImaginaryI]", " ", "v"}]}]}]}]]],
 ",  where ",
 StyleBox["u",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["v",
  FontFamily->"Courier New"],
 " are the real and imaginary parts of ",
 StyleBox["w",
  FontFamily->"Courier New"],
 ", respectively.  Doing so gives us the representation  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "=", 
    RowBox[{
     RowBox[{"f", 
      RowBox[{"(", 
       RowBox[{"x", ",", "y"}], ")"}]}], "=", 
     RowBox[{
      RowBox[{"f", 
       RowBox[{"(", 
        RowBox[{"x", "+", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "=", 
      RowBox[{"u", "+", 
       RowBox[{"\[ImaginaryI]", " ", "v"}]}]}]}]}]}]]],
 ".\n\nBecause u and v depend on ",
 StyleBox["x",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["y",
  FontFamily->"Courier New"],
 ", they can be considered to be real-valued functions of the real variables \
",
 StyleBox["x",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["y",
  FontFamily->"Courier New"],
 "; that is,\n\n\t\t\t  ",
 Cell[BoxData[
  RowBox[{"u", "=", 
   RowBox[{"u", 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{"v", "=", 
   RowBox[{"v", 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}]}]]],
 ".  \n\nCombining these ideas, we often write a complex function ",
 StyleBox["f",
  FontFamily->"Courier New"],
 " in the form\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", 
      RowBox[{"x", "+", 
       RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "=", 
    RowBox[{
     RowBox[{"u", 
      RowBox[{"(", 
       RowBox[{"x", ",", "y"}], ")"}]}], "+", 
     RowBox[{"\[ImaginaryI]", " ", "v", 
      RowBox[{"(", 
       RowBox[{"x", ",", "y"}], ")"}]}]}]}]}]]],
 ".  \n\nFigure 2.1 illustrates the notion of a function (mapping) using \
these symbols."
}], "Text"],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{542, 227},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 StyleBox["\t\tFigure 2.1",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  The mapping  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "=", 
    RowBox[{
     RowBox[{"u", 
      RowBox[{"(", 
       RowBox[{"x", ",", "y"}], ")"}]}], "+", 
     RowBox[{"\[ImaginaryI]", " ", "v", 
      RowBox[{"(", 
       RowBox[{"x", ",", "y"}], ")"}]}]}]}]}]]],
 "."
}], "Text"],

Cell[TextData[{
 "\tThere are two methods for defining a ",
 StyleBox["complex function",
  FontColor->RGBColor[0, 0, 1]],
 " in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ". "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "Before we start, make ",
 StyleBox["x",
  FontFamily->"Courier New"],
 ", ",
 StyleBox["y",
  FontFamily->"Courier New"],
 ", ",
 StyleBox["u",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["v",
  FontFamily->"Courier New"],
 " real variables."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"u", ",", "v", ",", "x", ",", "y", ",", "z"}], "]"}], ";"}], " ",
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "f", ",", "F", ",", "X", ",", "Y", ",", "U", ",", "V", ",", "Z"}], "]"}],
     ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"TagSet", "[", 
     RowBox[{"x", ",", 
      RowBox[{"Im", "[", "x", "]"}], ",", "0"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"TagSet", "[", 
     RowBox[{"y", ",", 
      RowBox[{"Im", "[", "y", "]"}], ",", "0"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"TagSet", "[", 
     RowBox[{"u", ",", 
      RowBox[{"Im", "[", 
       RowBox[{"u", "[", 
        RowBox[{"x", ",", "y"}], "]"}], "]"}], ",", "0"}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"TagSet", "[", 
     RowBox[{"v", ",", 
      RowBox[{"Im", "[", 
       RowBox[{"v", "[", 
        RowBox[{"x", ",", "y"}], "]"}], "]"}], ",", "0"}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"TagSet", "[", 
     RowBox[{"x", ",", 
      RowBox[{"Re", "[", "x", "]"}], ",", "x"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"TagSet", "[", 
     RowBox[{"y", ",", 
      RowBox[{"Re", "[", "y", "]"}], ",", "y"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"TagSet", "[", 
     RowBox[{"u", ",", 
      RowBox[{"Re", "[", 
       RowBox[{"u", "[", 
        RowBox[{"x", ",", "y"}], "]"}], "]"}], ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"TagSet", "[", 
     RowBox[{"v", ",", 
      RowBox[{"Re", "[", 
       RowBox[{"v", "[", 
        RowBox[{"x", ",", "y"}], "]"}], "]"}], ",", 
      RowBox[{"v", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.398976893484375*^9, 3.39897689475*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Method 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 "  Make  ",
 StyleBox["f[x,y]",
  FontFamily->"Courier New"],
 "  a function of two real variables ",
 StyleBox["(x,y)",
  FontFamily->"Courier New"],
 "."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"v", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[x,y] = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[2,1] = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"2", ",", "1"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Re[f[x,y]] = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"Re", "[", 
        RowBox[{"f", "[", 
         RowBox[{"x", ",", "y"}], "]"}], "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Im[f[x,y]] = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"Im", "[", 
        RowBox[{"f", "[", 
         RowBox[{"x", ",", "y"}], "]"}], "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Re[f[2,1]] = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"Re", "[", 
        RowBox[{"f", "[", 
         RowBox[{"2", ",", "1"}], "]"}], "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Im[f[2,1]] = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"Im", "[", 
        RowBox[{"f", "[", 
         RowBox[{"2", ",", "1"}], "]"}], "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39897689878125*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Method 2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 "  Make  ",
 StyleBox["F[z]",
  FontFamily->"Courier New"],
 "  a function of  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{"x", " ", "+", " ", 
    RowBox[{"\[ImaginaryI]", " ", "y"}]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "Z_", "]"}], ":=", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"x", "=", 
          RowBox[{"Re", "[", "Z", "]"}]}], ",", 
         RowBox[{"y", "=", 
          RowBox[{"Im", "[", "Z", "]"}]}]}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Return", "[", 
        RowBox[{
         RowBox[{"u", "[", 
          RowBox[{"x", ",", "y"}], "]"}], " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"v", "[", 
           RowBox[{"x", ",", "y"}], "]"}]}]}], "]"}]}], " ", "]"}]}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[x + \[ImaginaryI] y] = \>\"", ",", 
      RowBox[{"F", "[", 
       RowBox[{"x", "+", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<F[x + \[ImaginaryI] y] = \>\"", ",", "\[IndentingNewLine]", 
      RowBox[{"MapAll", "[", 
       RowBox[{"ComplexExpand", ",", 
        RowBox[{"F", "[", 
         RowBox[{"x", "+", 
          RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}]}], "]"}]}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  F[2 + \[ImaginaryI]] = \>\"", ",", 
      RowBox[{"F", "[", 
       RowBox[{"2", "+", "\[ImaginaryI]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Re[F[2 + \[ImaginaryI]]] = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"Re", "[", 
        RowBox[{"F", "[", 
         RowBox[{"2", "+", "\[ImaginaryI]"}], "]"}], "]"}], "]"}]}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Im[F[2 + \[ImaginaryI]]] = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"Im", "[", 
        RowBox[{"F", "[", 
         RowBox[{"2", "+", "\[ImaginaryI]"}], "]"}], "]"}], "]"}]}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.398976908078125*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Remark.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  It was necessary to use the power of  ",
 StyleBox["MapAll",
  FontFamily->"Courier New"],
 "  to find the real and imaginary parts of  ",
 Cell[BoxData[
  RowBox[{"F", "[", 
   RowBox[{"x", " ", "+", " ", 
    RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[x + \[ImaginaryI] y] = \>\"", ",", 
      RowBox[{"F", "[", 
       RowBox[{"x", "+", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Re[F[x + \[ImaginaryI] y]] = \>\"", ",", 
      RowBox[{"Re", "[", 
       RowBox[{"F", "[", 
        RowBox[{"x", "+", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Re[F[x + \[ImaginaryI] y]] = \>\"", ",", 
      RowBox[{"MapAll", "[", 
       RowBox[{"ComplexExpand", ",", " ", 
        RowBox[{"Re", "[", 
         RowBox[{"F", "[", 
          RowBox[{"x", "+", 
           RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}]}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Im[F[x + \[ImaginaryI] y]] = \>\"", ",", 
      RowBox[{"Im", "[", 
       RowBox[{"F", "[", 
        RowBox[{"x", "+", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Im[F[x + \[ImaginaryI] y]] = \>\"", ",", 
      RowBox[{"MapAll", "[", 
       RowBox[{"ComplexExpand", ",", " ", 
        RowBox[{"Im", "[", 
         RowBox[{"F", "[", 
          RowBox[{"x", "+", 
           RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}]}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.398976916578125*^9}]
}, Closed]],

Cell["\<\
We now give several examples that illustrate how to express a complex \
function.\
\>", "Text"],

Cell[TextData[{
 StyleBox["Example 2.1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Write  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   SuperscriptBox["z", "4"]}]]],
 "  in the for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    RowBox[{"u", 
     RowBox[{"(", 
      RowBox[{"x", ",", "y"}], ")"}]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", "v", 
     RowBox[{"(", 
      RowBox[{"x", ",", "y"}], ")"}]}]}]}]]],
 ". \n\nSolution.  Using the binomial formula, we obtain \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], " ", "=", "  ", 
    RowBox[{
     RowBox[{"f", 
      RowBox[{"(", 
       RowBox[{"x", "+", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], " ", "=", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"x", "+", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "4"]}]}], 
   "\[IndentingNewLine]"}], "\n", 
  RowBox[{"           ", 
   RowBox[{
    RowBox[{"=", " ", 
     RowBox[{
      SuperscriptBox["x", "4"], "+", 
      RowBox[{"4", "  ", 
       SuperscriptBox["x", "3"], " ", 
       RowBox[{"(", 
        RowBox[{"\[ImaginaryI]", " ", "y"}], ")"}]}], "+", 
      RowBox[{"6", " ", 
       SuperscriptBox["x", "2"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"\[ImaginaryI]", " ", "y"}], ")"}], "2"]}], "+", 
      RowBox[{"4", "  ", "x", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"\[ImaginaryI]", " ", "y"}], ")"}], "3"]}], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"\[ImaginaryI]", " ", "y"}], ")"}], "4"]}]}], 
    "\[IndentingNewLine]"}]}], "\n", 
  RowBox[{"           ", 
   RowBox[{
    RowBox[{"=", " ", 
     RowBox[{
      SuperscriptBox["x", "4"], "+", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["x", "3"], " ", "y"}], "-", 
      RowBox[{"6", " ", 
       SuperscriptBox["x", "2"], " ", 
       SuperscriptBox["y", "2"]}], "-", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", "x", " ", 
       SuperscriptBox["y", "3"]}], "+", 
      SuperscriptBox["y", "4"]}]}], "\[IndentingNewLine]"}]}], "\n", 
  RowBox[{"           ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      SuperscriptBox["x", "4"], "-", 
      RowBox[{"6", " ", 
       SuperscriptBox["x", "2"], " ", 
       SuperscriptBox["y", "2"]}], "+", 
      SuperscriptBox["y", "4"], " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"4", " ", 
          SuperscriptBox["x", "3"], " ", "y"}], "-", 
         RowBox[{"4", " ", "x", " ", 
          SuperscriptBox["y", "3"]}]}], ")"}]}]}]}], 
    "\[IndentingNewLine]"}]}], "\n", 
  RowBox[{"           ", 
   RowBox[{"=", " ", 
    RowBox[{
     RowBox[{"u", 
      RowBox[{"(", 
       RowBox[{"x", ",", "y"}], ")"}]}], " ", "+", " ", 
     RowBox[{"\[ImaginaryI]", " ", "v", 
      RowBox[{"(", 
       RowBox[{"x", ",", "y"}], ")"}]}]}]}]}]}]],
 "\n\nso that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"u", 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["x", "4"], "-", 
     RowBox[{"6", " ", 
      SuperscriptBox["x", "2"], " ", 
      SuperscriptBox["y", "2"]}], "+", 
     RowBox[{
      SuperscriptBox["y", "4"], "  ", 
      StyleBox["and",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "  ", "v", 
      RowBox[{"(", 
       RowBox[{"x", ",", "y"}], ")"}]}]}], "=", 
    RowBox[{
     RowBox[{"4", " ", 
      SuperscriptBox["x", "3"], " ", "y"}], "-", 
     RowBox[{"4", " ", "x", " ", 
      SuperscriptBox["y", "3"]}]}]}]}]]],
 ". "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 2.1.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell["Use Method 1 to construct  f[x,y].  ", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"x", ",", "y", ",", "z", ",", "Z"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "F"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"TagSet", "[", 
     RowBox[{"x", ",", 
      RowBox[{"Im", "[", "x", "]"}], ",", "0"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"TagSet", "[", 
     RowBox[{"y", ",", 
      RowBox[{"Im", "[", "y", "]"}], ",", "0"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"TagSet", "[", 
     RowBox[{"x", ",", 
      RowBox[{"Re", "[", "x", "]"}], ",", "x"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"TagSet", "[", 
     RowBox[{"y", ",", 
      RowBox[{"Re", "[", "y", "]"}], ",", "y"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], "=", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"x", "+", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "4"]}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[x,y] = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], "=", 
     RowBox[{"ComplexExpand", "[", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"x", "+", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "4"], "]"}]}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[x,y] = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Check out a few points.\>\"", "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[0,1] = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"0", ",", "1"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[1,1] = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"1", ",", "1"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[1,\!\(\*FractionBox[\(1\), \(2\)]\)] = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"1", ",", 
        FractionBox["1", "2"]}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.3989769265625*^9},
 AspectRatioFixed->True],

Cell["Use Method 2 to construct  F[z].  ", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "z_", "]"}], ":=", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"x", "=", 
          RowBox[{"Re", "[", "z", "]"}]}], ",", 
         RowBox[{"y", "=", 
          RowBox[{"Im", "[", "z", "]"}]}], ",", "Z"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Z", "=", 
         RowBox[{"x", "+", 
          RowBox[{"\[ImaginaryI]", " ", "y"}]}]}], ";", " ", 
        "\[IndentingNewLine]", 
        RowBox[{"Return", "[", 
         RowBox[{"ComplexExpand", "[", 
          SuperscriptBox["Z", "4"], "]"}], "]"}]}]}], " ", "]"}]}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Z", "=", 
     RowBox[{"x", " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", "y"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[\>\"", ",", "Z", ",", "\"\<] = \>\"", ",", 
      SuperscriptBox["z", "4"]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[\>\"", ",", "Z", ",", "\"\<] = \>\"", ",", 
      RowBox[{"F", "[", "Z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Check out a few points.\>\"", "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Z", "=", 
     FractionBox["9", "10"]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[\>\"", ",", "Z", ",", "\"\<] = \>\"", ",", 
      RowBox[{"F", "[", "Z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Z", "=", "\[ImaginaryI]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[\>\"", ",", "Z", ",", "\"\<] = \>\"", ",", 
      RowBox[{"F", "[", "Z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Z", "=", 
     RowBox[{"1", " ", "+", " ", "\[ImaginaryI]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[\>\"", ",", "Z", ",", "\"\<] = \>\"", ",", 
      RowBox[{"F", "[", "Z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Z", "=", 
     RowBox[{"1", " ", "+", " ", 
      FractionBox["\[ImaginaryI]", "2"]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[\>\"", ",", "Z", ",", "\"\<] = \>\"", ",", 
      RowBox[{"F", "[", "Z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Z", "=", 
     RowBox[{
      FractionBox["1", "2"], " ", "+", " ", "\[ImaginaryI]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[\>\"", ",", "Z", ",", "\"\<] = \>\"", ",", 
      RowBox[{"F", "[", "Z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Z", "=", 
     RowBox[{
      FractionBox["1", "2"], " ", "+", " ", 
      FractionBox["\[ImaginaryI]", "2"]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[\>\"", ",", "Z", ",", "\"\<] = \>\"", ",", 
      RowBox[{"F", "[", "Z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.398976934078125*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Aside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  We can let ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " plot the image of a region under the mapping w = f[z]."
}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<    f[\>\"", ",", "1", ",", "\"\<] = \>\"", ",", 
    RowBox[{"f", "[", "1", "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<f[\>\"", ",", 
    RowBox[{"1", "+", 
     FractionBox["\[ImaginaryI]", "2"]}], ",", "\"\<] = \>\"", ",", 
    RowBox[{"f", "[", 
     RowBox[{"1", "+", 
      FractionBox["\[ImaginaryI]", "2"]}], "]"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\< f[\>\"", ",", 
    RowBox[{"1", "+", "\[ImaginaryI]"}], ",", "\"\<] = \>\"", ",", 
    RowBox[{"f", "[", 
     RowBox[{"1", "+", "\[ImaginaryI]"}], "]"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.400238972328125*^9, 3.40023900484375*^9}, {
  3.400239245796875*^9, 3.400239329625*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"d", ",", "f", ",", "g", ",", "Iden", ",", "z"}], "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"Iden", "[", "z_", "]"}], " ", "=", " ", "z"}], ";"}], " ", "\n",
    
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     SuperscriptBox["z", "4"]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"set", " ", "=", "  ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         FractionBox["1", "2"]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         FractionBox["1", "2"], ",", "1"}], "}"}]}], "}"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"zdots", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           SubscriptBox["set", 
            RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], 
           "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Green", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           SubscriptBox["set", 
            RowBox[{"\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]], 
           "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           SubscriptBox["set", 
            RowBox[{"\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}]], 
           "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Magenta", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           SubscriptBox["set", 
            RowBox[{"\[LeftDoubleBracket]", "4", "\[RightDoubleBracket]"}]], 
           "]"}]}], "}"}]}], "}"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"set", " ", "=", "  ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["7", "16"]}], ",", 
         FractionBox[
          RowBox[{"3", " "}], "2"]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "4"}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["7", "16"]}], ",", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"3", " "}], "2"]}]}], "}"}]}], "}"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"wdots", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           SubscriptBox["set", 
            RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], 
           "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Green", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           SubscriptBox["set", 
            RowBox[{"\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]], 
           "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           SubscriptBox["set", 
            RowBox[{"\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}]], 
           "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Magenta", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           SubscriptBox["set", 
            RowBox[{"\[LeftDoubleBracket]", "4", "\[RightDoubleBracket]"}]], 
           "]"}]}], "}"}]}], "}"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g1", "=", 
     RowBox[{"CartesianMap", "[", 
      RowBox[{"Iden", ",", " ", 
       RowBox[{"{", 
        RowBox[{"0", ",", "1", ",", "0.1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "1", ",", "0.1"}], "}"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.1"}], ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.1"}], ",", "1"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "1", ",", 
            FractionBox["1", "2"]}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "1", ",", 
            FractionBox["1", "2"]}], "]"}]}], "}"}]}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"Show", "[", 
      RowBox[{"g1", ",", "zdots"}], "]"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<A unit square in the z-plane.\>\"", "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"g2", "=", 
     RowBox[{"CartesianMap", "[", 
      RowBox[{"f", ",", " ", 
       RowBox[{"{", 
        RowBox[{"0", ",", "1", ",", "0.1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "1", ",", "0.1"}], "}"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4"}], ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2"}], ",", "2"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", 
        FractionBox["4", "5"]}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "4"}], ",", "0", ",", "1"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"Show", "[", 
      RowBox[{"g2", ",", "wdots"}], "]"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The image region,\>\"", "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<under the mapping  w = f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<    f[\>\"", ",", "1", ",", "\"\<] = \>\"", ",", 
      RowBox[{"f", "[", "1", "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[\>\"", ",", 
      RowBox[{"1", "+", 
       FractionBox["\[ImaginaryI]", "2"]}], ",", "\"\<] = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"1", "+", 
        FractionBox["\[ImaginaryI]", "2"]}], "]"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f[\>\"", ",", 
      RowBox[{"1", "+", "\[ImaginaryI]"}], ",", "\"\<] = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"1", "+", "\[ImaginaryI]"}], "]"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[\>\"", ",", 
      RowBox[{
       FractionBox["1", "2"], "+", "\[ImaginaryI]"}], ",", "\"\<] = \>\"", 
      ",", 
      RowBox[{"f", "[", 
       RowBox[{
        FractionBox["1", "2"], "+", "\[ImaginaryI]"}], "]"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3989769515625*^9, 3.39897697371875*^9}, {
  3.399119650609375*^9, 3.399119659375*^9}, {3.39972075540625*^9, 
  3.399720763359375*^9}, {3.40023850996875*^9, 3.400238513640625*^9}, {
  3.400238831953125*^9, 3.4002388895625*^9}, {3.400238943703125*^9, 
  3.4002389441875*^9}, {3.400238985921875*^9, 3.400238988203125*^9}, {
  3.40023933578125*^9, 3.400239336140625*^9}, {3.400239383203125*^9, 
  3.4002395678125*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"d", "[", "z_", "]"}], "=", 
     RowBox[{"z", "+", 
      FractionBox[
       RowBox[{"1", "+", "\[ImaginaryI]"}], "2"]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"g", "[", "z_", "]"}], "=", 
     RowBox[{"f", "[", 
      RowBox[{"z", "+", 
       FractionBox[
        RowBox[{"1", "+", "\[ImaginaryI]"}], "2"]}], "]"}]}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"PolarMap", "[", 
    RowBox[{"d", " ", ",", " ", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       FractionBox["1", "2"], ",", 
       FractionBox["1", "20"]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"2", "\[Pi]"}], ",", 
       FractionBox["\[Pi]", "12"]}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "1", ",", 
          FractionBox["1", "2"]}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "1", ",", 
          FractionBox["1", "2"]}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The disk |z-\!\(\*FractionBox[\(1 + \[ImaginaryI]\), \(2\)]\)| < \!\
\(\*FractionBox[\(1\), \(2\)]\) in the z-plane.\>\"", "]"}], ";"}], " ", "\n",
    
   RowBox[{"PolarMap", "[", 
    RowBox[{"g", " ", ",", 
     RowBox[{"{", " ", 
      RowBox[{"0", ",", 
       FractionBox["1", "2"], ",", 
       FractionBox["1", "20"]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"2", "\[Pi]"}], ",", 
       FractionBox["\[Pi]", "12"]}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.2"}], ",", "1.0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.6"}], ",", "1.6"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "1", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The image region in the w = u + \[ImaginaryI]v plane\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<under the mapping  w = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39897697859375*^9, 3.398976982765625*^9}, {
  3.399119670234375*^9, 3.399119672953125*^9}, {3.399720770578125*^9, 
  3.399720770765625*^9}, {3.4002395823125*^9, 3.4002395890625*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 2.2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Express the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    RowBox[{
     OverscriptBox[
      RowBox[{"z", " "}], "_"], " ", 
     RowBox[{"Re", "[", "z", "]"}]}], "+", 
    SuperscriptBox["z", "2"], "+", 
    RowBox[{"Im", "[", "z", "]"}]}]}]]],
 "  in the form  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    RowBox[{"u", 
     RowBox[{"(", 
      RowBox[{"x", ",", "y"}], ")"}]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", "v", 
     RowBox[{"(", 
      RowBox[{"x", ",", "y"}], ")"}]}]}]}]]],
 ".\n\nSolution.  Using the elementary properties of complex numbers, it \
follows that  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"x", "-", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "x"}], "+", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"x", "+", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"], "+", "y"}], "  ", 
    "=", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        SuperscriptBox["x", "2"]}], "-", 
       SuperscriptBox["y", "2"], "+", "y"}], ")"}], "+", 
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{"(", 
       RowBox[{"x", " ", "y"}], ")"}]}]}]}]}]]],
 "\n\nso that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"u", 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"2", " ", 
      SuperscriptBox["x", "2"]}], "-", 
     SuperscriptBox["y", "2"], "+", 
     RowBox[{"y", "  ", 
      StyleBox["and",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "  ", "v", 
      RowBox[{"(", 
       RowBox[{"x", ",", "y"}], ")"}]}]}], "=", 
    RowBox[{"x", " ", "y"}]}]}]]],
 ". "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 2.2.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell["Use Method 1 to construct  f[x,y].  ", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"x", ",", "y", ",", "z", ",", "Z"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "F"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"TagSet", "[", 
     RowBox[{"x", ",", 
      RowBox[{"Im", "[", "x", "]"}], ",", "0"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"TagSet", "[", 
     RowBox[{"y", ",", 
      RowBox[{"Im", "[", "y", "]"}], ",", "0"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"TagSet", "[", 
     RowBox[{"x", ",", 
      RowBox[{"Re", "[", "x", "]"}], ",", "x"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"TagSet", "[", 
     RowBox[{"y", ",", 
      RowBox[{"Re", "[", "y", "]"}], ",", "y"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Z", "=", 
     RowBox[{"x", "+", 
      RowBox[{"\[ImaginaryI]", " ", "y"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], "=", "\[IndentingNewLine]", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Conjugate", "[", "Z", "]"}], 
        RowBox[{"Re", "[", "Z", "]"}]}], "+", 
       SuperscriptBox["Z", "2"], "+", 
       RowBox[{"Im", "[", "Z", "]"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[x,y] = \>\"", ",", 
      RowBox[{
       RowBox[{
        RowBox[{"Conjugate", "[", "Z", "]"}], 
        RowBox[{"Re", "[", "Z", "]"}]}], "+", 
       SuperscriptBox["Z", "2"], "+", 
       RowBox[{"Im", "[", "Z", "]"}]}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[x,y] = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Check out a few points.\>\"", "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[1,0] = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"1", ",", "0"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[0,1] = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"0", ",", "1"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[1,1] = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"1", ",", "1"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[\!\(\*FractionBox[\(1\), \(2\)]\),1] = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{
        FractionBox["1", "2"], ",", "1"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[1,\!\(\*FractionBox[\(1\), \(2\)]\)] = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"1", ",", 
        FractionBox["1", "2"]}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[3,2] = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"3", ",", "2"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.398976992484375*^9},
 AspectRatioFixed->True],

Cell["Use Method 2 to construct  F[z].  ", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "Z_", "]"}], ":=", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"x", "=", 
          RowBox[{"Re", "[", "Z", "]"}]}], ",", 
         RowBox[{"y", "=", 
          RowBox[{"Im", "[", "Z", "]"}]}], ",", "z"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"z", "=", 
         RowBox[{"x", "+", 
          RowBox[{"\[ImaginaryI]", " ", "y"}]}]}], ";", " ", 
        "\[IndentingNewLine]", 
        RowBox[{"Return", "[", 
         RowBox[{"ComplexExpand", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Conjugate", "[", "z", "]"}], 
            RowBox[{"Re", "[", "z", "]"}]}], "+", 
           SuperscriptBox["z", "2"], "+", 
           RowBox[{"Im", "[", "z", "]"}]}], "]"}], "]"}]}]}], "]"}]}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Z", "=", 
     RowBox[{"x", " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", "y"}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[x,y] = \>\"", ",", 
      RowBox[{
       RowBox[{
        RowBox[{"Conjugate", "[", "Z", "]"}], 
        RowBox[{"Re", "[", "Z", "]"}]}], "+", 
       SuperscriptBox["Z", "2"], "+", 
       RowBox[{"Im", "[", "Z", "]"}]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[\>\"", ",", "Z", ",", "\"\<] = \>\"", ",", 
      RowBox[{"F", "[", "Z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Check out a few points.\>\"", "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Z", "=", "1"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[\>\"", ",", "Z", ",", "\"\<] = \>\"", ",", 
      RowBox[{"F", "[", "Z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Z", "=", "\[ImaginaryI]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[\>\"", ",", "Z", ",", "\"\<] = \>\"", ",", 
      RowBox[{"F", "[", "Z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Z", "=", 
     RowBox[{"1", " ", "+", " ", "\[ImaginaryI]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[\>\"", ",", "Z", ",", "\"\<] = \>\"", ",", 
      RowBox[{"F", "[", "Z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Z", "=", 
     RowBox[{
      FractionBox["1", "2"], "+", "  ", "\[ImaginaryI]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[\>\"", ",", "Z", ",", "\"\<] = \>\"", ",", 
      RowBox[{"F", "[", "Z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Z", "=", 
     RowBox[{"1", "+", " ", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]"}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[\>\"", ",", "Z", ",", "\"\<] = \>\"", ",", 
      RowBox[{"F", "[", "Z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Z", "=", 
     RowBox[{"3", " ", "+", " ", 
      RowBox[{"2", " ", "\[ImaginaryI]"}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[\>\"", ",", "Z", ",", "\"\<] = \>\"", ",", 
      RowBox[{"F", "[", "Z", "]"}]}], "]"}], ";"}], " ", "\n"}]}]], "Input",
 CellChangeTimes->{3.3989769990625*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Aside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  We can let ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " plot the image of a region under the mapping w = f[z]."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "z"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Iden", "[", "z_", "]"}], "=", "z"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", 
     RowBox[{
      RowBox[{
       RowBox[{"Conjugate", "[", "z", "]"}], 
       RowBox[{"Re", "[", "z", "]"}]}], "+", 
      SuperscriptBox["z", "2"], "+", 
      RowBox[{"Im", "[", "z", "]"}]}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"CartesianMap", "[", 
    RowBox[{"Iden", ",", " ", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1", ",", "0.1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1", ",", "0.1"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.1"}], ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.1"}], ",", "1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "1", ",", 
          FractionBox["1", "2"]}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "1", ",", 
          FractionBox["1", "2"]}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", "\"\<A unit square in the z-plane.\>\"", "]"}], 
    ";"}], " ", "\n", 
   RowBox[{"CartesianMap", "[", 
    RowBox[{"f", ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1", ",", "0.1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1", ",", "0.1"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "2.3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "1.15"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["1", "2"]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "2", ",", 
          FractionBox["1", "2"]}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "1", ",", 
          FractionBox["1", "2"]}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The image region in the w = u + \[ImaginaryI]v plane\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<under the mapping  w = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<                   w = \>\"", ",", 
      RowBox[{"MapAll", "[", 
       RowBox[{"ComplexExpand", ",", 
        RowBox[{"f", "[", 
         RowBox[{"x", "+", 
          RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}]}], "]"}]}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39897700440625*^9, 3.39897700828125*^9}, {
  3.399119687546875*^9, 3.399119690390625*^9}, {3.39972077734375*^9, 
  3.39972077753125*^9}, {3.4002396071875*^9, 3.400239611078125*^9}}]
}, Closed]],

Cell[TextData[{
 "\tExamples 2.1 and 2.2 show how to find ",
 StyleBox["u(x,y)",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["v(x,y)",
  FontFamily->"Courier New"],
 " when a rule for computing f is given.  Conversely, if ",
 StyleBox["u(x,y)",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["v(x,y)",
  FontFamily->"Courier New"],
 " are two real-valued functions of the real \nvariables ",
 StyleBox["x",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["y",
  FontFamily->"Courier New"],
 ", they determine a complex-valued function    ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    RowBox[{"u", 
     RowBox[{"(", 
      RowBox[{"x", ",", "y"}], ")"}]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", "v", 
     RowBox[{"(", 
      RowBox[{"x", ",", "y"}], ")"}]}]}]}]]],
 ",  and we can use the formulas\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"x", "=", 
   FractionBox[
    RowBox[{"z", " ", "+", " ", 
     OverscriptBox[
      RowBox[{"z", " "}], "_"]}], "2"]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{"y", "=", 
   FractionBox[
    RowBox[{"z", " ", "-", " ", 
     OverscriptBox[
      RowBox[{"z", " "}], "_"]}], 
    RowBox[{"2", "\[ImaginaryI]"}]]}]]],
 " \n\nto find a formula for f involving the variables z and ",
 Cell[BoxData[
  OverscriptBox[
   RowBox[{"z", " "}], "_"]]],
 ".  "
}], "Text",
 CellChangeTimes->{3.3989766503125*^9}],

Cell[TextData[{
 StyleBox["Example 2.3.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Express  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"4", 
     SuperscriptBox["x", "2"]}], " ", "+", " ", 
    RowBox[{"\[ImaginaryI]", " ", "4", 
     SuperscriptBox["y", "2"]}]}]}]],
  AspectRatioFixed->True],
 "  by a formula involving the variables  ",
 Cell[BoxData[
  RowBox[{"z", "  ", "and", "  ", 
   OverscriptBox[
    RowBox[{"z", " "}], "_"]}]]],
 ".  \n\nSolution.  Calculation reveals that \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{"4", 
      SuperscriptBox[
       RowBox[{"(", 
        FractionBox[
         RowBox[{"z", " ", "+", " ", 
          OverscriptBox[
           RowBox[{"z", " "}], "_"]}], "2"], ")"}], "2"]}], "+", 
     RowBox[{"\[ImaginaryI]", " ", "4", 
      SuperscriptBox[
       RowBox[{"(", 
        FractionBox[
         RowBox[{"z", " ", "-", " ", 
          OverscriptBox[
           RowBox[{"z", " "}], "_"]}], 
         RowBox[{"2", "\[ImaginaryI]"}]], ")"}], "2"]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"           ", 
   RowBox[{
    RowBox[{"=", " ", 
     RowBox[{
      SuperscriptBox["z", "2"], "+", 
      RowBox[{"2", " ", "z", " ", 
       OverscriptBox[
        RowBox[{"z", " "}], "_"]}], "+", 
      SuperscriptBox[
       RowBox[{
        OverscriptBox[
         RowBox[{"z", " "}], "_"], " "}], "2"], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z", "2"], "-", 
         RowBox[{"2", " ", "z", " ", 
          OverscriptBox[
           RowBox[{"z", " "}], "_"]}], "+", 
         SuperscriptBox[
          RowBox[{
           OverscriptBox[
            RowBox[{"z", " "}], "_"], " "}], "2"]}], ")"}]}]}]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"           ", 
   RowBox[{"=", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "\[ImaginaryI]"}], ")"}], 
      SuperscriptBox["z", "2"]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2", "+", 
        RowBox[{"2", "\[ImaginaryI]"}]}], ")"}], " ", "z", " ", 
      OverscriptBox[
       RowBox[{"z", " "}], "_"]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "\[ImaginaryI]"}], ")"}], 
      SuperscriptBox[
       RowBox[{
        OverscriptBox[
         RowBox[{"z", " "}], "_"], " "}], "2"]}]}]}]}]}]]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 2.3.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell["Enter the function.", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"w", ",", "x", ",", "y", ",", "z", ",", "Z"}], "]"}], ";"}], " ",
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", "f", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"TagSet", "[", 
     RowBox[{"x", ",", 
      RowBox[{"Im", "[", "x", "]"}], ",", "0"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"TagSet", "[", 
     RowBox[{"y", ",", 
      RowBox[{"Im", "[", "y", "]"}], ",", "0"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"TagSet", "[", 
     RowBox[{"x", ",", 
      RowBox[{"Re", "[", "x", "]"}], ",", "x"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"TagSet", "[", 
     RowBox[{"y", ",", 
      RowBox[{"Re", "[", "y", "]"}], ",", "y"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"w", " ", "=", " ", 
     RowBox[{
      RowBox[{"4", 
       SuperscriptBox["x", "2"]}], " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", "4", 
       SuperscriptBox["y", "2"]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{"w", " ", ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"x", "\[Rule]", 
          FractionBox[
           RowBox[{"z", " ", "+", " ", 
            RowBox[{"Conjugate", "[", "z", "]"}]}], "2"]}], ",", 
         RowBox[{"y", "\[Rule]", 
          FractionBox[
           RowBox[{"z", " ", "-", " ", 
            RowBox[{"Conjugate", "[", "z", "]"}]}], 
           RowBox[{"2", "\[ImaginaryI]"}]]}]}], "}"}]}], "]"}]}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<    f[z] = \>\"", ",", "w"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<    f[z] = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<    f[z] = \>\"", ",", 
      RowBox[{"Expand", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", ",", "y"}], "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", "Z", "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"u", "[", 
      RowBox[{"x", ",", "y"}], "]"}], "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"Re", "[", "w", "]"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"v", "[", 
      RowBox[{"x", ",", "y"}], "]"}], "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"Im", "[", "w", "]"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "Z_", "]"}], ":=", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"x", "=", 
          RowBox[{"Re", "[", "Z", "]"}]}], ",", 
         RowBox[{"y", "=", 
          RowBox[{"Im", "[", "Z", "]"}]}]}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Return", "[", 
        RowBox[{
         RowBox[{"u", "[", 
          RowBox[{"x", ",", "y"}], "]"}], " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"v", "[", 
           RowBox[{"x", ",", "y"}], "]"}]}]}], "]"}]}], " ", "]"}]}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[\>\"", ",", "Z", ",", "\"\<] = \>\"", ",", 
      RowBox[{"F", "[", "Z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[\>\"", ",", 
      RowBox[{"x", "+", 
       RowBox[{"\[ImaginaryI]", " ", "y"}]}], ",", "\"\<] = \>\"", ",", 
      RowBox[{"F", "[", 
       RowBox[{"x", "+", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.398977015546875*^9, 3.3989770335*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Aside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  We can let ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " plot the image of a region under the mapping w = f[z]."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "z"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Iden", "[", "z_", "]"}], "=", "z"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", 
     RowBox[{
      RowBox[{"4", 
       SuperscriptBox[
        RowBox[{"Re", "[", "z", "]"}], "2"]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", "4", 
       SuperscriptBox[
        RowBox[{"Im", "[", "z", "]"}], "2"]}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"CartesianMap", "[", 
    RowBox[{"Iden", ",", " ", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1", ",", "0.1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1", ",", "0.1"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.1"}], ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.1"}], ",", "1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "1", ",", 
          FractionBox["1", "2"]}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "1", ",", 
          FractionBox["1", "2"]}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", "\"\<A unit square in the z-plane.\>\"", "]"}], 
    ";"}], " ", "\n", 
   RowBox[{"CartesianMap", "[", 
    RowBox[{"f", ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1", ",", "0.1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1", ",", "0.1"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "4.2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "4.2"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "4", ",", 
          FractionBox["1", "2"]}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "4", ",", 
          FractionBox["1", "2"]}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The image region in the w = u + \[ImaginaryI]v plane\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<under the mapping  w = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<                   w = \>\"", ",", 
      RowBox[{"MapAll", "[", 
       RowBox[{"ComplexExpand", ",", 
        RowBox[{"f", "[", 
         RowBox[{"x", "+", 
          RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}]}], "]"}]}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.398977038703125*^9, 3.398977042015625*^9}, {
  3.399119698984375*^9, 3.399119701609375*^9}, {3.39972078359375*^9, 
  3.399720783796875*^9}, {3.40023962396875*^9, 3.40023962815625*^9}}]
}, Closed]],

Cell[TextData[{
 "\tUsing  ",
 Cell[BoxData[
  RowBox[{"z", " ", "=", " ", 
   RowBox[{"r", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]]}]}]]],
 "  in the expression of a complex function f may be convenient.  It gives us \
the polar representation  \n\n\t\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", " ", ")"}]}], "=", " ", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", 
      RowBox[{"r", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]]}], ")"}]}], " ", "=", " ",
     
    RowBox[{
     RowBox[{"U", 
      RowBox[{"(", 
       RowBox[{"r", ",", "\[Theta]"}], ")"}]}], " ", "+", " ", 
     RowBox[{"\[ImaginaryI]", " ", "V", 
      RowBox[{"(", 
       RowBox[{"r", ",", "\[Theta]"}], ")"}]}]}]}]}]]],
 ", \n\nwhere ",
 StyleBox["U",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["V",
  FontFamily->"Courier New"],
 " are real functions of the real variables ",
 StyleBox["r",
  FontFamily->"Courier New"],
 " and ",
 Cell[BoxData["\[Theta]"]],
 ".\n\n",
 StyleBox["Remark.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  For a given function ",
 StyleBox["f",
  FontFamily->"Courier New"],
 ", the functions u and v defined above are different from those used \
previously in  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", 
      RowBox[{"x", "+", 
       RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "=", 
    RowBox[{
     RowBox[{"u", 
      RowBox[{"(", 
       RowBox[{"x", ",", "y"}], ")"}]}], "+", 
     RowBox[{"\[ImaginaryI]", " ", "v", 
      RowBox[{"(", 
       RowBox[{"x", ",", "y"}], ")"}]}]}]}]}]]],
 "  which used Cartesian coordinates instead of polar coordinates."
}], "Text"],

Cell[TextData[{
 StyleBox["Example 2.4.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Express  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   SuperscriptBox["z", "2"]}]],
  AspectRatioFixed->True],
 "  in both Cartesian and polar form. \n\nSolution.  For the Cartesian form, \
a simple calculation gives \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], " ", "=", "  ", 
    RowBox[{
     RowBox[{"f", 
      RowBox[{"(", 
       RowBox[{"x", "+", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], " ", "=", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"x", "+", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"           ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      SuperscriptBox["x", "2"], "-", 
      SuperscriptBox["y", "2"], " ", "+", " ", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "x", " ", "y"}]}]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"           ", 
   RowBox[{"=", " ", 
    RowBox[{
     RowBox[{"u", 
      RowBox[{"(", 
       RowBox[{"x", ",", "y"}], ")"}]}], " ", "+", " ", 
     RowBox[{"\[ImaginaryI]", " ", "v", 
      RowBox[{"(", 
       RowBox[{"x", ",", "y"}], ")"}]}]}]}]}]}]],
 " \n\nso that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"u", 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["x", "2"], "-", 
     RowBox[{
      SuperscriptBox["y", "2"], "  ", 
      StyleBox["and",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "  ", "v", 
      RowBox[{"(", 
       RowBox[{"x", ",", "y"}], ")"}]}]}], "=", 
    RowBox[{"2", "x", " ", "y"}]}]}]]],
 ". \n\nFor the polar form, we get v \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{"f", 
      RowBox[{"(", 
       RowBox[{"r", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]]}], ")"}]}], " ", "=", 
     " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"r", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]]}], ")"}], "2"], " ", 
      "=", 
      RowBox[{
       SuperscriptBox["r", "2"], 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "2", "\[Theta]"}]]}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"           ", 
   RowBox[{
    RowBox[{"=", " ", 
     RowBox[{
      SuperscriptBox["r", "2"], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"cos", " ", "2", "\[Theta]"}], "+", 
        RowBox[{"\[ImaginaryI]", " ", "sin", " ", "2", "\[Theta]"}]}], 
       ")"}]}]}], "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"           ", 
   RowBox[{
    RowBox[{"=", " ", 
     RowBox[{
      RowBox[{
       SuperscriptBox["r", "2"], "cos", " ", "2", "\[Theta]"}], " ", "+", " ",
       
      RowBox[{"\[ImaginaryI]", " ", 
       SuperscriptBox["r", "2"], "sin", " ", "2", "\[Theta]"}]}]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"           ", 
   RowBox[{"=", " ", 
    RowBox[{
     RowBox[{"U", 
      RowBox[{"(", 
       RowBox[{"r", ",", "\[Theta]"}], ")"}]}], " ", "+", " ", 
     RowBox[{"\[ImaginaryI]", " ", "V", 
      RowBox[{"(", 
       RowBox[{"r", ",", "\[Theta]"}], ")"}]}]}]}]}]}]],
 "\n\nso that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"U", 
    RowBox[{"(", 
     RowBox[{"r", ",", "\[Theta]"}], ")"}]}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["r", "2"], "cos", " ", "2", "\[Theta]", "  ", "and", "  ",
      "V", 
     RowBox[{"(", 
      RowBox[{"r", ",", "\[Theta]"}], ")"}]}], "=", 
    RowBox[{
     SuperscriptBox["r", "2"], "sin", " ", "2", "\[Theta]"}]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 2.4.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell["Enter the function.", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", "z", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "F", ",", "r", ",", "\[Theta]"}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", 
     SuperscriptBox["z", "2"]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", 
      RowBox[{"r_", ",", "\[Theta]_"}], "]"}], " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{
       RowBox[{"f", "[", "z", "]"}], " ", ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["z", "2"], "\[Rule]", 
          RowBox[{
           RowBox[{
            SuperscriptBox["r", "2"], " ", 
            RowBox[{"Cos", "[", 
             RowBox[{"2", "\[Theta]"}], "]"}]}], "+", 
           RowBox[{"\[ImaginaryI]", " ", 
            SuperscriptBox["r", "2"], " ", 
            RowBox[{"Sin", "[", 
             RowBox[{"2", "\[Theta]"}], "]"}]}]}]}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          SuperscriptBox["z", "5"], "\[Rule]", 
          RowBox[{
           RowBox[{
            SuperscriptBox["r", "5"], " ", 
            RowBox[{"Cos", "[", 
             RowBox[{"5", "\[Theta]"}], "]"}]}], "+", 
           RowBox[{"\[ImaginaryI]", " ", 
            SuperscriptBox["r", "5"], " ", 
            RowBox[{"Sin", "[", 
             RowBox[{"5", "\[Theta]"}], "]"}]}]}]}]}], "}"}]}], "]"}]}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<      f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[1+\[ImaginaryI] \!\(\*SqrtBox[\(3\)]\)] = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"1", "+", 
        RowBox[{"\[ImaginaryI]", " ", 
         SqrtBox["3"]}]}], "]"}]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<      f[z] = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"Re", "[", 
        RowBox[{"f", "[", 
         RowBox[{"x", "+", 
          RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], "]"}], ",", 
      "\"\< + \[ImaginaryI](\>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"Im", "[", 
        RowBox[{"f", "[", 
         RowBox[{"x", "+", 
          RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], "]"}], ",", 
      "\"\<)\>\""}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[1+\[ImaginaryI] \!\(\*SqrtBox[\(3\)]\)] = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"f", "[", 
        RowBox[{"1", "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          SqrtBox["3"]}]}], "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<  f[r \!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\[ImaginaryI]\
\[Theta]\)]\)] = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"r", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]]}], "]"}]}], "]"}], ";"}],
    " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< f[2 \!\(\*SuperscriptBox[\(\[ExponentialE]\), \
\(\[ImaginaryI]\[Pi]/3\)]\)] = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"2", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"\[Pi]", "/", "3"}]}]]}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< f[2 \!\(\*SuperscriptBox[\(\[ExponentialE]\), \
\(\[ImaginaryI]\[Pi]/3\)]\)] = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"f", "[", 
        RowBox[{"2", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"\[ImaginaryI]", " ", 
           RowBox[{"\[Pi]", "/", "3"}]}]]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  F[r,\[Theta]] = \>\"", ",", 
      RowBox[{"F", "[", 
       RowBox[{"r", ",", "\[Theta]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< F[2,\!\(\*FractionBox[\(\[Pi]\), \(3\)]\)] = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"F", "[", 
        RowBox[{"2", ",", 
         FractionBox["\[Pi]", "3"]}], "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.3989770565*^9},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Remark.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  Once we have defined ",
 StyleBox["u",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["v",
  FontFamily->"Courier New"],
 " for a function ",
 StyleBox["f",
  FontFamily->"Courier New"],
 " in Cartesian form, we must use different symbols if we want to express ",
 StyleBox["f",
  FontFamily->"Courier New"],
 " in polar form.  As is clear here, the functions ",
 StyleBox["u",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["U",
  FontFamily->"Courier New"],
 " are quite different, as are ",
 StyleBox["v",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["V",
  FontFamily->"Courier New"],
 ".  Of course, if we are working only in one context, we can use any symbols \
we choose.\n\nFor a given function f, the functions u and v defined here are \
different from those defined by equation (2-1), because equation (2-1) \
involves Cartesian coordinates and equation (2-2) involves polar \
coordinates."
}], "Text",
 CellChangeTimes->{3.3989766605625*^9}],

Cell[TextData[{
 StyleBox["Example 2.5.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Express  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    SuperscriptBox["z", "5"], "+", 
    RowBox[{"4", " ", 
     SuperscriptBox["z", "2"]}], "-", "6"}]}]],
  AspectRatioFixed->True],
 "  in polar form. \n\nSolution. We obtain\n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{"f", 
      RowBox[{"(", 
       RowBox[{"r", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]]}], ")"}]}], " ", "=", 
     " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"r", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]]}], ")"}], "5"], "+", 
      RowBox[{"4", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"r", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]]}], ")"}], "2"]}], "-", 
      "6"}]}]}], " ", "\[IndentingNewLine]"}], "\n", 
  RowBox[{"           ", 
   RowBox[{
    RowBox[{"=", " ", 
     RowBox[{
      RowBox[{
       SuperscriptBox["r", "5"], 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "5", "\[Theta]"}]]}], " ", "+", " ", 
      RowBox[{"4", 
       SuperscriptBox["r", "2"], 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "2", "\[Theta]"}]]}], " ", "-", " ", 
      "6"}]}], "\[IndentingNewLine]"}]}], "\n", 
  RowBox[{"           ", 
   RowBox[{
    RowBox[{"=", " ", 
     RowBox[{
      RowBox[{
       SuperscriptBox["r", "5"], " ", "cos", " ", "5", " ", "\[Theta]"}], "+",
       
      RowBox[{"4", " ", 
       SuperscriptBox["r", "2"], " ", "cos", " ", "2", " ", "\[Theta]"}], "-",
       "6", "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["r", "5"], "sin", " ", "5", " ", "\[Theta]"}], "+", 
         RowBox[{"4", " ", 
          SuperscriptBox["r", "2"], " ", "sin", " ", "2", " ", "\[Theta]"}]}],
         ")"}]}]}]}], "\n"}]}], "\[IndentingNewLine]", 
  RowBox[{"           ", 
   RowBox[{"=", " ", 
    RowBox[{
     RowBox[{"U", 
      RowBox[{"(", 
       RowBox[{"r", ",", "\[Theta]"}], ")"}]}], " ", "+", " ", 
     RowBox[{"\[ImaginaryI]", " ", "V", 
      RowBox[{"(", 
       RowBox[{"r", ",", "\[Theta]"}], ")"}]}]}]}]}]}]],
 "  \n\nso that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"U", 
    RowBox[{"(", 
     RowBox[{"r", ",", "\[Theta]"}], ")"}]}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["r", "5"], " ", "cos", " ", "5", " ", "\[Theta]"}], "+", 
     
     RowBox[{"4", " ", 
      SuperscriptBox["r", "2"], " ", "cos", " ", "2", " ", "\[Theta]"}], "-", 
     
     RowBox[{"6", "  ", "and", "  ", "V", 
      RowBox[{"(", 
       RowBox[{"r", ",", "\[Theta]"}], ")"}]}]}], "=", 
    RowBox[{
     RowBox[{
      SuperscriptBox["r", "5"], "sin", " ", "5", " ", "\[Theta]"}], "+", 
     RowBox[{"4", " ", 
      SuperscriptBox["r", "2"], " ", "sin", " ", "2", " ", 
      "\[Theta]"}]}]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 2.5.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell["Enter the function.", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", "z", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "F", ",", "r", ",", "\[Theta]"}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", 
     RowBox[{
      SuperscriptBox["z", "5"], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["z", "2"]}], "-", "6"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", 
      RowBox[{"r_", ",", "\[Theta]_"}], "]"}], " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{
       RowBox[{"f", "[", "z", "]"}], " ", ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["z", "2"], "\[Rule]", 
          RowBox[{
           RowBox[{
            SuperscriptBox["r", "2"], " ", 
            RowBox[{"Cos", "[", 
             RowBox[{"2", "\[Theta]"}], "]"}]}], "+", 
           RowBox[{"\[ImaginaryI]", " ", 
            SuperscriptBox["r", "2"], " ", 
            RowBox[{"Sin", "[", 
             RowBox[{"2", "\[Theta]"}], "]"}]}]}]}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          SuperscriptBox["z", "5"], "\[Rule]", 
          RowBox[{
           RowBox[{
            SuperscriptBox["r", "5"], " ", 
            RowBox[{"Cos", "[", 
             RowBox[{"5", "\[Theta]"}], "]"}]}], "+", 
           RowBox[{"\[ImaginaryI]", " ", 
            SuperscriptBox["r", "5"], " ", 
            RowBox[{"Sin", "[", 
             RowBox[{"5", "\[Theta]"}], "]"}]}]}]}]}], "}"}]}], "]"}]}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<      f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[1+\[ImaginaryI] \!\(\*SqrtBox[\(3\)]\)] = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"1", "+", 
        RowBox[{"\[ImaginaryI]", " ", 
         SqrtBox["3"]}]}], "]"}]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[1+\[ImaginaryI] \!\(\*SqrtBox[\(3\)]\)] = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"f", "[", 
        RowBox[{"1", "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          SqrtBox["3"]}]}], "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<  f[r \!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\[ImaginaryI]\
\[Theta]\)]\)] = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"r", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]]}], "]"}]}], "]"}], ";"}],
    " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< f[2 \!\(\*SuperscriptBox[\(\[ExponentialE]\), \
\(\[ImaginaryI]\[Pi]/3\)]\)] = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"2", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"\[Pi]", "/", "3"}]}]]}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< f[2 \!\(\*SuperscriptBox[\(\[ExponentialE]\), \
\(\[ImaginaryI]\[Pi]/3\)]\)] = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"f", "[", 
        RowBox[{"2", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"\[ImaginaryI]", " ", 
           RowBox[{"\[Pi]", "/", "3"}]}]]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  F[r,\[Theta]] = \>\"", ",", 
      RowBox[{"F", "[", 
       RowBox[{"r", ",", "\[Theta]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< F[2,\!\(\*FractionBox[\(\[Pi]\), \(3\)]\)] = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"F", "[", 
        RowBox[{"2", ",", 
         FractionBox["\[Pi]", "3"]}], "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.398977066328125*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Aside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  We can let ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " plot the image of a region under the mapping w = f[z]."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "Iden", ",", "z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"Iden", "[", "z_", "]"}], " ", "=", " ", "z"}], ";"}], " ", "\n",
    
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{
      SuperscriptBox["z", "5"], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["z", "2"]}], "-", "6"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"CartesianMap", "[", 
    RowBox[{"Iden", ",", " ", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1", ",", "0.1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1", ",", "0.1"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.1"}], ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.1"}], ",", "1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "1", ",", 
          FractionBox["1", "2"]}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "1", ",", 
          FractionBox["1", "2"]}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", "\"\<A unit square in the z-plane.\>\"", "]"}], 
    ";"}], " ", "\n", 
   RowBox[{"CartesianMap", "[", 
    RowBox[{"f", ",", " ", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1", ",", "0.1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1", ",", "0.1"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "10"}], ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "6"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["6", "10"]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "10"}], ",", "0", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "6", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The image region in the w = u + \[ImaginaryI]v plane\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<under the mapping  w = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.398977073484375*^9, 3.3989770781875*^9}, {
  3.399119713171875*^9, 3.399119715890625*^9}, {3.3997207893125*^9, 
  3.3997207895*^9}, {3.400239641640625*^9, 3.40023964503125*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"PolarMap", "[", 
    RowBox[{"Iden", " ", ",", " ", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1", ",", 
       FractionBox["1", "20"]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       FractionBox["\[Pi]", "2"], ",", 
       FractionBox["\[Pi]", "24"]}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "1", ",", 
          FractionBox["1", "2"]}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "1", ",", 
          FractionBox["1", "2"]}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", "\"\<A quarter disk in the z-plane.\>\"", "]"}], 
    ";"}], " ", "\n", 
   RowBox[{"PolarMap", "[", 
    RowBox[{"f", " ", ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1", ",", 
       FractionBox["1", "20"]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       FractionBox["\[Pi]", "2"], ",", 
       FractionBox["\[Pi]", "24"]}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "10"}], ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "4"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["4", "10"]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "10"}], ",", "0", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "4", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The image region in the w = u + \[ImaginaryI]v plane\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<under the mapping  w = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.398977084109375*^9, 3.398977088265625*^9}, {
  3.39911972415625*^9, 3.399119727515625*^9}, {3.399720795828125*^9, 
  3.399720796*^9}, {3.400239709953125*^9, 3.400239712859375*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 "\tWe now look at the geometric interpretation of a complex function.  If ",
 StyleBox["D",
  FontFamily->"Courier New"],
 " is the domain of real-valued functions ",
 StyleBox["u(x,y)",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["v(x,y)",
  FontFamily->"Courier New"],
 ", the equations  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"u", "=", 
   RowBox[{"u", 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{"v", "=", 
   RowBox[{"v", 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}]}]]],
 " \n\ndescribe a transformation (or mapping) from ",
 StyleBox["D",
  FontFamily->"Courier New"],
 " in the xy plane into the ",
 StyleBox["uv",
  FontFamily->"Courier New"],
 " plane, also called the ",
 StyleBox["w",
  FontFamily->"Courier New"],
 " plane.  Therefore, we can also consider the function  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "=", 
    RowBox[{
     RowBox[{"u", 
      RowBox[{"(", 
       RowBox[{"x", ",", "y"}], ")"}]}], "+", 
     RowBox[{"\[ImaginaryI]", " ", "v", 
      RowBox[{"(", 
       RowBox[{"x", ",", "y"}], ")"}]}]}]}]}]]],
 "  \n\nto be a transformation (or mapping) from the set ",
 StyleBox["D",
  FontFamily->"Courier New"],
 " in the z plane onto the range ",
 StyleBox["R",
  FontFamily->"Courier New"],
 " in the ",
 StyleBox["w",
  FontFamily->"Courier New"],
 " plane.  This idea was illustrated in Figure 2.1.  In the following \
paragraphs we present some additional key ideas.  They are staples for any \
kind of function, and you should memorize all the terms in bold.  "
}], "Text",
 Evaluatable->False,
 CellChangeTimes->{{3.39897667284375*^9, 3.398976680421875*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "\tIf ",
 StyleBox["A",
  FontFamily->"Courier New"],
 " is a subset of the domain ",
 StyleBox["D",
  FontFamily->"Courier New"],
 " of ",
 StyleBox["f",
  FontFamily->"Courier New"],
 ", the set  ",
 Cell[BoxData[
  RowBox[{"B", "=", 
   RowBox[{"{", 
    RowBox[{"w", "=", 
     RowBox[{
      RowBox[{"f", 
       RowBox[{"(", "z", ")"}]}], ":", 
      RowBox[{"z", "\[Element]", "A"}]}]}], "}"}]}]]],
 "  is called the image of the set ",
 StyleBox["A",
  FontFamily->"Courier New"],
 ", and ",
 StyleBox["f",
  FontFamily->"Courier New"],
 " is said to map ",
 StyleBox["A",
  FontFamily->"Courier New"],
 " onto ",
 StyleBox["B",
  FontFamily->"Courier New"],
 ".  The image of a single point is a single point, and the image of the \
entire domain, ",
 StyleBox["D",
  FontFamily->"Courier New"],
 ", is the range, ",
 StyleBox["R",
  FontFamily->"Courier New"],
 ".  The mapping  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}]}]]],
 "  is said to be from ",
 StyleBox["A",
  FontFamily->"Courier New"],
 " into ",
 StyleBox["S",
  FontFamily->"Courier New"],
 " if the image of ",
 StyleBox["A",
  FontFamily->"Courier New"],
 " is contained in ",
 StyleBox["S",
  FontFamily->"Courier New"],
 ".  Mathematicians use the notation  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", ":", "A"}], "\[Rule]", "S"}]]],
 " to indicate that a function maps ",
 StyleBox["A",
  FontFamily->"Courier New"],
 " into ",
 StyleBox["S",
  FontFamily->"Courier New"],
 ".  Figure 2.2 illustrates a function f whose domain is ",
 StyleBox["D",
  FontFamily->"Courier New"],
 " and whose range is ",
 StyleBox["R",
  FontFamily->"Courier New"],
 ".  The shaded areas depict that the function maps ",
 StyleBox["A",
  FontFamily->"Courier New"],
 " onto ",
 StyleBox["B",
  FontFamily->"Courier New"],
 ".  The function also maps ",
 StyleBox["A",
  FontFamily->"Courier New"],
 " into ",
 StyleBox["R",
  FontFamily->"Courier New"],
 ", and, of course, it maps ",
 StyleBox["D",
  FontFamily->"Courier New"],
 " onto ",
 StyleBox["R",
  FontFamily->"Courier New"],
 "."
}], "Text"],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{569, 293},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 StyleBox["\t\t\tFigure 2.2",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}]}]]],
 " maps ",
 StyleBox["A",
  FontFamily->"Courier New"],
 " onto ",
 StyleBox["B",
  FontFamily->"Courier New"],
 ";  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}]}]]],
 " maps ",
 StyleBox["A",
  FontFamily->"Courier New"],
 " into ",
 StyleBox["R",
  FontFamily->"Courier New"],
 ". "
}], "Text"],

Cell[TextData[{
 "    The inverse image of a point ",
 StyleBox["w",
  FontFamily->"Courier New"],
 " is the set of all points ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " in",
 " ",
 StyleBox["D",
  FontFamily->"Courier New"],
 " ",
 "such that  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}]}]]],
 ".  The inverse image of a point may be one point, several points, or \
nothing at all.  If the last case occurs then the point ",
 StyleBox["w",
  FontFamily->"Courier New"],
 " is not in the range of ",
 StyleBox["f",
  FontFamily->"Courier New"],
 ".  For example, if  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "=", 
    RowBox[{"\[ImaginaryI]", " ", "z"}]}]}]]],
 ",  the inverse image of the point ",
 Cell[BoxData[
  RowBox[{"-", "1"}]]],
 " is the single point ",
 Cell[BoxData["\[ImaginaryI]"]],
 ", because  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "\[ImaginaryI]", ")"}]}], "=", 
    RowBox[{
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{"(", "\[ImaginaryI]", ")"}]}], "=", 
     RowBox[{"-", "1"}]}]}]}]]],
 ",  and ",
 Cell[BoxData["\[ImaginaryI]"]],
 " is the only point that maps to ",
 Cell[BoxData[
  RowBox[{"-", "1"}]]],
 ".  In the case of  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "=", 
    SuperscriptBox["z", "2"]}]}]]],
 ",  the inverse image of the point ",
 Cell[BoxData[
  RowBox[{"-", "1"}]]],
 " is the set ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{"\[ImaginaryI]", ",", 
    RowBox[{"-", "\[ImaginaryI]"}]}], "}"}]]],
 ".  You will learn in Chapter 5 that, if  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "=", 
    SuperscriptBox["\[ExponentialE]", "z"]}]}]]],
 ",  the inverse image of the point ",
 StyleBox["0",
  FontFamily->"Courier New"],
 " is the empty set---there is no complex number ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " such that ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[ExponentialE]", "z"], "=", "0"}]]],
 "."
}], "Text"],

Cell[TextData[{
 "    The inverse image of a set of points, S, is the collection of all \
points in the domain that map into S.  If f maps ",
 StyleBox["D",
  FontFamily->"Courier New"],
 " onto ",
 StyleBox["R",
  FontFamily->"Courier New"],
 " it is possible for the inverse image of ",
 StyleBox["R",
  FontFamily->"Courier New"],
 " to be function as well, but the original function must have a special \
property: a function ",
 StyleBox["f",
  FontFamily->"Courier New"],
 " is said to be one-to-one if it maps distinct points  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], "\[NotEqual]", 
   SubscriptBox["z", "2"]}]]],
 "  onto distinct points  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", 
     SubscriptBox["z", "1"], ")"}]}], "\[NotEqual]", 
   RowBox[{"f", 
    RowBox[{"(", 
     SubscriptBox["z", "2"], ")"}]}]}]]],
 ".  Many times an easy way to prove that a function ",
 StyleBox["f",
  FontFamily->"Courier New"],
 " is one-to-one is to suppose  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", 
     SubscriptBox["z", "1"], ")"}]}], "=", 
   RowBox[{"f", 
    RowBox[{"(", 
     SubscriptBox["z", "2"], ")"}]}]}]]],
 ",  and from this assumption deduce that ",
 Cell[BoxData[
  SubscriptBox["z", "1"]]],
 " must equal ",
 Cell[BoxData[
  SubscriptBox["z", "2"]]],
 ".  Thus,  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{"\[ImaginaryI]", " ", "z"}]}]]],
 "  is one-to-one because if ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", 
     SubscriptBox["z", "1"], ")"}]}], "=", 
   RowBox[{"f", 
    RowBox[{"(", 
     SubscriptBox["z", "2"], ")"}]}]}]]],
 ",  then ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[ImaginaryI]", " ", 
    SubscriptBox["z", "1"]}], "=", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubscriptBox["z", "2"]}]}]]],
 ".  Dividing both sides of the last equation by ",
 Cell[BoxData["\[ImaginaryI]"]],
 " gives  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], "=", 
   SubscriptBox["z", "2"]}]]],
 ".  Figure 2.3 illustrates the idea of a one-to-one function: distinct \
points get mapped to distinct points."
}], "Text"],

Cell[GraphicsData["CompressedBitmap", "\<\
eJztmdtPE0EUxqc36AUsclMuYsELRo2ApkhEDRILhFhBRFCEYG0VqkUU0WgU
NCYmJiYaX/TVGP9O152Z3W/bcmbaIT5o4gaHcc6c3/nO2dnpTklnNlfvrWU2
89lMYnwj83g1n32aGFvfsIcCPsZ8XxljhQTjfcvuOo1l/1jfeMNH/r3+W/Er
wGQywsJ+EmOF/9PNpx/ibYAXfNvMsYe3Ie64ZebYzdta7vj6b3f0cmRBd126
/17uts4h9J6bIU7x1s8dN80c+xHxiZnjGURcN3NMImJBUwtmjakRQ0DkNXeG
WSk1YhjyVzSrglmX1YgLUJEjrF28jVZAjEDFXcLawtumCohRqFhWIRor1CIF
FUuEtZW3MT7gr+bejEPPggoW4QNpNWISiHlVSgJxVY1II6UbhLURidgGwXAe
3CBvp9XYKSibIaxxYEPozahhM9A4TVhjvBV6wrBapb40dhYa04Q1DGUZNWIe
iEnC6iWXUyMWkNwEYfVW0ooasQgVqTIrH/Pz9oHaexkCRhFsTT09g2Dndy4O
OU3jnYP3ILyDxDzNtrgCvQNA1Joh8lBxAoioGaIAFUeBqDdDuMuaybsseq1Q
lgC2gfA9C4+i2vOrXx3vumiDJWP21Y5MOhCyiXAfJJenfQ1Iksg0xwdqIe4A
0mmRUu3uBKawUAnMTWOgwiMryAmQvc2kTanaOJCiVj2oVYT3xK7T+eeiUivC
e+cJINEE4ZskfDWhtpFJ2YbZbbaIX0GUH0INES+ACAPRZYZ4BsQe5EXdFw1i
o3TxCxXUgtIg1ktXolCxzwxRAKILKprNEHkgDgOx1wxxH4jjSCRuhsgC0QcV
dWaIO0AkocJwl14C4hxUGH5WLAAxAoThJ5bzCFvO7ix2jTGk5DeDOS/ttvUk
lF2BskdqR+dV3bYeg+O1onnusazSGTDCJ3mnj1linpCSr0aKSL6O95pBpN5l
AyhXxIsA6+1qyhVHKO+9jHrz9o6WNehpAng3t1NqdHdUkd8c4eHtcn4pDkcA
MsAlqI0iA+ptMyZvjm2+qYZdBExsUTEO64XuVsKjDth5NXYY2F5o7EDlqbcJ
gY1y7JwaOwTsILBxrJ0aVD5M+Ipy1KPKot5T6lBJhEohVEBqdJepyIXaPUSo
Jh5Ac9A6XfrEtCAD6mzUwHAqIWF9gN2SsRUw8ekTrgDz9pFFLWy/rLweJvYW
scMty9ju86asXhseAk31jkBjFnc9pr3/7dXc9R5g3xBWzU54EI7vzBw74fje
zLEBjjXofTBDxJ1KF39B8dEMscdZUMz6tAtH8UXRZ7XjF0z6JQe23dUk0xfa
rWpqJP7vU8+s9AWveH0un8Qv52xbvlyqmr7jOPFDdOhjQqGoAoopVbhvuRXB
l6/e9V1jeygHBM/5CwLz/QbJE1Cu\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{406, 108},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 StyleBox["\t\t\tFigure 2.3",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  A function  ",
 StyleBox["w = f(z)",
  FontFamily->"Courier New"],
 "  that is one-to-one. "
}], "Text"],

Cell[TextData[{
 "    The function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   SuperscriptBox["z", "2"]}]]],
 "  is not one-to-one because ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"-", "\[ImaginaryI]"}], "\[NotEqual]", "\[ImaginaryI]"}]]],
 ",  but  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "\[ImaginaryI]", ")"}]}], "=", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", 
      RowBox[{"-", "\[ImaginaryI]"}], ")"}]}], "=", 
    RowBox[{"-", "1"}]}]}]]],
 ".  Figure 2.4 depicts this situation: at least two different points get \
mapped to the same point. "
}], "Text"],

Cell[GraphicsData["CompressedBitmap", "\<\
eJzNmG9rE0EQxjdJk7SC/6j4TohGQRCsCY2tBkuKtZFKpNpSaanaI9E2NaEh
qcViNFIQqh9A34pEv5ztZzhvdjdPo94lffLKI9kbZvY3u3d7uzs7BWd740XV
2S4XnUS+7tQ2ysVGYnar7qkiIaVCX5RSlYQS2fVEW7jez/0qhWj+L/mn3CLS
y0Oj+CG3qCgOjKItt7gofhnFB30TRmlJ/hdRqeljrfQBh0XxlgMvoZ9hPMIb
zkUSYAzSa87FGMA6B6YBbnFgBmCFAycBljkwC/AlB04BLHLgNMA1DpwB+JQD
8wBXOHAO4BMOLABc5MB5gI84cAHgQw5cAviAA5cB3ufAVSnDopjlwGdo8S4H
OgBzHFgCeIcD1wHe5sBNgBMcWAU4zoE1gCkObAC8zoE7AK9x4C7AqxzYBHiF
A1sAR2B1YT3POduDs6MtiXTxEaDeGGMineNc7Es5IopRDvwM8OwA4AlRnOHA
T1KeFMWpAcDTeqyGTC1Xdf7DnKvHUspqpcKQbomkA6KoeIz7YBOo7Bm0c3vd
CG5Kr+Feh7t13pWzrbkq5gPd9NHpds1sNo9WEkUcXbog0mWjUxI8dKwq+oef
Tr9TwX1ehNOs+SBd6zS4r3QbAe8lbQbZkwNHYcAG/cY8Zb5F145nJOhTygSx
PeeGZyXnhp2NnpWcjfsAyflv1x7XPpkeanLt2YOLGCRyBWwB7KzIbpeVdNaE
M3Jf2AVI7kQ7AMm9rwGQ3G1rAMn9vQqQjCg2AZIxzDpAMmoqASTjNAdgjgOf
SxkWkIxFV9HiPQ5cBkjG20sAyQh/ASB5ppgHSJ5iCgDJc9McQPKklgdIng1n
AJKn0WmAaxw4BZA8cWcBkmf8SYBkViEDkMxjpAGSmZMxgGSuJgnwaEsi80Q2
W9XZGLULMltlM2WelcyU2dycZ+2Rm2ujks3yvZebDqiS6PvBcd7RYXCldp+O
60jo70pyVY3U8jH1rf5PUPhdC/4RX6Xr4QOqHAN/Z16GXEOw2etbD9sro9D+
bH5WhX4D67Q9sw==\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{406, 108},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 StyleBox["\t\t\tFigure 2.4",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  A function that is not one-to-one."
}], "Text"],

Cell[TextData[{
 "\tIn the exercises we ask you to demonstrate that one-to-one functions give \
rise to inverses that are functions.  Loosely speaking, if  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}]}]]],
 "  maps the set ",
 StyleBox["A",
  FontFamily->"Courier New"],
 " one-to-one and onto the set ",
 StyleBox["B",
  FontFamily->"Courier New"],
 ", then for each ",
 StyleBox["w",
  FontFamily->"Courier New"],
 " in ",
 StyleBox["B",
  FontFamily->"Courier New"],
 " there exists exactly one point ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " in ",
 StyleBox["A",
  FontFamily->"Courier New"],
 "  A such that  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}]}]]],
 ".  For any such value of ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " we can take the equation  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}]}]]],
 "  and \"solve\" for ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " as a function of ",
 StyleBox["w",
  FontFamily->"Courier New"],
 ".  Doing so produces an inverse function  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{"g", 
    RowBox[{"(", "w", ")"}]}]}]]],
 "  where the following equations hold:  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"g", 
      RowBox[{"(", 
       RowBox[{"f", 
        RowBox[{"(", "z", ")"}]}], ")"}]}], "=", 
     RowBox[{
      RowBox[{"z", "   ", 
       StyleBox["for",
        FontFamily->"Times New Roman"], 
       StyleBox[" ",
        FontFamily->"Times New Roman"], 
       StyleBox["all",
        FontFamily->"Times New Roman"], "  ", "z"}], "\[Element]", "A"}]}], 
    ",", "  ", 
    StyleBox["and",
     FontFamily->"Times New Roman"]}], "\n"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", 
     RowBox[{"g", 
      RowBox[{"(", "w", ")"}]}], ")"}]}], "=", 
   RowBox[{
    RowBox[{"w", "   ", 
     StyleBox["for",
      FontFamily->"Times New Roman"], 
     StyleBox[" ",
      FontFamily->"Times New Roman"], 
     StyleBox["all",
      FontFamily->"Times New Roman"], "  ", "z"}], "\[Element]", "B"}]}]}]],
 "   \n\n\tConversely, if ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{"g", 
    RowBox[{"(", "w", ")"}]}]}]]],
 " are functions that map ",
 StyleBox["A",
  FontFamily->"Courier New"],
 " into ",
 StyleBox["B",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["B",
  FontFamily->"Courier New"],
 " into ",
 StyleBox["A",
  FontFamily->"Courier New"],
 ", respectively, and the above hold, then f maps the set ",
 StyleBox["A",
  FontFamily->"Courier New"],
 " one-to-one and onto the set ",
 StyleBox["B",
  FontFamily->"Courier New"],
 "."
}], "Text"],

Cell[TextData[{
 "\tFurther, if f is a one-to-one mapping from ",
 StyleBox["D",
  FontFamily->"Courier New"],
 " onto ",
 StyleBox["T",
  FontFamily->"Courier New"],
 " and if ",
 StyleBox["A",
  FontFamily->"Courier New"],
 " is a subset of ",
 StyleBox["D",
  FontFamily->"Courier New"],
 ", then f is a one-to-one mapping from ",
 StyleBox["A",
  FontFamily->"Courier New"],
 " onto its image ",
 StyleBox["B",
  FontFamily->"Courier New"],
 ".  We can also show that, if  ",
 Cell[BoxData[
  RowBox[{"\[Zeta]", "=", 
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}]}]]],
 "  is a one-to-one mapping from ",
 StyleBox["A",
  FontFamily->"Courier New"],
 " onto ",
 StyleBox["B",
  FontFamily->"Courier New"],
 " and  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{"g", 
    RowBox[{"(", "\[Zeta]", ")"}]}]}]]],
 "  is a one-to-one mapping from ",
 StyleBox["B",
  FontFamily->"Courier New"],
 " onto ",
 StyleBox["S",
  FontFamily->"Courier New"],
 ", then the composite mapping  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{"g", 
    RowBox[{"(", 
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], ")"}]}]}]]],
 "  is a one-to-one mapping from ",
 StyleBox["A",
  FontFamily->"Courier New"],
 " onto ",
 StyleBox["S",
  FontFamily->"Courier New"],
 "."
}], "Text"],

Cell[TextData[{
 "\tWe usually indicate the inverse of ",
 Cell[BoxData["f"]],
 " by the symbol ",
 Cell[BoxData[
  SuperscriptBox["f", 
   RowBox[{"-", "1"}]]]],
 ".  If the domains of ",
 Cell[BoxData["f"]],
 " and ",
 Cell[BoxData[
  SuperscriptBox["f", 
   RowBox[{"-", "1"}]]]],
 " are ",
 StyleBox["A",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["B",
  FontFamily->"Courier New"],
 " respectively, then we write  \n\t\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["f", 
     RowBox[{"-", "1"}]], 
    RowBox[{"(", 
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], ")"}]}], " ", "=", " ", "z"}]]],
 "   for all  ",
 Cell[BoxData[
  RowBox[{"z", " ", "\[Element]", " ", "A"}]]],
 ",  and  \n\t\t\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["f", 
       RowBox[{"-", "1"}]], 
      RowBox[{"(", "w", ")"}]}], ")"}]}], " ", "=", " ", "w"}]]],
 "   for all  ",
 Cell[BoxData[
  RowBox[{"w", " ", "\[Element]", " ", "B"}]]],
 ".  \n\t\t\nAlso, for  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "0"], " ", "\[Element]", " ", "A"}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["w", "0"], " ", "\[Element]", " ", "B"}]]],
 ".     \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["w", "0"], "=", 
   RowBox[{"f", 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}]}]]],
 "   iff   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["f", 
     RowBox[{"-", "1"}]], 
    RowBox[{"(", 
     SubscriptBox["w", "0"], ")"}]}], "=", 
   SubscriptBox["z", "0"]}]]],
 ",    and \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "0"], "=", 
   RowBox[{
    SuperscriptBox["f", 
     RowBox[{"-", "1"}]], 
    RowBox[{"(", 
     SubscriptBox["w", "0"], ")"}]}]}]]],
 "   iff   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}], "=", 
   SubscriptBox["w", "0"]}]]],
 ".   "
}], "Text"],

Cell[TextData[{
 StyleBox["Example 2.6.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  If  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "=", 
    RowBox[{"\[ImaginaryI]", " ", "z"}]}]}]]],
 "  for any complex number z, find  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["f", 
    RowBox[{"-", "1"}]], 
   RowBox[{"(", "w", ")"}]}]]],
 ". \n\nSolution.  We can easily show ",
 StyleBox["f",
  FontFamily->"Courier New"],
 " is one-to-one and onto the entire complex plane.  We solve for ",
 StyleBox["z",
  FontFamily->"Courier New"],
 ", given  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "=", "\[ImaginaryI]", " "}]}]]],
 ",  to get  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{
    FractionBox["w", "\[ImaginaryI]"], "=", 
    RowBox[{
     RowBox[{"-", "\[ImaginaryI]"}], " ", "w"}]}]}]]],
 ".  This result implies that ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["f", 
     RowBox[{"-", "1"}]], 
    RowBox[{"(", "w", ")"}]}], "=", 
   RowBox[{
    RowBox[{"-", "\[ImaginaryI]"}], " ", "w"}]}]]],
 "  for all complex numbers ",
 StyleBox["w",
  FontFamily->"Courier New"],
 ".  "
}], "Text",
 Evaluatable->False,
 CellChangeTimes->{3.3989767115625*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Remark.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  Once we have specified  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["f", 
     RowBox[{"-", "1"}]], 
    RowBox[{"(", "w", ")"}]}], "=", 
   RowBox[{
    RowBox[{"-", "\[ImaginaryI]"}], " ", "w"}]}]]],
 "  for all complex numbers ",
 StyleBox["w",
  FontFamily->"Courier New"],
 ", we note that there is nothing magical about the symbol ",
 StyleBox["w",
  FontFamily->"Courier New"],
 ".  We could just as easily write  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["f", 
     RowBox[{"-", "1"}]], 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    RowBox[{"-", "\[ImaginaryI]"}], " ", "z"}]}]]],
 "  for all complex numbers ",
 StyleBox["z",
  FontFamily->"Courier New"],
 ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 2.6.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", 
     RowBox[{"\[ImaginaryI]", " ", "z"}]}], ";"}], " ", "\[IndentingNewLine]",
    
   RowBox[{
    RowBox[{"solset", "=", 
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"w", "==", 
        RowBox[{"f", "[", "z", "]"}]}], ",", "z"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"g", "[", "w_", "]"}], "=", 
     SubscriptBox["solset", 
      RowBox[{"\[LeftDoubleBracket]", 
       RowBox[{"1", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]]}], ";"}],
    " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "solset", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<z = \!\(\*SuperscriptBox[\(f\), \(-1\)]\)[w] = \>\"", ",", 
      RowBox[{"g", "[", "w", "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SuperscriptBox[\(f\), \(-1\)]\)[f[z]] = -\[ImaginaryI](\>\"", 
      ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\<)\>\""}], " ", "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SuperscriptBox[\(f\), \(-1\)]\)[f[z]] = \>\"", ",", 
      RowBox[{"g", "[", 
       RowBox[{"f", "[", "z", "]"}], "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<f[\!\(\*SuperscriptBox[\(f\), \(-1\)]\)[w]] = \[ImaginaryI](\>\"", 
      ",", 
      RowBox[{"g", "[", "w", "]"}], ",", "\"\<)\>\""}], " ", "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[\!\(\*SuperscriptBox[\(f\), \(-1\)]\)[w]] = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"g", "[", "w", "]"}], "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.3989771*^9}]
}, Closed]],

Cell[TextData[{
 "\tWe now show how to find the image B of a specified set A under a given \
mapping  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"u", "+", 
    RowBox[{"\[ImaginaryI]", " ", "v"}]}], "=", 
   RowBox[{"w", "=", 
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}]}]}]],
  CellChangeTimes->{{3.3989767348125*^9, 3.3989767476875*^9}}],
 ".  The set A is usually described with an equation or inequality involving \
",
 StyleBox["x",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["y",
  FontFamily->"Courier New"],
 ".  Using inverse functions, we can construct a chain of equivalent \
statements leading to a description of the set B in terms of an equation or \
an inequality involving ",
 StyleBox["u",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["v",
  FontFamily->"Courier New"],
 "."
}], "Text",
 CellChangeTimes->{{3.398976752484375*^9, 3.398976775953125*^9}}],

Cell[TextData[{
 StyleBox["Example 2.7.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Show that the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], "=", 
   RowBox[{"\[ImaginaryI]", " ", "z"}]}]]],
 "  maps the line  ",
 Cell[BoxData[
  RowBox[{"y", "=", 
   RowBox[{"x", "+", "1"}]}]]],
 "  in the ",
 StyleBox["xy",
  FontFamily->"Courier New"],
 " plane onto the line  ",
 Cell[BoxData[
  RowBox[{"v", "=", 
   RowBox[{
    RowBox[{"-", " ", "u"}], "-", "1"}]}]]],
 "  in the w plane.  \n\nSolution.  Method 1:  With  ",
 Cell[BoxData[
  RowBox[{"A", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"x", ",", "y"}], ")"}], ":", " ", "y"}], "=", 
     RowBox[{"x", "+", "1"}]}], "}"}]}]]],
 ",  we want to describe  ",
 Cell[BoxData[
  RowBox[{"B", "=", 
   RowBox[{"f", 
    RowBox[{"(", "A", ")"}]}]}]]],
 ".  We let  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{
    RowBox[{"x", "+", 
     RowBox[{"\[ImaginaryI]", " ", "y"}]}], " ", "\[Element]", " ", 
    "A"}]}]]],
 "  and get  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{"u", "+", 
    RowBox[{"\[ImaginaryI]", " ", "v"}]}], "=", 
   RowBox[{"w", "=", 
    RowBox[{
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], "\[Element]", " ", "B"}]}]}], "\n", 
  RowBox[{
   RowBox[{
    RowBox[{"\[DoubleLongLeftRightArrow]", " ", 
     SuperscriptBox["f", 
      RowBox[{"-", "1"}]]}], 
    RowBox[{"(", "w", ")"}]}], "=", 
   RowBox[{"z", "=", 
    RowBox[{
     RowBox[{"x", "+", 
      RowBox[{"\[ImaginaryI]", " ", "y"}]}], " ", "\[Element]", " ", 
     "A"}]}]}], "\n", 
  RowBox[{
   RowBox[{
    RowBox[{"\[DoubleLongLeftRightArrow]", "  ", "\[ImaginaryI]"}], " ", 
    "w"}], " ", "\[Element]", " ", "A"}], "\n", 
  RowBox[{
   RowBox[{
    RowBox[{"\[DoubleLongLeftRightArrow]", "  ", "v"}], "-", 
    RowBox[{"\[ImaginaryI]", " ", "u"}]}], " ", "\[Element]", " ", 
   "A"}], "\n", 
  RowBox[{
   RowBox[{"\[DoubleLongLeftRightArrow]", "  ", 
    RowBox[{"(", 
     RowBox[{"v", ",", 
      RowBox[{"-", "u"}]}], ")"}]}], "\[Element]", " ", "A"}], "\n", 
  RowBox[{
   RowBox[{"\[DoubleLongLeftRightArrow]", "  ", "u"}], " ", "=", " ", 
   RowBox[{"v", "+", "1"}]}], "\n", 
  RowBox[{
   RowBox[{"\[DoubleLongLeftRightArrow]", "  ", "v"}], " ", "=", " ", 
   RowBox[{
    RowBox[{"-", "u"}], "-", "1"}]}]}]],
 "  \n\nwhere ",
 Cell[BoxData["\[DoubleLongLeftRightArrow]"]],
 " is the notation for \"if and only if.\"  Note what this result says:  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"u", "+", 
    RowBox[{"\[ImaginaryI]", " ", "v"}]}], "=", 
   RowBox[{
    RowBox[{"w", "\[Element]", " ", 
     RowBox[{"B", " ", "\[DoubleLongLeftRightArrow]", "  ", "v"}]}], "=", 
    RowBox[{
     RowBox[{"-", "u"}], "-", "1"}]}]}]]],
 ".  The image of ",
 StyleBox["A",
  FontFamily->"Courier New"],
 " under ",
 StyleBox["f",
  FontFamily->"Courier New"],
 ", therefore, is the set  ",
 Cell[BoxData[
  RowBox[{"B", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"u", ",", "v"}], ")"}], ":", " ", "v"}], "=", 
     RowBox[{
      RowBox[{"-", "u"}], "-", "1"}]}], "}"}]}]]],
 ".  \n\nMethod 2:  We write  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"u", "+", 
    RowBox[{"\[ImaginaryI]", " ", "v"}]}], "=", 
   RowBox[{"w", "=", 
    RowBox[{
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], "=", 
     RowBox[{
      RowBox[{"\[ImaginaryI]", 
       RowBox[{"(", 
        RowBox[{"x", "+", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "=", 
      RowBox[{
       RowBox[{"-", " ", "y"}], "+", 
       RowBox[{"\[ImaginaryI]", " ", "x"}]}]}]}]}]}]]],
 "  and note that the transformation can be given by the equations  ",
 Cell[BoxData[
  RowBox[{"u", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "y"}], "  ", 
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", "v"}], "=", "x"}]}]]],
 ".  Because ",
 StyleBox["A",
  FontFamily->"Courier New"],
 " is described by  ",
 Cell[BoxData[
  RowBox[{"A", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"y", ":", " ", "y"}]}]}], "=", 
     RowBox[{"x", "+", "1"}]}], "}"}]}]]],
 ",  we can substitute  ",
 Cell[BoxData[
  RowBox[{"u", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "y"}], "  ", 
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", "v"}], "=", "x"}]}]]],
 "  into the equation  ",
 Cell[BoxData[
  RowBox[{"y", "=", 
   RowBox[{"x", "+", "1"}]}]]],
 "  to obtain  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"-", "u"}], "=", 
   RowBox[{"v", "+", "1"}]}]]],
 ",  which we can rewrite as  ",
 Cell[BoxData[
  RowBox[{"v", "=", 
   RowBox[{
    RowBox[{"-", "u"}], "-", "1"}]}]]],
 ".  If you use this method, be sure to pay careful attention to domains and \
ranges. "
}], "Text",
 Evaluatable->False,
 CellChangeTimes->{3.39897683453125*^9},
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 2.7.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "Enter the function  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{"f", "[", "z", "]"}], "=", 
    RowBox[{"\[ImaginaryI]", " ", "z"}]}]}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"x", ",", "y", ",", "z"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "eq1", ",", "eq2", ",", "eq3", ",", "f", ",", "solset", ",", "u", ",", 
      "v"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"TagSet", "[", 
     RowBox[{"x", ",", 
      RowBox[{"Im", "[", "x", "]"}], ",", "0"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"TagSet", "[", 
     RowBox[{"y", ",", 
      RowBox[{"Im", "[", "y", "]"}], ",", "0"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"TagSet", "[", 
     RowBox[{"x", ",", 
      RowBox[{"Re", "[", "x", "]"}], ",", "x"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"TagSet", "[", 
     RowBox[{"y", ",", 
      RowBox[{"Re", "[", "y", "]"}], ",", "y"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], ":=", 
     RowBox[{"\[ImaginaryI]", " ", "z"}]}], ";"}], " ", "\[IndentingNewLine]",
    
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<    f[\>\"", ",", "z", ",", "\"\<] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[\>\"", ",", 
      RowBox[{"x", " ", "+", " ", 
       RowBox[{"\[ImaginaryI]", " ", "y"}]}], ",", "\"\<] = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"x", " ", "+", " ", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[\>\"", ",", 
      RowBox[{"x", " ", "+", " ", 
       RowBox[{"\[ImaginaryI]", " ", "y"}]}], ",", "\"\<] = \>\"", ",", 
      RowBox[{"Expand", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39897710871875*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "Form the line  ",
 Cell[BoxData[
  RowBox[{"y", "=", 
   RowBox[{"x", "+", "1"}]}]]],
 "  and its image."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"eq1", "=", 
     RowBox[{"u", "\[Equal]", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"Re", "[", 
        RowBox[{"f", "[", 
         RowBox[{"x", "+", 
          RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], "]"}]}]}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"eq2", "=", 
     RowBox[{"v", "\[Equal]", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"Im", "[", 
        RowBox[{"f", "[", 
         RowBox[{"x", "+", 
          RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], "]"}]}]}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"eq3", "=", 
     RowBox[{"y", "\[Equal]", 
      RowBox[{"x", " ", "+", " ", "1"}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"sol1", "=", 
     RowBox[{"Solve", "[", 
      RowBox[{"eq1", ",", "y"}], "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"sol2", "=", 
     RowBox[{"Solve", "[", 
      RowBox[{"eq2", ",", "x"}], "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<u + \[ImaginaryI] v = \>\"", ",", 
      RowBox[{"Expand", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", "+", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<u = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"Re", "[", 
        RowBox[{"f", "[", 
         RowBox[{"x", "+", 
          RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], "]"}]}], "]"}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<v = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"Im", "[", 
        RowBox[{"f", "[", 
         RowBox[{"x", "+", 
          RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], "]"}]}], "]"}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "sol1", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "sol2", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"eq4", "=", 
     RowBox[{"Eliminate", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"eq1", ",", "eq2", ",", "eq3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "y"}], "}"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<In the z-plane.\>\"", "]"}], ";"}], " ", "\n", 
   
   RowBox[{
    RowBox[{"Print", "[", "eq3", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{"eq3", ",", 
       RowBox[{"{", 
        RowBox[{
         SubscriptBox["sol1", 
          RowBox[{"\[LeftDoubleBracket]", 
           RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]], ",", 
         SubscriptBox["sol2", 
          RowBox[{"\[LeftDoubleBracket]", 
           RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]]}], "}"}]}], 
      "]"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<In the w-plane.\>\"", "]"}], ";"}], " ", "\n", 
   
   RowBox[{
    RowBox[{"Print", "[", "eq4", "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39897711296875*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "Plot the mapping  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{"f", "[", "z", "]"}], "=", 
    RowBox[{"\[ImaginaryI]", " ", "z"}]}]}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"g1", "=", 
     RowBox[{"ContourPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eq3", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", 
         RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
       RowBox[{"ContourStyle", "\[Rule]", 
        RowBox[{"{", "Red", "}"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "6", ",", "1"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "3"}], ",", "4", ",", "1"}], "]"}]}], "}"}]}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
       RowBox[{"GridLines", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"{", 
            RowBox[{"0", ",", "Dashed"}], "}"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"{", 
            RowBox[{"0", ",", "Dashed"}], "}"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "g1", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The line in the z-plane,\>\"", "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "eq3", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g2", "=", 
     RowBox[{"ContourPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eq4", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"u", ",", 
         RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"v", ",", 
         RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
       RowBox[{"ContourStyle", "\[Rule]", 
        RowBox[{"{", "Blue", "}"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "6", ",", "1"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "3"}], ",", "4", ",", "1"}], "]"}]}], "}"}]}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
       RowBox[{"GridLines", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"{", 
            RowBox[{"0", ",", "Dashed"}], "}"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"{", 
            RowBox[{"0", ",", "Dashed"}], "}"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "g2", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The image line in the w-plane,\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "eq4", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<under the mapping w = f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.398977117734375*^9, 3.398977126328125*^9}, {
   3.3991197595*^9, 3.399119817015625*^9}, {3.399720801703125*^9, 
   3.39972080190625*^9}, {3.399720855765625*^9, 3.399720869421875*^9}, {
   3.399720943015625*^9, 3.399720948421875*^9}, 3.399721068453125*^9, {
   3.399721116328125*^9, 3.399721152375*^9}, {3.399721441203125*^9, 
   3.39972145809375*^9}, {3.399721491953125*^9, 3.399721514921875*^9}, {
   3.400239733859375*^9, 3.400239738*^9}, {3.40023995078125*^9, 
   3.400240078046875*^9}}],

Cell[TextData[{
 "We see that he transformation  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{"f", "[", "z", "]"}], "=", 
    RowBox[{"\[ImaginaryI]", " ", "z"}]}]}]]],
 "  maps the line  ",
 Cell[BoxData[
  RowBox[{"y", "=", 
   RowBox[{"x", "+", "1"}]}]]],
 "  onto the line  ",
 Cell[BoxData[
  RowBox[{"v", "=", 
   RowBox[{
    RowBox[{"-", " ", "u"}], "-", "1"}]}]]],
 ".  "
}], "Text"]
}, Closed]],

Cell[TextData[{
 "\tWe now look at some elementary mappings.  If we let  ",
 Cell[BoxData[
  RowBox[{"B", "=", 
   RowBox[{"a", "+", "\[ImaginaryI]b"}]}]]],
 "  denote a fixed complex constant, the transformation  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{"T", 
     RowBox[{"(", "z", ")"}]}], "=", 
    RowBox[{
     RowBox[{"z", "+", "B"}], "=", 
     RowBox[{"x", "+", "a", "+", 
      RowBox[{"\[ImaginaryI]", 
       RowBox[{"(", 
        RowBox[{"y", "+", "b"}], ")"}]}]}]}]}]}]]],
 "  \n\nis a one-to-one mapping of the z-plane onto the w-plane and is called \
a ",
 ButtonBox["translation",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/Translation.html"], None}],
 ".  This transformation can be visualized as a rigid translation whereby the \
point  z  is displaced through the vector  ",
 Cell[BoxData[
  RowBox[{"B", "=", 
   RowBox[{"a", "+", "\[ImaginaryI]b"}]}]]],
 "  to its new position  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{"T", 
    RowBox[{"(", "z", ")"}]}]}]]],
 ".  The inverse mapping is given by  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{"z", "=", 
    RowBox[{
     RowBox[{
      SuperscriptBox["T", 
       RowBox[{"-", "1"}]], 
      RowBox[{"(", "w", ")"}]}], "=", 
     RowBox[{
      RowBox[{"w", "-", "B"}], "=", 
      RowBox[{"u", "-", "a", "+", 
       RowBox[{"\[ImaginaryI]", 
        RowBox[{"(", 
         RowBox[{"v", "-", "b"}], ")"}]}]}]}]}]}]}]]],
 "  \n\nand shows that  T  is a one-to-one mapping from the z-plane onto the \
w-plane. The effect of a translation is depicted in Figure 2.5."
}], "Text"],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{599, 227},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 FontWeight->"Bold"],

Cell[TextData[{
 StyleBox["\t\t\t\tFigure 2.5",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  ",
 StyleBox["The translation",
  FontWeight->"Plain"],
 "  ",
 Cell[BoxData[
  StyleBox[
   RowBox[{"w", "=", 
    RowBox[{
     RowBox[{"T", 
      RowBox[{"(", "z", ")"}]}], "=", 
     RowBox[{
      RowBox[{"z", "+", "B"}], "=", 
      RowBox[{"x", "+", "a", "+", 
       RowBox[{"\[ImaginaryI]", 
        RowBox[{"(", 
         RowBox[{"y", "+", "b"}], ")"}]}]}]}]}]}],
   FontWeight->"Plain"]]],
 StyleBox[".",
  FontWeight->"Plain"]
}], "Text",
 FontWeight->"Bold"],

Cell[TextData[{
 "\tIf we let  ",
 Cell[BoxData["\[Alpha]"]],
 "  be a fixed real number, then for  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{"r", " ", 
    SuperscriptBox["\[ExponentialE]", "\[ImaginaryI]\[Theta]"]}]}]]],
 ",  the transformation  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{"R", 
     RowBox[{"(", "z", ")"}]}], "=", 
    RowBox[{
     RowBox[{"z", " ", 
      SuperscriptBox["\[ExponentialE]", "\[ImaginaryI]\[Alpha]"]}], "=", 
     RowBox[{
      RowBox[{"r", " ", 
       SuperscriptBox["\[ExponentialE]", "\[ImaginaryI]\[Theta]"], 
       SuperscriptBox["\[ExponentialE]", "\[ImaginaryI]\[Alpha]"]}], "=", 
      RowBox[{"r", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", 
         RowBox[{"(", 
          RowBox[{"\[Theta]", "+", "\[Alpha]"}], ")"}]}]]}]}]}]}]}]]],
 "  \n\nis a one-to-one mapping of the z-plane onto the w-plane and is called \
a ",
 ButtonBox["rotation",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/Rotation.html"], None}],
 ".  It can be visualized as a rigid rotation whereby the point  z  is \
rotated about the origin through an angle  ",
 Cell[BoxData["\[Alpha]"]],
 "   to its new position  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{"R", 
    RowBox[{"(", "z", ")"}]}]}]]],
 ".  If we use polar coordinates and designate  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{"\[Rho]", " ", 
    SuperscriptBox["\[ExponentialE]", "\[ImaginaryI]\[Phi]"]}]}]]],
 "  in the w-plane, then the inverse mapping is \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["R", 
      RowBox[{"-", "1"}]], 
     RowBox[{"(", "w", ")"}]}], "=", 
    RowBox[{
     RowBox[{"w", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", "\[ImaginaryI]\[Alpha]"}]]}], "=", 
     RowBox[{
      RowBox[{"\[Rho]", " ", 
       SuperscriptBox["\[ExponentialE]", "\[ImaginaryI]\[Phi]"], 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", "\[ImaginaryI]\[Alpha]"}]]}], "=", 
      RowBox[{"\[Rho]", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", 
         RowBox[{"(", 
          RowBox[{"\[Phi]", "-", "\[Alpha]"}], ")"}]}]]}]}]}]}]}]]],
 ".  \n\nThis analysis shows that  R  is a one-to-one mapping from the \
z-plane onto the w-plane.  ",
 "The effect of rotation is depicted in Figure 2.6."
}], "Text"],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{644, 235},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 StyleBox["\t\t\t\t\tFigure 2.6",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  The rotation  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{"R", 
     RowBox[{"(", "z", ")"}]}], "=", 
    RowBox[{"r", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", 
       RowBox[{"(", 
        RowBox[{"\[Theta]", "+", "\[Alpha]"}], ")"}]}]]}]}]}]]],
 ". "
}], "Text"],

Cell[TextData[{
 StyleBox["Example 2.8.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  The ellipse centered at the origin with a horizontal major axis of 4 \
units and vertical minor axis of 2 units can be represented by the parametric \
equation  \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"s", 
    RowBox[{"(", "t", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"2", "cos", " ", "t"}], "+", 
     RowBox[{"\[ImaginaryI]", " ", "sin", " ", "t"}]}], " ", "=", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", "cos", " ", "t"}], ",", 
      RowBox[{"sin", " ", "t"}]}], ")"}]}]}]]],
 ",   for  ",
 Cell[BoxData[
  RowBox[{"0", "\[LessEqual]", "t", "\[LessEqual]", 
   RowBox[{"2", "\[Pi]"}]}]]],
 ".  \n\nSuppose we wanted to rotate the ellipse by an angle of ",
 Cell[BoxData[
  FractionBox["\[Pi]", "6"]]],
 " radians and shift the center of the ellipse 2 units to the right and 1 \
unit up.  Using complex arithmetic, we can easily generate a parametric \
equation ",
 StyleBox["r(t)",
  FontFamily->"Courier New"],
 " that does so:\n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"r", "[", "t", "]"}], "=", 
    RowBox[{
     RowBox[{
      RowBox[{"s", "[", "t", "]"}], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"\[Pi]", "/", "6"}]}]]}], "+", 
     RowBox[{"(", 
      RowBox[{"2", "+", "\[ImaginaryI]"}], ")"}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"         ", 
   RowBox[{
    RowBox[{"=", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", "cos", " ", "t"}], "+", 
         RowBox[{"\[ImaginaryI]", " ", "sin", " ", "t"}]}], ")"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"cos", " ", 
          FractionBox["\[Pi]", "6"]}], "+", 
         RowBox[{"\[ImaginaryI]", " ", "sin", " ", 
          FractionBox["\[Pi]", "6"]}]}], ")"}]}], "+", 
      RowBox[{"(", 
       RowBox[{"2", "+", "\[ImaginaryI]"}], ")"}]}]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"         ", 
   RowBox[{
    RowBox[{"=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "cos", " ", "t", " ", "cos", 
         FractionBox["\[Pi]", "6"]}], " ", "-", 
        RowBox[{"sin", " ", "t", " ", "sin", 
         FractionBox["\[Pi]", "6"]}]}], " ", ")"}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "cos", " ", "t", " ", "sin", 
          FractionBox["\[Pi]", "6"]}], "+", " ", 
         RowBox[{"sin", " ", "t", " ", "cos", 
          FractionBox["\[Pi]", "6"]}]}], ")"}]}], "+", 
      RowBox[{"(", 
       RowBox[{"2", "+", "\[ImaginaryI]"}], ")"}]}]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"         ", 
   RowBox[{"=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SqrtBox["3"], " ", "cos", " ", "t"}], " ", "-", 
       RowBox[{
        FractionBox["1", "2"], "sin", " ", "t"}], " ", "+", "2"}], ")"}], "+",
      
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"cos", " ", "t"}], " ", "+", 
        RowBox[{
         FractionBox[
          SqrtBox["3"], "2"], "  ", "sin", " ", "t"}], " ", "+", "1"}], 
       ")"}]}]}]}]}], "\[IndentingNewLine]", 
  RowBox[{"         ", 
   RowBox[{"=", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        SqrtBox["3"], " ", "cos", " ", "t"}], " ", "-", 
       RowBox[{
        FractionBox["1", "2"], "sin", " ", "t"}], " ", "+", "2"}], ",", " ", 
      RowBox[{
       RowBox[{"cos", " ", "t"}], " ", "+", 
       RowBox[{
        FractionBox[
         SqrtBox["3"], "2"], "  ", "sin", " ", "t"}], " ", "+", "1"}]}], 
     ")"}]}]}]}]],
 "    \nfor  ",
 Cell[BoxData[
  RowBox[{"0", "\[LessEqual]", "t", "\[LessEqual]", 
   RowBox[{"2", "\[Pi]"}]}]]],
 ".  Figure 2.7 shows parametric plots of these ellipses."
}], "Text",
 Evaluatable->False,
 CellChangeTimes->{3.3989768525*^9},
 AspectRatioFixed->True],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{553, 186},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 StyleBox["\tFigure 2.7  (a)",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Plot of the original ellipse\t\t\t     ",
 StyleBox["(b)",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Plot of the rotated ellipse\n\t\t\t  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"s", 
    RowBox[{"(", "t", ")"}]}], "=", 
   RowBox[{
    RowBox[{"2", "cos", " ", "t"}], "+", 
    RowBox[{"\[ImaginaryI]", " ", "sin", " ", "t"}]}]}]]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"r", 
    RowBox[{"(", "t", ")"}]}], "=", 
   RowBox[{
    RowBox[{"s", 
     RowBox[{"(", "t", ")"}], " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"\[Pi]", "/", "6"}]}]]}], "+", 
    RowBox[{"(", 
     RowBox[{"2", "+", "\[ImaginaryI]"}], ")"}]}]}]]]
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 2.8.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"r", ",", "s", ",", "t"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"s", "[", "t_", "]"}], "=", 
     RowBox[{
      RowBox[{"2", 
       RowBox[{"Cos", "[", "t", "]"}]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"Sin", "[", "t", "]"}]}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"r", "[", "t_", "]"}], "=", 
     RowBox[{
      RowBox[{
       RowBox[{"s", "[", "t", "]"}], " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"\[Pi]", "/", "6"}]}]]}], "+", 
      RowBox[{"(", 
       RowBox[{"2", "+", "\[ImaginaryI]"}], ")"}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"ParametricPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Re", "[", 
        RowBox[{"s", "[", "t", "]"}], "]"}], ",", 
       RowBox[{"Im", "[", 
        RowBox[{"s", "[", "t", "]"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", 
       RowBox[{"2", "\[Pi]"}]}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Red"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.1"}], ",", "2.1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.05"}], ",", "1.05"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["1", "2"]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<s[t] = \>\"", ",", 
      RowBox[{"s", "[", "t", "]"}], ",", 
      "\"\< for 0 \[LessEqual] t \[LessEqual] 2\[Pi].\>\""}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{"ParametricPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Re", "[", 
        RowBox[{"r", "[", "t", "]"}], "]"}], ",", 
       RowBox[{"Im", "[", 
        RowBox[{"r", "[", "t", "]"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", 
       RowBox[{"2", "\[Pi]"}]}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Blue"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "4"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.5"}], ",", "2.5"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["3", "4"]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "4", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "3", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Print", "[", 
    RowBox[{"\"\<r[t] = \>\"", ",", 
     RowBox[{"r", "[", "t", "]"}], ",", 
     "\"\< for 0 \[LessEqual] t \[LessEqual] 2\[Pi].\>\""}], "]"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3989771363125*^9, 3.39897714203125*^9}, {
  3.39972080690625*^9, 3.399720807078125*^9}, {3.39972173471875*^9, 
  3.399721739265625*^9}}]
}, Closed]],

Cell[TextData[{
 "\tIf we let  ",
 Cell[BoxData[
  RowBox[{"K", ">", "0"}]]],
 "  be a fixed positive real number, then the transformation  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"w", " ", "=", " ", 
   RowBox[{
    RowBox[{"S", 
     RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{"K", " ", "z"}], " ", "=", " ", 
     RowBox[{
      RowBox[{"K", " ", "x"}], "+", 
      RowBox[{"\[ImaginaryI]", " ", "K", " ", "y"}]}]}]}]}]]],
 "  \n\nis a one-to-one mapping of the z-plane onto the w-plane and is called \
a ",
 StyleBox["magnification",
  FontColor->RGBColor[0, 0, 1]],
 ".  If   ",
 Cell[BoxData[
  RowBox[{"K", ">", "1"}]]],
 ",  it has the effect of stretching the distance between points by the \
factor  K.  If   ",
 Cell[BoxData[
  RowBox[{"K", "<", "1"}]]],
 ",  then it reduces the distance between points by the factor  K.  The \
inverse transformation is given by  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"z", " ", "=", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox["S", 
      RowBox[{"-", "1"}]], 
     RowBox[{"(", "w", ")"}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      FractionBox["1", "K"], "w"}], " ", "=", " ", 
     RowBox[{
      RowBox[{
       FractionBox["1", "K"], "u"}], " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", 
       FractionBox["1", "K"], "v"}]}]}]}]}]]],
 "  \n\nand shows that  S  is a one-to-one mapping from the z-plane onto the \
w-plane.  The effect of magnification is shown in Figure 2.8."
}], "Text"],

Cell[TextData[{
 StyleBox["Figure 2.8",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  The magnification  ",
 Cell[BoxData[
  RowBox[{"w", " ", "=", " ", 
   RowBox[{
    RowBox[{"S", 
     RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{"K", " ", "z"}], " ", "=", " ", 
     RowBox[{
      RowBox[{"K", " ", "x"}], "+", 
      RowBox[{"\[ImaginaryI]", " ", "K", " ", "y"}]}]}]}]}]]],
 ". "
}], "Text"],

Cell[TextData[{
 "\tFinally, if we let  ",
 Cell[BoxData[
  RowBox[{"A", "=", 
   RowBox[{"K", " ", 
    SuperscriptBox["\[ExponentialE]", "\[ImaginaryI]\[Alpha]"]}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{"B", "=", 
   RowBox[{"a", "+", 
    RowBox[{"\[ImaginaryI]", " ", "b"}]}]}]]],
 ", where  ",
 Cell[BoxData[
  RowBox[{"K", ">", "0"}]]],
 "  is a positive real number, then the transformation \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"w", " ", "=", " ", 
   RowBox[{
    RowBox[{"L", 
     RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{"A", " ", "z"}], "+", "B"}]}]}]]],
 " \n\nis a one-to-one mapping of the ",
 StyleBox["z",
  FontFamily->"Courier New"],
 "-plane onto the ",
 StyleBox["w",
  FontFamily->"Courier New"],
 "-plane and is called a ",
 StyleBox["linear transformation",
  FontColor->RGBColor[0, 0, 1]],
 ".  It can be considered as the composition of a rotation, a magnification, \
and a translation.  It has the effect of rotating the plane though an angle \
given by  ",
 Cell[BoxData[
  RowBox[{"\[Alpha]", "=", 
   RowBox[{"Arg", " ", "A"}]}]]],
 ",  followed by a magnification by the factor  ",
 Cell[BoxData[
  RowBox[{"K", "=", 
   RowBox[{"|", "A", "|"}]}]]],
 ", followed by a translation by the vector  ",
 Cell[BoxData[
  RowBox[{"B", "=", 
   RowBox[{"a", "+", "\[ImaginaryI]b"}]}]]],
 ".  The inverse mapping is given by  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["L", 
      RowBox[{"-", "1"}]], 
     RowBox[{"(", "w", ")"}]}], "=", 
    RowBox[{
     RowBox[{
      FractionBox["1", "A"], " ", "w"}], "-", 
     FractionBox["B", "A"]}]}]}]]],
 "  and shows that ",
 StyleBox["L",
  FontFamily->"Courier New"],
 " is a one-to-one mapping from the ",
 StyleBox["z",
  FontFamily->"Courier New"],
 "-plane onto the ",
 StyleBox["w",
  FontFamily->"Courier New"],
 "-plane."
}], "Text"],

Cell[TextData[{
 StyleBox["Example 2.9.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Show that the linear transformation  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "=", 
    RowBox[{
     RowBox[{"\[ImaginaryI]", " ", "z"}], "+", "\[ImaginaryI]"}]}]}]]],
 "  maps the right half plane  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Re", 
    RowBox[{"(", "z", ")"}]}], ">", "1"}]]],
 "  onto the upper half plane  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", 
    RowBox[{"(", "w", ")"}]}], ">", "2"}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "Solution.  Method 1:  Let  ",
 Cell[BoxData[
  RowBox[{"A", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"x", ",", "y"}], ")"}], ":", " ", 
     RowBox[{"x", "\[GreaterEqual]", "1"}]}], "}"}]}]]],
 ".  To describe  ",
 Cell[BoxData[
  RowBox[{"B", "=", 
   RowBox[{"f", 
    RowBox[{"(", "A", ")"}]}]}]]],
 ",  we solve  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{"\[ImaginaryI]", " ", "z"}], "+", "\[ImaginaryI]"}]}]]],
 "  for z to get  ",
 Cell[BoxData[
  RowBox[{"z", " ", "=", " ", 
   RowBox[{
    FractionBox[
     RowBox[{"w", "-", "\[ImaginaryI]"}], "\[ImaginaryI]"], " ", "=", " ", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "w"}], "-", "1"}], " ", "=", " ", 
     
     RowBox[{
      SuperscriptBox["f", 
       RowBox[{"-", "1"}]], 
      RowBox[{"(", "w", ")"}]}]}]}]}]]],
 ".  We have the following \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{"u", "+", "iv"}], " ", "=", " ", 
   RowBox[{"w", " ", "=", 
    RowBox[{
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], "\[Element]", "B"}]}]}], "\n", 
  RowBox[{
   RowBox[{
    RowBox[{"\[DoubleLongLeftRightArrow]", "    ", 
     SuperscriptBox["f", 
      RowBox[{"-", "1"}]]}], 
    RowBox[{"(", "w", ")"}]}], " ", "=", " ", 
   RowBox[{"z", " ", "\[Element]", "A"}]}], "\n", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[DoubleLongLeftRightArrow]", "  ", 
      RowBox[{"-", "\[ImaginaryI]"}]}], " ", "w"}], "-", "1"}], " ", 
   "\[Element]", "A"}], "\n", 
  RowBox[{
   RowBox[{
    RowBox[{"\[DoubleLongLeftRightArrow]", "  ", "v"}], "-", "1", "-", 
    RowBox[{"\[ImaginaryI]", " ", "u"}]}], " ", "\[Element]", "A"}], "\n", 
  RowBox[{
   RowBox[{"\[DoubleLongLeftRightArrow]", "  ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"v", "-", "1"}], ",", 
      RowBox[{"-", "u"}]}], ")"}]}], " ", "\[Element]", "A"}], "\n", 
  RowBox[{
   RowBox[{
    RowBox[{"\[DoubleLongLeftRightArrow]", "  ", "v"}], "-", "1"}], 
   "\[GreaterEqual]", "1"}], "\n", 
  RowBox[{
   RowBox[{"\[DoubleLongLeftRightArrow]", "  ", "v"}], "\[GreaterEqual]", 
   "2"}]}]],
 "  \n\nThus  ",
 Cell[BoxData[
  RowBox[{"B", "=", 
   RowBox[{"{", 
    RowBox[{"w", "=", 
     RowBox[{"u", "+", 
      RowBox[{"iv", ":", " ", 
       RowBox[{"v", "\[GreaterEqual]", "2"}]}]}]}], "}"}]}]]],
 ",  which is the same as saying  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", 
    RowBox[{"(", "w", ")"}]}], ">", "2"}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "Method 2: When we write  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}]}]]],
 "  in Cartesian form as  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"w", " ", "=", " ", 
   RowBox[{
    RowBox[{"u", "+", "iv"}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"\[ImaginaryI]", 
       RowBox[{"(", 
        RowBox[{"x", "+", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "+", 
      "\[ImaginaryI]"}], " ", "=", " ", 
     RowBox[{
      RowBox[{"-", "y"}], "+", 
      RowBox[{"\[ImaginaryI]", 
       RowBox[{"(", 
        RowBox[{"x", "+", "1"}], ")"}]}]}]}]}]}]]],
 ",  \n\nwe see that the transformation can be given by the equations  ",
 Cell[BoxData[
  RowBox[{"u", "=", 
   RowBox[{"-", "y"}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{"v", "=", 
   RowBox[{"x", "+", "1"}]}]]],
 ".  Substituting  ",
 Cell[BoxData[
  RowBox[{"x", "=", 
   RowBox[{"v", "-", "1"}]}]]],
 "  in the inequality  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Re", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{"x", "\[GreaterEqual]", "1"}]}]]],
 "  gives  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"v", "-", "1"}], "\[GreaterEqual]", "1"}]]],
 ",  or  ",
 Cell[BoxData[
  RowBox[{"v", "\[GreaterEqual]", "2"}]]],
 ",  which is the upper half-plane  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", 
    RowBox[{"(", "w", ")"}]}], ">", "2"}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "Method 3:  The effect of the transformation  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}]}]]],
 " is a rotation of the plane through the angle  ",
 Cell[BoxData[
  RowBox[{"\[Alpha]", "=", 
   FractionBox["\[Pi]", "2"]}]]],
 " (when z is multiplied by ",
 Cell[BoxData["\[ImaginaryI]"]],
 ") followed by a translation by the vector  ",
 Cell[BoxData[
  RowBox[{"B", "=", "\[ImaginaryI]"}]]],
 ".  The first operation yields the set  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", 
    RowBox[{"(", "w", ")"}]}], "\[GreaterEqual]", "1"}]]],
 ".  The second shifts this set up ",
 StyleBox["1",
  FontFamily->"Courier New"],
 " unit, resulting in the set  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", 
    RowBox[{"(", "w", ")"}]}], ">", "2"}]]],
 ".  We illustrate this result in Figure 2.9."
}], "Text"],

Cell[GraphicsData["CompressedBitmap", "\<\
eJztnU9u00AUh92kbkC0ScsOKlAPgBCsUCUkUiqBEOIIXUQVUiuEikpZtRAo
3II9WxYIFZb0AFwp5I2TcWyP/8RxiO35LDwdxpOx5/e+57HHL86L3snBy9e9
k8P93tbT496bg8P9t1tPjo6HRc0lx1n64zjO1y1H8oNhdpQMhv8Gl5JIyYz5
O5K40u6mzq1Jbllybck1JLchuabeqso6umxzosW7Kq+KVU7WW4ayNUOZ2p+z
HCgb7zxU9Zq5akwLN73MmT727xmPsm0o68T1xtWqhLauJh7VqXnrN22G5YwH
a9r1FIfjWzti2feGTwTQ2JPcw6lMH9l/THG4B76Z03s6UvidltI17+P6xGed
wQ+1rqi06fT7/UhZWr1WxnpZ2zPVa6XUG3dvW1vqts6tB03t27Gh1W0GQUhm
tWHQfr3Gmv4Nn0+adgrwiW7b0O3f+vy5YacADyQ9k5LEAcROXTKMw1nH66Lr
NbHWRN+eGfr7Sg9hI7HGS5pGe7K754at54iLFEiBFEiBFLNIcaqvOm27vUwT
xXiVgzzjO/LQpoa+xPGnqhIuXPzJIm/ezQ1UGl8i1XnGKBU/6+d/0gi0ck6I
UU33rSup659DEGW4Pjb0F3mQB3mQZ97y7OhReSWHKMx1MdIjBVIgBVLMRwp1
X+3NNPiPYeTvRo316Eo6EZZjVMYLPbJvEqZrkCTh2iVbhNauoYEE7ZkKm/Ky
2m5YI9OCCWjZO002261ITUVRgSRXHY8HVXm0tA1lnRnqZf1sS5JNi42Rcx9u
wcdcdHumem6O9sZa3QCRRZsUREAEREDEWkTUd6HUTYeaqN5G1SJUjfk60hV8
D0qgBEqgBEqgJCclUlfWjkqDZW1D2TzrZbDMqp6za8yAepUMtGi3q7Abc8cG
IiBSCpOCSCkR8b+R4QS/dHoPdqZl50j+nMuG8NNWWe4jaBHO2DKUrdTYQU0h
Dvgm53XO67AzJ3a4bASRLIgQJFQiY5TEv/BXEAEREAEREAGRtC+yEh+Ez+Fz
IAIiIPLfEJG6slYk4MMWsyza0/BcEAEREAEREAERS98DAidTc2LriyZAJScq
aW+GYVIQH8QHQWUOqJQ1YsPeVxDhwdy7gQiIgAiIgAiIgAiIgIgViBABhs/h
cyBSMCJSV1bCe0pllkV7Gp4LIiACIiACIiBi809aA0s+WEKbeFIJNinYZP0J
dCaBppbW6jCOkpi2Iqh4J+/Iu3ytHPYJACqlWUrigBVxaO7uQAREQAREQARE
QAREQKSKiBAAhM/hcyBSMCJSV1YCgEpllkV7Gp4LIiACIiACIiDCI6dyGLci
sPAMGXLykcM7f+Yk7AezS9Y++KesIRycIjlF5vNkrsTKYNyKwMKdHYiACIiA
CIiACIiACIiACIjUEJFIfJg0KCuRHXBeI85BBERAZNEmBREQAREQAREQAZFR
4Ia3hd9/g5NYTmyNQymJVStCifHXJGUJxYBVLLpHZXa9/4XfdhXerk6ojXCp
yl9G8/1g7R2v9KNh3Fbpo/hx/UK39MXciCy/wpX65g5fmIs/T5wLwmOGLD91
8/77v86TBYjLO0v/AA5G3Hc=\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{449, 155},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 StyleBox["\t\t\tFigure 2.9",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  The linear transformation  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "=", 
    RowBox[{
     RowBox[{"\[ImaginaryI]", " ", "z"}], "+", "\[ImaginaryI]"}]}]}]]],
 ". "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 2.9.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "Enter the function  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{"f", "[", "z", "]"}], "=", 
    RowBox[{
     RowBox[{"\[ImaginaryI]", " ", "z"}], "+", "\[ImaginaryI]"}]}]}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"w", ",", "x", ",", "y", ",", "z", ",", "Z"}], "]"}], ";"}], " ",
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "eq1", ",", "eq2", ",", "f", ",", "ineq", ",", "u", ",", "v", ",", 
      "zz"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"TagSet", "[", 
     RowBox[{"x", ",", 
      RowBox[{"Im", "[", "x", "]"}], ",", "0"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"TagSet", "[", 
     RowBox[{"y", ",", 
      RowBox[{"Im", "[", "y", "]"}], ",", "0"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"TagSet", "[", 
     RowBox[{"x", ",", 
      RowBox[{"Re", "[", "x", "]"}], ",", "x"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"TagSet", "[", 
     RowBox[{"y", ",", 
      RowBox[{"Re", "[", "y", "]"}], ",", "y"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], ":=", 
     RowBox[{
      RowBox[{"\[ImaginaryI]", " ", "z"}], "+", "\[ImaginaryI]"}]}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<    f[\>\"", ",", "z", ",", "\"\<] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[\>\"", ",", 
      RowBox[{"x", " ", "+", " ", 
       RowBox[{"\[ImaginaryI]", " ", "y"}]}], ",", "\"\<] = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"x", " ", "+", " ", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[\>\"", ",", 
      RowBox[{"x", " ", "+", " ", 
       RowBox[{"\[ImaginaryI]", " ", "y"}]}], ",", "\"\<] = \>\"", ",", 
      RowBox[{"Expand", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39897714978125*^9},
 AspectRatioFixed->True],

Cell["Solve for the inverse function.", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"solset", "=", 
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"w", "\[Equal]", 
        RowBox[{
         RowBox[{"\[ImaginaryI]", " ", "z"}], "+", "\[ImaginaryI]"}]}], ",", 
       "z"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Z", "=", 
     SubscriptBox["solset", 
      RowBox[{"\[LeftDoubleBracket]", 
       RowBox[{"1", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<      w = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<      w = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"x", "+", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}]}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<      w = \>\"", ",", 
      RowBox[{"Expand", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", "+", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<u + \[ImaginaryI] v = \>\"", ",", 
      RowBox[{"Expand", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", "+", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<u = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"Re", "[", 
        RowBox[{"f", "[", 
         RowBox[{"x", "+", 
          RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], "]"}]}], "]"}],
     ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<v = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"Im", "[", 
        RowBox[{"f", "[", 
         RowBox[{"x", "+", 
          RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], "]"}]}], "]"}],
     ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "solset", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<z = \>\"", ",", "Z"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<z = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", "Z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Z", "=", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{"Z", " ", ",", 
       RowBox[{"w", "\[Rule]", 
        RowBox[{"u", "+", 
         RowBox[{"\[ImaginaryI]", " ", "v"}]}]}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<z = \>\"", ",", "Z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<z = \>\"", ",", 
      RowBox[{"Expand", "[", "Z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<x = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"Re", "[", "Z", "]"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"Im", "[", "Z", "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.398977153984375*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "To solve for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Re", "[", "z", "]"}], ">", "1"}]]],
 ",   we use the following computations."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"Re", "[", "z", "]"}], ">", "1"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"x", ">", "1"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"ineq", "=", 
      RowBox[{
       RowBox[{"ComplexExpand", "[", 
        RowBox[{"Re", "[", "Z", "]"}], "]"}], ">", "1"}]}], "]"}], ";"}], " ",
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"solset", "=", 
     RowBox[{"Reduce", "[", 
      RowBox[{"ineq", ",", "v", ",", "Reals"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "solset", "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{
  3.398977158921875*^9, {3.399742096640625*^9, 3.39974210928125*^9}, {
   3.3997423894375*^9, 3.399742389640625*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "The solution is the upper half plane  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", "[", "w", "]"}], ">", "2"}]]],
 ".  Now use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to graph the transformation. "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Iden", "[", "z_", "]"}], "=", "z"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", 
     RowBox[{
      RowBox[{"\[ImaginaryI]", " ", "z"}], "+", "\[ImaginaryI]"}]}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"CartesianMap", "[", 
    RowBox[{"Iden", ",", " ", 
     RowBox[{"{", 
      RowBox[{"1", ",", "5", ",", "0.5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "6"}], ",", "4", ",", "0.5"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "6"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "4"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "6", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "4", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", "\"\<The half-plane  Re[z] > 1.\>\"", "]"}], ";"}], 
   " ", "\n", 
   RowBox[{"CartesianMap", "[", 
    RowBox[{"f", ",", " ", 
     RowBox[{"{", 
      RowBox[{"1", ",", "5", ",", "0.5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "6"}], ",", "4", ",", "0.5"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "6"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "6"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "6", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "6", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", "\"\<The image half-plane Im[w] > 2,\>\"", "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<under the mapping  w = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.398977170046875*^9, 3.3989771744375*^9}, {
  3.39911986153125*^9, 3.39911986409375*^9}, {3.39972081234375*^9, 
  3.39972081253125*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "We see that the linear transformation  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{"f", "[", "z", "]"}], "=", 
    RowBox[{
     RowBox[{"\[ImaginaryI]", " ", "z"}], "+", "\[ImaginaryI]"}]}]}]]],
 "  maps the right half plane  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Re", "[", "z", "]"}], ">", "1"}]]],
 "  onto the upper half plane  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", "[", "w", "]"}], ">", "2"}]]],
 ".  "
}], "Text"]
}, Closed]],

Cell[TextData[{
 "\tTranslations and rotations preserve angles.  First, magnifications \
rescale distance by a factor K, so it follows that triangles are mapped onto \
similar triangles, preserving angles.  Then, because a linear transformation \
can be considered to be a composition of a rotation, a magnification, and a \
translation, it follows that linear transformations preserve angles.  \
Consequently, any geometric object is mapped onto an object that is similar \
to the original object; hence linear transformations can be called ",
 StyleBox["similarity mappings",
  FontColor->RGBColor[0, 0, 1]],
 "."
}], "Text"],

Cell[TextData[{
 StyleBox["Note.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 " The usage of the phrase \"",
 StyleBox["linear transformation",
  FontColor->RGBColor[0, 0, 1]],
 "\" in a \"complex analysis course\" is different than that the usage in \
\"linear algebra courses\"."
}], "Text"],

Cell[TextData[{
 StyleBox["Example 2.10.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Show that the image of the open disk  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["D", "1"], Cell["(-1-\[ImaginaryI])"]}], "=", 
   RowBox[{"{", 
    RowBox[{"z", ":", 
     RowBox[{"|", 
      RowBox[{"z", "+", "1", "+", "\[ImaginaryI]"}], "|", 
      RowBox[{"<", " ", "1"}]}]}], "}"}]}]]],
 "  under the linear transformation  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "=", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3", "-", 
        RowBox[{"4", "\[ImaginaryI]"}]}], ")"}], "z"}], " ", "+", " ", "6", 
     "+", 
     RowBox[{"2", "\[ImaginaryI]"}]}]}]}]]],
 "  is the open disk  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["D", "5"], Cell["(-1+3\[ImaginaryI])"]}], "=", 
   RowBox[{"{", 
    RowBox[{"w", ":", 
     RowBox[{"|", 
      RowBox[{"w", "+", "1", "-", 
       RowBox[{"3", " ", "\[ImaginaryI]"}]}], "|", 
      RowBox[{"<", " ", "5"}]}]}], "}"}]}]]],
 ".  \n\nSolution.  The inverse transformation is  ",
 Cell[BoxData[
  RowBox[{"z", " ", "=", " ", 
   FractionBox[
    RowBox[{"w", "-", "6", "-", 
     RowBox[{"2", "\[ImaginaryI]"}]}], 
    RowBox[{"3", "-", 
     RowBox[{"4", "\[ImaginaryI]"}]}]]}]]],
 ",  so if we designate the range of ",
 StyleBox["f",
  FontFamily->"Courier New"],
 " as ",
 StyleBox["B",
  FontFamily->"Courier New"],
 ", then\n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], "\[Element]", 
     RowBox[{"B", "\[DoubleLeftRightArrow]", 
      RowBox[{
       SuperscriptBox["f", 
        RowBox[{"-", "1"}]], 
       RowBox[{"(", "w", ")"}]}]}]}], "=", 
    RowBox[{"z", "\[Element]", 
     RowBox[{
      SubscriptBox["D", "1"], Cell["(-1-\[ImaginaryI])"]}]}]}]}], "\n", 
  RowBox[{
   RowBox[{"\[DoubleLongLeftRightArrow]", "   ", 
    FractionBox[
     RowBox[{"w", "-", "6", "-", 
      RowBox[{"2", "i"}]}], 
     RowBox[{"3", "-", 
      RowBox[{"4", "i"}]}]]}], "\[Element]", 
   RowBox[{
    SubscriptBox["D", "1"], Cell["(-1-\[ImaginaryI])"]}]}], "\n", 
  RowBox[{"\[DoubleLongLeftRightArrow]", "   ", 
   RowBox[{"|", 
    RowBox[{
     FractionBox[
      RowBox[{"w", "-", "6", "-", 
       RowBox[{"2", "i"}]}], 
      RowBox[{"3", "-", 
       RowBox[{"4", "i"}]}]], "+", "1", "+", "i"}], "|", 
    RowBox[{"<", " ", "1"}]}]}]}]],
 "   \n\t\t\t",
 Cell[BoxData[
  RowBox[{"\[DoubleLongLeftRightArrow]", "   ", 
   RowBox[{"|", 
    RowBox[{
     FractionBox[
      RowBox[{"w", "-", "6", "-", 
       RowBox[{"2", "i"}]}], 
      RowBox[{"3", "-", 
       RowBox[{"4", "i"}]}]], "+", "1", "+", "i"}], "|"}]}]]],
 Cell[BoxData[
  RowBox[{"|", 
   RowBox[{"3", "-", 
    RowBox[{"4", "i"}]}], "|", 
   RowBox[{"<", " ", "1"}], "|", 
   RowBox[{"3", "-", 
    RowBox[{"4", "i"}]}], "|", " "}]]],
 "\n\t\t\t",
 Cell[BoxData[{
  RowBox[{"\[DoubleLongLeftRightArrow]", "   ", 
   RowBox[{"|", 
    RowBox[{"w", "-", "6", "-", 
     RowBox[{"2", "i"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", "i"}], ")"}], 
      RowBox[{"(", 
       RowBox[{"3", "-", 
        RowBox[{"4", "i"}]}], ")"}]}]}], "|", 
    RowBox[{"<", " ", "5"}]}]}], "\n", 
  RowBox[{"\[DoubleLongLeftRightArrow]", "   ", 
   RowBox[{"|", 
    RowBox[{"w", "+", "1", "-", 
     RowBox[{"3", "i"}]}], "|", 
    RowBox[{"<", " ", "5"}]}]}]}]],
 "\n\nHence the disk with center  ",
 Cell[BoxData[Cell["-1-\[ImaginaryI]"]]],
 "  and radius ",
 StyleBox["1",
  FontFamily->"Courier New"],
 " is mapped one-to-one and onto the disk with center  ",
 Cell[BoxData[Cell["-1+3\[ImaginaryI]"]]],
 "  and radius ",
 StyleBox["5",
  FontFamily->"Courier New"],
 " as shown in Figure 2.10."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{464, 155},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 StyleBox["\t\t\tFigure 2.10",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  The mapping  ",
 Cell[BoxData[
  RowBox[{"w", " ", "=", " ", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "=", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3", "-", 
        RowBox[{"4", "\[ImaginaryI]"}]}], ")"}], "z"}], " ", "+", " ", "6", 
     "+", 
     RowBox[{"2", "\[ImaginaryI]"}]}]}]}]]],
 ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 2.10.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "Enter the function  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{"f", "[", "z", "]"}], "=", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3", "-", 
        RowBox[{"4", "\[ImaginaryI]"}]}], ")"}], "z"}], " ", "+", " ", "6", 
     "+", 
     RowBox[{"2", "\[ImaginaryI]"}]}]}]}]]],
 " .  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"w", ",", "x", ",", "y", ",", "z", ",", "Z"}], "]"}], ";"}], " ",
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "ineq", ",", "solset", ",", "term"}], "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"3", "-", 
         RowBox[{"4", "\[ImaginaryI]"}]}], ")"}], "z"}], "+", "6", "+", 
      RowBox[{"2", "\[ImaginaryI]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<    f[\>\"", ",", "z", ",", "\"\<] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[\>\"", ",", 
      RowBox[{"x", " ", "+", " ", 
       RowBox[{"\[ImaginaryI]", " ", "y"}]}], ",", "\"\<] = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"x", " ", "+", " ", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[\>\"", ",", 
      RowBox[{"x", " ", "+", " ", 
       RowBox[{"\[ImaginaryI]", " ", "y"}]}], ",", "\"\<] = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39897718296875*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "Solve for the inverse function, i.e. solve for  z  in terms of  w.  Then \
find ",
 Cell[BoxData[
  RowBox[{"z", "+", "1", "+", "\[ImaginaryI]"}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"solset", " ", "=", " ", 
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"w", " ", "\[Equal]", " ", 
        RowBox[{"f", "[", "z", "]"}]}], ",", "z"}], "]"}]}], ";"}], " ", "\n",
    
   RowBox[{
    RowBox[{"Z", " ", "=", " ", 
     RowBox[{"Factor", "[", 
      SubscriptBox["solset", 
       RowBox[{"\[LeftDoubleBracket]", 
        RowBox[{"1", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]], 
      "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"term", " ", "=", " ", 
     RowBox[{"Together", "[", 
      RowBox[{"Z", "+", "1", "+", "\[ImaginaryI]"}], "]"}]}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", "solset", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<        z = \>\"", ",", "Z"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"z", "+", "1", "+", "\[ImaginaryI]"}], ",", "\"\< = \>\"", ",", 
      
      RowBox[{"Z", "+", "1", "+", "\[ImaginaryI]"}]}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"z", "+", "1", "+", "\[ImaginaryI]"}], ",", "\"\< = \>\"", ",", 
      "term"}], "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39897718671875*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "To solve for ",
 Cell[BoxData[
  RowBox[{"|", 
   RowBox[{"z", "+", "1", "+", "\[ImaginaryI]"}], "|", 
   RowBox[{"<", " ", "1"}]}]]],
 ",  we use the computations."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"Abs", "[", 
       RowBox[{"z", "+", "1", "+", "\[ImaginaryI]"}], "]"}], " ", "<", " ", 
      "1"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"ineq", " ", "=", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"Abs", "[", 
         RowBox[{"term", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "]"}], " ", 
        RowBox[{"Abs", "[", 
         RowBox[{"term", "[", 
          RowBox[{"[", "2", "]"}], "]"}], "]"}]}], " ", "<", " ", "1"}]}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"Distribute", "[", 
      RowBox[{
       RowBox[{"5", " ", "ineq"}], ",", " ", "Less"}], "]"}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.398977217671875*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "Which is the disk  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["D", "5"], Cell["(-1+3 \[ImaginaryI])"]}], "=", 
   RowBox[{"{", 
    RowBox[{"w", ":", 
     RowBox[{"|", 
      RowBox[{"w", "+", "1", "-", 
       RowBox[{"3", " ", "\[ImaginaryI]"}]}], "|", 
      RowBox[{"<", " ", "5"}]}]}], "}"}]}]]],
 "  in the w-plane.  Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to graph the transformation. "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"Z", ",", "W"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Iden", "[", "z_", "]"}], " ", "=", " ", "z"}], ";"}], " ", "\n",
    
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"3", " ", "-", " ", 
         RowBox[{"4", "\[ImaginaryI]"}]}], ")"}], "z"}], " ", "+", " ", "6", 
      " ", "+", " ", 
      RowBox[{"2", "\[ImaginaryI]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"Z", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"Iden", "[", 
      RowBox[{"z", "-", "1", "-", "\[ImaginaryI]"}], "]"}]}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"W", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"f", "[", 
      RowBox[{"z", "-", "1", "-", "\[ImaginaryI]"}], "]"}]}], ";"}], " ", 
   "\n", 
   RowBox[{"RegionPlot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Abs", "[", 
       RowBox[{"x", "+", 
        RowBox[{"\[ImaginaryI]", " ", "y"}], "+", "1", "+", "\[ImaginaryI]"}],
        "]"}], "<", " ", "1"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"x", ",", " ", 
       RowBox[{"-", "6"}], ",", "4"}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"y", ",", " ", 
       RowBox[{"-", "2"}], ",", "8"}], "}"}], ",", 
     RowBox[{"GridLines", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{"0", ",", "Dashed"}], "}"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{"0", ",", "Dashed"}], "}"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "6"}], ",", "4", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "8", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", "Cyan", "}"}]}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The open disk |z+1+\[ImaginaryI]| < 1.\>\"", "]"}], 
    ";"}], " ", "\n", 
   RowBox[{"RegionPlot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Abs", "[", 
       RowBox[{"u", "+", 
        RowBox[{"\[ImaginaryI]", " ", "v"}], "+", "1", "-", 
        RowBox[{"3", " ", "\[ImaginaryI]"}]}], "]"}], "<", " ", "5"}], ",", 
     " ", 
     RowBox[{"{", 
      RowBox[{"u", ",", " ", 
       RowBox[{"-", "6"}], ",", "4"}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"v", ",", " ", 
       RowBox[{"-", "2"}], ",", "8"}], "}"}], ",", 
     RowBox[{"GridLines", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{"0", ",", "Dashed"}], "}"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{"0", ",", "Dashed"}], "}"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "6"}], ",", "4", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "8", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", "Cyan", "}"}]}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The image is the open disk |w+1-3\[ImaginaryI]| < 5,\>\"", "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<under the mapping w = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.398977222515625*^9, 3.39897722784375*^9}, {
   3.39911987540625*^9, 3.39911990478125*^9}, {3.3997208184375*^9, 
   3.399720818625*^9}, 3.4002404853125*^9, {3.400240555375*^9, 
   3.400240608203125*^9}, {3.40024071034375*^9, 3.400240798640625*^9}, {
   3.400240904015625*^9, 3.40024093003125*^9}},
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"Z", ",", "W"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Iden", "[", "z_", "]"}], " ", "=", " ", "z"}], ";"}], " ", "\n",
    
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"3", " ", "-", " ", 
         RowBox[{"4", "\[ImaginaryI]"}]}], ")"}], "z"}], " ", "+", " ", "6", 
      " ", "+", " ", 
      RowBox[{"2", "\[ImaginaryI]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"Z", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"Iden", "[", 
      RowBox[{"z", "-", "1", "-", "\[ImaginaryI]"}], "]"}]}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"W", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"f", "[", 
      RowBox[{"z", "-", "1", "-", "\[ImaginaryI]"}], "]"}]}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"PolarMap", "[", 
    RowBox[{"Z", " ", ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1", ",", "0.2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"2", "\[Pi]"}], ",", 
       FractionBox["\[Pi]", "12"]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "6"}], ",", "4"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "8"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "6"}], ",", "4", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "8", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Red", ",", "Blue"}], "}"}]}]}], "]"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The open disk |z+1+\[ImaginaryI]| < 1.\>\"", "]"}], 
    ";"}], " ", "\n", 
   RowBox[{"PolarMap", "[", 
    RowBox[{"W", " ", ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1", ",", "0.2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"2", "\[Pi]"}], ",", 
       FractionBox["\[Pi]", "12"]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "6"}], ",", "4"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "8"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "6"}], ",", "4", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "8", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Red", ",", "Blue"}], "}"}]}]}], "]"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The image is the open disk |w+1-3\[ImaginaryI]| < 5,\>\"", "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<under the mapping w = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.398977222515625*^9, 3.39897722784375*^9}, {
  3.39911987540625*^9, 3.39911990478125*^9}, {3.3997208184375*^9, 
  3.399720818625*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "We see that the image of the open disk  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["D", "1"], Cell["(-1-\[ImaginaryI])"]}], "=", 
   RowBox[{"{", 
    RowBox[{"z", ":", 
     RowBox[{"|", 
      RowBox[{"z", "+", "1", "+", "\[ImaginaryI]"}], "|", 
      RowBox[{"<", " ", "1"}]}]}], "}"}]}]]],
 "  under the transformation  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"3", "-", 
       RowBox[{"4", "\[ImaginaryI]"}]}], ")"}], "z"}], " ", "+", " ", "6", 
    "+", 
    RowBox[{"2", "\[ImaginaryI]"}]}]}]]],
 "  is the open disk  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["D", "5"], Cell["(-1+3 \[ImaginaryI])"]}], "=", 
   RowBox[{"{", 
    RowBox[{"w", ":", 
     RowBox[{"|", 
      RowBox[{"w", "+", "1", "-", 
       RowBox[{"3", " ", "\[ImaginaryI]"}]}], "|", 
      RowBox[{"<", " ", "5"}]}]}], "}"}]}]]],
 ".  "
}], "Text"]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 2.11.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Show that the image of the right half plane  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Re", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{"x", ">", "1"}]}]]],
 "  under the linear transformation  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "\[ImaginaryI]"}], ")"}], "z"}], " ", "-", 
    " ", "2", "+", 
    RowBox[{"3", "\[ImaginaryI]"}]}]}]]],
 "  is the half plane  ",
 Cell[BoxData[
  RowBox[{"v", ">", 
   RowBox[{"u", "+", "7"}]}]]],
 ".  \n\nSolution.  The inverse transformation is given by  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"z", " ", "=", " ", 
   RowBox[{
    FractionBox[
     RowBox[{"w", "+", "2", "-", 
      RowBox[{"3", "\[ImaginaryI]"}]}], 
     RowBox[{
      RowBox[{"-", "1"}], "+", "\[ImaginaryI]"}]], " ", "=", " ", 
    FractionBox[
     RowBox[{"u", "+", "2", "+", 
      RowBox[{"\[ImaginaryI]", 
       RowBox[{"(", 
        RowBox[{"v", "-", "3"}], ")"}]}]}], 
     RowBox[{
      RowBox[{"-", "1"}], "+", "\[ImaginaryI]"}]]}]}]]],
 ",  \n\nwhich we write as  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"x", "+", 
    RowBox[{"\[ImaginaryI]", " ", "y"}]}], " ", "=", " ", 
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{"-", "u"}], "+", "v", "-", "5"}], "2"], " ", "+", " ", 
    RowBox[{"\[ImaginaryI]", 
     FractionBox[
      RowBox[{
       RowBox[{"-", "u"}], "-", "v", "+", "1"}], "2"]}]}]}]]],
 ".  \n\nSubstituting  ",
 Cell[BoxData[
  RowBox[{"x", " ", "=", " ", 
   FractionBox[
    RowBox[{
     RowBox[{"-", "u"}], "+", "v", "-", "5"}], "2"]}]]],
 "  into  e  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Re", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{"x", ">", "1"}]}]]],
 "  gives  ",
 Cell[BoxData[
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{"-", "u"}], "+", "v", "-", "5"}], "2"], ">", "1"}]]],
 ",  which simplifies  ",
 Cell[BoxData[
  RowBox[{"v", ">", 
   RowBox[{"u", "+", "7"}]}]]],
 ".  Figure 2.11 illustrates the mapping."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 2.11.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell["Enter the function w = f[z].", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"w", ",", "x", ",", "y", ",", "z", ",", "Z"}], "]"}], ";"}], " ",
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "ineq1", ",", "ineq2", ",", "ineq3"}], "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"TagSet", "[", 
     RowBox[{"x", ",", 
      RowBox[{"Im", "[", "x", "]"}], ",", "0"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"TagSet", "[", 
     RowBox[{"y", ",", 
      RowBox[{"Im", "[", "y", "]"}], ",", "0"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"TagSet", "[", 
     RowBox[{"x", ",", 
      RowBox[{"Re", "[", "x", "]"}], ",", "x"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"TagSet", "[", 
     RowBox[{"y", ",", 
      RowBox[{"Re", "[", "y", "]"}], ",", "y"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], ":=", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[ImaginaryI]"}], ")"}], "z"}], "-", "2", 
      "+", 
      RowBox[{"3", "\[ImaginaryI]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<    f[\>\"", ",", "z", ",", "\"\<] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[\>\"", ",", 
      RowBox[{"x", " ", "+", " ", 
       RowBox[{"\[ImaginaryI]", " ", "y"}]}], ",", "\"\<] = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"x", " ", "+", " ", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[\>\"", ",", 
      RowBox[{"x", " ", "+", " ", 
       RowBox[{"\[ImaginaryI]", " ", "y"}]}], ",", "\"\<] = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.398977234765625*^9},
 AspectRatioFixed->True],

Cell["\<\
Solve for the inverse function, i.e. solve for  z  in terms of  w.  \
\>", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"solset", " ", "=", " ", 
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"w", " ", "\[Equal]", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], " ", "+", " ", "\[ImaginaryI]"}], ")"}], 
          "z"}], " ", "-", " ", "2", " ", "+", " ", 
         RowBox[{"3", "\[ImaginaryI]"}]}]}], ",", " ", "z"}], "]"}]}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"zz", " ", "=", " ", 
     SubscriptBox["solset", 
      RowBox[{"\[LeftDoubleBracket]", 
       RowBox[{"1", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"Z", " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{"zz", " ", ",", 
       RowBox[{"w", "\[Rule]", 
        RowBox[{"u", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "v"}]}]}]}], "]"}]}], ";"}], " ", "\n",
    
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"x", " ", "+", " ", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}]}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = \>\"", ",", 
      RowBox[{"Expand", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", "+", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<u = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"Re", "[", 
        RowBox[{"f", "[", 
         RowBox[{"x", "+", 
          RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], "]"}]}], "]"}],
     ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<v = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"Im", "[", 
        RowBox[{"f", "[", 
         RowBox[{"x", "+", 
          RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], "]"}]}], "]"}],
     ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "solset", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<z = \>\"", ",", "zz"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<z = \>\"", ",", "Z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<z = \>\"", ",", 
      RowBox[{"Expand", "[", "Z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<x = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"Re", "[", "Z", "]"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"Im", "[", "Z", "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39897723865625*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "To solve for ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Re", "[", "z", "]"}], ">", "1"}]]],
 " ,  we use the computations."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"Re", "[", "z", "]"}], " ", ">", " ", "1"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"x", " ", ">", " ", "1"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"ineq1", " ", "=", " ", 
      RowBox[{
       RowBox[{"ComplexExpand", "[", 
        RowBox[{"Re", "[", "Z", "]"}], "]"}], " ", ">", " ", "1"}]}], "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"ineq2", " ", "=", " ", 
      RowBox[{"MapAll", "[", 
       RowBox[{"Together", ",", "ineq1"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"ineq3", " ", "=", " ", 
      RowBox[{"Distribute", "[", 
       RowBox[{
        RowBox[{"2", " ", "ineq2"}], ",", " ", "Greater"}], "]"}]}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"Distribute", "[", 
      RowBox[{
       RowBox[{"ineq3", " ", "+", " ", "u", " ", "+", " ", "5"}], ",", " ", 
       "Greater"}], "]"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39897724296875*^9},
 AspectRatioFixed->True],

Cell["Or the following commands will also find the solution.", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"Re", "[", "z", "]"}], " ", ">", " ", "1"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"x", " ", ">", " ", "1"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"ineq", " ", "=", " ", 
      RowBox[{
       RowBox[{"ComplexExpand", "[", 
        RowBox[{"Re", "[", "Z", "]"}], "]"}], " ", ">", " ", "1"}]}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"solset", "=", 
     RowBox[{"Reduce", "[", 
      RowBox[{"ineq", ",", "v", ",", "Reals"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "solset", "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{
  3.398977247234375*^9, {3.400240211796875*^9, 3.400240215984375*^9}}],

Cell[TextData[{
 "Which is the right half plane  ",
 Cell[BoxData[
  RowBox[{"v", ">", 
   RowBox[{"u", "+", "7"}]}]]],
 "  in the w-plane.  Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to graph the transformation. "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], " ", "+", " ", "\[ImaginaryI]"}], ")"}], "z"}], 
      " ", "-", " ", "2", " ", "+", " ", 
      RowBox[{"3", "\[ImaginaryI]"}]}]}], ";"}], " ", "\n", 
   RowBox[{"RegionPlot", "[", 
    RowBox[{
     RowBox[{"x", ">", "1"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "1"}], ",", "6"}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"y", ",", " ", 
       RowBox[{"-", "1"}], ",", "6"}], "}"}], ",", 
     RowBox[{"GridLines", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{"0", ",", "Dashed"}], "}"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{"0", ",", "Dashed"}], "}"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "6", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "6", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", "Cyan", "}"}]}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The right half plane Re[z] > 1.\>\"", "]"}], 
    ";"}], " ", "\n", 
   RowBox[{"RegionPlot", "[", 
    RowBox[{
     RowBox[{"v", ">", 
      RowBox[{"u", "+", "7"}]}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"u", ",", " ", 
       RowBox[{"-", "10"}], ",", "2"}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"v", ",", " ", 
       RowBox[{"-", "2"}], ",", "10"}], "}"}], ",", 
     RowBox[{"GridLines", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{"0", ",", "Dashed"}], "}"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{"0", ",", "Dashed"}], "}"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "10"}], ",", "2", ",", "2"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"2", ",", "10", ",", "2"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", "Cyan", "}"}]}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The image is the half plane v > u + 7,\>\"", "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<under the mapping w = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.398977222515625*^9, 3.39897722784375*^9}, {
   3.39911987540625*^9, 3.39911990478125*^9}, {3.3997208184375*^9, 
   3.399720818625*^9}, 3.4002404853125*^9, {3.400240555375*^9, 
   3.400240608203125*^9}, {3.40024071034375*^9, 3.400240798640625*^9}, {
   3.400240904015625*^9, 3.40024093003125*^9}, {3.40024106971875*^9, 
   3.40024123859375*^9}},
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Iden", "[", "z_", "]"}], " ", "=", " ", "z"}], ";"}], " ", "\n",
    
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], " ", "+", " ", "\[ImaginaryI]"}], ")"}], "z"}], 
      " ", "-", " ", "2", " ", "+", " ", 
      RowBox[{"3", "\[ImaginaryI]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"CartesianMap", "[", 
    RowBox[{"Iden", ",", " ", 
     RowBox[{"{", 
      RowBox[{"1", ",", "5", ",", "0.5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "6"}], ",", "7", ",", "0.5"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "6"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "6"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "6", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "6", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", "\"\<The right half plane Re[z] > 1.\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{"CartesianMap", "[", 
    RowBox[{"f", ",", " ", 
     RowBox[{"{", 
      RowBox[{"1", ",", "5", ",", "0.5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "6"}], ",", "7", ",", "0.5"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "10"}], ",", "2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "10"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "10"}], ",", "2", ",", "2"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"2", ",", "10", ",", "2"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The image is the half plane v > u + 7,\>\"", "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<under the mapping w = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.398977251140625*^9, 3.39897725528125*^9}, {
  3.399119917015625*^9, 3.39911992053125*^9}, {3.399720823859375*^9, 
  3.39972082403125*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "We see that the image of the right half plane  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Re", "[", "z", "]"}], ">", "1"}]]],
 "  under the linear transformation  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "\[ImaginaryI]"}], ")"}], "z"}], " ", "-", 
    " ", "2", "+", 
    RowBox[{"3", "\[ImaginaryI]"}]}]}]]],
 "  is the half plane  ",
 Cell[BoxData[
  RowBox[{"v", ">", 
   RowBox[{"u", "+", "7"}]}]]],
 ".  "
}], "Text"]
}, Closed]],

Cell[GraphicsData["CompressedBitmap", "\<\
eJztXXuzFUcRH87Zc24SRCCXhwQSHjEQCAgEKYyamPfDSKxAWT4iKFJWQVkp
NInlH4Sgfg0/A39Z+R7mA1h+lOPZ5/T0dPf07Nm93HtnbsF57M6Zne3Hb37d
07t79dYXd/746a0v7t6+dey9z279+c7d258fe/feZ8tN0x3G7PiPMeZfx0z5
ebH82Lwslv8W35Qv5ZbhP98v32b18ZafDpQvhTGFuVLvf1C9TU09mEX9v2tZ
7ijsjh/A3xTubxaLSfl9b/npRvnpLaKD3xHbps1vC/Ny3f1fmzGWm8oNM3yg
6vvTYOBm8e/q/7x6nZqHDx9620Lt1pTttP1R7dYC7drze6M9t8WjTlS/6jRX
EEKcENsuQm2lLMSvO0HebC0XiGn5ecpL78vOsqdAVm2jPdtefkUtOyvDm527
UnbYSO0fScpqZuUEbO52FpMjphrWXL/8Q5aRa0prvik17/cf3De3srjIqbIR
0aSxsFJUrYX9PovMFdmTpGVh8KIImyC2neVrRTVulMN4y/r7Guj+kXeYm3GH
2UUQ0OXfE9tKQTt5xRCzzI0sQQYVWulNGju00vPt8LdZioQdBu0PvFfM8JMs
Rk+MBXblFhcdeyyFAOzxN3GC/FbDzY2NBwc6/80nz91GBY9QoECw+5qZqTAH
u09VMFx0n5DY7d7DKdOGuSNKIPqWdEGJd9uA5Ndbb3BD8IOEyPcS29Y51aBt
R1JXEsntKnQmqB/lIk/TitrXULxCrQqqXaI+NOkA2kzbaa76+6FlyiCLULlS
rRVytkAK3tlB1KQDtd3uNl+fu7oGVD6HcsF9xLZn6u7ulW//LE9ohjRb/v2o
MQfK2lQ8F6NOYcgB7kfbBNhhkd5vKpjsGrFtvo3NuCDOt7Jg8xRSmEtpBPZD
BZ97Ois+0PhNAz8TDn7Wu72J4r8MMEvPCJEjzgdZ31z2cZ3QRMq5FZ4K2ZkX
yxN+n7a/BzK+xk2igLCmKe0ldWSZPmPE6oB22efH7GznzRDrKWtBNneKrrjm
Pufa3i07nmWJexI/5BDEoe2+fX9SQbA4Vqjd1s5aRTdrlQPoWFui+i1cXbSc
KWYOAfECNpXl94/yvO1K/DAvrhXoEbf9aha/K34UPCDRecED7wh+4OySqZ/1
kLxd0Kp+5aizhq6ah9Rj0QewWjz+MFuLYy1esqSTa6tznn3EJlZ+mmXveupR
0lQ701dQ8VVyPh9kdbjqcJPywBM0kaiAs55zUED7ftaGq43jtFNgo2ZWpoZi
He9ltThqcYuChCgVLcG6rtA/gfNu1gfSRykxxVLUoikqMAeC7aAeImLdd3jV
2PJ5Y/Op5fve7a4fjauIlCom+TMj21Zqf5tXTtqV7S8YbbgB0zmDuxCCS+qq
D0ddBVYXddmICqyJjEZ/sJYzJW9mI6SN8JRjDKQxChmQobgOt/2NrDZVpsUG
DFikHjwDadcz+NTpKrTMFcrMvM5rLPUrcU77Jt66XEQaSTVfEDG3tv+fZJrr
qI1yIDdNNTfQD4Fea9ZLUyPJL6WMVmsur2U1ud4FUv+ESENe4+0PZMBsHV6Y
ZVmY/bpT16tZfa76/AxYowKeSc6A5pyYYyFmzDqrkNjknL7apciKw4o7q/Ib
7F/BWQz3I/ijFBsQ/V4uh10VIghXDaepS7BgXcubmuBa1dUT3EKI/V0/LIy6
qMTSUnpuXfb1fUJ3fa5nBquC5/Q8SWPBIYvW8DZF+2omukScuXdbhjRtempt
Gs8EFLVaKBchnYwM35bKxNRtC9x2wpm1cGuINFV63opOcNhNM+WgcVZ6vtDi
rVsOl2ckKviaI9IGAyxv/nG9d2Ycb1VwRO4qZzLjSAyrVfeFDn7zbTaQ/14S
/WPoUA3uD/mplO3i/PpyVi854+JYrcubWF+R6KUpTAy9LH+mrlmuylQbF2ba
lm2oyThpzV4mHSEqgxnJhKOZdsw4GpOgyDNcPa4WvCYpKhzOoW4uWceONUxa
3S9Rb8Y5Mezz5YB20XmnuTRxhXSMPjPs4DO4UNymncEv8ibwJaFuewkevhfi
nDsUTyhlAjpIUpMhoZSjSLfwucBLKe211ld0xhcRPlJOEBWeBma5PuHp+RBO
unUfqU6JTY7Uu5YBJSpt0lNDYkFKNdx+UicKhNl3QWVSZar7vQBEJrxsfyIq
HTsiuYUXqWi6jxp2YwfncshDBbOtKMUIU5kShvM7mayCbbtFE2buZ4ivhiTD
8Z7NanfV/qrOi7b4nI+/v5TNgIh/2VoAcqp2vF9m82xxLFGi4NcHxaSq6Qz6
clvWOHL812TH2uKRsDDuM9kSqJnf9c8ZSnYiHyNwQFklAa+81F6pYbl9TMp7
TrctzOkeBgCqJ15nHSKGh26WqgrNjIvG/WJ2IGLy9PNfIbMdI9FMFULHJ5rZ
hapTWfUudp4JOpPkjKus8IZABB3XXpi4+qRLDPtkNgzXMNwMOpCuRLW5OZSg
2jGJdupQqyba+eNNu/GVcjjaIGRhcnUXMpHnrSIjQt4hq7tgf3XxPr7ciu2/
xpP1QYd9rBLLzLGQyj6W3y+lbCkFdvcaCQogwer/pH+tspK1Lx6p2mtSeNhK
LF0SrrGubiQ56+AkV/3uNEbh5FaGpZSvBNupCQnybnVUA+xP1T7ASOC7tZPG
bwCM5LJTOvZv0KV2VRlWKDIxrVvZ2Lud1Ch/thOOElsaG1Hdtn/RXoUWXr2E
c25rMNYy6tGz1pL6WuGPaTkq3JV1Y44DEds5mGHhh4MZZjvRj6VHimE35jQJ
QE4uNyCSKCj2kFiBs4+IWah90kIkRiYfaWRkYpc5UP/Ybqbt8UA48BxvNjEP
tf1QNFjNdE1llMR3IqsUog1qGmBzzar2UQW7y3bP8kL/ivbV7V8URq8OuOlu
5G6YvDNEAP+OZRaadAj6nfoeasgCXHiQ77V5JCO7OhVG+mbNGN8hd/eFlGjI
6gMpWshaAWoxH83cc4EvlVv4BQdGKEMEKCQhjbePQ6/g5L8CuQCGw/cv3+z0
mRzqujD0c0P6MYMHnB+T/qrZvnoIMti4uX6k0OxQNieOF9liZrbkANImLfCw
kU8wHxKbb9mY28p+J1sQlbrVEo+aLL0dbAdVoSJMkanYMVO9UeOuzYp6GmfS
VlVgUsSuFUlkSSJEizHCsuHXk+xY5CtCDmQLci3oulH7t5tDD7ZPCJe6d+oJ
VBHVhhTNCKRYhuAYTZ/DcYxYDjPcHZGpx3gl7d+/IP2G9WvF9kHWesYMhJjt
Q65RUQ95TdnMIKw4sCNlgzd9joYPlXxY6n9vaepZzynbkvml73KLfrnYLZdD
btqNMu6mHfVk8qTNzZIuDykccsUHO6FiNg1Zo5BJE1xFB0tO4Dbcs+j2ZLNy
zerXhvNuLXps1cV45/gjo/XubHYsEYNwM3RljdTn8JU1tj20ERUEIt+R4kmK
uH2bt68HjbxNes/g+sT1yZGDLW0/IxYEytg01ipi088u3gZzoRLIXMnIJma2
MeoJYavNzA2b+YLISSPVxqzczRpYE+/wSz5/sPzDJYknRE+jxtUn7apoX5f0
Hg93C4c7UjbaXp6pJzsRYilaUAB6M7k2ecXrr8YI+6bO7yoT7RfzxS7AMbUL
7XUduoc7+UgiXMs1FYwSXtiFb12Zrh3uN2NAZ63g940WOrkp6bFg50asQNbH
mWhmwQeN8aZqoZEkjL9gFeak2FIFnBWjCF2Hbo51dEfQRKsipwMGOOhqJko0
tseirqLPVzUiK7xoWD9W4JaHOyFcQfsl3IopDa1x+Xx4fNJ2Cc9XDdIluTSm
OA3QzCTt02F6jYIA0xvrbkFy4KpikKAkJGIttQudxf67wNiSaLd9ga0RzAty
idc8G6ALkLcN5bjq0iktMK7QP1yYUvVfRDwxeMRxq1dmwHnOsnm65rmGROXc
gyyqYFQsmqMoXkT/LSKr+++gPha5H88DRfLjvJBZnjSU96pRJYImkvv5/us5
9il6WFTzsgEgyREkccBRe/tDQTm1GteHW9ry2toNtvN9jzVhs3QKbCxLnAIF
MNwpcLFs0gBzV+cK2KUCLoZdMkhnmGUkjUsG82oR+bqVxh3ov8+4m/x02rei
mzri0lAZTcDqpmXHfiIxWuqw6ekYpqhlljD7HX8rPHlVJmlLvKtfANXwkAD4
DNl/EuNuPCtpEy2w2LYc/mw1aJef/pP0nUL/5Kl5VRK1GUnalh938z3pOGjO
iS+4WIGi0tBixThRLx+461aLY5MK8rlT56JPLKzRiYXmXOpHqaZ+RyrzqREh
4PElBj1o6ZNieyzjRvsHHXezv34QbK505K4VgWLtlnA3w7JFzGNvaK7NVR1x
UNt71SnmgVWaB9c25f2u6sg7v94TbV/0jRhaFMCEKJ8NvW+ScUctNUeOu5XL
uTyx2myjx3ZYZHC9Hbjv+N67+mPsVq/wEfolVpf0gCuvE58FtuohU4pW+xcT
ggAJ+lahSSHo60OTNsO4vf0DjpuTy0vArKeJM0J6eZlhUdTyckxw6mAho6QO
w4TgFE8NVNDLEUFikV+fW+BPgYRh5hRiV9PPpJwx+pwUcQiihkz64f76JP20
EDXmuIP9rzBurVxOp2zKU0esEhEdY2klql+nT4hUBW47+pPpNKQdjjdE2v2l
MDk8fzFlk31l88Tmsf1HjNteL/74x11XfO5Xt4/JtVR9n0rZngtsG1J2YVMC
G103dF/xGD/MdnvPF7F3lF1hmR862vLzyZRt92++VazK+Cgs2yqMciPHHeh/
iLKAF1I2bbcsAIhnuGX+zRLqb+AlCfTdSDaieuC7AWMGt0E/LXrHmCvPMf3b
63BUXl0TyjfF5htWSKAhwuMuyD+fMLZ5lKnAzyIca82IZoqBJbNuuAX3GEi/
22YZKsh9aydiHmOy8gJf2+vQy/MnEjZeQ8MMXneMgRfNuzpeBuu66n4jxx0T
X48pF9u3Uo6xeZtl++Mpmzqe3B9xs6iHV+Uua4nBm66V3Ur3HJ+T+wI9w1wF
Qcy45S6bBA0kdpV9ujPQ1OkTdKjLEmjKFsp9WE/HUjbjdeN5thYZiO21td4h
25PIyCEUs51D7qhxM/1zyM0iekT/UeMOIb2ypEEY99GELT54ST6lWiqEZ8RM
hfAUQHdUNQzQCz+Kr3r2b4dHThDxT/sKVzvMkel2UE5268Qku1TZD1qUYIZY
9vFcwmZsrgG7UFI7JcWjsu1BoFNSTbiYoWkf03/UuK08NCtofYdd971v6GE/
Wxv+/a4iLdWiYBHEEbpIIC4h0RDZEQ7BV+s2uHQnwTr6nfZufri9ipizUpVT
KUeAmVfHsQZg0qvC/G9YGuj6j/9hmKhaX6+3UlXa1es1sN/+qtlaff7G//yw
O3y19XDztbszxd+5ox3CLanZvHo92J54AU68uzc4PkA3lIPdASbdp4tg0L4o
qw8f1d++6qRg3IcZVI2uykLhPpsd/wfa08Su\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{464, 155},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 StyleBox["\t\t\tFigure 2.11",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  The the linear transformation  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "\[ImaginaryI]"}], ")"}], "z"}], " ", "-", 
    " ", "2", "+", 
    RowBox[{"3", "\[ImaginaryI]"}]}]}]]],
 ".  "
}], "Text"],

Cell["\<\
The \"legacy version\" being used to implement the commands \"CartesianMap \
and PolarMap.\"  The following Initialization Cell will load these \
subroutines. \
\>", "Text",
 CellChangeTimes->{{3.399722161203125*^9, 3.399722165296875*^9}, {
  3.39972222759375*^9, 3.3997223229375*^9}, {3.399722389046875*^9, 
  3.399722641234375*^9}, {3.399722683734375*^9, 3.3997227230625*^9}, {
  3.3997227559375*^9, 3.399722850765625*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Initialization Cell",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text",
 CellChangeTimes->{{3.399722161203125*^9, 3.399722165296875*^9}, {
  3.39972222759375*^9, 3.3997223229375*^9}, {3.399722389046875*^9, 
  3.399722641234375*^9}, {3.399722683734375*^9, 3.3997227230625*^9}, {
  3.3997227559375*^9, 3.399722850765625*^9}, {3.399742279828125*^9, 
  3.39974228209375*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}]], "Input",\

 InitializationCell->True]
}, Closed]],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Graphics for Complex Functions",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/ComplexGraphicsBib.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Mobius - Bilinear Transformation",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/MobiusTranformationBib.html"],
    None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/complex.html"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2008 John H. Mathews, Russell W. \
Howell",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/"], None}],
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[0, 1, 0]]], "Text",
 CellChangeTimes->{{3.39897661809375*^9, 3.39897661821875*^9}}]
},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{994, 632},
WindowMargins->{{5, Automatic}, {Automatic, 2}},
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "CHAPTER 1"->{
  Cell[568, 21, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"CHAPTER 1", 251566, 7585}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"],
Cell[905, 32, 116, 2, 29, "Text"],
Cell[1024, 36, 96, 2, 29, "Text"],
Cell[1123, 40, 659, 10, 83, "Text"],
Cell[1785, 52, 121, 2, 29, "Text"],
Cell[1909, 56, 1535, 60, 65, "Text"],
Cell[3447, 118, 897, 26, 65, "Text"],
Cell[4347, 146, 307, 5, 47, "Text"],
Cell[4657, 153, 2359, 87, 263, "Text"],
Cell[7019, 242, 4035, 69, 241, "Text",
 Evaluatable->False],
Cell[11057, 313, 448, 18, 29, "Text"],
Cell[11508, 333, 244, 10, 29, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[11777, 347, 146, 4, 29, "Text",
 Evaluatable->False],
Cell[11926, 353, 324, 16, 29, "Text",
 Evaluatable->False],
Cell[12253, 371, 1968, 60, 252, "Input"],
Cell[14224, 433, 308, 13, 29, "Text",
 Evaluatable->False],
Cell[14535, 448, 2037, 61, 232, "Input"],
Cell[16575, 511, 356, 15, 29, "Text",
 Evaluatable->False],
Cell[16934, 528, 2488, 71, 272, "Input"],
Cell[19425, 601, 419, 15, 29, "Text",
 Evaluatable->False],
Cell[19847, 618, 1878, 52, 192, "Input"]
}, Closed]],
Cell[21740, 673, 105, 3, 26, "Text"],
Cell[21848, 678, 3942, 131, 292, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[25815, 813, 156, 4, 29, "Text",
 Evaluatable->False],
Cell[25974, 819, 52, 0, 29, "Text"],
Cell[26029, 821, 2695, 82, 369, "Input"],
Cell[28727, 905, 50, 0, 29, "Text"],
Cell[28780, 907, 3474, 99, 521, "Input"],
Cell[32257, 1008, 228, 8, 29, "Text"],
Cell[32488, 1018, 832, 21, 88, "Input"],
Cell[33323, 1041, 9091, 253, 632, "Input"],
Cell[42417, 1296, 3737, 108, 341, "Input"]
}, Closed]],
Cell[46169, 1407, 2192, 80, 137, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[48386, 1491, 156, 4, 29, "Text",
 Evaluatable->False],
Cell[48545, 1497, 52, 0, 29, "Text"],
Cell[48600, 1499, 3463, 102, 465, "Input"],
Cell[52066, 1603, 50, 0, 29, "Text"],
Cell[52119, 1605, 3782, 109, 489, "Input"],
Cell[55904, 1716, 228, 8, 29, "Text"],
Cell[56135, 1726, 3907, 109, 341, "Input"]
}, Closed]],
Cell[60057, 1838, 1404, 52, 123, "Text"],
Cell[61464, 1892, 2623, 89, 189, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[64112, 1985, 156, 4, 29, "Text",
 Evaluatable->False],
Cell[64271, 1991, 35, 0, 29, "Text"],
Cell[64309, 1993, 4105, 120, 475, "Input"],
Cell[68417, 2115, 228, 8, 29, "Text"],
Cell[68648, 2125, 3914, 110, 334, "Input"]
}, Closed]],
Cell[72577, 2238, 1837, 64, 155, "Text"],
Cell[74417, 2304, 4181, 138, 442, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[78623, 2446, 156, 4, 29, "Text",
 Evaluatable->False],
Cell[78782, 2452, 35, 0, 29, "Text"],
Cell[78820, 2454, 4980, 139, 464, "Input"]
}, Closed]],
Cell[83815, 2596, 1060, 34, 98, "Text"],
Cell[84878, 2632, 3322, 106, 259, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[88225, 2742, 156, 4, 29, "Text",
 Evaluatable->False],
Cell[88384, 2748, 35, 0, 29, "Text"],
Cell[88422, 2750, 4403, 124, 424, "Input"],
Cell[92828, 2876, 228, 8, 29, "Text"],
Cell[93059, 2886, 3477, 98, 314, "Input"],
Cell[96539, 2986, 3155, 88, 254, "Input"]
}, Closed]],
Cell[99709, 3077, 1782, 59, 188, "Text",
 Evaluatable->False],
Cell[101494, 3138, 2124, 90, 83, "Text"],
Cell[103621, 3230, 5914, 100, 307, "Text",
 Evaluatable->False],
Cell[109538, 3332, 533, 27, 29, "Text"],
Cell[110074, 3361, 2161, 84, 83, "Text"],
Cell[112238, 3447, 2166, 78, 101, "Text"],
Cell[114407, 3527, 1599, 29, 122, "Text",
 Evaluatable->False],
Cell[116009, 3558, 209, 8, 29, "Text"],
Cell[116221, 3568, 634, 23, 47, "Text"],
Cell[116858, 3593, 1221, 23, 122, "Text",
 Evaluatable->False],
Cell[118082, 3618, 152, 5, 29, "Text"],
Cell[118237, 3625, 2836, 111, 176, "Text"],
Cell[121076, 3738, 1277, 55, 47, "Text"],
Cell[122356, 3795, 1959, 84, 212, "Text"],
Cell[124318, 3881, 1332, 52, 89, "Text",
 Evaluatable->False],
Cell[125653, 3935, 821, 32, 47, "Text"],
Cell[CellGroupData[{
Cell[126499, 3971, 156, 4, 29, "Text",
 Evaluatable->False],
Cell[126658, 3977, 2361, 67, 305, "Input"]
}, Closed]],
Cell[129034, 4047, 883, 28, 44, "Text"],
Cell[129920, 4077, 5273, 187, 324, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[135218, 4268, 156, 4, 29, "Text",
 Evaluatable->False],
Cell[135377, 4274, 194, 8, 29, "Text"],
Cell[135574, 4284, 2076, 58, 252, "Input"],
Cell[137653, 4344, 135, 6, 29, "Text"],
Cell[137791, 4352, 3837, 112, 472, "Input"],
Cell[141631, 4466, 192, 8, 29, "Text"],
Cell[141826, 4476, 3956, 101, 292, "Input"],
Cell[145785, 4579, 410, 17, 29, "Text"]
}, Closed]],
Cell[146210, 4599, 1638, 50, 188, "Text"],
Cell[147851, 4651, 2775, 49, 241, "Text",
 Evaluatable->False],
Cell[150629, 4702, 579, 24, 29, "Text"],
Cell[151211, 4728, 2442, 70, 191, "Text"],
Cell[153656, 4800, 5694, 96, 249, "Text",
 Evaluatable->False],
Cell[159353, 4898, 428, 16, 29, "Text"],
Cell[159784, 4916, 4062, 124, 375, "Text",
 Evaluatable->False],
Cell[163849, 5042, 3726, 64, 200, "Text",
 Evaluatable->False],
Cell[167578, 5108, 821, 29, 47, "Text"],
Cell[CellGroupData[{
Cell[168424, 5141, 156, 4, 29, "Text",
 Evaluatable->False],
Cell[168583, 5147, 3798, 110, 275, "Input"]
}, Closed]],
Cell[172396, 5260, 1479, 45, 194, "Text"],
Cell[173878, 5307, 435, 16, 29, "Text"],
Cell[174316, 5325, 1885, 67, 143, "Text"],
Cell[176204, 5394, 640, 25, 29, "Text",
 Evaluatable->False],
Cell[176847, 5421, 2498, 86, 222, "Text"],
Cell[179348, 5509, 1409, 54, 119, "Text"],
Cell[180760, 5565, 862, 29, 53, "Text"],
Cell[181625, 5596, 1778, 32, 169, "Text",
 Evaluatable->False],
Cell[183406, 5630, 341, 13, 29, "Text"],
Cell[CellGroupData[{
Cell[183772, 5647, 156, 4, 29, "Text",
 Evaluatable->False],
Cell[183931, 5653, 232, 9, 29, "Text"],
Cell[184166, 5664, 2098, 59, 252, "Input"],
Cell[186267, 5725, 47, 0, 29, "Text"],
Cell[186317, 5727, 3772, 111, 472, "Input"],
Cell[190092, 5840, 208, 8, 29, "Text",
 Evaluatable->False],
Cell[190303, 5850, 1078, 32, 172, "Input"],
Cell[191384, 5884, 289, 11, 29, "Text",
 Evaluatable->False],
Cell[191676, 5897, 3400, 97, 292, "Input"],
Cell[195079, 5996, 467, 17, 29, "Text"]
}, Closed]],
Cell[195561, 6016, 627, 11, 62, "Text"],
Cell[196191, 6029, 306, 9, 29, "Text"],
Cell[196500, 6040, 3865, 133, 281, "Text",
 Evaluatable->False],
Cell[200368, 6175, 7691, 129, 169, "Text",
 Evaluatable->False],
Cell[208062, 6306, 460, 18, 29, "Text"],
Cell[CellGroupData[{
Cell[208547, 6328, 157, 4, 29, "Text",
 Evaluatable->False],
Cell[208707, 6334, 354, 14, 29, "Text"],
Cell[209064, 6350, 1617, 45, 172, "Input"],
Cell[210684, 6397, 185, 6, 29, "Text"],
Cell[210872, 6405, 1567, 46, 232, "Input"],
Cell[212442, 6453, 195, 7, 29, "Text"],
Cell[212640, 6462, 1104, 32, 152, "Input"],
Cell[213747, 6496, 504, 18, 29, "Text",
 Evaluatable->False],
Cell[214254, 6516, 4501, 126, 292, "Input"],
Cell[218758, 6644, 4143, 120, 390, "Input"],
Cell[222904, 6766, 932, 33, 47, "Text"]
}, Closed]],
Cell[223851, 6802, 2158, 78, 227, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[226034, 6884, 157, 4, 29, "Text",
 Evaluatable->False],
Cell[226194, 6890, 44, 0, 29, "Text"],
Cell[226241, 6892, 2183, 62, 252, "Input"],
Cell[228427, 6956, 92, 2, 29, "Text"],
Cell[228522, 6960, 3406, 100, 412, "Input"],
Cell[231931, 7062, 151, 6, 29, "Text"],
Cell[232085, 7070, 1471, 43, 212, "Input"],
Cell[233559, 7115, 70, 0, 29, "Text"],
Cell[233632, 7117, 1030, 30, 172, "Input"],
Cell[234665, 7149, 288, 11, 29, "Text",
 Evaluatable->False],
Cell[234956, 7162, 3598, 97, 212, "Input"],
Cell[238557, 7261, 3560, 101, 292, "Input"],
Cell[242120, 7364, 527, 20, 29, "Text"]
}, Closed]],
Cell[242662, 7387, 5694, 96, 166, "Text",
 Evaluatable->False],
Cell[248359, 7485, 391, 15, 29, "Text"],
Cell[248753, 7502, 435, 8, 29, "Text"],
Cell[CellGroupData[{
Cell[249213, 7514, 407, 7, 29, "Text"],
Cell[249623, 7523, 132, 4, 31, "Input",
 InitializationCell->True]
}, Closed]],
Cell[249770, 7530, 281, 7, 26, "Text"],
Cell[250054, 7539, 293, 7, 29, "Text"],
Cell[250350, 7548, 299, 7, 29, "Text"],
Cell[250652, 7557, 249, 5, 29, "Text"],
Cell[250904, 7564, 318, 7, 29, "Text"]
}
]
*)

(* End of internal cache information *)
