(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    268585,      10487]
NotebookOptionsPosition[    263634,      10331]
NotebookOutlinePosition[    264160,      10355]
CellTagsIndexPosition[    264085,      10350]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"],

Cell[TextData[{
 StyleBox["2.2  The Mappings ",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 Cell[BoxData[
  StyleBox[
   RowBox[{"w", "=", 
    SuperscriptBox["z", "n"]}],
   FontWeight->"Bold"]],
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[" and ",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 Cell[BoxData[
  StyleBox[
   RowBox[{"w", "=", 
    SuperscriptBox["z", 
     RowBox[{"1", "/", "n"}]]}],
   FontWeight->"Bold"]],
  FontColor->RGBColor[0, 0, 1]]
}], "Text"],

Cell[TextData[{
 "\n\tIn this section we turn our attention to power functions.  For ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{"r", " ", 
    SuperscriptBox["\[ExponentialE]", "\[ImaginaryI]\[Theta]"]}]}]]],
 ", we can express the function ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "=", 
    SuperscriptBox["z", "2"]}]}]]],
 " in polar coordinates by \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "=", 
    RowBox[{
     SuperscriptBox["z", "2"], "=", 
     RowBox[{
      SuperscriptBox["r", "2"], 
      SuperscriptBox["\[ExponentialE]", "\[ImaginaryI]2\[Theta]"]}]}]}]}]]],
 ".  \n\nIf we also use polar coordinates for ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{"\[Rho]", " ", 
    SuperscriptBox["\[ExponentialE]", "\[ImaginaryI]\[Phi]"]}]}]]],
 " in the w -plane, we can express this mapping by the system of equations \n\
\n\t\t\t",
 Cell[BoxData[
  RowBox[{"\[Rho]", "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["r", "2"], "  ", "and", "  ", "\[Phi]"}], "=", 
    RowBox[{"2", "\[Theta]"}]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "\tBecause an argument of the product  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"(", "z", ")"}], 
   RowBox[{"(", "z", ")"}]}]],
  CellChangeTimes->{3.399144690328125*^9}],
 "  is twice an argument of ",
 StyleBox["z",
  FontFamily->"Courier New"],
 ", we say that ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", "z", ")"}]}]]],
 " doubles angles at the origin.  Points that lie on the ray  ",
 Cell[BoxData[
  RowBox[{"r", ">", "0"}]]],
 ", ",
 Cell[BoxData[
  RowBox[{"\[Theta]", "=", "\[Alpha]"}]]],
 "  are mapped onto points that lie on the ray  ",
 Cell[BoxData[
  RowBox[{"\[Rho]", ">", "0"}]]],
 " , ",
 Cell[BoxData[
  RowBox[{"\[Phi]", "=", 
   RowBox[{"2", "\[Alpha]"}]}]]],
 ".  If we now restrict the domain of ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "=", 
    SuperscriptBox["z", "2"]}]}]]],
 " to the region  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"A", "=", 
   RowBox[{"{", 
    RowBox[{"r", " ", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", "\[ImaginaryI]\[Theta]"], ":", " ", 
      RowBox[{"r", ">", 
       RowBox[{"0", " ", "and", " ", 
        FractionBox[
         RowBox[{"-", "\[Pi]"}], "2"]}], "<", " ", "\[Theta]", "\[LessEqual]",
        
       FractionBox["\[Pi]", "2"]}]}]}], "}"}]}]]],
 ",  \n\nthen the image of ",
 StyleBox["A",
  FontFamily->"Courier New"],
 " under the mapping ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   SuperscriptBox["z", "2"]}]]],
 " can be described by the set  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"B", "=", 
   RowBox[{"{", 
    RowBox[{"\[Rho]", " ", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", "\[ImaginaryI]\[Phi]"], ":", " ", 
      RowBox[{"\[Rho]", ">", 
       RowBox[{
        RowBox[{"0", " ", "and"}], " ", "-", "\[Pi]"}], "<", " ", "\[Phi]", 
       "\[LessEqual]", "\[Pi]"}]}]}], "}"}]}]]],
 ",   \n\nwhich consists of all points in the ",
 StyleBox["w",
  FontFamily->"Courier New"],
 "-plane except the point ",
 StyleBox["w=0",
  FontFamily->"Courier New"],
 "."
}], "Text",
 CellChangeTimes->{
  3.398977329671875*^9, {3.39914469375*^9, 3.399144728703125*^9}, {
   3.399144769046875*^9, 3.39914477178125*^9}}],

Cell[TextData[{
 "\tThe inverse mapping of f, which we shall denote by ",
 Cell[BoxData[
  RowBox[{"g", 
   RowBox[{"(", "z", ")"}]}]]],
 ", is then\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{
    RowBox[{"g", 
     RowBox[{"(", "w", ")"}]}], "=", 
    RowBox[{
     SuperscriptBox["w", 
      RowBox[{"1", "/", "2"}]], "=", 
     RowBox[{
      SuperscriptBox["\[Rho]", 
       RowBox[{"1", "/", "2"}]], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]\[Phi]", "/", "2"}]]}]}]}]}]]],
 ", \n\nwhere  ",
 Cell[BoxData[
  RowBox[{"w", "\[Element]", "B"}]]],
 ".  That is\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{
    RowBox[{"g", 
     RowBox[{"(", "w", ")"}]}], "=", 
    RowBox[{
     SuperscriptBox["w", 
      RowBox[{"1", "/", "2"}]], "=", 
     RowBox[{"|", "w", 
      SuperscriptBox["|", 
       RowBox[{"1", "/", "2"}]], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]Arg", 
        RowBox[{
         RowBox[{"(", "w", ")"}], "/", "2"}]}]]}]}]}]}]]],
 ", \n\nwhere  ",
 Cell[BoxData[
  RowBox[{"w", "\[NotEqual]", "0"}]]],
 ".  The function g is so important that we call special attention to it with \
a formal definition."
}], "Text",
 CellChangeTimes->{{3.3991447839375*^9, 3.39914479128125*^9}}],

Cell[TextData[{
 StyleBox["Definition 2.1 (Principal ",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Square Root",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/SquareRoot.html"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 StyleBox[" Function).",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["  ",
  FontColor->RGBColor[0, 0, 1]],
 "The function",
 StyleBox[" \n\n\t\t\t",
  FontColor->RGBColor[0, 0, 1]],
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{
    RowBox[{"g", 
     RowBox[{"(", "w", ")"}]}], "=", 
    RowBox[{
     SuperscriptBox["w", 
      RowBox[{"1", "/", "2"}]], "=", 
     RowBox[{"|", "w", 
      SuperscriptBox["|", 
       RowBox[{"1", "/", "2"}]], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]Arg", 
        RowBox[{
         RowBox[{"(", "w", ")"}], "/", "2"}]}]]}]}]}]}]]],
 ",    for   ",
 Cell[BoxData[
  RowBox[{"w", "\[NotEqual]", "0"}]]],
 ".  \n\nis called the principal square root function."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "\tIt is left as an exercise to show that f and g satisfy equations  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"g", 
    RowBox[{"(", 
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], ")"}]}], "=", "z"}]],
  CellChangeTimes->{3.39897734709375*^9}],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", 
     RowBox[{"g", 
      RowBox[{"(", "w", ")"}]}], ")"}]}], "=", "w"}]],
  CellChangeTimes->{{3.39897734709375*^9, 3.398977358625*^9}}],
 ",  and thus are inverses of each other that map the set A one-to-one and \
onto the set B and the set B one-to-one and onto the set A, respectively.  \
Figure 2.12. illustrates this relationship. "
}], "Text",
 CellChangeTimes->{{3.398977350796875*^9, 3.3989773874375*^9}}],

Cell[TextData[{
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.309017 0.309017 [
[1.025 .30902 0 -6.28125 ]
[1.025 .30902 10 6.28125 ]
[.5 .64303 -8 0 ]
[.5 .64303 8 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 .30902 m
.5 -0.30902 L
.75882 -0.28796 L
.5 .30902 L
F
0 .5 .95 r
.5 .30902 m
.75882 -0.28796 L
1 -0.22622 L
.5 .30902 L
F
0 .9 1 r
.5 .30902 m
1 -0.22622 L
1.20711 -0.128 L
.5 .30902 L
F
1 0 0 r
.5 .30902 m
1.20711 -0.128 L
1.36603 0 L
.5 .30902 L
F
.9 .45 .45 r
.5 .30902 m
1.36603 0 L
1.46593 .14906 L
.5 .30902 L
F
1 .75 .75 r
.5 .30902 m
1.46593 .14906 L
1.5 .30902 L
.5 .30902 L
F
0 1 0 r
.5 .30902 m
1.5 .30902 L
1.46593 .46898 L
.5 .30902 L
F
0 .95 0 r
.5 .30902 m
1.46593 .46898 L
1.36603 .61803 L
.5 .30902 L
F
.45 .95 .45 r
.5 .30902 m
1.36603 .61803 L
1.20711 .74603 L
.5 .30902 L
F
1 .5 0 r
.5 .30902 m
1.20711 .74603 L
1 .84425 L
.5 .30902 L
F
1 .6 0 r
.5 .30902 m
1 .84425 L
.75882 .90599 L
.5 .30902 L
F
1 1 0 r
.5 .30902 m
.75882 .90599 L
.5 .92705 L
.5 .30902 L
F
0 0 0 r
.5 Mabswid
0 .30902 m
1 .30902 L
s
.01 w
.5 .30902 m
.5 .61803 L
s
[ .025 .025 ] 0 setdash
.5 .30902 m
.5 0 L
s
0 g
gsave
1 .32447 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
77.375 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.47 .63348 -61 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
77.375 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1, -1, 0, 0}}],
 StyleBox["       ",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.309017 0.309017 [
[1.025 .30902 0 -6.28125 ]
[1.025 .30902 10 6.28125 ]
[.5 .64303 -8 0 ]
[.5 .64303 8 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 .30902 m
-0.5 .30902 L
-0.36603 0 L
.5 .30902 L
F
0 .5 .95 r
.5 .30902 m
-0.36603 0 L
0 -0.22622 L
.5 .30902 L
F
0 .9 1 r
.5 .30902 m
0 -0.22622 L
.5 -0.30902 L
.5 .30902 L
F
1 0 0 r
.5 .30902 m
.5 -0.30902 L
1 -0.22622 L
.5 .30902 L
F
.9 .45 .45 r
.5 .30902 m
1 -0.22622 L
1.36603 0 L
.5 .30902 L
F
1 .75 .75 r
.5 .30902 m
1.36603 0 L
1.5 .30902 L
.5 .30902 L
F
0 1 0 r
.5 .30902 m
1.5 .30902 L
1.36603 .61803 L
.5 .30902 L
F
0 .95 0 r
.5 .30902 m
1.36603 .61803 L
1 .84425 L
.5 .30902 L
F
.45 .95 .45 r
.5 .30902 m
1 .84425 L
.5 .92705 L
.5 .30902 L
F
1 .5 0 r
.5 .30902 m
.5 .92705 L
0 .84425 L
.5 .30902 L
F
1 .6 0 r
.5 .30902 m
0 .84425 L
-0.36603 .61803 L
.5 .30902 L
F
1 1 0 r
.5 .30902 m
-0.36603 .61803 L
-0.5 .30902 L
.5 .30902 L
F
0 0 0 r
.5 Mabswid
0 .30902 m
1 .30902 L
s
.5 .30902 m
.5 .61803 L
s
.5 .30902 m
.5 0 L
s
0 g
gsave
1 .32447 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(u) show
77.375 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.47 .63348 -61 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(v) show
77.375 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1, -1, 0, 0}}],
 StyleBox["  \n\t\tFigure 2.12",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  The mapping   ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "=", 
    SuperscriptBox["z", "2"]}]}]]],
 "   (and  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{
    RowBox[{"g", 
     RowBox[{"(", "w", ")"}]}], "=", 
    SuperscriptBox["w", 
     RowBox[{"1", "/", "2"}]]}]}]]],
 ").  "
}], "Text"],

Cell[TextData[{
 "\tWhat are the images of rectangles under the mapping ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   SuperscriptBox["z", "2"]}]]],
 "?  To find out, we make use of the Cartesian form  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{"u", "+", 
     RowBox[{"\[ImaginaryI]", " ", "v"}]}], "=", 
    RowBox[{
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], "=", 
     SuperscriptBox["z", "2"]}]}]}]]],
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{"=", 
    RowBox[{
     RowBox[{
      SuperscriptBox["x", "2"], "-", 
      SuperscriptBox["y", "2"], "+", 
      RowBox[{"\[ImaginaryI]", " ", "2", " ", "x", " ", "y"}]}], "=", 
     " "}]}]}]]],
 Cell[BoxData[
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["x", "2"], "-", 
      SuperscriptBox["y", "2"]}], ",", 
     RowBox[{"2", " ", "x", " ", "y"}]}], ")"}], "=", 
   RowBox[{"(", 
    RowBox[{"u", ",", "v"}], ")"}]}]]],
 "\n\nand the resulting system of equations  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"u", "=", 
     RowBox[{
      SuperscriptBox["x", "2"], "-", 
      SuperscriptBox["y", "2"]}]}], 
    StyleBox[",",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], 
    StyleBox["  ",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], 
    StyleBox["and",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"v", "=", 
   RowBox[{"2", " ", "x", " ", 
    RowBox[{"y", " ", 
     StyleBox[".",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]]}]}]}]}]],
 "   "
}], "Text"],

Cell[TextData[{
 StyleBox["Example 2.12.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Show that the transformation  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "=", 
    SuperscriptBox["z", "2"]}]}]]],
 ",  usually maps vertical and horizontal lines onto parabolas and use this \
fact to find the image of the rectangle ",
 Cell[BoxData[
  RowBox[{"R", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"x", ",", "y"}], ")"}], ":", " ", 
      RowBox[{"0", "<", "x", "<", "a"}]}], ",", 
     RowBox[{"0", "<", "y", "<", "b"}]}], "}"}]}]]],
 ".  ",
 StyleBox["(a)",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 " Find the image of the vertical line  ",
 Cell[BoxData[
  RowBox[{"x", "=", "a"}]]],
 ".  ",
 StyleBox["(b)",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 " Find the image of the horizontal line  ",
 Cell[BoxData[
  RowBox[{"y", "=", "b"}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "Solution.  Using the above equations, we determine that the vertical line  \
",
 Cell[BoxData[
  RowBox[{"x", "=", "a"}]]],
 "  is mapped onto the set of points given by the equations  ",
 Cell[BoxData[
  RowBox[{"u", "=", 
   RowBox[{
    SuperscriptBox["a", "2"], "-", 
    SuperscriptBox["y", "2"]}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{"v", "=", 
   RowBox[{"2", " ", "a", " ", "y"}]}]]],
 ".  If  ",
 Cell[BoxData[
  RowBox[{"a", " ", "\[NotEqual]", "0"}]]],
 ",  then  ",
 Cell[BoxData[
  RowBox[{"y", "=", 
   FractionBox["v", 
    RowBox[{"2", " ", "a"}]]}]]],
 "  and  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"u", " ", "=", " ", 
   RowBox[{
    SuperscriptBox["a", "2"], " ", "-", " ", 
    FractionBox[
     SuperscriptBox["v", "2"], 
     RowBox[{"4", " ", 
      SuperscriptBox["a", "2"]}]]}]}]]],
 ",  \n\nthis equation represents a parabola with vertex at  ",
 Cell[BoxData[
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["a", "2"], ",", "0"}], ")"}]]],
 ",  oriented horizontally, and opening to the left.  If  ",
 Cell[BoxData[
  RowBox[{"a", " ", ">", "0"}]]],
 ",  the set  ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"u", ",", "v"}], ")"}], ":", " ", "u"}], "=", 
     RowBox[{
      SuperscriptBox["a", "2"], "-", 
      SuperscriptBox["y", "2"]}]}], ",", 
    RowBox[{"v", "=", 
     RowBox[{"2", "a", " ", "y"}]}]}], "}"}]]],
 "  has  ",
 Cell[BoxData[
  RowBox[{"v", ">", "0"}]]],
 "  precisely when  ",
 Cell[BoxData[
  RowBox[{"y", ">", "0"}]]],
 ",  so the part of the line  ",
 Cell[BoxData[
  RowBox[{"x", "=", "a"}]]],
 "  lying above the x axis is mapped to the top half of the parabola.  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "\tThe horizontal line  ",
 Cell[BoxData[
  RowBox[{"y", "=", "b"}]]],
 "  is mapped onto the parabola given by the equations  ",
 Cell[BoxData[
  RowBox[{"u", "=", 
   RowBox[{
    SuperscriptBox["x", "2"], "-", 
    SuperscriptBox["b", "2"]}]}]]],
 "  and   ",
 Cell[BoxData[
  RowBox[{"v", "=", 
   RowBox[{"2", "  ", "x", " ", "b"}]}]]],
 ".  If  ",
 Cell[BoxData[
  RowBox[{"b", " ", "\[NotEqual]", "0"}]]],
 ",  then as before we get  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"v", " ", "=", " ", 
   RowBox[{
    RowBox[{"-", " ", 
     SuperscriptBox["b", "2"]}], " ", "+", " ", 
    FractionBox[
     SuperscriptBox["v", "2"], 
     RowBox[{"4", " ", 
      SuperscriptBox["b", "2"]}]]}]}]]],
 ",   \n\nthis equation represents a parabola with vertex at  ",
 Cell[BoxData[
  RowBox[{"-", " ", 
   SuperscriptBox["b", "2"]}]]],
 ",  oriented horizontally and opening to the right.  If  ",
 Cell[BoxData[
  RowBox[{"b", " ", ">", "0"}]]],
 ",  the part of the line  ",
 Cell[BoxData[
  RowBox[{"y", "=", "b"}]]],
 "  to the right of the y axis is mapped to the top half of the parabola \
because the set  ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"u", ",", "v"}], ")"}], ":", " ", "u"}], "=", 
     RowBox[{
      SuperscriptBox["x", "2"], "-", 
      SuperscriptBox["b", "2"]}]}], ",", 
    RowBox[{"v", "=", 
     RowBox[{"2", "b", " ", "x"}]}]}], "}"}]]],
 "  has  ",
 Cell[BoxData[
  RowBox[{"v", ">", "0"}]]],
 " precisely when  ",
 Cell[BoxData[
  RowBox[{"x", ">", "0"}]]],
 "."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "\tQuadrant I is mapped onto quadrants I and II by  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   SuperscriptBox["z", "2"]}]]],
 ",  so the rectangle  ",
 Cell[BoxData[
  RowBox[{"R", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"x", ",", "y"}], ")"}], ":", " ", 
      RowBox[{"0", "<", "x", "<", "a"}]}], ",", 
     RowBox[{"0", "<", "y", "<", "b"}]}], "}"}]}]]],
 "  is mapped onto the region bounded by the top halves of the parabolas \
given by ",
 Cell[BoxData[
  RowBox[{"u", "=", 
   RowBox[{
    SuperscriptBox["a", "2"], "-", 
    FractionBox[
     SuperscriptBox["v", "2"], 
     RowBox[{"4", " ", 
      SuperscriptBox["a", "2"]}]]}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{"v", "=", 
   RowBox[{
    RowBox[{"-", " ", 
     SuperscriptBox["b", "2"]}], "+", 
    FractionBox[
     SuperscriptBox["v", "2"], 
     RowBox[{"4", " ", 
      SuperscriptBox["b", "2"]}]]}]}]]],
 " and the ",
 StyleBox["u",
  FontFamily->"Courier New"],
 " axis. The vertices  ",
 Cell[BoxData[
  RowBox[{"0", ",", 
   SuperscriptBox["a", "2"], ",", 
   RowBox[{
    SuperscriptBox["a", "2"], "+", 
    RowBox[{"2", " ", "\[ImaginaryI]", " ", "a", " ", "b"}], "-", 
    SuperscriptBox["b", "2"]}], ",", " ", 
   RowBox[{
    StyleBox["and",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], " ", "-", 
    SuperscriptBox["b", "2"]}]}]]],
 "  of the rectangle are mapped onto the four points ",
 Cell[BoxData[
  RowBox[{"0", ",", 
   SuperscriptBox["a", "2"], ",", 
   RowBox[{
    SuperscriptBox["a", "2"], "-", 
    SuperscriptBox["b", "2"], "+", 
    RowBox[{"2", " ", "\[ImaginaryI]", " ", "a", " ", "b"}]}], ",", " ", 
   RowBox[{
    StyleBox["and",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], " ", "-", 
    SuperscriptBox["b", "2"]}]}]]],
 ",  respectively, as indicated in Figure 2.13."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "\tFinally, we can easily verify that the vertical line  ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"0", ",", "y"}], ")"}], ":", " ", 
    RowBox[{
     RowBox[{"-", "\[Infinity]"}], "<", "y", "<", "\[Infinity]"}]}], "}"}]]],
 "  is mapped to the set ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", " ", 
       SuperscriptBox["y", "2"]}], ",", "0"}], ")"}], ":", " ", 
    RowBox[{
     RowBox[{"-", "\[Infinity]"}], "<", "y", "<", "\[Infinity]"}]}], "}"}]]],
 ".  This is simply the set of non-positive real numbers.  Similarly, the \
horizontal line  ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"x", ",", "0"}], ")"}], ":", " ", 
    RowBox[{
     RowBox[{"-", "\[Infinity]"}], "<", "x", "<", "\[Infinity]"}]}], "}"}]]],
 "  is mapped to the set ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["x", "2"], ",", "0"}], ")"}], ":", " ", 
    RowBox[{
     RowBox[{"-", "\[Infinity]"}], "<", "x", "<", "\[Infinity]"}]}], "}"}]]],
 ", which is the set of non-negative real numbers."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 3.14286 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0714286 1.42857 0.142857 1.42857 [
[.42857 .13036 -11.0938 -20.125 ]
[.42857 .13036 11.0938 0 ]
[.78571 .13036 -11.0938 -20.125 ]
[.78571 .13036 11.0938 0 ]
[1.025 .14286 0 -6.28125 ]
[1.025 .14286 10 6.28125 ]
[.05893 1.57143 -16 -6.28125 ]
[.05893 1.57143 0 6.28125 ]
[.05893 3 -16 -6.28125 ]
[.05893 3 0 6.28125 ]
[.07143 3.16786 -5 0 ]
[.07143 3.16786 5 12.5625 ]
[ 0 0 0 0 ]
[ 1 3.14286 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.42857 .14286 m
.42857 .14911 L
s
gsave
.42857 .13036 -72.0938 -24.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.063 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
66.063 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
64.750 17.063 moveto
(\\200\\200) show
69.000 17.063 moveto
(\\200) show
71.063 17.063 moveto
(\\200) show
66.063 23.125 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
81.188 17.063 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.78571 .14286 m
.78571 .14911 L
s
gsave
.78571 .13036 -72.0938 -24.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.063 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
66.063 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
64.750 17.063 moveto
(\\200\\200) show
69.000 17.063 moveto
(\\200) show
71.063 17.063 moveto
(\\200) show
66.063 23.125 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
81.188 17.063 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .14286 m
1 .14286 L
s
gsave
1.025 .14286 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.07143 1.57143 m
.07768 1.57143 L
s
gsave
.05893 1.57143 -77 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.07143 3 m
.07768 3 L
s
gsave
.05893 3 -77 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.07143 0 m
.07143 3.14286 L
s
gsave
.07143 3.16786 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 3.14286 L
0 3.14286 L
closepath
clip
newpath
.5 .165 .165 r
.5 Mabswid
.07143 .14286 m
.07143 .25876 L
.07143 .38517 L
.07143 .50388 L
.07143 .61805 L
.07143 .73958 L
.07143 .85656 L
.07143 .98089 L
.07143 1.10068 L
.07143 1.21593 L
.07143 1.33853 L
.07143 1.45658 L
.07143 1.57008 L
.07143 1.69095 L
.07143 1.80726 L
.07143 1.93093 L
.07143 2.05006 L
.07143 2.16464 L
.07143 2.28658 L
.07143 2.40396 L
.07143 2.52871 L
.07143 2.64891 L
.07143 2.76456 L
.07143 2.88757 L
.07143 3 L
s
1 0 1 r
.25 .14286 m
.25 .25876 L
.25 .38517 L
.25 .50388 L
.25 .61805 L
.25 .73958 L
.25 .85656 L
.25 .98089 L
.25 1.10068 L
.25 1.21593 L
.25 1.33853 L
.25 1.45658 L
.25 1.57008 L
.25 1.69095 L
.25 1.80726 L
.25 1.93093 L
.25 2.05006 L
.25 2.16464 L
.25 2.28658 L
.25 2.40396 L
.25 2.52871 L
.25 2.64891 L
.25 2.76456 L
.25 2.88757 L
.25 3 L
s
.5 .165 .165 r
.42857 .14286 m
.42857 .25876 L
.42857 .38517 L
.42857 .50388 L
.42857 .61805 L
.42857 .73958 L
.42857 .85656 L
.42857 .98089 L
.42857 1.10068 L
.42857 1.21593 L
.42857 1.33853 L
.42857 1.45658 L
.42857 1.57008 L
.42857 1.69095 L
.42857 1.80726 L
.42857 1.93093 L
.42857 2.05006 L
.42857 2.16464 L
.42857 2.28658 L
.42857 2.40396 L
.42857 2.52871 L
.42857 2.64891 L
.42857 2.76456 L
.42857 2.88757 L
.42857 3 L
s
1 0 1 r
.60714 .14286 m
.60714 .25876 L
.60714 .38517 L
.60714 .50388 L
.60714 .61805 L
.60714 .73958 L
.60714 .85656 L
.60714 .98089 L
.60714 1.10068 L
.60714 1.21593 L
.60714 1.33853 L
.60714 1.45658 L
.60714 1.57008 L
.60714 1.69095 L
.60714 1.80726 L
.60714 1.93093 L
.60714 2.05006 L
.60714 2.16464 L
.60714 2.28658 L
.60714 2.40396 L
.60714 2.52871 L
.60714 2.64891 L
.60714 2.76456 L
.60714 2.88757 L
.60714 3 L
s
.5 .165 .165 r
.78571 .14286 m
.78571 .25876 L
.78571 .38517 L
.78571 .50388 L
.78571 .61805 L
.78571 .73958 L
.78571 .85656 L
.78571 .98089 L
.78571 1.10068 L
.78571 1.21593 L
.78571 1.33853 L
.78571 1.45658 L
.78571 1.57008 L
.78571 1.69095 L
.78571 1.80726 L
.78571 1.93093 L
.78571 2.05006 L
.78571 2.16464 L
.78571 2.28658 L
.78571 2.40396 L
.78571 2.52871 L
.78571 2.64891 L
.78571 2.76456 L
.78571 2.88757 L
.78571 3 L
s
.07143 .14286 m
.1004 .14286 L
.13201 .14286 L
.16169 .14286 L
.19023 .14286 L
.22061 .14286 L
.24985 .14286 L
.28094 .14286 L
.31089 .14286 L
.3397 .14286 L
.37035 .14286 L
.39986 .14286 L
.42824 .14286 L
.45845 .14286 L
.48753 .14286 L
.51845 .14286 L
.54823 .14286 L
.57687 .14286 L
.60736 .14286 L
.63671 .14286 L
.66789 .14286 L
.69794 .14286 L
.72686 .14286 L
.75761 .14286 L
.78571 .14286 L
s
1 0 1 r
.07143 .28571 m
.1004 .28571 L
.13201 .28571 L
.16169 .28571 L
.19023 .28571 L
.22061 .28571 L
.24985 .28571 L
.28094 .28571 L
.31089 .28571 L
.3397 .28571 L
.37035 .28571 L
.39986 .28571 L
.42824 .28571 L
.45845 .28571 L
.48753 .28571 L
.51845 .28571 L
.54823 .28571 L
.57687 .28571 L
.60736 .28571 L
.63671 .28571 L
.66789 .28571 L
.69794 .28571 L
.72686 .28571 L
.75761 .28571 L
.78571 .28571 L
s
.5 .165 .165 r
.07143 .42857 m
.1004 .42857 L
.13201 .42857 L
.16169 .42857 L
.19023 .42857 L
.22061 .42857 L
.24985 .42857 L
.28094 .42857 L
.31089 .42857 L
.3397 .42857 L
.37035 .42857 L
.39986 .42857 L
.42824 .42857 L
.45845 .42857 L
.48753 .42857 L
.51845 .42857 L
.54823 .42857 L
.57687 .42857 L
.60736 .42857 L
.63671 .42857 L
.66789 .42857 L
.69794 .42857 L
.72686 .42857 L
.75761 .42857 L
.78571 .42857 L
s
1 0 1 r
.07143 .57143 m
.1004 .57143 L
.13201 .57143 L
.16169 .57143 L
.19023 .57143 L
.22061 .57143 L
.24985 .57143 L
.28094 .57143 L
.31089 .57143 L
.3397 .57143 L
.37035 .57143 L
.39986 .57143 L
.42824 .57143 L
.45845 .57143 L
.48753 .57143 L
.51845 .57143 L
.54823 .57143 L
.57687 .57143 L
.60736 .57143 L
.63671 .57143 L
.66789 .57143 L
.69794 .57143 L
.72686 .57143 L
.75761 .57143 L
.78571 .57143 L
s
.5 .165 .165 r
.07143 .71429 m
.1004 .71429 L
.13201 .71429 L
.16169 .71429 L
.19023 .71429 L
.22061 .71429 L
.24985 .71429 L
.28094 .71429 L
.31089 .71429 L
.3397 .71429 L
.37035 .71429 L
.39986 .71429 L
.42824 .71429 L
.45845 .71429 L
.48753 .71429 L
.51845 .71429 L
.54823 .71429 L
.57687 .71429 L
.60736 .71429 L
.63671 .71429 L
.66789 .71429 L
.69794 .71429 L
.72686 .71429 L
.75761 .71429 L
.78571 .71429 L
s
1 0 1 r
.07143 .85714 m
.1004 .85714 L
.13201 .85714 L
.16169 .85714 L
.19023 .85714 L
.22061 .85714 L
.24985 .85714 L
.28094 .85714 L
.31089 .85714 L
.3397 .85714 L
.37035 .85714 L
.39986 .85714 L
.42824 .85714 L
.45845 .85714 L
.48753 .85714 L
.51845 .85714 L
.54823 .85714 L
.57687 .85714 L
.60736 .85714 L
.63671 .85714 L
.66789 .85714 L
.69794 .85714 L
.72686 .85714 L
.75761 .85714 L
.78571 .85714 L
s
.5 .165 .165 r
.07143 1 m
.1004 1 L
.13201 1 L
.16169 1 L
.19023 1 L
.22061 1 L
.24985 1 L
.28094 1 L
.31089 1 L
.3397 1 L
.37035 1 L
.39986 1 L
.42824 1 L
.45845 1 L
.48753 1 L
.51845 1 L
.54823 1 L
.57687 1 L
.60736 1 L
.63671 1 L
.66789 1 L
.69794 1 L
.72686 1 L
.75761 1 L
.78571 1 L
s
1 0 1 r
.07143 1.14286 m
.1004 1.14286 L
.13201 1.14286 L
.16169 1.14286 L
.19023 1.14286 L
.22061 1.14286 L
.24985 1.14286 L
.28094 1.14286 L
.31089 1.14286 L
.3397 1.14286 L
.37035 1.14286 L
.39986 1.14286 L
.42824 1.14286 L
.45845 1.14286 L
.48753 1.14286 L
.51845 1.14286 L
.54823 1.14286 L
.57687 1.14286 L
.60736 1.14286 L
.63671 1.14286 L
.66789 1.14286 L
.69794 1.14286 L
.72686 1.14286 L
.75761 1.14286 L
.78571 1.14286 L
s
.5 .165 .165 r
.07143 1.28571 m
.1004 1.28571 L
.13201 1.28571 L
.16169 1.28571 L
.19023 1.28571 L
.22061 1.28571 L
.24985 1.28571 L
.28094 1.28571 L
.31089 1.28571 L
.3397 1.28571 L
.37035 1.28571 L
.39986 1.28571 L
.42824 1.28571 L
.45845 1.28571 L
.48753 1.28571 L
.51845 1.28571 L
.54823 1.28571 L
.57687 1.28571 L
.60736 1.28571 L
.63671 1.28571 L
.66789 1.28571 L
.69794 1.28571 L
.72686 1.28571 L
.75761 1.28571 L
.78571 1.28571 L
s
1 0 1 r
.07143 1.42857 m
.1004 1.42857 L
.13201 1.42857 L
.16169 1.42857 L
.19023 1.42857 L
.22061 1.42857 L
.24985 1.42857 L
.28094 1.42857 L
.31089 1.42857 L
.3397 1.42857 L
.37035 1.42857 L
.39986 1.42857 L
.42824 1.42857 L
.45845 1.42857 L
.48753 1.42857 L
.51845 1.42857 L
.54823 1.42857 L
.57687 1.42857 L
.60736 1.42857 L
.63671 1.42857 L
.66789 1.42857 L
.69794 1.42857 L
.72686 1.42857 L
.75761 1.42857 L
.78571 1.42857 L
s
.5 .165 .165 r
.07143 1.57143 m
.1004 1.57143 L
.13201 1.57143 L
.16169 1.57143 L
.19023 1.57143 L
.22061 1.57143 L
.24985 1.57143 L
.28094 1.57143 L
.31089 1.57143 L
.3397 1.57143 L
.37035 1.57143 L
.39986 1.57143 L
.42824 1.57143 L
.45845 1.57143 L
.48753 1.57143 L
.51845 1.57143 L
.54823 1.57143 L
.57687 1.57143 L
.60736 1.57143 L
.63671 1.57143 L
.66789 1.57143 L
.69794 1.57143 L
.72686 1.57143 L
.75761 1.57143 L
.78571 1.57143 L
s
1 0 1 r
.07143 1.71429 m
.1004 1.71429 L
.13201 1.71429 L
.16169 1.71429 L
.19023 1.71429 L
.22061 1.71429 L
.24985 1.71429 L
.28094 1.71429 L
.31089 1.71429 L
.3397 1.71429 L
.37035 1.71429 L
.39986 1.71429 L
.42824 1.71429 L
.45845 1.71429 L
.48753 1.71429 L
.51845 1.71429 L
.54823 1.71429 L
.57687 1.71429 L
.60736 1.71429 L
.63671 1.71429 L
.66789 1.71429 L
.69794 1.71429 L
.72686 1.71429 L
.75761 1.71429 L
.78571 1.71429 L
s
.5 .165 .165 r
.07143 1.85714 m
.1004 1.85714 L
.13201 1.85714 L
.16169 1.85714 L
.19023 1.85714 L
.22061 1.85714 L
.24985 1.85714 L
.28094 1.85714 L
.31089 1.85714 L
.3397 1.85714 L
.37035 1.85714 L
.39986 1.85714 L
.42824 1.85714 L
.45845 1.85714 L
.48753 1.85714 L
.51845 1.85714 L
.54823 1.85714 L
.57687 1.85714 L
.60736 1.85714 L
.63671 1.85714 L
.66789 1.85714 L
.69794 1.85714 L
.72686 1.85714 L
.75761 1.85714 L
.78571 1.85714 L
s
1 0 1 r
.07143 2 m
.1004 2 L
.13201 2 L
.16169 2 L
.19023 2 L
.22061 2 L
.24985 2 L
.28094 2 L
.31089 2 L
.3397 2 L
.37035 2 L
.39986 2 L
.42824 2 L
.45845 2 L
.48753 2 L
.51845 2 L
.54823 2 L
.57687 2 L
.60736 2 L
.63671 2 L
.66789 2 L
.69794 2 L
.72686 2 L
.75761 2 L
.78571 2 L
s
.5 .165 .165 r
.07143 2.14286 m
.1004 2.14286 L
.13201 2.14286 L
.16169 2.14286 L
.19023 2.14286 L
.22061 2.14286 L
.24985 2.14286 L
.28094 2.14286 L
.31089 2.14286 L
.3397 2.14286 L
.37035 2.14286 L
.39986 2.14286 L
.42824 2.14286 L
.45845 2.14286 L
.48753 2.14286 L
.51845 2.14286 L
.54823 2.14286 L
.57687 2.14286 L
.60736 2.14286 L
.63671 2.14286 L
.66789 2.14286 L
.69794 2.14286 L
.72686 2.14286 L
.75761 2.14286 L
.78571 2.14286 L
s
1 0 1 r
.07143 2.28571 m
.1004 2.28571 L
.13201 2.28571 L
.16169 2.28571 L
.19023 2.28571 L
.22061 2.28571 L
.24985 2.28571 L
.28094 2.28571 L
.31089 2.28571 L
.3397 2.28571 L
.37035 2.28571 L
.39986 2.28571 L
.42824 2.28571 L
.45845 2.28571 L
.48753 2.28571 L
.51845 2.28571 L
.54823 2.28571 L
.57687 2.28571 L
.60736 2.28571 L
.63671 2.28571 L
.66789 2.28571 L
.69794 2.28571 L
.72686 2.28571 L
.75761 2.28571 L
.78571 2.28571 L
s
.5 .165 .165 r
.07143 2.42857 m
.1004 2.42857 L
.13201 2.42857 L
.16169 2.42857 L
.19023 2.42857 L
.22061 2.42857 L
.24985 2.42857 L
.28094 2.42857 L
.31089 2.42857 L
.3397 2.42857 L
.37035 2.42857 L
.39986 2.42857 L
.42824 2.42857 L
.45845 2.42857 L
.48753 2.42857 L
.51845 2.42857 L
.54823 2.42857 L
.57687 2.42857 L
.60736 2.42857 L
.63671 2.42857 L
.66789 2.42857 L
.69794 2.42857 L
.72686 2.42857 L
.75761 2.42857 L
.78571 2.42857 L
s
1 0 1 r
.07143 2.57143 m
.1004 2.57143 L
.13201 2.57143 L
.16169 2.57143 L
.19023 2.57143 L
.22061 2.57143 L
.24985 2.57143 L
.28094 2.57143 L
.31089 2.57143 L
.3397 2.57143 L
.37035 2.57143 L
.39986 2.57143 L
.42824 2.57143 L
.45845 2.57143 L
.48753 2.57143 L
.51845 2.57143 L
.54823 2.57143 L
.57687 2.57143 L
.60736 2.57143 L
.63671 2.57143 L
.66789 2.57143 L
.69794 2.57143 L
.72686 2.57143 L
.75761 2.57143 L
.78571 2.57143 L
s
.5 .165 .165 r
.07143 2.71429 m
.1004 2.71429 L
.13201 2.71429 L
.16169 2.71429 L
.19023 2.71429 L
.22061 2.71429 L
.24985 2.71429 L
.28094 2.71429 L
.31089 2.71429 L
.3397 2.71429 L
.37035 2.71429 L
.39986 2.71429 L
.42824 2.71429 L
.45845 2.71429 L
.48753 2.71429 L
.51845 2.71429 L
.54823 2.71429 L
.57687 2.71429 L
.60736 2.71429 L
.63671 2.71429 L
.66789 2.71429 L
.69794 2.71429 L
.72686 2.71429 L
.75761 2.71429 L
.78571 2.71429 L
s
1 0 1 r
.07143 2.85714 m
.1004 2.85714 L
.13201 2.85714 L
.16169 2.85714 L
.19023 2.85714 L
.22061 2.85714 L
.24985 2.85714 L
.28094 2.85714 L
.31089 2.85714 L
.3397 2.85714 L
.37035 2.85714 L
.39986 2.85714 L
.42824 2.85714 L
.45845 2.85714 L
.48753 2.85714 L
.51845 2.85714 L
.54823 2.85714 L
.57687 2.85714 L
.60736 2.85714 L
.63671 2.85714 L
.66789 2.85714 L
.69794 2.85714 L
.72686 2.85714 L
.75761 2.85714 L
.78571 2.85714 L
s
.5 .165 .165 r
.07143 3 m
.1004 3 L
.13201 3 L
.16169 3 L
.19023 3 L
.22061 3 L
.24985 3 L
.28094 3 L
.31089 3 L
.3397 3 L
.37035 3 L
.39986 3 L
.42824 3 L
.45845 3 L
.48753 3 L
.51845 3 L
.54823 3 L
.57687 3 L
.60736 3 L
.63671 3 L
.66789 3 L
.69794 3 L
.72686 3 L
.75761 3 L
.78571 3 L
s
0 1 0 r
.1 w
.78571 .14286 Mdot
1 0 0 r
.78571 3 Mdot
0 0 1 r
.07143 3 Mdot
0 g
gsave
.81429 .21429 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.1 3.1 -61 -10.3438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.6875 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.938 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.938 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
77.375 12.938 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.64286 3.1 -61 -10.3438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.6875 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.938 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.938 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
70.188 12.938 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
77.375 12.938 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
91.750 12.938 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{91.625, 287.875},
  ImageMargins->{{24, 0}, {0, 7}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\
eJztnNtOGzEQhp09JCHQkkChJQQ1FW2lgqjKS5Qg1CfgKkKV4KJqRbnvo7s7
tpn17tqhLakTnN8Sa8cz48+etXeEZM2X6d3112/Tu5ur6fjsdvrj+ubq5/jz
99uiK20JIS6FaL0eC2rL4qd5XAopJQmfYvWOqpTWsU2tjFojLXqvKiVTLfrb
cvQdaPVDqnISvHAojSwlkVVERdl1WOxr4duaqAQ0RhlZS0qoY4dbB5VFv6Gq
S/19bg1d3uk75jX5J1GfvbPNrX2/usvPO34nRT3EgN/iLrcKFaUv9Skc+q2P
zbY2r6BibUqmf23wATgRv46O2mSzUcqrWzCvEgt9Jq6ZPilko+8hvTY9FXng
WEv2f6CdP3bRvMldw5PanzkfyfmjXHqJeuYVH9+verBy00h5/6/o2tVh2woH
fWWhTkl3uBg2UECtDOqUJDhoQAEVDQrBEyigAqAQPIECKi4UgidQQAVAIXgC
BVRcKARPoICKC4U4DRRQAVAInkCtJCqlSt156IaD5kZk37RYBrwdbpd1jmHw
6pKVun3Vi3LbA/XEUAjQQAEVFwr/3QIFVAAUgidQQMWFQvAECqgAKARPoICK
C4XgCRRQcaEQp4ECKgAKwRMooOJCIXgCtWQoun0ie48AmIw+knMypVRlfNeJ
WvIxKzDJioqR9yyAcFzaaVPHBxqwTer2JZuaesdSV61S3XUlqMMLOXZPppGZ
bI19e1L3T/PSj207I6OYypyzTj0qd1ZeJm3y6XX9g7lSXM1KzbM3Q+by8N+O
3wkz1YQ9t8AJDvmELMpzSTlo1eLlvF6zl5D7p1u+nKR2qkxR+17Z9B5SNVt/
5MB8cvTpD4/5BtRnVZSPPsG6NjTpA5/z0i90x6bD7tzvgYnbisq5RWh+b4z0
GTvIfBnuy6QyzYgq0foNJ9V/3g==\
\>"],
  ImageRangeCache->{{{0, 90.625}, {286.875, 0}} -> {-0.176181, -0.486165, 
  0.0104643, 0.0104643}}],
 "       ",
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .6 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.888889 0.222222 0.133333 0.222222 [
[.22222 .12083 -6 -9 ]
[.22222 .12083 6 0 ]
[.44444 .12083 -6 -9 ]
[.44444 .12083 6 0 ]
[.66667 .12083 -6 -9 ]
[.66667 .12083 6 0 ]
[.94444 .12083 -11.0938 -20.125 ]
[.94444 .12083 11.0938 0 ]
[1.025 .13333 0 -6.28125 ]
[1.025 .13333 10 6.28125 ]
[.87639 .35556 -6 -4.5 ]
[.87639 .35556 0 4.5 ]
[.87639 .57778 -6 -4.5 ]
[.87639 .57778 0 4.5 ]
[.88889 .625 -5 0 ]
[.88889 .625 5 12.5625 ]
[ 0 0 0 0 ]
[ 1 .6 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.22222 .13333 m
.22222 .13958 L
s
[(-3)] .22222 .12083 0 1 Mshowa
.44444 .13333 m
.44444 .13958 L
s
[(-2)] .44444 .12083 0 1 Mshowa
.66667 .13333 m
.66667 .13958 L
s
[(-1)] .66667 .12083 0 1 Mshowa
.94444 .13333 m
.94444 .13958 L
s
gsave
.94444 .12083 -72.0938 -24.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.063 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
66.063 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
64.750 17.063 moveto
(\\200\\200) show
69.000 17.063 moveto
(\\200) show
71.063 17.063 moveto
(\\200) show
66.063 23.125 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
81.188 17.063 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .13333 m
1 .13333 L
s
gsave
1.025 .13333 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(u) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.88889 .35556 m
.89514 .35556 L
s
[(1)] .87639 .35556 1 0 Mshowa
.88889 .57778 m
.89514 .57778 L
s
[(2)] .87639 .57778 1 0 Mshowa
.88889 0 m
.88889 .6 L
s
gsave
.88889 .625 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(v) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .6 L
0 .6 L
closepath
clip
newpath
.5 .165 .165 r
.5 Mabswid
.88889 .13333 m
.88743 .13333 L
.8825 .13333 L
.8747 .13333 L
.8643 .13333 L
.85012 .13333 L
.83342 .13333 L
.81242 .13333 L
.78899 .13333 L
.76351 .13333 L
.73322 .13333 L
.70096 .13333 L
.66708 .13333 L
.62793 .13333 L
.58724 .13333 L
.54075 .13333 L
.49281 .13333 L
.44379 .13333 L
.38849 .13333 L
.33218 .13333 L
.26906 .13333 L
.20503 .13333 L
.14046 .13333 L
.06858 .13333 L
0 .13333 L
s
1 0 1 r
.89236 .13333 m
.89236 .13347 L
.89236 .1336 L
.89235 .13374 L
.89234 .13388 L
.89232 .13412 L
.89228 .13438 L
.89223 .13467 L
.89217 .13498 L
.89201 .13553 L
.89181 .1361 L
.89158 .13663 L
.8909 .13784 L
.88999 .13908 L
.88896 .14021 L
.88597 .14276 L
.88261 .14497 L
.87814 .14739 L
.86692 .15213 L
.85306 .1567 L
.83505 .16155 L
.81448 .16622 L
.79172 .17072 L
.76432 .1755 L
.73482 .18011 L
.70357 .18454 L
.66719 .18926 L
.62915 .1938 L
.58546 .19862 L
.5402 .20327 L
.49373 .20774 L
.44112 .2125 L
.38738 .21708 L
.33287 .22148 L
.27175 .22618 L
.20994 .23069 L
.14099 .23549 L
.07145 .24011 L
.00347 .24444 L
s
.5 .165 .165 r
.90278 .13333 m
.90278 .13361 L
.90277 .13386 L
.90277 .13415 L
.90276 .13442 L
.90273 .1349 L
.9027 .13543 L
.90265 .13601 L
.90258 .13662 L
.90243 .13772 L
.90223 .13886 L
.902 .13992 L
.90131 .14235 L
.9004 .14482 L
.89937 .14708 L
.89638 .15218 L
.89303 .15661 L
.88855 .16145 L
.87734 .17093 L
.86348 .18006 L
.84546 .18976 L
.8249 .19911 L
.80214 .20811 L
.77474 .21767 L
.74524 .22689 L
.71398 .23575 L
.67761 .24518 L
.63957 .25426 L
.59588 .26391 L
.55062 .27321 L
.50414 .28215 L
.45153 .29167 L
.3978 .30083 L
.34329 .30964 L
.28217 .31902 L
.22036 .32804 L
.15141 .33764 L
.08187 .34689 L
.01389 .35556 L
s
1 0 1 r
.92014 .13333 m
.92014 .13374 L
.92013 .13412 L
.92013 .13455 L
.92012 .13496 L
.92009 .13569 L
.92006 .13647 L
.92001 .13734 L
.91994 .13826 L
.91979 .13992 L
.91959 .14162 L
.91936 .14322 L
.91868 .14686 L
.91776 .15057 L
.91674 .15396 L
.91375 .1616 L
.91039 .16825 L
.90591 .1755 L
.8947 .18973 L
.88084 .20342 L
.86282 .21798 L
.84226 .232 L
.8195 .24549 L
.7921 .25984 L
.7626 .27366 L
.73134 .28695 L
.69497 .3011 L
.65693 .31472 L
.61324 .3292 L
.56798 .34314 L
.5215 .35656 L
.4689 .37083 L
.41516 .38457 L
.36065 .39779 L
.29953 .41186 L
.23772 .4254 L
.16877 .4398 L
.09923 .45367 L
.03125 .46667 L
s
.5 .165 .165 r
.94444 .13333 m
.94444 .13388 L
.94444 .13438 L
.94443 .13496 L
.94442 .1355 L
.9444 .13647 L
.94437 .13752 L
.94432 .13868 L
.94425 .13991 L
.9441 .14211 L
.94389 .14438 L
.94366 .14651 L
.94298 .15136 L
.94207 .15631 L
.94104 .16084 L
.93805 .17103 L
.93469 .17989 L
.93022 .18956 L
.919 .20852 L
.90514 .22679 L
.88713 .24619 L
.86656 .26489 L
.84381 .28288 L
.81641 .30201 L
.7869 .32044 L
.75565 .33816 L
.71927 .35703 L
.68123 .37518 L
.63754 .39448 L
.59228 .41308 L
.54581 .43097 L
.4932 .45 L
.43947 .46832 L
.38496 .48594 L
.32383 .5047 L
.26202 .52275 L
.19308 .54195 L
.12354 .56044 L
.05556 .57778 L
s
.88889 .13333 m
.88898 .13333 L
.88929 .13333 L
.88978 .13333 L
.89043 .13333 L
.89131 .13333 L
.89236 .13333 L
.89367 .13333 L
.89513 .13333 L
.89673 .13333 L
.89862 .13333 L
.90063 .13333 L
.90275 .13333 L
.9052 .13333 L
.90774 .13333 L
.91065 .13333 L
.91364 .13333 L
.91671 .13333 L
.92016 .13333 L
.92368 .13333 L
.92763 .13333 L
.93163 .13333 L
.93567 .13333 L
.94016 .13333 L
.94444 .13333 L
s
1 0 1 r
.88667 .13333 m
.88667 .13336 L
.88667 .13339 L
.88667 .13341 L
.88667 .13344 L
.88667 .13349 L
.88667 .13354 L
.88667 .1336 L
.88668 .13366 L
.88669 .13377 L
.8867 .13389 L
.88672 .13399 L
.88676 .13423 L
.88682 .13448 L
.88688 .13471 L
.88707 .13522 L
.88728 .13566 L
.88756 .13614 L
.88826 .13709 L
.88912 .13801 L
.89025 .13898 L
.89153 .13991 L
.89296 .14081 L
.89467 .14177 L
.89651 .14269 L
.89847 .14357 L
.90074 .14452 L
.90312 .14543 L
.90585 .14639 L
.90868 .14732 L
.91158 .14821 L
.91487 .14917 L
.91823 .15008 L
.92163 .15096 L
.92545 .1519 L
.92932 .1528 L
.93363 .15376 L
.93797 .15469 L
.94222 .15556 L
s
.5 .165 .165 r
.88 .13333 m
.88 .13339 L
.88 .13344 L
.88 .1335 L
.88 .13355 L
.88 .13365 L
.88 .13375 L
.88001 .13387 L
.88001 .13399 L
.88002 .13421 L
.88003 .13444 L
.88005 .13465 L
.88009 .13514 L
.88015 .13563 L
.88021 .13608 L
.8804 .1371 L
.88061 .13799 L
.88089 .13896 L
.88159 .14085 L
.88246 .14268 L
.88358 .14462 L
.88487 .14649 L
.88629 .14829 L
.888 .1502 L
.88985 .15204 L
.8918 .15382 L
.89407 .1557 L
.89645 .15752 L
.89918 .15945 L
.90201 .16131 L
.90491 .1631 L
.9082 .165 L
.91156 .16683 L
.91497 .16859 L
.91879 .17047 L
.92265 .17228 L
.92696 .1742 L
.93131 .17604 L
.93556 .17778 L
s
1 0 1 r
.86889 .13333 m
.86889 .13342 L
.86889 .13349 L
.86889 .13358 L
.86889 .13366 L
.86889 .1338 L
.86889 .13396 L
.8689 .13414 L
.8689 .13432 L
.86891 .13465 L
.86892 .13499 L
.86894 .13531 L
.86898 .13604 L
.86904 .13678 L
.8691 .13746 L
.86929 .13899 L
.8695 .14032 L
.86978 .14177 L
.87048 .14461 L
.87135 .14735 L
.87247 .15026 L
.87376 .15307 L
.87518 .15577 L
.87689 .15864 L
.87874 .1614 L
.88069 .16406 L
.88296 .16689 L
.88534 .16961 L
.88807 .17251 L
.8909 .1753 L
.8938 .17798 L
.89709 .18083 L
.90045 .18358 L
.90386 .18622 L
.90768 .18904 L
.91154 .19175 L
.91585 .19463 L
.9202 .1974 L
.92444 .2 L
s
.5 .165 .165 r
.85333 .13333 m
.85333 .13344 L
.85333 .13354 L
.85333 .13366 L
.85333 .13377 L
.85334 .13396 L
.85334 .13417 L
.85334 .1344 L
.85335 .13465 L
.85335 .13509 L
.85337 .13554 L
.85338 .13597 L
.85342 .13694 L
.85348 .13793 L
.85355 .13883 L
.85373 .14087 L
.85394 .14264 L
.85422 .14458 L
.85492 .14837 L
.85579 .15202 L
.85692 .1559 L
.8582 .15964 L
.85962 .16324 L
.86134 .16707 L
.86318 .17075 L
.86513 .1743 L
.86741 .17807 L
.86978 .1817 L
.87251 .18556 L
.87534 .18928 L
.87825 .19286 L
.88154 .19667 L
.88489 .20033 L
.8883 .20385 L
.89212 .20761 L
.89598 .21122 L
.90029 .21506 L
.90464 .21876 L
.90889 .22222 L
s
1 0 1 r
.83333 .13333 m
.83333 .13347 L
.83333 .1336 L
.83333 .13374 L
.83333 .13388 L
.83334 .13412 L
.83334 .13438 L
.83334 .13467 L
.83335 .13498 L
.83335 .13553 L
.83337 .1361 L
.83338 .13663 L
.83342 .13784 L
.83348 .13908 L
.83355 .14021 L
.83373 .14276 L
.83394 .14497 L
.83422 .14739 L
.83492 .15213 L
.83579 .1567 L
.83692 .16155 L
.8382 .16622 L
.83962 .17072 L
.84134 .1755 L
.84318 .18011 L
.84513 .18454 L
.84741 .18926 L
.84978 .1938 L
.85251 .19862 L
.85534 .20327 L
.85825 .20774 L
.86154 .2125 L
.86489 .21708 L
.8683 .22148 L
.87212 .22618 L
.87598 .23069 L
.88029 .23549 L
.88464 .24011 L
.88889 .24444 L
s
.5 .165 .165 r
.80889 .13333 m
.80889 .1335 L
.80889 .13365 L
.80889 .13382 L
.80889 .13398 L
.80889 .13427 L
.80889 .13459 L
.8089 .13494 L
.8089 .13531 L
.80891 .13597 L
.80892 .13665 L
.80894 .13729 L
.80898 .13874 L
.80904 .14023 L
.8091 .14158 L
.80929 .14464 L
.8095 .1473 L
.80978 .1502 L
.81048 .15589 L
.81135 .16137 L
.81247 .16719 L
.81376 .1728 L
.81518 .1782 L
.81689 .18394 L
.81874 .18947 L
.82069 .19478 L
.82296 .20044 L
.82534 .20589 L
.82807 .21168 L
.8309 .21726 L
.8338 .22262 L
.83709 .22833 L
.84045 .23383 L
.84386 .23912 L
.84768 .24474 L
.85154 .25016 L
.85585 .25592 L
.8602 .26147 L
.86444 .26667 L
s
1 0 1 r
.78 .13333 m
.78 .13353 L
.78 .1337 L
.78 .1339 L
.78 .13409 L
.78 .13443 L
.78 .1348 L
.78001 .1352 L
.78001 .13563 L
.78002 .13641 L
.78003 .1372 L
.78005 .13795 L
.78009 .13964 L
.78015 .14138 L
.78021 .14296 L
.7804 .14653 L
.78061 .14963 L
.78089 .15301 L
.78159 .15965 L
.78246 .16604 L
.78358 .17283 L
.78487 .17938 L
.78629 .18567 L
.788 .19237 L
.78985 .19882 L
.7918 .20502 L
.79407 .21163 L
.79645 .21798 L
.79918 .22474 L
.80201 .23124 L
.80491 .2375 L
.8082 .24417 L
.81156 .25058 L
.81497 .25675 L
.81879 .26331 L
.82265 .26963 L
.82696 .27635 L
.83131 .28282 L
.83556 .28889 L
s
.5 .165 .165 r
.74667 .13333 m
.74667 .13355 L
.74667 .13375 L
.74667 .13398 L
.74667 .1342 L
.74667 .13459 L
.74667 .13501 L
.74667 .13547 L
.74668 .13596 L
.74669 .13684 L
.7467 .13775 L
.74672 .13861 L
.74676 .14055 L
.74682 .14252 L
.74688 .14433 L
.74707 .14841 L
.74728 .15195 L
.74756 .15582 L
.74826 .16341 L
.74912 .17071 L
.75025 .17848 L
.75153 .18596 L
.75296 .19315 L
.75467 .20081 L
.75651 .20818 L
.75847 .21526 L
.76074 .22281 L
.76312 .23007 L
.76585 .23779 L
.76868 .24523 L
.77158 .25239 L
.77487 .26 L
.77823 .26733 L
.78163 .27438 L
.78545 .28188 L
.78932 .2891 L
.79363 .29678 L
.79797 .30418 L
.80222 .31111 L
s
1 0 1 r
.70889 .13333 m
.70889 .13358 L
.70889 .1338 L
.70889 .13406 L
.70889 .13431 L
.70889 .13475 L
.70889 .13522 L
.7089 .13574 L
.7089 .13629 L
.70891 .13728 L
.70892 .13831 L
.70894 .13926 L
.70898 .14145 L
.70904 .14367 L
.7091 .14571 L
.70929 .1503 L
.7095 .15428 L
.70978 .15863 L
.71048 .16717 L
.71135 .17539 L
.71247 .18412 L
.71376 .19253 L
.71518 .20063 L
.71689 .20924 L
.71874 .21753 L
.72069 .22551 L
.72296 .23399 L
.72534 .24217 L
.72807 .25085 L
.7309 .25922 L
.7338 .26727 L
.73709 .27583 L
.74045 .28408 L
.74386 .29201 L
.74768 .30045 L
.75154 .30857 L
.75585 .31721 L
.7602 .32553 L
.76444 .33333 L
s
.5 .165 .165 r
.66667 .13333 m
.66667 .13361 L
.66667 .13386 L
.66667 .13415 L
.66667 .13442 L
.66667 .1349 L
.66667 .13543 L
.66667 .13601 L
.66668 .13662 L
.66669 .13772 L
.6667 .13886 L
.66672 .13992 L
.66676 .14235 L
.66682 .14482 L
.66688 .14708 L
.66707 .15218 L
.66728 .15661 L
.66756 .16145 L
.66826 .17093 L
.66912 .18006 L
.67025 .18976 L
.67153 .19911 L
.67296 .20811 L
.67467 .21767 L
.67651 .22689 L
.67847 .23575 L
.68074 .24518 L
.68312 .25426 L
.68585 .26391 L
.68868 .27321 L
.69158 .28215 L
.69487 .29167 L
.69823 .30083 L
.70163 .30964 L
.70545 .31902 L
.70932 .32804 L
.71363 .33764 L
.71797 .34689 L
.72222 .35556 L
s
1 0 1 r
.62 .13333 m
.62 .13364 L
.62 .13391 L
.62 .13423 L
.62 .13453 L
.62 .13506 L
.62 .13564 L
.62001 .13627 L
.62001 .13695 L
.62002 .13816 L
.62003 .13941 L
.62005 .14058 L
.62009 .14325 L
.62015 .14597 L
.62021 .14846 L
.6204 .15406 L
.62061 .15894 L
.62089 .16426 L
.62159 .17469 L
.62246 .18473 L
.62358 .1954 L
.62487 .20569 L
.62629 .21558 L
.628 .22611 L
.62985 .23624 L
.6318 .24599 L
.63407 .25636 L
.63645 .26635 L
.63918 .27697 L
.64201 .28719 L
.64491 .29703 L
.6482 .3075 L
.65156 .31758 L
.65497 .32727 L
.65879 .33759 L
.66265 .34752 L
.66696 .35807 L
.67131 .36824 L
.67556 .37778 L
s
.5 .165 .165 r
.56889 .13333 m
.56889 .13366 L
.56889 .13396 L
.56889 .13431 L
.56889 .13463 L
.56889 .13522 L
.56889 .13585 L
.5689 .13654 L
.5689 .13728 L
.56891 .1386 L
.56892 .13996 L
.56894 .14124 L
.56898 .14415 L
.56904 .14712 L
.5691 .14983 L
.56929 .15595 L
.5695 .16126 L
.56978 .16707 L
.57048 .17845 L
.57135 .1894 L
.57247 .20105 L
.57376 .21227 L
.57518 .22306 L
.57689 .23454 L
.57874 .2456 L
.58069 .25623 L
.58296 .26755 L
.58534 .27844 L
.58807 .29002 L
.5909 .30118 L
.5938 .31191 L
.59709 .32333 L
.60045 .33433 L
.60386 .3449 L
.60768 .35615 L
.61154 .36699 L
.61585 .37851 L
.6202 .3896 L
.62444 .4 L
s
1 0 1 r
.51333 .13333 m
.51333 .13369 L
.51333 .13401 L
.51333 .13439 L
.51333 .13474 L
.51334 .13537 L
.51334 .13606 L
.51334 .13681 L
.51335 .13761 L
.51335 .13904 L
.51337 .14052 L
.51338 .1419 L
.51342 .14505 L
.51348 .14827 L
.51355 .15121 L
.51373 .15783 L
.51394 .16359 L
.51422 .16988 L
.51492 .18221 L
.51579 .19408 L
.51692 .20669 L
.5182 .21884 L
.51962 .23054 L
.52134 .24298 L
.52318 .25495 L
.52513 .26647 L
.52741 .27873 L
.52978 .29054 L
.53251 .30308 L
.53534 .31517 L
.53825 .32679 L
.54154 .33917 L
.54489 .35108 L
.5483 .36253 L
.55212 .37472 L
.55598 .38646 L
.56029 .39894 L
.56464 .41096 L
.56889 .42222 L
s
.5 .165 .165 r
.45333 .13333 m
.45333 .13372 L
.45333 .13407 L
.45333 .13447 L
.45333 .13485 L
.45334 .13553 L
.45334 .13627 L
.45334 .13708 L
.45335 .13794 L
.45335 .13948 L
.45337 .14107 L
.45338 .14256 L
.45342 .14595 L
.45348 .14942 L
.45355 .15259 L
.45373 .15972 L
.45394 .16592 L
.45422 .17269 L
.45492 .18597 L
.45579 .19875 L
.45692 .21233 L
.4582 .22542 L
.45962 .23801 L
.46134 .25141 L
.46318 .26431 L
.46513 .27671 L
.46741 .28992 L
.46978 .30263 L
.47251 .31614 L
.47534 .32916 L
.47825 .34168 L
.48154 .355 L
.48489 .36783 L
.4883 .38016 L
.49212 .39329 L
.49598 .40593 L
.50029 .41937 L
.50464 .43231 L
.50889 .44444 L
s
1 0 1 r
.38889 .13333 m
.38889 .13374 L
.38889 .13412 L
.38889 .13455 L
.38889 .13496 L
.38889 .13569 L
.38889 .13647 L
.3889 .13734 L
.3889 .13826 L
.38891 .13992 L
.38892 .14162 L
.38894 .14322 L
.38898 .14686 L
.38904 .15057 L
.3891 .15396 L
.38929 .1616 L
.3895 .16825 L
.38978 .1755 L
.39048 .18973 L
.39135 .20342 L
.39247 .21798 L
.39376 .232 L
.39518 .24549 L
.39689 .25984 L
.39874 .27366 L
.40069 .28695 L
.40296 .3011 L
.40534 .31472 L
.40807 .3292 L
.4109 .34314 L
.4138 .35656 L
.41709 .37083 L
.42045 .38457 L
.42386 .39779 L
.42768 .41186 L
.43154 .4254 L
.43585 .4398 L
.4402 .45367 L
.44444 .46667 L
s
.5 .165 .165 r
.32 .13333 m
.32 .13377 L
.32 .13417 L
.32 .13463 L
.32 .13507 L
.32 .13584 L
.32 .13668 L
.32001 .13761 L
.32001 .13859 L
.32002 .14035 L
.32003 .14217 L
.32005 .14388 L
.32009 .14776 L
.32015 .15171 L
.32021 .15534 L
.3204 .16349 L
.32061 .17058 L
.32089 .17831 L
.32159 .19349 L
.32246 .20809 L
.32358 .22362 L
.32487 .23858 L
.32629 .25297 L
.328 .26828 L
.32985 .28302 L
.3318 .2972 L
.33407 .31229 L
.33645 .32681 L
.33918 .34225 L
.34201 .35713 L
.34491 .37144 L
.3482 .38666 L
.35156 .40132 L
.35497 .41542 L
.35879 .43043 L
.36265 .44487 L
.36696 .46023 L
.37131 .47502 L
.37556 .48889 L
s
1 0 1 r
.24667 .13333 m
.24667 .1338 L
.24667 .13422 L
.24667 .13471 L
.24667 .13518 L
.24667 .136 L
.24667 .13689 L
.24667 .13788 L
.24668 .13892 L
.24669 .14079 L
.2467 .14273 L
.24672 .14454 L
.24676 .14866 L
.24682 .15286 L
.24688 .15671 L
.24707 .16537 L
.24728 .1729 L
.24756 .18112 L
.24826 .19725 L
.24912 .21277 L
.25025 .22926 L
.25153 .24515 L
.25296 .26045 L
.25467 .27671 L
.25651 .29237 L
.25847 .30744 L
.26074 .32347 L
.26312 .33891 L
.26585 .35531 L
.26868 .37112 L
.27158 .38632 L
.27487 .4025 L
.27823 .41807 L
.28163 .43305 L
.28545 .449 L
.28932 .46434 L
.29363 .48066 L
.29797 .49638 L
.30222 .51111 L
s
.5 .165 .165 r
.16889 .13333 m
.16889 .13383 L
.16889 .13428 L
.16889 .13479 L
.16889 .13529 L
.16889 .13616 L
.16889 .1371 L
.1689 .13815 L
.1689 .13925 L
.16891 .14123 L
.16892 .14328 L
.16894 .1452 L
.16898 .14956 L
.16904 .15401 L
.1691 .15809 L
.16929 .16726 L
.1695 .17523 L
.16978 .18393 L
.17048 .20101 L
.17135 .21744 L
.17247 .2349 L
.17376 .25173 L
.17518 .26792 L
.17689 .28515 L
.17874 .30173 L
.18069 .31768 L
.18296 .33466 L
.18534 .351 L
.18807 .36837 L
.1909 .3851 L
.1938 .4012 L
.19709 .41833 L
.20045 .43482 L
.20386 .45068 L
.20768 .46756 L
.21154 .48381 L
.21585 .50109 L
.2202 .51773 L
.22444 .53333 L
s
1 0 1 r
.08667 .13333 m
.08667 .13385 L
.08667 .13433 L
.08667 .13488 L
.08667 .13539 L
.08667 .13631 L
.08667 .13731 L
.08667 .13841 L
.08668 .13958 L
.08669 .14167 L
.0867 .14383 L
.08672 .14585 L
.08676 .15046 L
.08682 .15516 L
.08688 .15946 L
.08707 .16914 L
.08728 .17756 L
.08756 .18675 L
.08826 .20477 L
.08912 .22211 L
.09025 .24055 L
.09153 .25831 L
.09296 .2754 L
.09467 .29358 L
.09651 .31109 L
.09847 .32792 L
.10074 .34584 L
.10312 .36309 L
.10585 .38143 L
.10868 .39909 L
.11158 .41608 L
.11487 .43416 L
.11823 .45157 L
.12163 .46831 L
.12545 .48613 L
.12932 .50328 L
.13363 .52152 L
.13797 .53909 L
.14222 .55556 L
s
.5 .165 .165 r
0 .13333 m
0 .13388 L
0 .13438 L
0 .13496 L
0 .1355 L
0 .13647 L
0 .13752 L
1e-005 .13868 L
1e-005 .13991 L
2e-005 .14211 L
3e-005 .14438 L
5e-005 .14651 L
9e-005 .15136 L
.00015 .15631 L
.00021 .16084 L
.0004 .17103 L
.00061 .17989 L
.00089 .18956 L
.00159 .20852 L
.00246 .22679 L
.00358 .24619 L
.00487 .26489 L
.00629 .28288 L
.008 .30201 L
.00985 .32044 L
.0118 .33816 L
.01407 .35703 L
.01645 .37518 L
.01918 .39448 L
.02201 .41308 L
.02491 .43097 L
.0282 .45 L
.03156 .46832 L
.03497 .48594 L
.03879 .5047 L
.04265 .52275 L
.04696 .54195 L
.05131 .56044 L
.05556 .57778 L
s
0 1 0 r
.02 w
.94444 .13333 Mdot
1 0 0 r
.05556 .57778 Mdot
0 0 1 r
0 .13333 Mdot
0 g
gsave
.94444 .16667 -61 -11.3438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22.6875 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 14.938 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.938 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
70.188 10.375 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
75.813 14.938 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
-0.04444 .1 -61 -11.3438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22.6875 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 14.938 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
70.188 14.938 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
77.375 14.938 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
84.563 10.375 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
90.188 14.938 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
0 .6 -61 -11.3438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22.6875 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 14.938 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.938 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
70.188 10.375 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
75.813 14.938 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
83.000 14.938 moveto
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
90.188 10.375 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
95.813 14.938 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
103.000 14.938 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2ab) show
131.750 14.938 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{379.563, 227.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
  ImageRangeCache->{{{0, 378.563}, {226.75, 0}} -> {-4, 0, 0, 0}}],
 "  ",
 StyleBox["\nFigure 2.13",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  The transformation  ",
 Cell[BoxData[
  RowBox[{"w", " ", "=", " ", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "=", 
    SuperscriptBox["z", "2"]}]}]]],
 ". "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 2.12.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell["\<\
Enter the function w = f[z] and determine the real and imaginary parts.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "a", ",", "b", ",", "eq1", ",", "eq2", ",", "eq3", ",", "eq4", ",", "x", 
      ",", "y", ",", "u", ",", "u1", ",", "u2", ",", "v", ",", "U", ",", 
      "V"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], ":=", 
     SuperscriptBox["z", "2"]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"eq1", " ", "=", " ", 
     RowBox[{"u", " ", "\[Equal]", " ", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"Re", "[", 
        RowBox[{"f", "[", 
         RowBox[{"x", "+", 
          RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], "]"}]}]}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"eq2", " ", "=", " ", 
     RowBox[{"v", " ", "\[Equal]", " ", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"Im", "[", 
        RowBox[{"f", "[", 
         RowBox[{"x", "+", 
          RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], "]"}]}]}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"x", "+", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}]}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"Expand", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", "+", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<u + \[ImaginaryI] v = \>\"", ",", 
      RowBox[{"Expand", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", "+", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "eq1", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "eq2", "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39897753375*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["(a)",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 " Find the image of the vertical line  ",
 Cell[BoxData[
  RowBox[{"x", "=", "a"}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"eqns", " ", "=", " ", 
      RowBox[{"ReplaceAll", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"eq1", ",", "eq2"}], "}"}], ",", 
        RowBox[{"x", "\[Rule]", "a"}]}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"eq3", " ", "=", " ", 
      RowBox[{"Eliminate", "[", 
       RowBox[{"eqns", ",", 
        RowBox[{"{", "y", "}"}]}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"solset1", " ", "=", " ", 
      RowBox[{"Solve", "[", 
       RowBox[{"eq3", ",", "u"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"u1", "[", "v_", "]"}], " ", "=", " ", 
     RowBox[{"Expand", "[", 
      SubscriptBox["solset1", 
       RowBox[{"\[LeftDoubleBracket]", 
        RowBox[{"1", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]], 
      "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<u[v] = \>\"", ",", 
      RowBox[{"u1", "[", "v", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39897753846875*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "Hence, the image of the vertical line  ",
 Cell[BoxData[
  RowBox[{"x", "=", "a"}]]],
 "  is the parabola  ",
 Cell[BoxData[
  RowBox[{"u", "=", 
   RowBox[{
    SuperscriptBox["a", "2"], "-", 
    FractionBox[
     SuperscriptBox["v", "2"], 
     RowBox[{"4", " ", 
      SuperscriptBox["a", "2"]}]]}]}]]],
 ".  \n\n",
 StyleBox["(b)",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 " Find the image of the horizontal line  ",
 Cell[BoxData[
  RowBox[{"y", "=", "b"}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"eqns", " ", "=", " ", 
      RowBox[{"ReplaceAll", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"eq1", ",", "eq2"}], "}"}], ",", 
        RowBox[{"y", "\[Rule]", "b"}]}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"eq4", " ", "=", " ", 
      RowBox[{"Eliminate", "[", 
       RowBox[{"eqns", ",", 
        RowBox[{"{", "x", "}"}]}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"solset2", " ", "=", " ", 
      RowBox[{"Solve", "[", 
       RowBox[{"eq4", ",", "u"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"u2", "[", "v_", "]"}], " ", "=", " ", 
     RowBox[{"Expand", "[", 
      SubscriptBox["solset2", 
       RowBox[{"\[LeftDoubleBracket]", 
        RowBox[{"1", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]], 
      "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<u[v] = \>\"", ",", 
      RowBox[{"u2", "[", "v", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39897754290625*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "Hence, the image of the horizontal line  ",
 Cell[BoxData[
  RowBox[{"y", "=", "b"}]]],
 "  is the parabola  ",
 Cell[BoxData[
  RowBox[{"u", "=", 
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["b", "2"]}], "+", 
    FractionBox[
     SuperscriptBox["v", "2"], 
     RowBox[{"4", " ", 
      SuperscriptBox["b", "2"]}]]}]}]]],
 ".  \nUse ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to make a graph of the mapping."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "Iden", ",", "z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"Iden", "[", "z_", "]"}], " ", "=", " ", "z"}], ";"}], " ", "\n",
    
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     SuperscriptBox["z", "2"]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"CartesianMap", "[", 
    RowBox[{"Iden", ",", " ", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0.6", ",", "0.1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "2", ",", "0.1"}], "}"}], ",", "\[IndentingNewLine]", 
     
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.05"}], ",", "0.65"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.1"}], ",", "2.1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["2.2", "0.7"]}], ",", "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "0.6", ",", "0.3"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "2", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<Vertical lines x = a, and horizontal lines y = b.\>\"",
      "]"}], ";"}], " ", "\n", 
   RowBox[{"CartesianMap", "[", 
    RowBox[{"f", ",", " ", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0.6", ",", "0.1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "2.0", ",", "0.1"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "4"}], ",", "0.5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.2"}], ",", "2.4"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["2.6", "4.5"]}], ",", "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "4"}], ",", "0", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "2", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The image parabolas u= \!\(\*SuperscriptBox[\(a\), \
\(2\)]\)-\!\(\*FractionBox[SuperscriptBox[\(v\), \(2\)], \(4\\\ \
\*SuperscriptBox[\(a\), \(2\)]\)]\) and u = -\!\(\*SuperscriptBox[\(b\), \
\(2\)]\)+\!\(\*FractionBox[SuperscriptBox[\(v\), \(2\)], \(4\\\ \
\*SuperscriptBox[\(b\), \(2\)]\)]\),\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<under the mapping  w = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.398977547359375*^9, 3.398977552625*^9}, {
  3.399135044046875*^9, 3.399135065484375*^9}, {3.3997430110625*^9, 
  3.39974301125*^9}},
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "Iden", ",", "z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"Iden", "[", "z_", "]"}], " ", "=", " ", "z"}], ";"}], " ", "\n",
    
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     SuperscriptBox["z", "2"]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"CartesianMap", "[", 
    RowBox[{"Iden", ",", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1.5"}], ",", "0.5", ",", "0.1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1", ",", "0.1"}], "}"}], ",", "\[IndentingNewLine]", 
     
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.5"}], ",", "0.5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.05"}], ",", "1.05"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["1.1", "2.0"]}], ",", "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1.5"}], ",", "0.5", ",", "0.5"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "1", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<Vertical lines x = a, and horizontal lines y = b.\>\"",
      "]"}], ";"}], " ", "\n", 
   RowBox[{"CartesianMap", "[", 
    RowBox[{"f", ",", "  ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1.5"}], ",", "0.5", ",", "0.1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1", ",", "0.1"}], "}"}], ",", "\[IndentingNewLine]", 
     
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "2.3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "3.2"}], ",", "1.0"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["4.2", "3.3"]}], ",", "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "4"}], ",", "4", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "4"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The image parabolas u= \!\(\*SuperscriptBox[\(a\), \
\(2\)]\)-\!\(\*FractionBox[SuperscriptBox[\(v\), \(2\)], \(4\\\ \
\*SuperscriptBox[\(a\), \(2\)]\)]\) and u = -\!\(\*SuperscriptBox[\(b\), \
\(2\)]\)+\!\(\*FractionBox[SuperscriptBox[\(v\), \(2\)], \(4\\\ \
\*SuperscriptBox[\(b\), \(2\)]\)]\),\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<under the mapping  w = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.398977555765625*^9, 3.398977560296875*^9}, {
  3.399135076796875*^9, 3.399135082953125*^9}, {3.399743016828125*^9, 
  3.399743017078125*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Extra Example 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 " Consider the mapping  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   SuperscriptBox["z", "2"]}]],
  AspectRatioFixed->True],
 ".  Find the image of the ray  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"r", ">", "0"}], ",", 
   RowBox[{"\[Theta]", "=", "\[Alpha]"}]}]]],
 "  and circle ",
 Cell[BoxData[
  RowBox[{"r", "=", "c"}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Extra Solution 1.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "Find the image of the ray  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"r", ">", "0"}], ",", 
   RowBox[{"\[Theta]", "=", "\[Alpha]"}]}]]],
 "  and circle ",
 Cell[BoxData[
  RowBox[{"r", "=", "c"}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", 
     SuperscriptBox["z", "2"]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Iden", "[", "z_", "]"}], " ", "=", " ", "z"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"PolarMap", "[", 
    RowBox[{"Iden", ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "3", ",", "0.25"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       FractionBox[
        RowBox[{" ", "\[Pi]"}], "2"], ",", " ", 
       FractionBox[
        RowBox[{" ", "\[Pi]"}], "24"]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "3"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["1", "2"]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "9"}], ",", "9", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "9", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The rays r > 0, \[Theta] = \[Alpha], and circles r = c.\>\"", "]"}],
     ";"}], " ", "\n", 
   RowBox[{"PolarMap", "[", 
    RowBox[{"f", " ", ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "3", ",", "0.25"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", " ", 
       FractionBox[
        RowBox[{" ", "\[Pi]"}], "2"], ",", " ", 
       FractionBox[
        RowBox[{" ", "\[Pi]"}], "24"]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "9"}], ",", "9"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "9"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["1", "2"]}], ",", "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "9"}], ",", 
          RowBox[{"-", "4"}], ",", 
          RowBox[{"-", "1"}], ",", "0", ",", "1", ",", "4", ",", "9"}], "}"}],
         ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "4", ",", "9"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The image rays r > 0, \[Theta] = 2\[Alpha], and circles r = \
\!\(\*SuperscriptBox[\(c\), \(2\)]\),\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<under the mapping  w = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.398977566515625*^9, 3.398977572296875*^9}, {
  3.399135094625*^9, 3.399135114421875*^9}, {3.399743023328125*^9, 
  3.39974302353125*^9}},
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", 
     SuperscriptBox["z", "2"]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"PolarMap", "[", 
    RowBox[{"Iden", ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "3", ",", "0.25"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox[
        RowBox[{"-", " ", "\[Pi]"}], "3"], ",", 
       FractionBox[
        RowBox[{" ", "\[Pi]"}], "3"], ",", " ", 
       FractionBox[
        RowBox[{" ", "\[Pi]"}], "24"]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "3"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "9"}], ",", "9", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "9"}], ",", "9", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The rays r > 0, \[Theta] = \[Alpha], and circles r = c.\>\"", "]"}],
     ";"}], " ", "\n", 
   RowBox[{"PolarMap", "[", 
    RowBox[{"f", " ", ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "3", ",", "0.25"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox[
        RowBox[{"-", " ", "\[Pi]"}], "3"], ",", 
       FractionBox[
        RowBox[{" ", "\[Pi]"}], "3"], ",", " ", 
       FractionBox[
        RowBox[{" ", "\[Pi]"}], "24"]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "9"}], ",", "9"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "9"}], ",", "9"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "9"}], ",", 
          RowBox[{"-", "4"}], ",", 
          RowBox[{"-", "1"}], ",", "0", ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "\"\< 1\>\""}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"4", ",", "\"\< 4\>\""}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"9", ",", "\"\< 9\>\""}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "9"}], ",", 
          RowBox[{"-", "4"}], ",", "0", ",", "1", ",", "4", ",", "9"}], 
         "}"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The image rays r > 0, \[Theta] = 2\[Alpha], and circles r = \
\!\(\*SuperscriptBox[\(c\), \(2\)]\),\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<under the mapping  w = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.398977575796875*^9, 3.3989775820625*^9}, {
  3.39913512375*^9, 3.399135143109375*^9}, {3.399743032609375*^9, 
  3.3997430328125*^9}},
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", 
     SuperscriptBox["z", "2"]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"g", "[", "z_", "]"}], "=", 
     RowBox[{"z", "+", "1"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"h", "[", "z_", "]"}], "=", 
     RowBox[{"f", "[", 
      RowBox[{"g", "[", "z", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"PolarMap", "[", 
    RowBox[{"g", ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1", ",", "0.1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", " ", "\[Pi]"}], ",", " ", "\[Pi]", ",", " ", 
       FractionBox[
        RowBox[{" ", "\[Pi]"}], "24"]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "2", ",", "0.5"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", 
          FractionBox["1", "2"]}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", "\"\<The radii, and circles.\>\"", "]"}], ";"}], 
   " ", "\n", 
   RowBox[{"range", "=", 
    RowBox[{"PolarMap", "[", 
     RowBox[{"h", " ", ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "1", ",", "0.1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", " ", "\[Pi]"}], ",", " ", "\[Pi]", ",", " ", 
        FractionBox[
         RowBox[{" ", "\[Pi]"}], "24"]}], "}"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "1"}], ",", "4.4"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "2.7"}], ",", "2.7"}], "}"}]}], "}"}]}], ",", 
      RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
      RowBox[{"Ticks", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Range", "[", 
          RowBox[{
           RowBox[{"-", "1"}], ",", "4", ",", "1"}], "]"}], ",", 
         RowBox[{"Range", "[", 
          RowBox[{
           RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}], ",", 
      RowBox[{"AxesLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<The image curves under the mapping  w = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"cardioid", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"2", 
          RowBox[{"Cos", "[", "t", "]"}], 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{"Cos", "[", "t", "]"}]}], ")"}]}], ",", 
         RowBox[{"2", 
          RowBox[{"Sin", "[", "t", "]"}], 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{"Cos", "[", "t", "]"}]}], ")"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", 
         RowBox[{"-", "\[Pi]"}], ",", "\[Pi]"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Thickness", "[", "0.009", "]"}], ",", "Blue"}], "}"}]}]}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"range", ",", "cardioid"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The outer boundary curve is a cardioid.\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<(\!\(\*SuperscriptBox[\(u\), \(2\)]\) + \!\(\*SuperscriptBox[\(v\), \
\(2\)]\) - 2 u\!\(\*SuperscriptBox[\()\), \(2\)]\) = \
4(\!\(\*SuperscriptBox[\(u\), \(2\)]\) + \!\(\*SuperscriptBox[\(v\), \
\(2\)]\))\>\"", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
   "Print", "[", 
    "\"\<(u,v) = (2 Cos[t](1 + Cos[t]), 2 Sin[t](1 + Cos[t])\>\"", "]"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.398977585265625*^9, 3.398977591046875*^9}, {
  3.399135150046875*^9, 3.39913515984375*^9}, {3.399135191890625*^9, 
  3.39913519234375*^9}, {3.399743037890625*^9, 3.3997430380625*^9}, {
  3.400243113453125*^9, 3.4002431208125*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 "\tWe can use knowledge of the inverse mapping  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   SuperscriptBox["w", "2"]}]],
  AspectRatioFixed->True],
 " to get further insight into how the mapping ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   SuperscriptBox["z", 
    RowBox[{"1", "/", "2"}]]}]],
  AspectRatioFixed->True],
 " acts on rectangles.  If we let ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{
    RowBox[{"x", "+", 
     RowBox[{"\[ImaginaryI]", " ", "y"}]}], "\[NotEqual]", "0"}]}]]],
 ", then  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"z", " ", "=", " ", 
   RowBox[{
    RowBox[{"x", "+", 
     RowBox[{"\[ImaginaryI]", " ", "y"}]}], " ", "=", " ", 
    RowBox[{
     SuperscriptBox["w", "2"], " ", "=", " ", 
     RowBox[{
      SuperscriptBox["u", "2"], "-", 
      SuperscriptBox["v", "2"], " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", "2", " ", "u", " ", "v"}]}]}]}]}]]],
 ",  \n\nand we note that the point  ",
 Cell[BoxData[
  RowBox[{"z", " ", "=", " ", 
   RowBox[{"x", "+", 
    RowBox[{"\[ImaginaryI]", " ", "y"}]}]}]]],
 "  in the z plane is related to the point  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{"u", "+", 
     RowBox[{"\[ImaginaryI]", " ", "v"}]}], "=", 
    SuperscriptBox["z", 
     RowBox[{"1", "/", "2"}]]}]}]],
  AspectRatioFixed->True],
 " in the w-plane by the system of equations  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"x", "=", 
     RowBox[{
      SuperscriptBox["u", "2"], "-", 
      SuperscriptBox["v", "2"]}]}], 
    StyleBox[",",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], 
    StyleBox["   ",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], 
    StyleBox["and",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"y", "=", 
   RowBox[{"2", " ", "u", " ", 
    RowBox[{"v", 
     StyleBox[".",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]]}]}]}]}]],
 "    "
}], "Text"],

Cell[TextData[{
 StyleBox["Example 2.13.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 " The transformation  ",
 Cell[BoxData[
  RowBox[{"w", " ", "=", " ", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
    SuperscriptBox["z", 
     RowBox[{"1", "/", "2"}]]}]}]],
  AspectRatioFixed->True],
 "  usually maps vertical and horizontal lines onto portions of hyperbolas.  \
\n",
 StyleBox["(a)",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Find the image of the vertical line  ",
 Cell[BoxData[
  RowBox[{"x", "=", "a"}]]],
 ".   ",
 StyleBox["(b)",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Find the image of the horizontal line  ",
 Cell[BoxData[
  RowBox[{"y", "=", "b"}]]],
 ".  \n\nSolution.  Let  ",
 Cell[BoxData[
  RowBox[{"a", ">", "0"}]]],
 ".  The above equations map the right half-plane given by  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Re", 
    RowBox[{"(", "z", ")"}]}], ">", "a"}]]],
 "  (i.e.,  ",
 Cell[BoxData[
  RowBox[{"x", ">", "a"}]]],
 ")  onto the region in the right half-plane satisfying  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["u", "2"], "-", 
    SuperscriptBox["v", "2"]}], ">", "a"}]]],
 "  and lying to the right of the hyperbola  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["u", "2"], "-", 
    SuperscriptBox["v", "2"]}], "=", "a"}]]],
 ".  If  ",
 Cell[BoxData[
  RowBox[{"b", ">", "0"}]]],
 ",  the equations  ",
 Cell[BoxData[
  RowBox[{"x", "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["u", "2"], "-", 
     RowBox[{
      SuperscriptBox["v", "2"], 
      StyleBox["   ",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox["and",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox["  ",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}]}], "=", 
    RowBox[{"2", " ", "u", " ", "v"}]}]}]]],
 "  map the upper half-plane  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", 
    RowBox[{"(", "z", ")"}]}], ">", "b"}]]],
 "  (i.e.,  ",
 Cell[BoxData[
  RowBox[{"y", ">", "b"}]]],
 ")   onto the region in quadrant I satisfying  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"2", "u", " ", "v"}], ">", "b"}]]],
 "  and lying above the hyperbola  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"2", "u", " ", "v"}], "=", "b"}]]],
 ".  This situation is illustrated in Figure 2.14.  We leave as an exercise \
the investigation of what happens when  ",
 Cell[BoxData[
  RowBox[{"a", "=", 
   RowBox[{
    RowBox[{"0", "  ", 
     StyleBox["or",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", "b"}], "=", "0"}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 CellChangeTimes->{3.3989774136875*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.309017 0.309017 [
[1.025 .30902 0 -6.28125 ]
[1.025 .30902 10 6.28125 ]
[.5 .64303 -8 0 ]
[.5 .64303 8 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 .30902 m
-0.5 .30902 L
-0.36603 0 L
.5 .30902 L
F
0 .5 .95 r
.5 .30902 m
-0.36603 0 L
0 -0.22622 L
.5 .30902 L
F
0 .9 1 r
.5 .30902 m
0 -0.22622 L
.5 -0.30902 L
.5 .30902 L
F
1 0 0 r
.5 .30902 m
.5 -0.30902 L
1 -0.22622 L
.5 .30902 L
F
.9 .45 .45 r
.5 .30902 m
1 -0.22622 L
1.36603 0 L
.5 .30902 L
F
1 .75 .75 r
.5 .30902 m
1.36603 0 L
1.5 .30902 L
.5 .30902 L
F
0 1 0 r
.5 .30902 m
1.5 .30902 L
1.36603 .61803 L
.5 .30902 L
F
0 .95 0 r
.5 .30902 m
1.36603 .61803 L
1 .84425 L
.5 .30902 L
F
.45 .95 .45 r
.5 .30902 m
1 .84425 L
.5 .92705 L
.5 .30902 L
F
1 .5 0 r
.5 .30902 m
.5 .92705 L
0 .84425 L
.5 .30902 L
F
1 .6 0 r
.5 .30902 m
0 .84425 L
-0.36603 .61803 L
.5 .30902 L
F
1 1 0 r
.5 .30902 m
-0.36603 .61803 L
-0.5 .30902 L
.5 .30902 L
F
0 0 0 r
.5 Mabswid
0 .30902 m
1 .30902 L
s
.5 .30902 m
.5 .61803 L
s
.5 .30902 m
.5 0 L
s
0 g
gsave
1 .32447 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
77.375 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.47 .63348 -61 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
77.375 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1, -1, 0, 0}}],
 StyleBox["       ",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.309017 0.309017 [
[1.025 .30902 0 -6.28125 ]
[1.025 .30902 10 6.28125 ]
[.5 .64303 -8 0 ]
[.5 .64303 8 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 .30902 m
.5 -0.30902 L
.75882 -0.28796 L
.5 .30902 L
F
0 .5 .95 r
.5 .30902 m
.75882 -0.28796 L
1 -0.22622 L
.5 .30902 L
F
0 .9 1 r
.5 .30902 m
1 -0.22622 L
1.20711 -0.128 L
.5 .30902 L
F
1 0 0 r
.5 .30902 m
1.20711 -0.128 L
1.36603 0 L
.5 .30902 L
F
.9 .45 .45 r
.5 .30902 m
1.36603 0 L
1.46593 .14906 L
.5 .30902 L
F
1 .75 .75 r
.5 .30902 m
1.46593 .14906 L
1.5 .30902 L
.5 .30902 L
F
0 1 0 r
.5 .30902 m
1.5 .30902 L
1.46593 .46898 L
.5 .30902 L
F
0 .95 0 r
.5 .30902 m
1.46593 .46898 L
1.36603 .61803 L
.5 .30902 L
F
.45 .95 .45 r
.5 .30902 m
1.36603 .61803 L
1.20711 .74603 L
.5 .30902 L
F
1 .5 0 r
.5 .30902 m
1.20711 .74603 L
1 .84425 L
.5 .30902 L
F
1 .6 0 r
.5 .30902 m
1 .84425 L
.75882 .90599 L
.5 .30902 L
F
1 1 0 r
.5 .30902 m
.75882 .90599 L
.5 .92705 L
.5 .30902 L
F
0 0 0 r
.5 Mabswid
0 .30902 m
1 .30902 L
s
.01 w
.5 .30902 m
.5 .61803 L
s
[ .025 .025 ] 0 setdash
.5 .30902 m
.5 0 L
s
0 g
gsave
1 .32447 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(u) show
77.375 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.47 .63348 -61 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(v) show
77.375 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1, -1, 0, 0}}],
 StyleBox["  \n\t\t\tFigure 2.14",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  The mapping   ",
 Cell[BoxData[
  RowBox[{"w", " ", "=", " ", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "=", 
    SuperscriptBox["z", 
     RowBox[{"1", "/", "2"}]]}]}]],
  AspectRatioFixed->True],
 "   and   (",
 Cell[BoxData[
  RowBox[{"z", " ", "=", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox["f", 
      RowBox[{"-", "1"}]], 
     RowBox[{"(", "w", ")"}]}], "=", 
    SuperscriptBox["w", "2"]}]}]]],
 ").  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 2.13.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell["Before we start, make x, y, u and v real variables.", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Remove", "[", 
    RowBox[{"u", ",", "v", ",", "x", ",", "y", ",", "z"}], "]"}], ";"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Clear", "[", 
    RowBox[{"f", ",", "F", ",", "X", ",", "Y", ",", "U", ",", "V", ",", "Z"}],
     "]"}], ";"}], " "}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"TagSet", "[", 
    RowBox[{"x", ",", 
     RowBox[{"Im", "[", "x", "]"}], ",", "0"}], "]"}], ";"}], " "}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"TagSet", "[", 
    RowBox[{"y", ",", 
     RowBox[{"Im", "[", "y", "]"}], ",", "0"}], "]"}], ";"}], " "}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"TagSet", "[", 
    RowBox[{"u", ",", 
     RowBox[{"Im", "[", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}], "]"}], ",", "0"}], "]"}], ";"}], 
  " "}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"TagSet", "[", 
    RowBox[{"v", ",", 
     RowBox[{"Im", "[", 
      RowBox[{"v", "[", 
       RowBox[{"x", ",", "y"}], "]"}], "]"}], ",", "0"}], "]"}], ";"}], 
  " "}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"TagSet", "[", 
    RowBox[{"x", ",", 
     RowBox[{"Re", "[", "x", "]"}], ",", "x"}], "]"}], ";"}], " "}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"TagSet", "[", 
    RowBox[{"y", ",", 
     RowBox[{"Re", "[", "y", "]"}], ",", "y"}], "]"}], ";"}], " "}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"TagSet", "[", 
    RowBox[{"u", ",", 
     RowBox[{"Re", "[", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}], "]"}], ",", 
     RowBox[{"u", "[", 
      RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " "}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"TagSet", "[", 
    RowBox[{"v", ",", 
     RowBox[{"Re", "[", 
      RowBox[{"v", "[", 
       RowBox[{"x", ",", "y"}], "]"}], "]"}], ",", 
     RowBox[{"v", "[", 
      RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " "}]}], "Input"],

Cell[TextData[{
 "The mapping  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   SuperscriptBox["z", 
    RowBox[{"1", "/", "2"}]]}]]],
 "  can be manipulated as follows.  "
}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"eq0", "=", 
    RowBox[{
     SqrtBox["z"], "\[Equal]", "w"}]}], ";"}], " "}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"eq1", "=", 
    RowBox[{"z", "\[Equal]", 
     SuperscriptBox["w", "2"]}]}], ";"}], " "}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"eq2", "=", 
    RowBox[{"ReplaceAll", "[", 
     RowBox[{"eq1", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"z", "\[Rule]", 
         RowBox[{"x", "+", 
          RowBox[{"\[ImaginaryI]", " ", "y"}]}]}], ",", 
        RowBox[{"w", "\[Rule]", 
         RowBox[{"u", "+", 
          RowBox[{"\[ImaginaryI]", " ", "v"}]}]}]}], "}"}]}], "]"}]}], ";"}], 
  " "}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"eq3", "=", 
    RowBox[{"ComplexExpand", "[", "eq2", "]"}]}], ";"}], " "}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"eq4", "=", 
    RowBox[{"ComplexExpand", "[", 
     RowBox[{"Map", "[", 
      RowBox[{"Re", ",", "eq3"}], "]"}], "]"}]}], ";"}], " "}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"eq5", "=", 
    RowBox[{"Thread", "[", 
     RowBox[{
      RowBox[{"-", "eq4"}], ",", "Equal"}], "]"}]}], ";"}], " "}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"eq6", "=", 
    RowBox[{"Thread", "[", 
     RowBox[{
      RowBox[{"eq5", "+", "eq3"}], ",", "Equal"}], "]"}]}], ";"}], 
  " "}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"eq7", "=", 
    RowBox[{"ComplexExpand", "[", 
     RowBox[{"Map", "[", 
      RowBox[{"Im", ",", "eq6"}], "]"}], "]"}]}], ";"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Print", "[", "eq0", "]"}], ";"}], " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Print", "[", "eq1", "]"}], ";"}], " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Print", "[", "eq2", "]"}], ";"}], " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Print", "[", "eq3", "]"}], ";"}], " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Print", "[", "eq4", "]"}], ";"}], " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Print", "[", "eq7", "]"}], ";"}], 
  " "}], "\[IndentingNewLine]"}], "Input"],

Cell[TextData[{
 StyleBox["(a)",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 " Find the image of the vertical line  ",
 Cell[BoxData[
  RowBox[{"x", "=", "a"}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Print", "[", "\"\<The vertical line is\>\"", "]"}], ";"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Print", "[", 
    RowBox[{
     SubscriptBox["eq4", 
      RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], 
     "\[Equal]", "a"}], "]"}], ";"}], " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Print", "[", "\"\<Its image is the hyperbola\>\"", "]"}], ";"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Print", "[", 
    RowBox[{
     SubscriptBox["eq4", 
      RowBox[{"\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]], 
     "\[Equal]", "a"}], "]"}], ";"}], " "}], "\[IndentingNewLine]"}], "Input"],

Cell[TextData[{
 StyleBox["(b)",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 " Find the image of the horizontal line  ",
 Cell[BoxData[
  RowBox[{"y", "=", "b"}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Print", "[", "\"\<The horizontal line is\>\"", "]"}], ";"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Print", "[", 
    RowBox[{
     SubscriptBox["eq7", 
      RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], 
     "\[Equal]", "b"}], "]"}], ";"}], " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Print", "[", "\"\<Its image is the hyperbola\>\"", "]"}], ";"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Print", "[", 
    RowBox[{
     SubscriptBox["eq7", 
      RowBox[{"\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]], 
     "\[Equal]", "b"}], "]"}], ";"}], " "}], "\[IndentingNewLine]"}], "Input"],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to make a graph of the mapping."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "Iden"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"Iden", "[", "z_", "]"}], "=", "z"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", 
     SuperscriptBox["z", 
      RowBox[{"1", "/", "2"}]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"CartesianMap", "[", 
    RowBox[{"Iden", ",", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "9"}], ",", "9", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "10", ",", "1"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "9"}], ",", "10"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.5"}], ",", "10.5"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["1", "2"]}], ",", "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "9"}], ",", "9", ",", "3"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "9", ",", "3"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<Vertical lines x = a, and horizontal lines y = b.\>\"",
      "]"}], ";"}], " ", "\n", 
   RowBox[{"CartesianMap", "[", 
    RowBox[{"f", ",", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "8"}], ",", "8", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "10", ",", "1"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.3"}], ",", "3.3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.3"}], ",", "3.3"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "3", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "3", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The image hyperbolas \!\(\*SuperscriptBox[\(u\), \
\(2\)]\)-\!\(\*SuperscriptBox[\(v\), \(2\)]\) = a and 2uv = b,\>\"", "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<under the mapping  w = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39974304321875*^9, 3.3997430434375*^9}, {
  3.40024327915625*^9, 3.4002432955*^9}, {3.40024332921875*^9, 
  3.40024339928125*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 "\tWhat happens to images of regions under the mapping  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"w", " ", "=", " ", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
    RowBox[{
     SuperscriptBox["z", 
      RowBox[{"1", "/", "2"}]], " ", "=", " ", 
     RowBox[{
      RowBox[{"|", "z", 
       SuperscriptBox["|", 
        RowBox[{"1", "/", "2"}]], 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "Arg", 
         RowBox[{
          RowBox[{"(", "z", ")"}], "/", "2"}]}]]}], " ", "=", " ", 
      RowBox[{
       SuperscriptBox["r", 
        RowBox[{"1", "/", "2"}]], 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]\[Theta]", "/", "2"}]]}]}]}]}]}]]],
 "   for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"r", " ", 
    SuperscriptBox["\[ExponentialE]", "\[ImaginaryI]\[Theta]"]}], 
   "\[NotEqual]", "0"}]]],
 ", \n\nwhere  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"-", "\[Pi]"}], "<", "\[Theta]", "\[LessEqual]", "\[Pi]"}]]],
 "?  If we use polar coordinates for  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{"\[Rho]", " ", 
    SuperscriptBox["\[ExponentialE]", "\[ImaginaryI]\[Phi]"]}]}]]],
 "  in the w plane, we can represent this mapping by the system\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"\[Rho]", "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["r", 
      RowBox[{"1", "/", "2"}]], "  ", "and", "  ", "\[Phi]"}], "=", 
    FractionBox["\[Theta]", "2"]}]}]]],
 ".  \n\nThis Equation indicate that the argument of ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", "z", ")"}]}]],
  CellChangeTimes->{{3.398977439875*^9, 3.39897748059375*^9}}],
 " is half the argument of z and that the modulus of ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", "z", ")"}]}]],
  CellChangeTimes->{{3.398977439875*^9, 3.39897748059375*^9}}],
 " is the square root of the modulus of z.  Points that lie on the ray  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"r", ">", "0"}], ",", 
   RowBox[{"\[Theta]", "=", "\[Alpha]"}]}]]],
 "  are mapped onto the ray  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Rho]", ">", "0"}], ",", 
   RowBox[{"\[Phi]", "=", 
    FractionBox["\[Alpha]", "2"]}]}]]],
 ".  The image of the z plane (with the point ",
 Cell[BoxData[
  RowBox[{"z", "=", "0"}]],
  CellChangeTimes->{{3.398977439875*^9, 3.3989774613125*^9}}],
 " deleted) consists of the right half-plane ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Re", 
    RowBox[{"(", "w", ")"}]}], ">", "0"}]],
  CellChangeTimes->{3.398977439875*^9}],
 " together with the positive v axis.  The mapping is shown in Figure 2.15."
}], "Text",
 CellChangeTimes->{{3.3989774435625*^9, 3.398977497546875*^9}}],

Cell[TextData[{
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .78571 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.285714 0.0714286 0.0714286 0.0714286 [
[.07143 .05893 -6 -9 ]
[.07143 .05893 6 0 ]
[.5 .05893 -3 -9 ]
[.5 .05893 3 0 ]
[.71429 .05893 -3 -9 ]
[.71429 .05893 3 0 ]
[.92857 .05893 -3 -9 ]
[.92857 .05893 3 0 ]
[1.025 .07143 0 -6.28125 ]
[1.025 .07143 10 6.28125 ]
[.27321 .21429 -6 -4.5 ]
[.27321 .21429 0 4.5 ]
[.27321 .35714 -6 -4.5 ]
[.27321 .35714 0 4.5 ]
[.27321 .71429 -6 -4.5 ]
[.27321 .71429 0 4.5 ]
[.28571 .81071 -5 0 ]
[.28571 .81071 5 12.5625 ]
[ 0 0 0 0 ]
[ 1 .78571 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07143 .07143 m
.07143 .07768 L
s
[(-3)] .07143 .05893 0 1 Mshowa
.5 .07143 m
.5 .07768 L
s
[(3)] .5 .05893 0 1 Mshowa
.71429 .07143 m
.71429 .07768 L
s
[(6)] .71429 .05893 0 1 Mshowa
.92857 .07143 m
.92857 .07768 L
s
[(9)] .92857 .05893 0 1 Mshowa
0 .07143 m
1 .07143 L
s
gsave
1.025 .07143 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.28571 .21429 m
.29196 .21429 L
s
[(2)] .27321 .21429 1 0 Mshowa
.28571 .35714 m
.29196 .35714 L
s
[(4)] .27321 .35714 1 0 Mshowa
.28571 .71429 m
.29196 .71429 L
s
[(9)] .27321 .71429 1 0 Mshowa
.28571 0 m
.28571 .78571 L
s
gsave
.28571 .81071 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .78571 L
0 .78571 L
closepath
clip
newpath
.5 Mabswid
.28571 .07143 m
.28571 .07143 L
.28571 .07143 L
.28571 .07143 L
.28571 .07143 L
.28571 .07143 L
.28571 .07143 L
.28571 .07143 L
.28571 .07143 L
.28571 .07143 L
.28571 .07143 L
.28571 .07143 L
.28571 .07143 L
.28571 .07143 L
.28571 .07143 L
.28571 .07143 L
.28571 .07143 L
.28571 .07143 L
.28571 .07143 L
.28571 .07143 L
.28571 .07143 L
.28571 .07143 L
.28571 .07143 L
.28571 .07143 L
.28571 .07143 L
s
1 0 0 r
.5 .07143 m
.5 .71429 L
s
.53571 .07143 m
.53571 .71429 L
s
.57143 .07143 m
.57143 .71429 L
s
.60714 .07143 m
.60714 .71429 L
s
.64286 .07143 m
.64286 .71429 L
s
.67857 .07143 m
.67857 .71429 L
s
.71429 .07143 m
.71429 .71429 L
s
.75 .07143 m
.75 .71429 L
s
.78571 .07143 m
.78571 .71429 L
s
.82143 .07143 m
.82143 .71429 L
s
.85714 .07143 m
.85714 .71429 L
s
.89286 .07143 m
.89286 .71429 L
s
.92857 .07143 m
.92857 .71429 L
s
0 0 1 r
0 .35714 m
.92857 .35714 L
s
0 .39286 m
.92857 .39286 L
s
0 .42857 m
.92857 .42857 L
s
0 .46429 m
.92857 .46429 L
s
0 .5 m
.92857 .5 L
s
0 .53571 m
.92857 .53571 L
s
0 .57143 m
.92857 .57143 L
s
0 .60714 m
.92857 .60714 L
s
0 .64286 m
.92857 .64286 L
s
0 .67857 m
.92857 .67857 L
s
0 .71429 m
.92857 .71429 L
s
0 g
0 .07143 m
1 .07143 L
s
.28571 0 m
.28571 .78571 L
s
gsave
.39286 .21429 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.188 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
77.375 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.06429 .28571 -61 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
70.188 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
77.375 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300.75, 236.313},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\
eJzt3V1u00AQwPFN7EBb3hASLRKQB5RUCN5o014ApH7wdYOoQmofEKj0XtwD
DtCKM/QOITvebhJn7DgxaSfobwl7s7v22L9MnSW2nOP+xemXr/2Ls5N++915
//vp2cmP9ttv58OqpOFc45Vz7rrtfHkwLIbZZzcYDFzi5MWw5P9dytytdNOW
XzR9Q0/p1Iute76UTJa2s01syiKdWHE47Srb29W79vTqfWULnazxidK0o9Tt
Vd+J0XF1s6qHfiHdWspW3ih12g7vTMJNx+3+K0XtWAtku/O9+fvKm9+1kca/
4k4OG8LRybRWvM7vXJ2f1rNS6hdS88jPNpS1w4YfV8y2m7rBWN39inX3aqxr
KcYoz/Q3CcvqdZ3ivIYHHnjggQcegzHggQceeOAxFwMeeOCBBx5zMeCBBx54
4DEXAx544IEHHnMx4IEHHnjgMRcDHnjgWS7PgV/IXZ8pUDOhcjza3b5P/Vzu
YGzGktwc2vKlOjv8n4EeKniSg1L1LLweb3XhptBW1HWtiQ6hk3mBW1Q+UpQT
pe55TNYHwFaBPdATVDuLjmzTmL7yHqSYTp8SBEo7sxacEjbI1yq22jio8LNK
uq0ZPzAGkXceAx544IEHHnMx4IEHHnjgMRcDHnjggQceczHgqcIjT6CRL2K1
h84AtfDDh6wezh2TySN35Bv+Lngz8eRr/CSSSang+kgHzjLOrRyPn8ouj8JZ
gXPqAl6TVK1vu1lCJ5f0Rpf5cogvgC2DlSeOZTppFA3Tei6hw8SHVKmoxrMN
WRmZLOQv+CVQ/McNHnjgMRMDnio8cieq6CRAlUEdKzzawB2ySCYj8/e+Phi5
rJf76efh6eNz3LELbeFt+pBVO9M1geITEx544LEVAx54avNUGnBiSIrBAw88
dmLAAw888DB2XGlDeOCBBx547MSABx54lsvD2JEUgwceezHggQceeOAxF4Ox
IykGDzxmY8ADDzzwMDhaaUN44IEHHnjsxIAHHniWy8PYkRSDBx57MeCBBx54
4DEXg7EjKQYPPGZjwAMPPPDAYy4GY0dSDB54zMaABx544IHHXAzGjqQYPPCY
jQEPPLV55LceRKcFVBnUkcKTQFZ76DTHj41cLrrGYUzykk7aiYKmlWySF69v
p/zRL+Q3TP5kFZ+U/bqaucv5tfx0NRZhOt9D64eY2+F0dDMtaOEafwEUhDZJ
\
\>"],
  ImageRangeCache->{{{0, 299.75}, {235.313, 0}} -> {-4, -1, 0, 0}}],
 "     ",
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0666667 0.266667 0.0666667 0.266667 [
[.33333 .05417 -3 -9 ]
[.33333 .05417 3 0 ]
[.6 .05417 -3 -9 ]
[.6 .05417 3 0 ]
[.86667 .05417 -3 -9 ]
[.86667 .05417 3 0 ]
[1.025 .06667 0 -6.28125 ]
[1.025 .06667 10 6.28125 ]
[.05417 .33333 -6 -4.5 ]
[.05417 .33333 0 4.5 ]
[.05417 .6 -6 -4.5 ]
[.05417 .6 0 4.5 ]
[.05417 .86667 -6 -4.5 ]
[.05417 .86667 0 4.5 ]
[.06667 1.025 -5 0 ]
[.06667 1.025 5 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.33333 .06667 m
.33333 .07292 L
s
[(1)] .33333 .05417 0 1 Mshowa
.6 .06667 m
.6 .07292 L
s
[(2)] .6 .05417 0 1 Mshowa
.86667 .06667 m
.86667 .07292 L
s
[(3)] .86667 .05417 0 1 Mshowa
0 .06667 m
1 .06667 L
s
gsave
1.025 .06667 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(u) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.06667 .33333 m
.07292 .33333 L
s
[(1)] .05417 .33333 1 0 Mshowa
.06667 .6 m
.07292 .6 L
s
[(2)] .05417 .6 1 0 Mshowa
.06667 .86667 m
.07292 .86667 L
s
[(3)] .05417 .86667 1 0 Mshowa
.06667 0 m
.06667 1 L
s
gsave
.06667 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(v) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.52855 .06667 m
.52855 .06752 L
.52855 .0683 L
.52855 .0692 L
.52856 .07005 L
.52857 .07156 L
.52859 .0732 L
.52862 .075 L
.52866 .07691 L
.52875 .08034 L
.52887 .08388 L
.529 .08719 L
.5294 .09472 L
.52993 .10238 L
.53052 .10936 L
.53221 .12496 L
.53651 .15282 L
.54197 .17883 L
.54897 .20552 L
.55664 .23018 L
.56557 .25526 L
.57474 .27835 L
.58397 .29962 L
.59407 .32127 L
.60401 .34126 L
.61368 .35973 L
.62404 .37865 L
.63405 .39619 L
.64468 .41417 L
.65488 .4309 L
.66466 .44648 L
.67499 .46256 L
.68487 .47757 L
.69429 .49162 L
.70424 .50617 L
.71372 .51982 L
.72371 .53397 L
.73298 .54692 L
s
.56555 .06667 m
.56555 .06746 L
.56556 .06818 L
.56556 .06901 L
.56556 .0698 L
.56557 .07119 L
.56559 .07271 L
.56561 .07438 L
.56564 .07615 L
.56571 .07933 L
.56581 .08261 L
.56592 .08567 L
.56623 .09265 L
.56665 .09975 L
.56712 .10623 L
.56848 .12075 L
.56998 .13326 L
.57195 .14678 L
.57672 .17281 L
.58234 .19715 L
.58923 .22216 L
.59661 .2454 L
.60426 .26695 L
.61286 .28902 L
.6215 .30947 L
.63006 .32843 L
.63936 .3479 L
.64845 .36597 L
.65821 .38453 L
.66767 .4018 L
.67679 .4179 L
.6865 .4345 L
.69583 .45002 L
.70477 .46453 L
.71425 .47956 L
.72333 .49365 L
.73292 .50825 L
.74208 .52197 L
.75062 .53454 L
s
.6 .06667 m
.6 .06741 L
.6 .06808 L
.6 .06886 L
.60001 .06959 L
.60002 .0709 L
.60003 .07232 L
.60005 .07388 L
.60007 .07554 L
.60013 .07851 L
.60021 .08158 L
.6003 .08445 L
.60055 .09098 L
.6009 .09763 L
.60128 .10371 L
.6024 .11732 L
.60364 .12909 L
.60527 .14183 L
.60925 .16644 L
.61399 .1896 L
.61986 .21355 L
.62622 .23594 L
.63289 .25683 L
.64046 .27833 L
.64815 .29835 L
.65582 .31698 L
.66423 .33619 L
.67252 .35408 L
.68147 .3725 L
.6902 .38969 L
.69866 .40574 L
.70771 .42233 L
.71645 .43785 L
.72486 .45238 L
.73381 .46746 L
.7424 .4816 L
.7515 .49627 L
.76024 .51005 L
.76838 .52269 L
s
.63235 .06667 m
.63235 .06736 L
.63235 .068 L
.63236 .06873 L
.63236 .06943 L
.63237 .07066 L
.63238 .072 L
.63239 .07347 L
.63241 .07503 L
.63246 .07784 L
.63253 .08073 L
.6326 .08343 L
.63282 .0896 L
.63311 .09587 L
.63343 .10161 L
.63437 .11447 L
.63541 .1256 L
.63679 .13767 L
.64017 .16106 L
.64422 .18317 L
.64929 .20613 L
.65483 .22771 L
.66068 .24793 L
.66739 .26884 L
.67425 .28839 L
.68116 .30666 L
.68878 .32556 L
.69633 .34321 L
.70455 .36144 L
.7126 .37849 L
.72045 .39444 L
.72889 .41096 L
.73707 .42644 L
.74496 .44095 L
.7534 .45602 L
.76152 .47018 L
.77016 .48488 L
.77846 .4987 L
.78623 .51138 L
s
.66295 .06667 m
.66295 .06733 L
.66295 .06793 L
.66295 .06863 L
.66296 .06929 L
.66296 .07045 L
.66297 .07172 L
.66299 .07312 L
.663 .0746 L
.66305 .07726 L
.6631 .08001 L
.66316 .08258 L
.66335 .08842 L
.6636 .09438 L
.66387 .09982 L
.66468 .11205 L
.66557 .12263 L
.66676 .13412 L
.66967 .15645 L
.67318 .1776 L
.6776 .19967 L
.68247 .22048 L
.68765 .24006 L
.69363 .26038 L
.69978 .27945 L
.70601 .29733 L
.71293 .31588 L
.71983 .33326 L
.72738 .35125 L
.73482 .36812 L
.7421 .38394 L
.74996 .40034 L
.75761 .41574 L
.76503 .4302 L
.77297 .44523 L
.78065 .45937 L
.78883 .47406 L
.79673 .48789 L
.80412 .50059 L
s
.69206 .06667 m
.69206 .0673 L
.69206 .06787 L
.69206 .06854 L
.69206 .06916 L
.69207 .07028 L
.69207 .07149 L
.69209 .07282 L
.6921 .07424 L
.69214 .07677 L
.69218 .07939 L
.69224 .08184 L
.6924 .08741 L
.69261 .0931 L
.69285 .09829 L
.69355 .10996 L
.69433 .12007 L
.69536 .13106 L
.69791 .15243 L
.70099 .17274 L
.70488 .19399 L
.7092 .21408 L
.71381 .23305 L
.71917 .2528 L
.72471 .27139 L
.73036 .28887 L
.73666 .30705 L
.74298 .32414 L
.74993 .34186 L
.7568 .35852 L
.76356 .37417 L
.77089 .39043 L
.77805 .40571 L
.78501 .42009 L
.79249 .43505 L
.79974 .44914 L
.80749 .4638 L
.81499 .47761 L
.82203 .4903 L
s
.71986 .06667 m
.71986 .06727 L
.71986 .06782 L
.71987 .06846 L
.71987 .06906 L
.71987 .07012 L
.71988 .07128 L
.71989 .07256 L
.7199 .07391 L
.71994 .07634 L
.71998 .07884 L
.72003 .08119 L
.72017 .08653 L
.72035 .09197 L
.72057 .09695 L
.72118 .10813 L
.72186 .11782 L
.72277 .12837 L
.72502 .1489 L
.72775 .16845 L
.73121 .18894 L
.73506 .20838 L
.7392 .22677 L
.74403 .24597 L
.74905 .26409 L
.75418 .28117 L
.75995 .29898 L
.76575 .31575 L
.77215 .33319 L
.77851 .34962 L
.7848 .36507 L
.79163 .38116 L
.79833 .39631 L
.80487 .41058 L
.81191 .42545 L
.81876 .43947 L
.8261 .45407 L
.83322 .46784 L
.83992 .4805 L
s
.74654 .06667 m
.74654 .06725 L
.74654 .06778 L
.74654 .06839 L
.74654 .06896 L
.74654 .06999 L
.74655 .0711 L
.74656 .07233 L
.74657 .07363 L
.7466 .07596 L
.74664 .07837 L
.74668 .08062 L
.7468 .08575 L
.74697 .09098 L
.74716 .09577 L
.7477 .10652 L
.74831 .11584 L
.74912 .12598 L
.75112 .14576 L
.75356 .16462 L
.75666 .18443 L
.76012 .20326 L
.76386 .2211 L
.76823 .23978 L
.7728 .25745 L
.77749 .27414 L
.78277 .29158 L
.78811 .30803 L
.79402 .32518 L
.79993 .34135 L
.80578 .3566 L
.81216 .3725 L
.81844 .3875 L
.82458 .40164 L
.83121 .4164 L
.83768 .43032 L
.84464 .44484 L
.85139 .45855 L
.85777 .47117 L
s
.7722 .06667 m
.7722 .06723 L
.7722 .06774 L
.7722 .06832 L
.7722 .06888 L
.77221 .06987 L
.77221 .07094 L
.77222 .07212 L
.77223 .07338 L
.77226 .07562 L
.77229 .07794 L
.77233 .08011 L
.77244 .08506 L
.77259 .0901 L
.77276 .09471 L
.77325 .10508 L
.77379 .11407 L
.77451 .12386 L
.77631 .14296 L
.7785 .16119 L
.7813 .18037 L
.78444 .19863 L
.78783 .21597 L
.79181 .23415 L
.79598 .25138 L
.80028 .26769 L
.80514 .28476 L
.81007 .3009 L
.81555 .31775 L
.82103 .33367 L
.82648 .3487 L
.83245 .3644 L
.83833 .37923 L
.84411 .39322 L
.85037 .40785 L
.85648 .42167 L
.86306 .43609 L
.86948 .44972 L
.87555 .46228 L
s
.79696 .06667 m
.79696 .06721 L
.79696 .0677 L
.79697 .06827 L
.79697 .0688 L
.79697 .06976 L
.79698 .0708 L
.79698 .07194 L
.79699 .07315 L
.79701 .07532 L
.79704 .07756 L
.79708 .07966 L
.79718 .08444 L
.79731 .08931 L
.79747 .09376 L
.79791 .10378 L
.7984 .11247 L
.79905 .12194 L
.80068 .14042 L
.80266 .15809 L
.8052 .17669 L
.80805 .19443 L
.81115 .21129 L
.81479 .22901 L
.81862 .24582 L
.82257 .26176 L
.82706 .27848 L
.83162 .2943 L
.8367 .31085 L
.84181 .32651 L
.8469 .34132 L
.85249 .35681 L
.85801 .37145 L
.86345 .38529 L
.86935 .39978 L
.87513 .41348 L
.88137 .42779 L
.88746 .44133 L
.89323 .45381 L
s
.82091 .06667 m
.82091 .06719 L
.82091 .06767 L
.82092 .06822 L
.82092 .06874 L
.82092 .06966 L
.82092 .07067 L
.82093 .07177 L
.82094 .07294 L
.82096 .07504 L
.82099 .07721 L
.82102 .07925 L
.82111 .08387 L
.82123 .08859 L
.82137 .0929 L
.82177 .10261 L
.82222 .11103 L
.82281 .1202 L
.82429 .13812 L
.8261 .15527 L
.82842 .17334 L
.83103 .19059 L
.83386 .20701 L
.83721 .22428 L
.84073 .24071 L
.84439 .25629 L
.84854 .27266 L
.85277 .28818 L
.8575 .30443 L
.86227 .31983 L
.86703 .33442 L
.87226 .34968 L
.87746 .36414 L
.88258 .37782 L
.88815 .39216 L
.89362 .40572 L
.89954 .41991 L
.90532 .43335 L
.91082 .44575 L
s
.84413 .06667 m
.84413 .06717 L
.84413 .06764 L
.84413 .06817 L
.84413 .06867 L
.84413 .06957 L
.84414 .07055 L
.84414 .07162 L
.84415 .07276 L
.84417 .07479 L
.84419 .0769 L
.84422 .07887 L
.84431 .08336 L
.84442 .08794 L
.84454 .09212 L
.84491 .10154 L
.84532 .10971 L
.84586 .11862 L
.84721 .13603 L
.84887 .15269 L
.851 .17027 L
.85339 .18706 L
.856 .20308 L
.85909 .21993 L
.86235 .23598 L
.86573 .25123 L
.86959 .26726 L
.87352 .28248 L
.87794 .29844 L
.88239 .31358 L
.88686 .32794 L
.89177 .34299 L
.89666 .35726 L
.90149 .37078 L
.90675 .38495 L
.91193 .39838 L
.91755 .41243 L
.92305 .42576 L
.92828 .43806 L
s
.86667 .06667 m
.86667 .06716 L
.86667 .06761 L
.86667 .06813 L
.86667 .06862 L
.86667 .06949 L
.86668 .07044 L
.86668 .07148 L
.86669 .07258 L
.86671 .07457 L
.86673 .07661 L
.86675 .07853 L
.86683 .08289 L
.86693 .08734 L
.86705 .09141 L
.86738 .10056 L
.86776 .10851 L
.86826 .11717 L
.8695 .1341 L
.87103 .15032 L
.87299 .16744 L
.8752 .18382 L
.87761 .19944 L
.88047 .2159 L
.88349 .23159 L
.88663 .24652 L
.89022 .26223 L
.8939 .27717 L
.89802 .29284 L
.9022 .30773 L
.90638 .32187 L
.91101 .3367 L
.91562 .35077 L
.92018 .36412 L
.92516 .37813 L
.93007 .39141 L
.9354 .40533 L
.94063 .41854 L
.94561 .43074 L
s
0 0 1 r
.21914 1 m
.22652 .95635 L
.23724 .90044 L
.24974 .84355 L
.26629 .77913 L
.28671 .713 L
.31553 .63816 L
.35338 .56271 L
.4023 .4904 L
.46856 .42055 L
.5414 .36625 L
.6208 .32333 L
.69453 .29318 L
.76141 .27138 L
.82808 .25345 L
.88531 .2404 L
s
.23821 1 m
.24577 .96001 L
.25756 .90483 L
.27121 .84889 L
.28914 .78586 L
.31095 .72164 L
.34108 .64973 L
.37944 .57822 L
.42723 .51041 L
.48995 .44467 L
.55818 .39219 L
.63319 .34909 L
.70382 .31778 L
.76861 .29461 L
.83372 .27526 L
.88994 .26101 L
s
.25729 1 m
.26478 .96401 L
.27757 .90961 L
.29228 .85466 L
.31141 .79306 L
.33438 .73074 L
.36548 .66161 L
.40404 .59362 L
.45066 .52964 L
.51034 .46736 L
.57468 .41661 L
.64581 .37363 L
.71353 .3415 L
.77627 .3172 L
.8398 .29661 L
.89496 .2813 L
s
.27636 1 m
.28355 .96834 L
.29725 .91475 L
.31291 .86081 L
.3331 .80065 L
.35702 .74018 L
.38883 .67367 L
.42735 .60884 L
.4728 .54817 L
.52985 .48887 L
.59087 .43972 L
.65856 .39705 L
.72357 .36436 L
.78432 .33916 L
.84627 .31751 L
.90035 .30124 L
s
.29542 1 m
.30206 .97297 L
.3166 .92022 L
.33312 .86731 L
.35421 .80858 L
.37891 .7499 L
.41121 .68584 L
.44954 .62385 L
.49385 .56606 L
.54859 .50934 L
.60672 .46169 L
.67136 .41946 L
.73386 .38642 L
.79269 .36051 L
.85308 .33794 L
.90607 .32082 L
s
.31447 1 m
.3203 .97788 L
.33562 .92598 L
.35289 .8741 L
.37477 .81678 L
.40008 .75984 L
.4327 .69805 L
.47074 .63862 L
.51396 .58336 L
.56663 .52892 L
.62224 .48265 L
.68414 .44095 L
.74432 .40771 L
.80133 .38125 L
.86019 .35791 L
.91208 .34004 L
s
.33351 1 m
.33827 .98304 L
.35429 .932 L
.37224 .88116 L
.39478 .82522 L
.42057 .76993 L
.45338 .71026 L
.49105 .65315 L
.53322 .60012 L
.58406 .54771 L
.63743 .50273 L
.69687 .4616 L
.75491 .4283 L
.81019 .40141 L
.86756 .37743 L
.91837 .35889 L
s
.35252 1 m
.35596 .98844 L
.37262 .93827 L
.39116 .88845 L
.41426 .83385 L
.44043 .78013 L
.47332 .72243 L
.51056 .66742 L
.55175 .6164 L
.60092 .56581 L
.6523 .52202 L
.70952 .48148 L
.76558 .44821 L
.81922 .42102 L
.87515 .3965 L
.92489 .37739 L
s
.37152 1 m
.37338 .99406 L
.39061 .94474 L
.40967 .89593 L
.43323 .84263 L
.45969 .7904 L
.49256 .73454 L
.52935 .68143 L
.56961 .63222 L
.61727 .58327 L
.66686 .54059 L
.72206 .50067 L
.77629 .4675 L
.82838 .44009 L
.88293 .41514 L
.93162 .39552 L
s
.39048 1 m
.39052 .99987 L
.40826 .95141 L
.42778 .90358 L
.45173 .85154 L
.47838 .80072 L
.51118 .74656 L
.5475 .6952 L
.58688 .64763 L
.63315 .60017 L
.68112 .55853 L
.73449 .51922 L
.78703 .48621 L
.83766 .45866 L
.89087 .43335 L
.93854 .4133 L
s
.40962 1 m
.42558 .95824 L
.44549 .91138 L
.46975 .86054 L
.49655 .81106 L
.52921 .75849 L
.56506 .70873 L
.6036 .66265 L
.64861 .61655 L
.69509 .57588 L
.74679 .53717 L
.79775 .50437 L
.84701 .47674 L
.89895 .45115 L
.94561 .43074 L
s
0 g
gsave
.30667 .2 -61 -11.3438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22.6875 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 14.938 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.938 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(u) show
70.188 10.375 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
75.813 14.938 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
83.000 14.938 moveto
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(v) show
90.813 10.375 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
96.438 14.938 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
103.625 14.938 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
110.813 14.938 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.16 .54667 -61 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
70.188 12.813 moveto
(uv) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
91.750 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
98.938 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{245, 245},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
  ImageRangeCache->{{{0, 244}, {244, 0}} -> {0, 0, 0, 0}}],
 "  ",
 StyleBox["\n\t\tFigure 2.15",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  The mapping   ",
 Cell[BoxData[
  RowBox[{"w", "  ", "=", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "=", " ", 
    SuperscriptBox["z", 
     RowBox[{"1", "/", "2"}]]}]}]]],
 "    (and  ",
 Cell[BoxData[
  RowBox[{"z", "  ", "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["f", 
      RowBox[{"-", "1"}]], 
     RowBox[{"(", "w", ")"}]}], "=", " ", 
    SuperscriptBox["w", "2"]}]}]]],
 ")."
}], "Text"],

Cell[TextData[{
 StyleBox["Extra Example 2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 " Consider the mapping  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   SuperscriptBox["z", 
    RowBox[{"1", "/", "2"}]]}]],
  AspectRatioFixed->True],
 ".  Find the image of the ray  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"r", ">", "0"}], ",", 
   RowBox[{"\[Theta]", "=", "\[Alpha]"}]}]]],
 "  and circle ",
 Cell[BoxData[
  RowBox[{"r", "=", "c"}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Extra Solution 2.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "Find the image of the ray  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"r", ">", "0"}], ",", 
   RowBox[{"\[Theta]", "=", "\[Alpha]"}]}]]],
 "  and circle ",
 Cell[BoxData[
  RowBox[{"r", "=", "c"}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", 
     SuperscriptBox["z", 
      RowBox[{"1", "/", "2"}]]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Iden", "[", "z_", "]"}], " ", "=", " ", "z"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"PolarMap", "[", 
    RowBox[{"Iden", ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "9", ",", "0.5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", " ", "\[Pi]", ",", " ", 
       FractionBox[
        RowBox[{" ", "\[Pi]"}], "18"]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "9"}], ",", "9"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "9"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["1", "2"]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "9"}], ",", "9", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "9", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The rays r > 0, \[Theta] = \[Alpha], and circles r = c.\>\"", "]"}],
     ";"}], " ", "\n", 
   RowBox[{"PolarMap", "[", 
    RowBox[{"f", " ", ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "9", ",", "0.5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", " ", "\[Pi]", ",", " ", 
       FractionBox[
        RowBox[{" ", "\[Pi]"}], "18"]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "3"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "3", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "3", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The image rays r>0, \[Theta]=\!\(\*FractionBox[\(\[Alpha]\), \(2\)]\
\), and circles r=\!\(\*SqrtBox[\(c\)]\),\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<under the mapping  w = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.398977603515625*^9, 3.39897760834375*^9}, {
  3.399144397203125*^9, 3.399144458671875*^9}, {3.399743048578125*^9, 
  3.39974304878125*^9}},
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", 
     SuperscriptBox["z", 
      RowBox[{"1", "/", "2"}]]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Iden", "[", "z_", "]"}], " ", "=", " ", "z"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"PolarMap", "[", 
    RowBox[{"Iden", ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "9", ",", "0.5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox[
        RowBox[{" ", 
         RowBox[{
          RowBox[{"-", "2"}], "\[Pi]"}]}], "3"], ",", " ", 
       FractionBox[
        RowBox[{" ", 
         RowBox[{"2", "\[Pi]"}]}], "3"], ",", " ", 
       FractionBox[
        RowBox[{" ", "\[Pi]"}], "18"]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "9"}], ",", "9"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "9"}], ",", "9"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["1", "1"]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "9"}], ",", "9", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "9"}], ",", "9", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The rays r > 0, \[Theta] = \[Alpha], and circles r = c.\>\"", "]"}],
     ";"}], " ", "\n", 
   RowBox[{"PolarMap", "[", 
    RowBox[{"f", " ", ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "9", ",", "0.5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox[
        RowBox[{" ", 
         RowBox[{
          RowBox[{"-", "2"}], "\[Pi]"}]}], "3"], ",", 
       FractionBox[
        RowBox[{" ", 
         RowBox[{"2", "\[Pi]"}]}], "3"], ",", " ", 
       FractionBox[
        RowBox[{" ", "\[Pi]"}], "18"]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "3"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "2"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "3", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "3", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The image rays r>0, \[Theta]=\!\(\*FractionBox[\(\[Alpha]\), \(2\)]\
\), and circles r=\!\(\*SqrtBox[\(c\)]\),\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<under the mapping  w = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.398977613578125*^9, 3.398977618546875*^9}, {
  3.399144468125*^9, 3.399144487875*^9}, {3.39914453240625*^9, 
  3.399144598125*^9}, {3.399743054140625*^9, 3.399743054328125*^9}},
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", 
     SuperscriptBox["z", 
      RowBox[{"1", "/", "2"}]]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"g", "[", "z_", "]"}], "=", 
     RowBox[{"z", "+", "1"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"h", "[", "z_", "]"}], "=", 
     RowBox[{"f", "[", 
      RowBox[{"g", "[", "z", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"PolarMap", "[", 
    RowBox[{"g", ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1", ",", "0.1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", " ", "\[Pi]"}], ",", " ", "\[Pi]", ",", " ", 
       FractionBox[
        RowBox[{" ", "\[Pi]"}], "24"]}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "2", ",", "0.5"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", 
          FractionBox["1", "2"]}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"lemniscate", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SqrtBox["2"], 
          FractionBox[
           RowBox[{"Cos", "[", "t", "]"}], 
           RowBox[{"1", "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"Sin", "[", "t", "]"}], ")"}], "2"]}]]}], ",", 
         RowBox[{
          SqrtBox["2"], 
          FractionBox[
           RowBox[{
            RowBox[{"Cos", "[", "t", "]"}], 
            RowBox[{"Sin", "[", "t", "]"}]}], 
           RowBox[{"1", "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"Sin", "[", "t", "]"}], ")"}], "2"]}]]}]}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{"t", ",", 
         RowBox[{"-", "1.57"}], ",", "1.57"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Thickness", "[", "0.009", "]"}], ",", "Blue"}], "}"}]}]}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The radii, and circles.\>\"", "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"range", "=", 
     RowBox[{"PolarMap", "[", 
      RowBox[{"h", " ", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "1", ",", "0.1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", " ", "\[Pi]"}], ",", " ", "\[Pi]", ",", " ", 
         FractionBox[
          RowBox[{" ", "\[Pi]"}], "24"]}], "}"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "1.42"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.5"}], ",", "0.5"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", 
        FractionBox[
         RowBox[{" ", "1"}], "1.42"]}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "0.5", ",", "0.5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "1", ",", "0.5"}], "]"}]}], "}"}]}], ",",
        
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Show", "[", "range", "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<The image curves under the mapping  w = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"range", ",", "lemniscate"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The outer boundary curve is a lemniscate.\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<((u - 1\!\(\*SuperscriptBox[\()\), \(2\)]\) + \!\(\*SuperscriptBox[\
\(v\), \(2\)]\))((u + 1\!\(\*SuperscriptBox[\()\), \(2\)]\) + \
\!\(\*SuperscriptBox[\(v\), \(2\)]\)) = 1\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
   "Print", "[", 
    "\"\<(u,v) = (\!\(\*SqrtBox[\(2\)]\)\!\(\*FractionBox[\(Cos[t]\), \(1 + \
\*SuperscriptBox[\((Sin[t])\), \(2\)]\)]\), \
\!\(\*SqrtBox[\(2\)]\)\!\(\*FractionBox[\(Cos[t] Sin[t]\), \(1 + \
\*SuperscriptBox[\((Sin[t])\), \(2\)]\)]\))\>\"", "]"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.398977624421875*^9, 3.398977633703125*^9}, {
  3.39914460871875*^9, 3.399144632796875*^9}, {3.39974305915625*^9, 
  3.399743059328125*^9}, {3.400243138734375*^9, 3.400243181953125*^9}, {
  3.400243423390625*^9, 3.40024344846875*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 "\tWe can easily extend what we've done to integer powers greater than 2.  \
We begin by letting n be a positive integer, considering the function  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "=", 
    SuperscriptBox["z", "n"]}]}]]],
 ",  for  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{
    RowBox[{"r", " ", 
     SuperscriptBox["\[ExponentialE]", "\[ImaginaryI]\[Theta]"]}], 
    "\[NotEqual]", "0"}]}]]],
 ",  and then expressing it in the polar coordinate form\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"w", " ", "=", " ", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
    RowBox[{
     SuperscriptBox["z", "n"], " ", "=", " ", 
     RowBox[{
      SuperscriptBox["r", "n"], 
      SuperscriptBox["\[ExponentialE]", "\[ImaginaryI]n\[Theta]"]}]}]}]}]]],
 ".  \n\nIf we use polar coordinates for ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{"\[Rho]", " ", 
    SuperscriptBox["\[ExponentialE]", "\[ImaginaryI]\[Phi]"]}]}]]],
 " in the w -plane, this mapping can be given by the system of equations  \n\n\
\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{"\[Rho]", "=", 
    RowBox[{
     SuperscriptBox["r", "n"], 
     StyleBox[
      RowBox[{"  ", 
       StyleBox["  ",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]]}]], 
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"\[Phi]", "=", 
   RowBox[{"n", " ", 
    RowBox[{"\[Theta]", 
     StyleBox[".",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]]}]}]}]}]],
 "  "
}], "Text"],

Cell[TextData[{
 "\tThe image of the ray  ",
 Cell[BoxData[
  RowBox[{"r", ">", "0"}]]],
 ", ",
 Cell[BoxData[
  RowBox[{"\[Theta]", "=", "\[Alpha]"}]]],
 "  is the ray  ",
 Cell[BoxData[
  RowBox[{"\[Rho]", ">", "0"}]]],
 " , ",
 Cell[BoxData[
  RowBox[{"\[Phi]", "=", 
   RowBox[{"n", " ", "\[Alpha]"}]}]]],
 "  and the angles at the origin are increased by the factor ",
 StyleBox["n",
  FontFamily->"Courier New"],
 ".  The functions  ",
 Cell[BoxData[
  RowBox[{"cos", " ", "n", " ", "\[Theta]", "  ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "  ", "sin", " ", "n", " ", "\[Theta]"}]]],
 "  are periodic with period  ",
 Cell[BoxData[
  FractionBox[
   RowBox[{"2", "\[Pi]"}], "n"]]],
 ",  so ",
 StyleBox["f",
  FontFamily->"Courier New"],
 " is in general an ",
 StyleBox["n",
  FontFamily->"Courier New"],
 "-to-one function; that is, ",
 StyleBox["n",
  FontFamily->"Courier New"],
 " points in the ",
 StyleBox["z",
  FontFamily->"Courier New"],
 "-plane are mapped onto each non-zero point in the w-plane."
}], "Text"],

Cell[TextData[{
 "\t If we now restrict the domain of  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "=", 
    SuperscriptBox["z", "n"]}]}]]],
 "  to the region \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"E", "=", 
   RowBox[{"{", 
    RowBox[{"r", " ", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", "\[ImaginaryI]\[Theta]"], ":", " ", 
      RowBox[{"r", ">", 
       RowBox[{"0", " ", "and", " ", 
        FractionBox[
         RowBox[{"-", "\[Pi]"}], "n"]}], "<", " ", "\[Theta]", "\[LessEqual]",
        
       FractionBox["\[Pi]", "n"]}]}]}], "}"}]}]]],
 ",  \n\nthen the image of ",
 StyleBox["E",
  FontFamily->"Courier New"],
 " under the mapping  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   SuperscriptBox["z", "n"]}]]],
 "  can be described by the set  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"F", "=", 
   RowBox[{"{", 
    RowBox[{"\[Rho]", " ", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", "\[ImaginaryI]\[Phi]"], ":", " ", 
      RowBox[{"\[Rho]", ">", 
       RowBox[{
        RowBox[{"0", " ", "and"}], " ", "-", "\[Pi]"}], "<", " ", "\[Phi]", 
       "\[LessEqual]", "\[Pi]"}]}]}], "}"}]}]]],
 ",   \n\nwhich consists of all points in the w-plane except the point w=0.  \
The inverse mapping of f, which we shall denote by g, is then\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{
    RowBox[{"g", 
     RowBox[{"(", "w", ")"}]}], "=", 
    RowBox[{
     SuperscriptBox["w", 
      RowBox[{"1", "/", "n"}]], "=", 
     RowBox[{
      SuperscriptBox["\[Rho]", 
       RowBox[{"1", "/", "n"}]], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]\[Phi]", "/", "n"}]]}]}]}]}]]],
 ", \n\nwhere ",
 Cell[BoxData[
  RowBox[{"w", "\[Element]", "F"}]]],
 ".  That is\n\t\t\t",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{
    RowBox[{"g", 
     RowBox[{"(", "w", ")"}]}], "=", 
    RowBox[{
     SuperscriptBox["w", 
      RowBox[{"1", "/", "n"}]], "=", 
     RowBox[{"|", "w", 
      SuperscriptBox["|", 
       RowBox[{"1", "/", "n"}]], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]Arg", 
        RowBox[{
         RowBox[{"(", "w", ")"}], "/", "n"}]}]]}]}]}]}]]],
 ", \n\nwhere ",
 Cell[BoxData[
  RowBox[{"w", "\[NotEqual]", "0"}]]],
 ".  As with the principle square root function, we make an analogous \
definition for  ",
 Cell[BoxData[
  SuperscriptBox["n", "th"]]],
 " roots."
}], "Text",
 CellChangeTimes->{3.39897751515625*^9}],

Cell[TextData[{
 StyleBox["Definition 2.2 (Principal ",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 Cell[BoxData[
  StyleBox[
   SuperscriptBox["n", "th"],
   FontWeight->"Bold"]],
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[" Root Function).",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["  ",
  FontColor->RGBColor[0, 0, 1]],
 "The function",
 StyleBox[" \n\n\t\t\t",
  FontColor->RGBColor[0, 0, 1]],
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{
    RowBox[{"g", 
     RowBox[{"(", "w", ")"}]}], "=", 
    RowBox[{
     SuperscriptBox["w", 
      RowBox[{"1", "/", "n"}]], "=", 
     RowBox[{"|", "w", 
      SuperscriptBox["|", 
       RowBox[{"1", "/", "n"}]], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]Arg", 
        RowBox[{
         RowBox[{"(", "w", ")"}], "/", "n"}]}]]}]}]}]}]]],
 ", for ",
 Cell[BoxData[
  RowBox[{"w", "\[NotEqual]", "0"}]]],
 "  \n\n",
 "is called the principal  ",
 Cell[BoxData[
  SuperscriptBox["n", "th"]]],
 " root function."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
\tWe leave as an exercise to show that f and g are inverses of each other \
that map the set E one-to-one and onto the set F and the set F one-to-one and \
onto the set E, respectively. Figure 2.16 illustrates this relationship.\
\>", "Text"],

Cell[TextData[{
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .83333 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.166667 0.833333 0.416667 0.833333 [
[1.025 .41667 0 -6.28125 ]
[1.025 .41667 10 6.28125 ]
[.16667 .85833 -5 0 ]
[.16667 .85833 5 12.5625 ]
[ 0 0 0 0 ]
[ 1 .83333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .41667 m
1 .41667 L
s
gsave
1.025 .41667 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.16667 0 m
.16667 .83333 L
s
gsave
.16667 .85833 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .83333 L
0 .83333 L
closepath
clip
newpath
0 .9 1 r
.16667 .41667 m
1.70647 -0.22114 L
1.74488 -0.11907 L
.16667 .41667 L
F
0 .5 .95 r
.16667 .41667 m
1.74488 -0.11907 L
1.77654 -0.0147 L
.16667 .41667 L
F
0 0 1 r
.16667 .41667 m
1.77654 -0.0147 L
1.80131 .09152 L
.16667 .41667 L
F
1 0 0 r
.16667 .41667 m
1.80131 .09152 L
1.81907 .19912 L
.16667 .41667 L
F
.9 .45 .45 r
.16667 .41667 m
1.81907 .19912 L
1.82976 .30766 L
.16667 .41667 L
F
1 .75 .75 r
.16667 .41667 m
1.82976 .30766 L
1.83333 .41667 L
.16667 .41667 L
F
0 1 0 r
.16667 .41667 m
1.83333 .41667 L
1.82976 .52567 L
.16667 .41667 L
F
0 .95 0 r
.16667 .41667 m
1.82976 .52567 L
1.81907 .63421 L
.16667 .41667 L
F
.45 .95 .45 r
.16667 .41667 m
1.81907 .63421 L
1.80131 .74182 L
.16667 .41667 L
F
1 .5 0 r
.16667 .41667 m
1.80131 .74182 L
1.77654 .84803 L
.16667 .41667 L
F
1 .6 0 r
.16667 .41667 m
1.77654 .84803 L
1.74488 .9524 L
.16667 .41667 L
F
1 1 0 r
.16667 .41667 m
1.74488 .9524 L
1.70647 1.05447 L
.16667 .41667 L
F
0 0 0 r
.5 Mabswid
0 .41667 m
1 .41667 L
s
.16667 .41667 m
0 0 rlineto s
.16667 .41667 m
.16667 .83333 L
s
.16667 .41667 m
0 0 rlineto s
.16667 .41667 m
.16667 0 L
s
newpath
.16667 .41667 .79167 -22.5 22.5 arc
s
0 g
gsave
.91667 .56667 -61 -14.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 29.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
73.938 10.250 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
72.313 17.250 moveto
(\\200\\200) show
77.563 17.250 moveto
(\\200) show
79.875 17.250 moveto
(\\200) show
73.938 24.813 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
84.875 17.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.91667 .29167 -61 -14.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 29.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
70.188 17.250 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
81.125 10.250 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
79.500 17.250 moveto
(\\200\\200) show
84.750 17.250 moveto
(\\200) show
87.063 17.250 moveto
(\\200) show
81.125 24.813 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
92.063 17.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
1 .45833 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
77.375 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.11667 .84167 -61 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
77.375 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{243, 202.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
  ImageRangeCache->{{{0, 242}, {201.438, 0}} -> {0, 0, 0, 0}}],
 StyleBox["       ",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.337109 0.280925 [
[1.025 .33711 0 -6.28125 ]
[1.025 .33711 10 6.28125 ]
[.5 .64303 -8 0 ]
[.5 .64303 8 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .33711 m
1 .33711 L
s
gsave
1.025 .33711 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 .9 1 r
.5 .33711 m
-0.5 .33711 L
-0.36603 .05618 L
.5 .33711 L
F
0 .5 .95 r
.5 .33711 m
-0.36603 .05618 L
0 -0.14947 L
.5 .33711 L
F
0 0 1 r
.5 .33711 m
0 -0.14947 L
.5 -0.22474 L
.5 .33711 L
F
1 0 0 r
.5 .33711 m
.5 -0.22474 L
1 -0.14947 L
.5 .33711 L
F
.9 .45 .45 r
.5 .33711 m
1 -0.14947 L
1.36603 .05618 L
.5 .33711 L
F
1 .75 .75 r
.5 .33711 m
1.36603 .05618 L
1.5 .33711 L
.5 .33711 L
F
0 1 0 r
.5 .33711 m
1.5 .33711 L
1.36603 .61803 L
.5 .33711 L
F
0 .95 0 r
.5 .33711 m
1.36603 .61803 L
1 .82369 L
.5 .33711 L
F
.45 .95 .45 r
.5 .33711 m
1 .82369 L
.5 .89896 L
.5 .33711 L
F
1 .5 0 r
.5 .33711 m
.5 .89896 L
0 .82369 L
.5 .33711 L
F
1 .6 0 r
.5 .33711 m
0 .82369 L
-0.36603 .61803 L
.5 .33711 L
F
1 1 0 r
.5 .33711 m
-0.36603 .61803 L
-0.5 .33711 L
.5 .33711 L
F
0 0 0 r
.5 Mabswid
0 .33711 m
1 .33711 L
s
.5 .33711 m
.5 .61803 L
s
.5 .33711 m
.5 .05618 L
s
0 g
gsave
1 .35116 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(u) show
77.375 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.47 .63208 -61 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(v) show
77.375 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{327.625, 202.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
  ImageRangeCache->{{{0, 326.625}, {201.438, 0}} -> {-1, -1, 0, 0}}],
 StyleBox["  \n\tFigure 2.16",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  The mapping   ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "=", 
    SuperscriptBox["z", "n"]}]}]]],
 "   (and  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{
    RowBox[{"g", 
     RowBox[{"(", "w", ")"}]}], "=", 
    SuperscriptBox["w", 
     RowBox[{"1", "/", "n"}]]}]}]]],
 ").  "
}], "Text"],

Cell[TextData[{
 StyleBox["Extra Example 3.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Explore the mapping  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   SuperscriptBox["z", "3"]}]],
  AspectRatioFixed->True],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Extra Solution 3.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "Find the image of the ray  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"r", ">", "0"}], ",", 
   RowBox[{"\[Theta]", "=", "\[Alpha]"}]}]]],
 "  and circle ",
 Cell[BoxData[
  RowBox[{"r", "=", "c"}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", 
     SuperscriptBox["z", "3"]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Iden", "[", "z_", "]"}], " ", "=", " ", "z"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"PolarMap", "[", 
    RowBox[{"Iden", ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "3", ",", "0.25"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       FractionBox[
        RowBox[{" ", "\[Pi]"}], "2"], ",", " ", 
       FractionBox[
        RowBox[{" ", "\[Pi]"}], "36"]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "3.5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "3.5"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "9"}], ",", "9", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "9", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The rays r > 0, \[Theta] = \[Alpha], and circles r = c.\>\"", "]"}],
     ";"}], " ", "\n", 
   RowBox[{"PolarMap", "[", 
    RowBox[{"f", " ", ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "3", ",", "0.25"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       FractionBox[
        RowBox[{" ", "\[Pi]"}], "2"], ",", " ", 
       FractionBox[
        RowBox[{" ", "\[Pi]"}], "36"]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "27"}], ",", "27"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "27"}], ",", "27"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "27"}], ",", 
          RowBox[{"-", "8"}], ",", "0", ",", "1", ",", "8", ",", "27"}], 
         "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "27"}], ",", 
          RowBox[{"-", "8"}], ",", "0", ",", "8", ",", "27"}], "}"}]}], 
       "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The image rays r > 0, \[Theta] = 3\[Alpha], and circles r = \
\!\(\*SuperscriptBox[\(c\), \(3\)]\),\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<under the mapping  w = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39897765325*^9, 3.398977658515625*^9}, {
  3.399144830203125*^9, 3.399144864921875*^9}, {3.39974306475*^9, 
  3.399743064921875*^9}},
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", 
     SuperscriptBox["z", "3"]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Iden", "[", "z_", "]"}], " ", "=", " ", "z"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"PolarMap", "[", 
    RowBox[{"Iden", ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "3", ",", "0.25"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox[
        RowBox[{" ", 
         RowBox[{"-", "\[Pi]"}]}], "4"], ",", 
       FractionBox[
        RowBox[{" ", "\[Pi]"}], "4"], ",", " ", 
       FractionBox[
        RowBox[{" ", "\[Pi]"}], "36"]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "4"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.5"}], ",", "2.5"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["5", "4"]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "9"}], ",", "9", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "9"}], ",", "9", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The rays r > 0, \[Theta] = \[Alpha], and circles r = c.\>\"", "]"}],
     ";"}], " ", "\n", 
   RowBox[{"PolarMap", "[", 
    RowBox[{"f", " ", ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "3", ",", "0.25"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox[
        RowBox[{" ", 
         RowBox[{"-", "\[Pi]"}]}], "4"], ",", 
       FractionBox[
        RowBox[{" ", "\[Pi]"}], "4"], ",", " ", 
       FractionBox[
        RowBox[{" ", "\[Pi]"}], "36"]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "27"}], ",", "27"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "27"}], ",", "27"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "27"}], ",", 
          RowBox[{"-", "8"}], ",", "0", ",", "1", ",", 
          RowBox[{"{", 
           RowBox[{"8", ",", "\"\< 8\>\""}], "}"}], ",", "27"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "27"}], ",", 
          RowBox[{"-", "8"}], ",", "0", ",", "8", ",", "27"}], "}"}]}], 
       "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The image rays r > 0, \[Theta] = 3\[Alpha], and circles r = \
\!\(\*SuperscriptBox[\(c\), \(3\)]\),\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<under the mapping  w = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.398977662421875*^9, 3.398977667578125*^9}, {
  3.39914487384375*^9, 3.39914489609375*^9}, {3.39974306984375*^9, 
  3.399743070015625*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "Find the image of the rectangle ",
 Cell[BoxData[
  RowBox[{"R", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"x", ",", "y"}], ")"}], ":", " ", 
      RowBox[{"0", "<", "x", "<", 
       FractionBox["1", "2"]}]}], ",", 
     RowBox[{"0", "<", "y", "<", 
      FractionBox["7", "5"]}]}], "}"}]}]],
  AspectRatioFixed->True],
 "."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "Iden", ",", "z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"Iden", "[", "z_", "]"}], " ", "=", " ", "z"}], ";"}], " ", "\n",
    
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     SuperscriptBox["z", "3"]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"CartesianMap", "[", 
    RowBox[{"Iden", ",", " ", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0.5", ",", "0.1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1.4", ",", "0.1"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.05"}], ",", "0.55"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.05"}], ",", "1.5"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["2.2", "0.7"]}], ",", "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", 
          FractionBox["1", "2"], ",", 
          FractionBox["1", "2"]}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "2", ",", 
          FractionBox["1", "5"]}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The rectangle {(x,y): 0 < x < \!\(\*FractionBox[\(1\), \(2\)]\), 0 \
< y < \!\(\*FractionBox[\(7\), \(5\)]\)}\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{"CartesianMap", "[", 
    RowBox[{"f", ",", " ", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0.5", ",", "0.1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1.4", ",", "0.1"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "0.25"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "0.25"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "0", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "4"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<The image under the mapping  w = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.398977670484375*^9, 3.398977675671875*^9}, {
  3.399144909484375*^9, 3.399144912609375*^9}, {3.399743075265625*^9, 
  3.3997430754375*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Extra Example 4.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Explore the mapping  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   SuperscriptBox["z", "4"]}]],
  AspectRatioFixed->True],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Extra Solution 4.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "Find the image of the ray  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"r", ">", "0"}], ",", 
   RowBox[{"\[Theta]", "=", "\[Alpha]"}]}]]],
 "  and circle ",
 Cell[BoxData[
  RowBox[{"r", "=", "c"}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", 
     SuperscriptBox["z", "4"]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Iden", "[", "z_", "]"}], " ", "=", " ", "z"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"PolarMap", "[", 
    RowBox[{"Iden", ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "2", ",", "0.25"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       FractionBox[
        RowBox[{" ", "\[Pi]"}], "4"], ",", " ", 
       FractionBox[
        RowBox[{" ", "\[Pi]"}], "32"]}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "1.5"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["1", "2"]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "9"}], ",", "9", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "9", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The rays r > 0, \[Theta] = \[Alpha], and circles r = c.\>\"", "]"}],
     ";"}], " ", "\n", 
   RowBox[{"PolarMap", "[", 
    RowBox[{"f", " ", ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "2", ",", "0.25"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       FractionBox[
        RowBox[{" ", "\[Pi]"}], "4"], ",", " ", 
       FractionBox[
        RowBox[{" ", "\[Pi]"}], "32"]}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "16"}], ",", "16"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "16"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["1", "2"]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "16"}], ",", "16", ",", "4"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "16", ",", "4"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The image rays r > 0, \[Theta] = 4\[Alpha], and circles r = \
\!\(\*SuperscriptBox[\(c\), \(4\)]\),\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<under the mapping  w = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.398977682109375*^9, 3.398977686578125*^9}, {
  3.3991449451875*^9, 3.399144985171875*^9}, {3.399743080171875*^9, 
  3.39974308034375*^9}, {3.40024347275*^9, 3.400243484734375*^9}},
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", 
     SuperscriptBox["z", "4"]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Iden", "[", "z_", "]"}], " ", "=", " ", "z"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"PolarMap", "[", 
    RowBox[{"Iden", ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "2", ",", "0.25"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox[
        RowBox[{" ", 
         RowBox[{"-", "\[Pi]"}]}], "6"], ",", 
       FractionBox[
        RowBox[{" ", "\[Pi]"}], "6"], ",", " ", 
       FractionBox[
        RowBox[{" ", "\[Pi]"}], "36"]}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.5"}], ",", "1.5"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "2", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The rays r > 0, \[Theta] = \[Alpha], and circles r = c.\>\"", "]"}],
     ";"}], " ", "\n", 
   RowBox[{"PolarMap", "[", 
    RowBox[{"f", " ", ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "2", ",", "0.25"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox[
        RowBox[{" ", 
         RowBox[{"-", "\[Pi]"}]}], "6"], ",", 
       FractionBox[
        RowBox[{" ", "\[Pi]"}], "6"], ",", " ", 
       FractionBox[
        RowBox[{" ", "\[Pi]"}], "36"]}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "16"}], ",", "16"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "16"}], ",", "16"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "16"}], ",", "16", ",", "4"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "16"}], ",", "16", ",", "4"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The image rays r > 0, \[Theta] = 4\[Alpha], and circles r = \
\!\(\*SuperscriptBox[\(c\), \(4\)]\),\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<under the mapping  w = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.398977690890625*^9, 3.398977696078125*^9}, {
  3.3991449983125*^9, 3.39914501884375*^9}, {3.399743085265625*^9, 
  3.399743085453125*^9}, {3.4002434898125*^9, 3.400243494421875*^9}},
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "Iden", ",", "z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"Iden", "[", "z_", "]"}], " ", "=", " ", "z"}], ";"}], " ", "\n",
    
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     SuperscriptBox["z", "4"]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"CartesianMap", "[", 
    RowBox[{"Iden", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.6"}], ",", "0.0", ",", "0.05"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1.1", ",", "0.05"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.65"}], ",", "0.05"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.05"}], ",", "1.15"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["2.2", "0.7"]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "0.6"}], ",", "0.0", ",", "0.6"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "1", ",", "0.2"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The rectangle {(x,y): -\!\(\*FractionBox[\(3\), \(5\)]\) < x < 0, 0 \
< y < \!\(\*FractionBox[\(11\), \(10\)]\)}\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{"CartesianMap", "[", 
    RowBox[{"f", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.6"}], ",", "0.0", ",", "0.05"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1.1", ",", "0.05"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.055"}], ",", "1.5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.2"}], ",", "2.3"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "3", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "4"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<The image under the mapping  w = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3989776996875*^9, 3.398977704015625*^9}, {
  3.39914503128125*^9, 3.399145034265625*^9}, {3.39974309059375*^9, 
  3.39974309078125*^9}, {3.40024350328125*^9, 3.40024350878125*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Extra Example 5.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Explore the mapping  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   SuperscriptBox["z", 
    RowBox[{"1", "/", "3"}]]}]],
  AspectRatioFixed->True],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Extra Solution 5.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", 
     SuperscriptBox["z", 
      RowBox[{"1", "/", "3"}]]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Iden", "[", "z_", "]"}], " ", "=", " ", "z"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"PolarMap", "[", 
    RowBox[{"Iden", ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "8", ",", "0.5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       FractionBox[
        RowBox[{" ", 
         RowBox[{"3", "\[Pi]"}]}], "4"], ",", " ", 
       FractionBox[
        RowBox[{" ", "\[Pi]"}], "16"]}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "6.5"}], ",", "8.5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "9"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["9", "15"]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "9"}], ",", "9", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "8", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The rays r > 0, \[Theta] = \[Alpha], and circles r = c.\>\"", "]"}],
     ";"}], " ", "\n", 
   RowBox[{"PolarMap", "[", 
    RowBox[{"f", " ", ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "8", ",", "0.5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       FractionBox[
        RowBox[{" ", 
         RowBox[{"3", "\[Pi]"}]}], "4"], ",", " ", 
       FractionBox[
        RowBox[{" ", "\[Pi]"}], "16"]}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "2.2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "1.5"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["1.5", "2.2"]}], ",", "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "9"}], ",", "9", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "8", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The image rays r > 0, \[Theta] = \!\(\*FractionBox[\(1\), \(3\)]\)\
\[Alpha], and circles r = \!\(\*SuperscriptBox[\(c\), \(1/3\)]\),\>\"", "]"}],
     ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<under the mapping  w = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.398977711859375*^9, 3.398977715828125*^9}, {
  3.39914505253125*^9, 3.3991450553125*^9}, {3.399743095453125*^9, 
  3.399743095640625*^9}, {3.400243516046875*^9, 3.400243518171875*^9}},
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "Iden"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"Iden", "[", "z_", "]"}], "=", "z"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", 
     SuperscriptBox["z", 
      RowBox[{"1", "/", "3"}]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"CartesianMap", "[", 
    RowBox[{"Iden", ",", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "9"}], ",", "9", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "10", ",", "1"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "10"}], ",", "10"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.5"}], ",", "11"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["1", "2"]}], ",", "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "9"}], ",", "9", ",", "3"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "9", ",", "3"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<Vertical lines x = a, and horizontal lines y = b.\>\"",
      "]"}], ";"}], " ", "\n", 
   RowBox[{"CartesianMap", "[", 
    RowBox[{"f", ",", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "10"}], ",", "10", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "10", ",", "1"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.3"}], ",", "3.3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.3"}], ",", "3.3"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "3", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "3", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<The image curves under the mapping  w = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3989777208125*^9, 3.398977726515625*^9}, {
  3.39914506346875*^9, 3.3991450665*^9}, {3.39914511246875*^9, 
  3.399145145953125*^9}, {3.399743100703125*^9, 3.39974310090625*^9}, {
  3.40024352515625*^9, 3.400243526734375*^9}},
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "Iden"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"Iden", "[", "z_", "]"}], "=", "z"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", 
     SuperscriptBox["z", 
      RowBox[{"1", "/", "3"}]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"CartesianMap", "[", 
    RowBox[{"Iden", ",", " ", 
     RowBox[{"{", 
      RowBox[{"0", ",", "10", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "9"}], ",", "9", ",", "1"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "10"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "10"}], ",", "10"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "2"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "8"}], ",", "8", ",", "2"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "8"}], ",", "8", ",", "2"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<Vertical lines x = a, and horizontal lines y = b.\>\"",
      "]"}], ";"}], " ", "\n", 
   RowBox[{"CartesianMap", "[", 
    RowBox[{"f", ",", " ", 
     RowBox[{"{", 
      RowBox[{"0", ",", "10", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "9"}], ",", "9", ",", "1"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.3"}], ",", "2.3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.3"}], ",", "1.3"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "3", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "3", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<The image curves under the mapping  w = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39897773046875*^9, 3.398977736*^9}, {
  3.39914515453125*^9, 3.3991451589375*^9}, {3.39914519915625*^9, 
  3.399145232515625*^9}, {3.399743106984375*^9, 3.3997431071875*^9}, {
  3.40024353353125*^9, 3.40024353503125*^9}},
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", 
     SuperscriptBox["z", 
      RowBox[{"1", "/", "3"}]]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"g", "[", "z_", "]"}], "=", 
     RowBox[{"z", "+", "1"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"h", "[", "z_", "]"}], "=", 
     RowBox[{"f", "[", 
      RowBox[{"g", "[", "z", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"PolarMap", "[", 
    RowBox[{"g", ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1", ",", "0.1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", " ", "\[Pi]"}], ",", " ", "\[Pi]", ",", " ", 
       FractionBox[
        RowBox[{" ", "\[Pi]"}], "24"]}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "2", ",", "0.5"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", 
          FractionBox["1", "2"]}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"lemniscate", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SqrtBox["2"], 
          FractionBox[
           RowBox[{"Cos", "[", "t", "]"}], 
           RowBox[{"1", "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"Sin", "[", "t", "]"}], ")"}], "2"]}]]}], ",", 
         RowBox[{
          SqrtBox["2"], 
          FractionBox[
           RowBox[{
            RowBox[{"Cos", "[", "t", "]"}], 
            RowBox[{"Sin", "[", "t", "]"}]}], 
           RowBox[{"1", "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"Sin", "[", "t", "]"}], ")"}], "2"]}]]}]}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{"t", ",", 
         RowBox[{"-", "1.57"}], ",", "1.57"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Thickness", "[", "0.009", "]"}], ",", "Red"}], "}"}]}]}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The radii, and circles.\>\"", "]"}], ";"}], 
   " ", "\n", 
   RowBox[{"PolarMap", "[", 
    RowBox[{"h", " ", ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1", ",", "0.1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", " ", "\[Pi]"}], ",", " ", "\[Pi]", ",", " ", 
       FractionBox[
        RowBox[{" ", "\[Pi]"}], "24"]}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "1.42"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.5"}], ",", "0.5"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox[
       RowBox[{" ", "1"}], "1.42"]}], ",", "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "0.5", ",", "0.5"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", "0.5"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<The image curves under the mapping  w = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39897774065625*^9, 3.398977746375*^9}, {
  3.399145266109375*^9, 3.39914526940625*^9}, {3.399743112375*^9, 
  3.3997431125625*^9}, {3.4002431645*^9, 3.40024316503125*^9}, {
  3.40024354221875*^9, 3.400243545078125*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell["\<\
The \"legacy version\" being used to implement the commands \"CartesianMap \
and PolarMap.\"  The following Initialization Cell will load these \
subroutines. \
\>", "Text",
 CellChangeTimes->{{3.399722161203125*^9, 3.399722165296875*^9}, {
  3.39972222759375*^9, 3.3997223229375*^9}, {3.399722389046875*^9, 
  3.399722641234375*^9}, {3.399722683734375*^9, 3.3997227230625*^9}, {
  3.3997227559375*^9, 3.399722850765625*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Initialization Cell",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text",
 CellChangeTimes->{{3.399722161203125*^9, 3.399722165296875*^9}, {
  3.39972222759375*^9, 3.3997223229375*^9}, {3.399722389046875*^9, 
  3.399722641234375*^9}, {3.399722683734375*^9, 3.3997227230625*^9}, {
  3.3997227559375*^9, 3.399722850765625*^9}, {3.399742279828125*^9, 
  3.39974228209375*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}]], "Input",\

 InitializationCell->True]
}, Closed]],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Graphics for Complex Functions",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/ComplexGraphicsBib.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/complex.html"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2008 John H. Mathews, Russell W. \
Howell",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/"], None}],
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[0, 1, 0]]], "Text",
 CellChangeTimes->{{3.3989773221875*^9, 3.39897732228125*^9}}]
},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{1012, 611},
WindowMargins->{{Automatic, 1}, {Automatic, 0}},
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "CHAPTER 1"->{
  Cell[568, 21, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"CHAPTER 1", 263975, 10343}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"],
Cell[905, 32, 491, 20, 30, "Text"],
Cell[1399, 54, 1168, 38, 155, "Text"],
Cell[2570, 94, 2183, 75, 200, "Text"],
Cell[4756, 171, 1287, 44, 178, "Text"],
Cell[6046, 217, 1121, 39, 104, "Text",
 Evaluatable->False],
Cell[7170, 258, 753, 21, 47, "Text"],
Cell[7926, 281, 14866, 611, 213, "Text"],
Cell[22795, 894, 2229, 79, 179, "Text"],
Cell[25027, 975, 1048, 39, 47, "Text",
 Evaluatable->False],
Cell[26078, 1016, 1764, 65, 159, "Text",
 Evaluatable->False],
Cell[27845, 1083, 1629, 60, 134, "Text",
 Evaluatable->False],
Cell[29477, 1145, 2219, 77, 77, "Text",
 Evaluatable->False],
Cell[31699, 1224, 1222, 40, 53, "Text",
 Evaluatable->False],
Cell[32924, 1266, 55743, 2802, 320, "Text"],
Cell[CellGroupData[{
Cell[88692, 4072, 157, 4, 29, "Text",
 Evaluatable->False],
Cell[88852, 4078, 95, 2, 29, "Text"],
Cell[88950, 4082, 2356, 69, 292, "Input"],
Cell[91309, 4153, 239, 10, 29, "Text",
 Evaluatable->False],
Cell[91551, 4165, 1335, 38, 172, "Input"],
Cell[92889, 4205, 563, 23, 77, "Text",
 Evaluatable->False],
Cell[93455, 4230, 1335, 38, 172, "Input"],
Cell[94793, 4270, 505, 20, 59, "Text",
 Evaluatable->False],
Cell[95301, 4292, 3715, 101, 388, "Input"],
Cell[99019, 4395, 3827, 105, 388, "Input"]
}, Closed]],
Cell[102861, 4503, 491, 20, 26, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[103377, 4527, 160, 4, 29, "Text",
 Evaluatable->False],
Cell[103540, 4533, 280, 12, 29, "Text",
 Evaluatable->False],
Cell[103823, 4547, 3651, 104, 360, "Input"],
Cell[107477, 4653, 3961, 113, 312, "Input"],
Cell[111441, 4768, 5158, 141, 427, "Input"]
}, Closed]],
Cell[116614, 4912, 2605, 89, 173, "Text"],
Cell[119222, 5003, 3380, 121, 119, "Text",
 Evaluatable->False],
Cell[122605, 5126, 14973, 615, 213, "Text"],
Cell[CellGroupData[{
Cell[137603, 5745, 157, 4, 29, "Text",
 Evaluatable->False],
Cell[137763, 5751, 67, 0, 29, "Text"],
Cell[137833, 5753, 1870, 64, 212, "Input"],
Cell[139706, 5819, 177, 7, 29, "Text"],
Cell[139886, 5828, 2206, 77, 336, "Input"],
Cell[142095, 5907, 239, 10, 29, "Text",
 Evaluatable->False],
Cell[142337, 5919, 842, 26, 138, "Input"],
Cell[143182, 5947, 241, 10, 29, "Text",
 Evaluatable->False],
Cell[143426, 5959, 844, 26, 138, "Input"],
Cell[144273, 5987, 167, 7, 29, "Text",
 Evaluatable->False],
Cell[144443, 5996, 3488, 98, 343, "Input"]
}, Closed]],
Cell[147946, 6097, 2673, 79, 223, "Text"],
Cell[150622, 6178, 30365, 1465, 280, "Text"],
Cell[180990, 7645, 516, 21, 29, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[181531, 7670, 160, 4, 29, "Text",
 Evaluatable->False],
Cell[181694, 7676, 280, 12, 29, "Text",
 Evaluatable->False],
Cell[181977, 7690, 3434, 95, 356, "Input"],
Cell[185414, 7787, 3931, 113, 360, "Input"],
Cell[189348, 7902, 5690, 158, 453, "Input"]
}, Closed]],
Cell[195053, 8063, 2150, 70, 191, "Text"],
Cell[197206, 8135, 1210, 45, 53, "Text"],
Cell[198419, 8182, 2475, 82, 313, "Text"],
Cell[200897, 8266, 1082, 42, 105, "Text",
 Evaluatable->False],
Cell[201982, 8310, 252, 4, 47, "Text"],
Cell[202237, 8316, 19824, 771, 238, "Text"],
Cell[222064, 9089, 288, 12, 29, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[222377, 9105, 160, 4, 29, "Text",
 Evaluatable->False],
Cell[222540, 9111, 280, 12, 29, "Text",
 Evaluatable->False],
Cell[222823, 9125, 3649, 104, 332, "Input"],
Cell[226475, 9231, 3951, 114, 346, "Input"],
Cell[230429, 9347, 449, 17, 35, "Text",
 Evaluatable->False],
Cell[230881, 9366, 3492, 97, 341, "Input"]
}, Closed]],
Cell[234388, 9466, 288, 12, 26, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[234701, 9482, 160, 4, 29, "Text",
 Evaluatable->False],
Cell[234864, 9488, 280, 12, 29, "Text",
 Evaluatable->False],
Cell[235147, 9502, 3545, 101, 296, "Input"],
Cell[238695, 9605, 3763, 109, 292, "Input"],
Cell[242461, 9716, 3451, 95, 287, "Input"]
}, Closed]],
Cell[245927, 9814, 313, 13, 26, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[246265, 9831, 160, 4, 29, "Text",
 Evaluatable->False],
Cell[246428, 9837, 3665, 104, 308, "Input"],
Cell[250096, 9943, 3350, 93, 273, "Input"],
Cell[253449, 10038, 3317, 92, 252, "Input"],
Cell[256769, 10132, 4680, 134, 332, "Input"]
}, Closed]],
Cell[261464, 10269, 435, 8, 26, "Text"],
Cell[CellGroupData[{
Cell[261924, 10281, 407, 7, 29, "Text"],
Cell[262334, 10290, 132, 4, 31, "Input",
 InitializationCell->True]
}, Closed]],
Cell[262481, 10297, 281, 7, 26, "Text"],
Cell[262765, 10306, 293, 7, 29, "Text"],
Cell[263061, 10315, 249, 5, 29, "Text"],
Cell[263313, 10322, 317, 7, 29, "Text"]
}
]
*)

(* End of internal cache information *)
