(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    136795,       4420]
NotebookOptionsPosition[    130494,       4221]
NotebookOutlinePosition[    131171,       4250]
CellTagsIndexPosition[    131097,       4245]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["Chapter 3  Analytic and Harmonic Functions",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
 StyleBox["Overview",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "\n\n\tDoes the notion of a derivative of a complex function make sense?  If \
so, how should it be defined and what does it represent?  These and similar \
questions are the focus of this chapter.  As you might guess, complex \
derivatives have a meaningful definition, and many of the standard derivative \
theorems from from calculus (such as the product rule and chain rule) carry \
over for complex functions.  There are also some interesting applications.  \
But not everything is symmetric.  You will learn in this chapter that the \
mean value theorem for derivatives does not extend to complex functions.  In \
later chapters you will see that differentiable complex functions are, in \
some sense, much more \"differentiable\" than differentiable real functions."
}], "Text"],

Cell[TextData[StyleBox["Section 3.1  Differentiable and Analytic Functions",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
 "\tUsing our imagination, we take our lead from elementary calculus and \
define the derivative of ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", "z", ")"}]}]]],
 " at ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 ", written ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "'"}], 
   RowBox[{"(", 
    SubscriptBox["z", "0"], ")"}]}]]],
 ", by  \n\n",
 StyleBox["(3-1)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"f", "'"}], 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}], " ", "=", " ", 
   RowBox[{
    UnderscriptBox["lim", 
     RowBox[{"z", " ", "\[Rule]", " ", 
      SubscriptBox["z", "0"]}]], " ", 
    FractionBox[
     RowBox[{
      RowBox[{"f", 
       RowBox[{"(", "z", ")"}]}], " ", "-", " ", 
      RowBox[{"f", 
       RowBox[{"(", 
        SubscriptBox["z", "0"], ")"}]}]}], 
     RowBox[{"z", " ", "-", " ", 
      SubscriptBox["z", "0"]}]]}]}]]],
 ",\n\nprovided that the limit exists.  If it does, we say that the function \
",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", "z", ")"}]}]]],
 " is differentiable at ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 ".  If we write  ",
 Cell[BoxData[
  RowBox[{"\[CapitalDelta]z", "=", 
   RowBox[{"z", "-", 
    SubscriptBox["z", "0"]}]}]]],
 ",  then we can express Equation ",
 StyleBox["(3-1)",
  FontColor->RGBColor[0, 0, 1]],
 " in the form\n\n",
 StyleBox["(3-2)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"f", "'"}], 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}], " ", "=", " ", 
   RowBox[{
    UnderscriptBox["lim", 
     RowBox[{"\[CapitalDelta]z", " ", "\[Rule]", " ", "0"}]], " ", 
    FractionBox[
     RowBox[{
      RowBox[{"f", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["z", "0"], "+", "\[CapitalDelta]z"}], ")"}]}], " ", "-",
       " ", 
      RowBox[{"f", 
       RowBox[{"(", 
        SubscriptBox["z", "0"], ")"}]}]}], "\[CapitalDelta]z"]}]}]]],
 ".  \n  \n\tIf we let  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{"\[CapitalDelta]w", "=", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "-", 
    RowBox[{"f", 
     RowBox[{"(", 
      SubscriptBox["z", "0"], ")"}]}]}]}]]],
 ",  then we can use the ",
 StyleBox[ButtonBox["Leibniz's",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Leibniz.\
html"], None}],
  FontVariations->{"Underline"->True}],
 " notation ",
 Cell[BoxData[
  FractionBox["dw", "dz"]]],
 " for the derivative:  \n\n",
 StyleBox["(3-3)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"f", "'"}], 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}], " ", "=", " ", 
   RowBox[{
    FractionBox["dw", "dz"], " ", "=", " ", 
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"\[CapitalDelta]z", " ", "\[Rule]", " ", "0"}]], " ", 
     FractionBox["\[CapitalDelta]w", "\[CapitalDelta]z"]}]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 StyleBox["Extra Example 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Use the limit definition to find the derivative  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "'"}], 
   RowBox[{"(", 
    SubscriptBox["z", "0"], ")"}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Extra Example 1.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "\[CapitalDelta]w", ",", "\[CapitalDelta]z", ",", "f", ",", "z", ",", 
      "z"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"lim1", "=", 
     RowBox[{"Limit", "[", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"f", "[", "Z", "]"}], "-", 
         RowBox[{"f", "[", 
          SubscriptBox["z", "0"], "]"}]}], 
        RowBox[{"Z", "-", 
         SubscriptBox["z", "0"]}]], ",", 
       RowBox[{"Z", "\[Rule]", 
        SubscriptBox["z", "0"]}], ",", 
       RowBox[{"Analytic", "\[Rule]", "True"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(lim\), \(z \[Rule] \*SubscriptBox[\(z\), \(0\
\)]\)]\) \!\(\*FractionBox[\(f[z] - f[\*SubscriptBox[\(z\), \(0\)]]\), \(z - \
\*SubscriptBox[\(z\), \(0\)]\)]\) = \>\"", ",", "lim1"}], " ", "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399019528921875*^9, 3.399019539546875*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", " ", 
     RowBox[{"lim1", " ", "\[Equal]", " ", 
      RowBox[{
       SuperscriptBox["f", "\[Prime]",
        MultilineFunction->None], "[", 
       SubscriptBox["z", "0"], "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399019542921875*^9, 3.39901954378125*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"lim2", "=", 
     RowBox[{"Limit", "[", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"f", "[", 
          RowBox[{
           SubscriptBox["z", "0"], "+", "\[CapitalDelta]z"}], "]"}], "-", 
         RowBox[{"f", "[", 
          SubscriptBox["z", "0"], "]"}]}], "\[CapitalDelta]z"], ",", 
       RowBox[{"\[CapitalDelta]z", "\[Rule]", "0"}], ",", 
       RowBox[{"Analytic", "\[Rule]", "True"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(lim\), \(\[CapitalDelta]z \[Rule] 0\)]\) \
\!\(\*FractionBox[\(f[\*SubscriptBox[\(z\), \(0\)] + \[CapitalDelta]z] - \
f[\*SubscriptBox[\(z\), \(0\)]]\), \(\[CapitalDelta]z\)]\) = \>\"", ",", 
      "lim2"}], " ", "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39901955203125*^9, 3.39901955384375*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", " ", 
     RowBox[{"lim2", " ", "\[Equal]", " ", 
      RowBox[{
       SuperscriptBox["f", "\[Prime]",
        MultilineFunction->None], "[", 
       SubscriptBox["z", "0"], "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399019556625*^9, 3.399019557625*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"\[CapitalDelta]w", "=", 
     RowBox[{
      RowBox[{"f", "[", 
       RowBox[{
        SubscriptBox["z", "0"], "+", "\[CapitalDelta]z"}], "]"}], "-", 
      RowBox[{"f", "[", 
       SubscriptBox["z", "0"], "]"}]}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"lim3", "=", 
     RowBox[{"Limit", "[", 
      RowBox[{
       FractionBox["\[CapitalDelta]w", "\[CapitalDelta]z"], ",", 
       RowBox[{"\[CapitalDelta]z", "\[Rule]", "0"}], ",", 
       RowBox[{"Analytic", "\[Rule]", "True"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(lim\), \(\[CapitalDelta]z \[Rule] 0\)]\) \
\!\(\*FractionBox[\(\[CapitalDelta]w\), \(\[CapitalDelta]z\)]\) = \>\"", ",", 
      "lim3"}], " ", "]"}], ";"}], " "}]}]], "Input",
 CellChangeTimes->{3.399019561359375*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", " ", 
     RowBox[{"lim3", " ", "\[Equal]", " ", 
      RowBox[{
       SuperscriptBox["f", "\[Prime]",
        MultilineFunction->None], "[", 
       SubscriptBox["z", "0"], "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399019530109375*^9, 3.399019567703125*^9}]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 3.1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Use the limit definition to find the derivative of  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   SuperscriptBox["z", "3"]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "Solution.  Using Equation ",
 StyleBox["(3-1)",
  FontColor->RGBColor[0, 0, 1]],
 ", we have  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "'"}], 
     RowBox[{"(", 
      SubscriptBox["z", "0"], ")"}]}], " ", "=", " ", 
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"z", " ", "\[Rule]", " ", 
       SubscriptBox["z", "0"]}]], " ", 
     FractionBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", " ", "-", " ", 
         SubscriptBox["z", "0"]}], ")"}], "3"], 
      RowBox[{"z", " ", "-", " ", 
       SubscriptBox["z", "0"]}]]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                ", 
   RowBox[{
    RowBox[{"=", " ", 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", " ", 
        SubscriptBox["z", "0"]}]], " ", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z", "2"], " ", "+", " ", 
          RowBox[{"z", " ", 
           SubscriptBox["z", "0"]}], " ", "+", " ", 
          SubsuperscriptBox["z", "0", "2"]}], ")"}], 
        RowBox[{"(", 
         RowBox[{"z", "-", 
          SubscriptBox["z", "0"]}], ")"}], " "}], 
       RowBox[{"z", " ", "-", " ", 
        SubscriptBox["z", "0"]}]]}]}], " ", 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                ", 
   RowBox[{
    RowBox[{"=", " ", 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", " ", 
        SubscriptBox["z", "0"]}]], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["z", "2"], "+", 
        RowBox[{"z", " ", 
         SubscriptBox["z", "0"]}], "+", 
        SubsuperscriptBox["z", "0", "2"]}], ")"}]}]}], " ", 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                ", 
   RowBox[{
    RowBox[{"=", " ", 
     RowBox[{"(", 
      RowBox[{
       SubsuperscriptBox["z", "0", "2"], "+", 
       RowBox[{
        SubscriptBox["z", "0"], " ", 
        SubscriptBox["z", "0"]}], "+", 
       SubsuperscriptBox["z", "0", "2"]}], ")"}]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                ", 
   RowBox[{"=", 
    RowBox[{"3", 
     SubsuperscriptBox["z", "0", "2"]}]}]}]}]],
 "  \n\nWe can drop the subscript on ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 " to obtain  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"f", "'"}], 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{"3", 
    SuperscriptBox["z", "2"]}]}]]],
 "  as a general formula."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 3.1.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell["Enter the function f[z].", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "difQuotient", ",", "\[CapitalDelta]f\[CapitalDelta]z", ",", "f", ",", 
      "lim", ",", "sub", ",", "z", ",", "Z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     SuperscriptBox["z", "3"]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f(z) = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.3990195785*^9}],

Cell["Form the difference quotient.", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"\[CapitalDelta]f\[CapitalDelta]z", " ", "=", " ", 
     FractionBox[
      RowBox[{
       RowBox[{"f", "[", "Z", "]"}], "-", 
       RowBox[{"f", "[", 
        SubscriptBox["z", "0"], "]"}]}], 
      RowBox[{"Z", " ", "-", " ", 
       SubscriptBox["z", "0"]}]]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<\!\(\*FractionBox[\(\[CapitalDelta]f\), \(\[CapitalDelta]z\)]\) = \
\!\(\*FractionBox[\(f[z] - f[\*SubscriptBox[\(z\), \(0\)]]\), \(z\\\  - \\\ \
\*SubscriptBox[\(z\), \(0\)]\)]\)\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*FractionBox[\(\[CapitalDelta]f\), \(\[CapitalDelta]z\)]\) = \
\>\"", ",", "\[CapitalDelta]f\[CapitalDelta]z"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399019583015625*^9}],

Cell[TextData[{
 "Observe that substitution of   ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "0"], "  ", 
   StyleBox["for",
    FontFamily->"Times New Roman"], "  ", "z"}]]],
 "  indeterminate."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"sub0", " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{"\[CapitalDelta]f\[CapitalDelta]z", ",", 
       RowBox[{
       "Z", " ", "\[Rule]", "\"\<\!\(\*SubscriptBox[\(z\), \(0\)]\)\>\""}]}], 
      "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"sub1", " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{"\[CapitalDelta]f\[CapitalDelta]z", ",", 
       RowBox[{"Z", " ", "\[Rule]", 
        SubscriptBox["z", "0"]}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Substitute Z = \!\(\*SubscriptBox[\(z\), \(0\)]\), \
\!\(\*FractionBox[\(\[CapitalDelta]f\), \(\[CapitalDelta]z\)]\) = \>\"", ",", 
      "\[CapitalDelta]f\[CapitalDelta]z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<              Get  \!\(\*FractionBox[\(\[CapitalDelta]f\), \(\
\[CapitalDelta]z\)]\) = \>\"", ",", "sub0"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<                   \!\(\*FractionBox[\(\[CapitalDelta]f\), \(\
\[CapitalDelta]z\)]\) = \>\"", ",", "sub1"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399019589203125*^9}],

Cell["\<\
Calculate the derivative as the limit of the difference quotient.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"lim", " ", "=", " ", 
     RowBox[{"Limit", "[", 
      RowBox[{"\[CapitalDelta]f\[CapitalDelta]z", ",", " ", 
       RowBox[{"Z", "\[Rule]", 
        SubscriptBox["z", "0"]}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<\!\(\*FractionBox[\(df\), \(dz\)]\) = \!\(\*UnderscriptBox[\(lim\), \
\(\[CapitalDelta]z \[Rule] 0\)]\) \!\(\*FractionBox[\(f[z] - \
f[\*SubscriptBox[\(z\), \(0\)]]\), \(z\\\  - \\\ \*SubscriptBox[\(z\), \(0\)]\
\)]\)\>\"", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*FractionBox[\(df\), \(dz\)]\) = \!\(\*UnderscriptBox[\(lim\), \
\(\[CapitalDelta]z \[Rule] 0\)]\) \>\"", ",", 
      "\[CapitalDelta]f\[CapitalDelta]z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*FractionBox[\(df\), \(dz\)]\) = \>\"", ",", "lim"}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399019598078125*^9}],

Cell[TextData[{
 "Notice that the difference quotient can be simplified before substitution \
of  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "0"], "  ", 
   StyleBox["for",
    FontFamily->"Times New Roman"], "  ", "z"}]]],
 "  and can be used to find the derivative."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"difQuotient", " ", "=", " ", 
     RowBox[{"Simplify", "[", "\[CapitalDelta]f\[CapitalDelta]z", "]"}]}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"n", " ", "=", " ", 
     RowBox[{"Factor", "[", 
      RowBox[{"Numerator", "[", "\[CapitalDelta]f\[CapitalDelta]z", "]"}], 
      "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"d", "=", 
     RowBox[{"Denominator", "[", "\[CapitalDelta]f\[CapitalDelta]z", "]"}]}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"sub", " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{"difQuotient", ",", 
       RowBox[{"Z", " ", "\[Rule]", 
        SubscriptBox["z", "0"]}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<\!\(\*FractionBox[\(df\), \(dz\)]\) = \!\(\*UnderscriptBox[\(lim\), \
\(\[CapitalDelta]z \[Rule] 0\)]\) \!\(\*FractionBox[\(f[z] - \
f[\*SubscriptBox[\(z\), \(0\)]]\), \(z\\\  - \\\ \*SubscriptBox[\(z\), \(0\)]\
\)]\)\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*FractionBox[\(df\), \(dz\)]\) = \!\(\*UnderscriptBox[\(lim\), \
\(\[CapitalDelta]z \[Rule] 0\)]\) \>\"", ",", 
      "\[CapitalDelta]f\[CapitalDelta]z"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*FractionBox[\(df\), \(dz\)]\) = \!\(\*UnderscriptBox[\(lim\), \
\(\[CapitalDelta]z \[Rule] 0\)]\) \>\"", ",", "n", ",", "\"\</(\>\"", ",", 
      "d", ",", "\"\<)\>\""}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*FractionBox[\(df\), \(dz\)]\) = \!\(\*UnderscriptBox[\(lim\), \
\(\[CapitalDelta]z \[Rule] 0\)]\) (\>\"", ",", "difQuotient", ",", 
      "\"\<)\>\""}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*FractionBox[\(df\), \(dz\)]\) = \>\"", ",", "sub"}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399019602609375*^9}],

Cell[TextData[{
 "Hence we have used the limit definition to find the derivative of  f[z]  at \
the point  ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 ".  \nThus, the derivative of   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["z", "3"], "  ", 
     StyleBox["is",
      FontFamily->"Times New Roman"], "  ", 
     RowBox[{"f", "'"}], 
     RowBox[{"(", "z", ")"}]}], "=", 
    RowBox[{"3", 
     SuperscriptBox["z", "2"]}]}]}]]],
 ".  "
}], "Text"]
}, Closed]],

Cell[TextData[{
 "\tPay careful attention to the complex value ",
 Cell[BoxData["\[CapitalDelta]z"]],
 " in Equation ",
 StyleBox["(3-3)",
  FontColor->RGBColor[0, 0, 1]],
 "; the value of the limit must be independent of the manner in which  ",
 Cell[BoxData[
  RowBox[{"\[CapitalDelta]z", "\[Rule]", "0"}]]],
 ".  If we can find two curves that end at ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 " along which ",
 Cell[BoxData[
  FractionBox["\[CapitalDelta]w", "\[CapitalDelta]z"]]],
 " approaches distinct values, then ",
 Cell[BoxData[
  FractionBox["\[CapitalDelta]w", "\[CapitalDelta]z"]]],
 " does not have a limit as  ",
 Cell[BoxData[
  RowBox[{"\[CapitalDelta]z", "\[Rule]", "0"}]]],
 "  and ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", "z", ")"}]}]]],
 " does not have a derivative at ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 ".  The same observation applies to the limits in Equations ",
 StyleBox["(3-2)",
  FontColor->RGBColor[0, 0, 1]],
 " and ",
 StyleBox["(3-1)",
  FontColor->RGBColor[0, 0, 1]],
 "."
}], "Text"],

Cell[TextData[{
 StyleBox["Example 3.2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  ",
 "Show that the function ",
 " ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   OverscriptBox[
    RowBox[{"z", " "}], "_"]}]]],
 "  is ",
 StyleBox["nowhere ",
  FontColor->RGBColor[1, 0, 1]],
 "differentiable."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "Solution.  We choose two approaches to the point  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "0"], " ", "=", " ", 
   RowBox[{
    SubscriptBox["x", "0"], "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["y", "0"]}]}]}]]],
 "  and compute limits of the difference quotients.  First, we approach ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "0"], " ", "=", " ", 
   RowBox[{
    SubscriptBox["x", "0"], "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["y", "0"]}]}]}]]],
 " along a line parallel to the x axis by forcing z to be of the form ",
 Cell[BoxData[
  RowBox[{"z", " ", "=", " ", 
   RowBox[{"x", "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["y", "0"]}]}]}]]],
 ".   \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{
    RowBox[{
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", " ", 
        SubscriptBox["z", "0"]}]], " ", 
      FractionBox[
       RowBox[{
        RowBox[{"f", 
         RowBox[{"(", "z", ")"}]}], " ", "-", " ", 
        RowBox[{"f", 
         RowBox[{"(", 
          SubscriptBox["z", "0"], ")"}]}]}], 
       RowBox[{"z", " ", "-", " ", 
        SubscriptBox["z", "0"]}]]}], " ", "=", "  ", 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"x", "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["y", "0"]}]}], ")"}], " ", "\[Rule]", " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["x", "0"], "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["y", "0"]}]}], ")"}]}]], " ", 
      FractionBox[
       RowBox[{
        RowBox[{"f", 
         RowBox[{"(", 
          RowBox[{"x", "+", 
           RowBox[{"\[ImaginaryI]", " ", 
            SubscriptBox["y", "0"]}]}], ")"}]}], " ", "-", " ", 
        RowBox[{"f", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["x", "0"], "+", 
           RowBox[{"\[ImaginaryI]", " ", 
            SubscriptBox["y", "0"]}]}], ")"}]}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"x", "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["y", "0"]}]}], ")"}], " ", "-", " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["x", "0"], "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["y", "0"]}]}], ")"}]}]]}]}], "\[IndentingNewLine]", 
    "\n", "                                            ", 
    RowBox[{"=", "  ", 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"x", "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["y", "0"]}]}], ")"}], " ", "\[Rule]", " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["x", "0"], "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["y", "0"]}]}], ")"}]}]], " ", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"x", "-", 
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["y", "0"]}]}], ")"}], " ", "-", " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["x", "0"], "-", 
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["y", "0"]}]}], ")"}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"x", "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["y", "0"]}]}], ")"}], " ", "-", " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["x", "0"], "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["y", "0"]}]}], ")"}]}]]}]}], "\[IndentingNewLine]", 
    "\n", "                                            ", 
    RowBox[{"=", "  ", 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"x", "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["y", "0"]}]}], ")"}], " ", "\[Rule]", " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["x", "0"], "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["y", "0"]}]}], ")"}]}]], " ", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"x", "-", 
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["y", "0"]}]}], ")"}], " ", "-", " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["x", "0"], "-", 
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["y", "0"]}]}], ")"}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"x", "-", 
          SubscriptBox["x", "0"]}], ")"}], " ", "+", " ", 
        RowBox[{"\[ImaginaryI]", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["y", "0"], "-", " ", 
           SubscriptBox["y", "0"]}], ")"}]}]}]]}]}], "\[IndentingNewLine]", 
    "\n", "                                            ", 
    RowBox[{"=", "  ", 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"x", "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["y", "0"]}]}], ")"}], " ", "\[Rule]", " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["x", "0"], "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["y", "0"]}]}], ")"}]}]], " ", 
      FractionBox[
       RowBox[{"x", " ", "-", " ", 
        SubscriptBox["x", "0"]}], 
       RowBox[{"x", " ", "-", " ", 
        SubscriptBox["x", "0"]}]]}]}], "\n", "\[IndentingNewLine]", 
    "                                            ", 
    RowBox[{"=", " ", 
     RowBox[{"1", 
      StyleBox[" ",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox[".",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]]}]}]}]}]]],
 "    "
}], "Text"],

Cell[TextData[{
 "Next, we approach ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 " along a line parallel to the y axis by forcing z to be of the form  ",
 Cell[BoxData[
  RowBox[{"z", " ", "=", " ", 
   RowBox[{
    SubscriptBox["x", "0"], "+", 
    RowBox[{"\[ImaginaryI]", " ", "y"}]}]}]]],
 ".   \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{
    RowBox[{
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", " ", 
        SubscriptBox["z", "0"]}]], " ", 
      FractionBox[
       RowBox[{
        RowBox[{"f", 
         RowBox[{"(", "z", ")"}]}], " ", "-", " ", 
        RowBox[{"f", 
         RowBox[{"(", 
          SubscriptBox["z", "0"], ")"}]}]}], 
       RowBox[{"z", " ", "-", " ", 
        SubscriptBox["z", "0"]}]]}], " ", "=", "  ", 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["x", "0"], "+", 
          RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], " ", "\[Rule]", " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["x", "0"], "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["y", "0"]}]}], ")"}]}]], " ", 
      FractionBox[
       RowBox[{
        RowBox[{"f", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["x", "0"], "+", 
           RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], " ", "-", " ", 
        RowBox[{"f", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["x", "0"], "+", 
           RowBox[{"\[ImaginaryI]", " ", 
            SubscriptBox["y", "0"]}]}], ")"}]}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["x", "0"], "+", 
          RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], " ", "-", " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["x", "0"], "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["y", "0"]}]}], ")"}]}]]}]}], "\[IndentingNewLine]", 
    "\n", "                                            ", 
    RowBox[{"=", "  ", 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["x", "0"], "+", 
          RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], " ", "\[Rule]", " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["x", "0"], "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["y", "0"]}]}], ")"}]}]], " ", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["x", "0"], "-", 
          RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], " ", "-", " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["x", "0"], "-", 
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["y", "0"]}]}], ")"}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["x", "0"], "+", 
          RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], " ", "-", " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["x", "0"], "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["y", "0"]}]}], ")"}]}]]}]}], "\[IndentingNewLine]", 
    "\n", "                                            ", 
    RowBox[{"=", "  ", 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["x", "0"], "+", 
          RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], " ", "\[Rule]", " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["x", "0"], "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["y", "0"]}]}], ")"}]}]], " ", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["x", "0"], "-", 
          RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], " ", "-", " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["x", "0"], "-", 
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["y", "0"]}]}], ")"}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["x", "0"], "-", 
          SubscriptBox["x", "0"]}], ")"}], " ", "+", " ", 
        RowBox[{"\[ImaginaryI]", 
         RowBox[{"(", 
          RowBox[{"y", "-", " ", 
           SubscriptBox["y", "0"]}], ")"}]}]}]]}]}], "\[IndentingNewLine]", 
    "\n", "                                            ", 
    RowBox[{"=", "  ", 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["x", "0"], "+", 
          RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], " ", "\[Rule]", " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["x", "0"], "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["y", "0"]}]}], ")"}]}]], " ", 
      FractionBox[
       RowBox[{
        RowBox[{"-", " ", "\[ImaginaryI]"}], 
        RowBox[{"(", 
         RowBox[{"y", " ", "-", " ", 
          SubscriptBox["y", "0"]}], ")"}]}], 
       RowBox[{"\[ImaginaryI]", 
        RowBox[{"(", 
         RowBox[{"y", " ", "-", " ", 
          SubscriptBox["y", "0"]}], ")"}]}]]}]}], "\n", "\[IndentingNewLine]",
     "                                            ", 
    RowBox[{"=", " ", 
     RowBox[{"-", " ", 
      RowBox[{"1", 
       StyleBox[" ",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], 
       StyleBox[".",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]]}]}]}]}]}]]],
 "   "
}], "Text"],

Cell[TextData[{
 "\tThe limits along the two paths are different, so there is no possible \
value for the right side of Equation ",
 StyleBox["(3-1)",
  FontColor->RGBColor[0, 0, 1]],
 ".  Therefore ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   OverscriptBox[
    RowBox[{"z", " "}], "_"]}]]],
 "  is not differentiable at the point ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 ", and since ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 " was arbitrary, ",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "=", 
    OverscriptBox[
     RowBox[{"z", " "}], "_"], " "}]}]]],
 " is ",
 StyleBox["nowhere",
  FontColor->RGBColor[1, 0, 1]],
 " differentiable."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 3.2.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "\[CapitalDelta]f", ",", "\[CapitalDelta]f\[CapitalDelta]x", ",", 
      "\[CapitalDelta]f\[CapitalDelta]y", ",", "\[CapitalDelta]x", ",", 
      "\[CapitalDelta]y", ",", "f", ",", "x", ",", "y", ",", "z"}], "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"Conjugate", "[", "z", "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f(z) = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39901961171875*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "First, form the difference quotient using  ",
 Cell[BoxData[
  RowBox[{"\[CapitalDelta]z", "=", "\[CapitalDelta]x"}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"\[CapitalDelta]f\[CapitalDelta]x", " ", "=", " ", 
     FractionBox[
      RowBox[{
       RowBox[{"f", "[", 
        RowBox[{
         SubscriptBox["x", "0"], " ", "+", " ", "\[CapitalDelta]x", " ", "+", 
         " ", 
         RowBox[{"\[ImaginaryI]", " ", 
          SubscriptBox["y", "0"]}]}], "]"}], "-", 
       RowBox[{"f", "[", 
        RowBox[{
         SubscriptBox["x", "0"], " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", 
          SubscriptBox["y", "0"]}]}], "]"}]}], 
      RowBox[{
       SubscriptBox["x", "0"], " ", "+", " ", "\[CapitalDelta]x", " ", "+", 
       " ", 
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["y", "0"]}], "  ", "-", " ", 
       SubscriptBox["x", "0"], " ", "-", " ", 
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["y", "0"]}]}]]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"n", "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"Numerator", "[", "\[CapitalDelta]f\[CapitalDelta]x", "]"}], 
      "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"d", "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"Denominator", "[", "\[CapitalDelta]f\[CapitalDelta]x", "]"}], 
      "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<\!\(\*FractionBox[\(df\), \(dz\)]\) = \!\(\*UnderscriptBox[\(lim\), \
\(\[CapitalDelta]x \[Rule] 0\)]\) \!\(\*FractionBox[\(f[\*SubscriptBox[\(x\), \
\(0\)]\\\  + \\\ \[CapitalDelta]x\\\  + \\\ \[ImaginaryI]\\\ \
\*SubscriptBox[\(y\), \(0\)]] - f[\*SubscriptBox[\(x\), \(0\)]\\\  + \\\ \
\[ImaginaryI]\\\ \*SubscriptBox[\(y\), \(0\)]]\), \(\*SubscriptBox[\(x\), \(0\
\)]\\\  + \\\ \[CapitalDelta]x\\\  + \\\ \[ImaginaryI]\\\ \
\*SubscriptBox[\(y\), \(0\)]\\\ \\\  - \\\ \*SubscriptBox[\(x\), \(0\)]\\\  - \
\\\ \[ImaginaryI]\\\ \*SubscriptBox[\(y\), \(0\)]\)]\)\>\"", "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*FractionBox[\(\[CapitalDelta]f\), \(\[CapitalDelta]x\)]\) = \
\>\"", ",", "\[CapitalDelta]f\[CapitalDelta]x"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*FractionBox[\(\[CapitalDelta]f\), \(\[CapitalDelta]x\)]\) = \
\>\"", ",", "n", ",", "\"\</\>\"", ",", "d"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"\[CapitalDelta]f\[CapitalDelta]x", " ", "=", " ", 
     RowBox[{
     "ComplexExpand", "[", "\[CapitalDelta]f\[CapitalDelta]x", "]"}]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*FractionBox[\(\[CapitalDelta]f\), \(\[CapitalDelta]x\)]\) = \
\>\"", ",", "\[CapitalDelta]f\[CapitalDelta]x"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399019615359375*^9}],

Cell["And this limit is easy to compute.", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(lim\), \(\[CapitalDelta]z \[Rule] 0\)]\) \
\!\(\*FractionBox[\(\[CapitalDelta]f\), \(\[CapitalDelta]z\)]\) = \
\!\(\*UnderscriptBox[\(lim\), \(\[CapitalDelta]x \[Rule] 0\)]\) \>\"", ",", 
      "n", ",", "\"\</\>\"", ",", "d", ",", "\"\< = \>\"", ",", 
      RowBox[{"Limit", "[", 
       RowBox[{"\[CapitalDelta]f\[CapitalDelta]x", ",", 
        RowBox[{"\[CapitalDelta]x", "\[Rule]", "0"}]}], "]"}]}], "]"}], ";"}],
    " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<where  \[CapitalDelta]z = \[CapitalDelta]x\>\"", "]"}],
     ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399019620640625*^9}],

Cell[TextData[{
 "Second, form the difference quotient using  ",
 Cell[BoxData[
  RowBox[{"\[CapitalDelta]z", "=", 
   RowBox[{"\[ImaginaryI]", " ", "\[CapitalDelta]y"}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"\[CapitalDelta]f\[CapitalDelta]y", " ", "=", " ", 
     FractionBox[
      RowBox[{
       RowBox[{"f", "[", 
        RowBox[{
         SubscriptBox["x", "0"], " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", 
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["y", "0"], "+", "\[CapitalDelta]y"}], ")"}]}]}], 
        "]"}], "-", 
       RowBox[{"f", "[", 
        RowBox[{
         SubscriptBox["x", "0"], " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", 
          SubscriptBox["y", "0"]}]}], "]"}]}], 
      RowBox[{
       SubscriptBox["x", "0"], " ", "+", " ", 
       RowBox[{"\[ImaginaryI]", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["y", "0"], "+", "\[CapitalDelta]y"}], ")"}]}], "  ", 
       "-", " ", 
       SubscriptBox["x", "0"], " ", "-", " ", 
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["y", "0"]}]}]]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"n", "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"Numerator", "[", "\[CapitalDelta]f\[CapitalDelta]y", "]"}], 
      "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"d", "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"Denominator", "[", "\[CapitalDelta]f\[CapitalDelta]y", "]"}], 
      "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\< \!\(\*FractionBox[\(df\), \(dz\)]\) = \
\!\(\*UnderscriptBox[\(lim\), \(\[CapitalDelta]y \[Rule] 0\)]\) \
\!\(\*FractionBox[\(f[\*SubscriptBox[\(x\), \(0\)]\\\  + \\\ \[ImaginaryI] \
\((\*SubscriptBox[\(y\), \(0\)] + \[CapitalDelta]y)\)] - f[\*SubscriptBox[\(x\
\), \(0\)]\\\  + \\\ \[ImaginaryI]\\\ \*SubscriptBox[\(y\), \(0\)]]\), \
\(\*SubscriptBox[\(x\), \(0\)]\\\  + \\\ \[ImaginaryI] \
\((\*SubscriptBox[\(y\), \(0\)] + \[CapitalDelta]y)\)\\\ \\\  - \\\ \
\*SubscriptBox[\(x\), \(0\)]\\\  - \\\ \[ImaginaryI]\\\ \*SubscriptBox[\(y\), \
\(0\)]\)]\)\>\"", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*FractionBox[\(\[CapitalDelta]f\), \(\[ImaginaryI]\\\ \
\[CapitalDelta]y\)]\) = \>\"", ",", "\[CapitalDelta]f\[CapitalDelta]y"}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*FractionBox[\(\[CapitalDelta]f\), \(\[ImaginaryI]\\\ \
\[CapitalDelta]y\)]\) = \>\"", ",", "n", ",", "\"\</\>\"", ",", "d"}], "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"\[CapitalDelta]f\[CapitalDelta]y", " ", "=", " ", 
     RowBox[{
     "ComplexExpand", "[", "\[CapitalDelta]f\[CapitalDelta]y", "]"}]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*FractionBox[\(\[CapitalDelta]f\), \(\[ImaginaryI]\\\ \
\[CapitalDelta]y\)]\) = \>\"", ",", "\[CapitalDelta]f\[CapitalDelta]y"}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.3990196245625*^9}],

Cell["And this limit is easy to compute.", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(lim\), \(\[CapitalDelta]z \[Rule] 0\)]\) \
\!\(\*FractionBox[\(\[CapitalDelta]f\), \(\[CapitalDelta]z\)]\) = \
\!\(\*UnderscriptBox[\(lim\), \(\[CapitalDelta]y \[Rule] 0\)]\) \>\"", ",", 
      "n", ",", "\"\</\>\"", ",", "d", ",", "\"\< = \>\"", ",", 
      RowBox[{"Limit", "[", 
       RowBox[{"\[CapitalDelta]f\[CapitalDelta]y", ",", 
        RowBox[{"\[CapitalDelta]y", "\[Rule]", "0"}]}], "]"}]}], "]"}], ";"}],
    " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<where  \[CapitalDelta]z = \[ImaginaryI] \[CapitalDelta]y\>\"", 
     "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399019629140625*^9}],

Cell[TextData[{
 "Since the two limits are different for any point  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "0"], ",", " ", 
   RowBox[{
    RowBox[{"f", "'"}], 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}]}]]],
 "  does ",
 StyleBox["not",
  FontColor->RGBColor[1, 0, 1]],
 " exist for any  ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(lim\), \(\[CapitalDelta]z \[Rule] 0\)]\) \
\!\(\*FractionBox[\(\[CapitalDelta]f\), \(\[CapitalDelta]z\)]\) = \>\"", ",", 
      
      RowBox[{"Limit", "[", 
       RowBox[{"\[CapitalDelta]f\[CapitalDelta]x", ",", 
        RowBox[{"\[CapitalDelta]x", "\[Rule]", "0"}]}], "]"}], ",", 
      "\"\<,   where  \[CapitalDelta]z = \[CapitalDelta]x\>\""}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(lim\), \(\[CapitalDelta]z \[Rule] 0\)]\) \
\!\(\*FractionBox[\(\[CapitalDelta]f\), \(\[CapitalDelta]z\)]\) = \>\"", ",", 
      
      RowBox[{"Limit", "[", 
       RowBox[{"\[CapitalDelta]f\[CapitalDelta]y", ",", 
        RowBox[{"\[CapitalDelta]y", "\[Rule]", "0"}]}], "]"}], ",", 
      "\"\<,  where  \[CapitalDelta]z = \[ImaginaryI] \[CapitalDelta]y\>\""}],
      "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399019634171875*^9}],

Cell[TextData[{
 StyleBox["Aside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " will ",
 StyleBox["not",
  FontColor->RGBColor[1, 0, 1]],
 " differentiate  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   OverscriptBox[
    RowBox[{"z", " "}], "_"]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f[x] = \>\"", ",", 
      RowBox[{"f", "[", "x", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f'[x] = \>\"", ",", 
      RowBox[{
       RowBox[{"f", "'"}], "[", "x", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399019638625*^9}],

Cell[TextData[{
 "The limit definition has shown that ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   OverscriptBox[
    RowBox[{"z", " "}], "_"]}]]],
 "  is ",
 StyleBox["nowhere ",
  FontColor->RGBColor[1, 0, 1]],
 "differentiable."
}], "Text"]
}, Closed]],

Cell[TextData[{
 StyleBox["Remark 3.1.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  In Section 2.3 we showed that ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   OverscriptBox[
    RowBox[{"z", " "}], "_"]}]]],
 "  is continuous for all ",
 StyleBox["z",
  FontFamily->"Courier New"],
 ".  Thus, we have a simple example of a function that is continuous \
everywhere but differentiable nowhere.  Such functions are hard to construct \
in real variables. In some sense, the complex case has made pathological \
constructions simpler!"
}], "Text"],

Cell[TextData[{
 "\tWe seldom are interested in studying functions that aren't \
differentiable, or are differentiable at only a single point.  Complex \
functions that have a derivative at all points in a neighborhood of ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 " deserve further study.  In Chapter 7 we demonstrate that, if the complex \
function ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " can be represented by a Taylor series at ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 ", then it must be differentiable in some neighborhood of ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 ".  Functions that are differentiable in neighborhoods of points are pillars \
of the complex analysis edifice; we give them a special name, as indicated in \
the following definition."
}], "Text"],

Cell[TextData[{
 StyleBox["Definition 3.1 (",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Analytic Function",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/AnalyticFunction.html"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 StyleBox[").",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["  ",
  FontWeight->"Bold"],
 "The complex function ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", "z", ")"}]}]]],
 " is analytic at the point ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 " provided there is some ",
 Cell[BoxData[
  RowBox[{"\[Epsilon]", ">", "0"}]]],
 " such that ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "'"}], 
   RowBox[{"(", "z", ")"}]}]]],
 " exists for all ",
 Cell[BoxData[
  RowBox[{"z", "\[Element]", 
   RowBox[{
    SubscriptBox["D", "\[Epsilon]"], 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}]}]]],
 ".  In other words, ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", "z", ")"}]}]]],
 " must be differentiable not only at ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 ", but also at all points in some ",
 Cell[BoxData["\[Epsilon]"]],
 "-neighborhood of ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 ". "
}], "Text"],

Cell[TextData[{
 "\n\tIf ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " is analytic at each point in the region ",
 StyleBox["R",
  FontFamily->"Courier New"],
 ", then we say that ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " is analytic on ",
 StyleBox["R",
  FontFamily->"Courier New"],
 ".  Again, we have a special term if ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " is analytic on the whole complex plane. "
}], "Text"],

Cell[TextData[{
 StyleBox["Definition 3.2 (",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Entire Function",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/EntireFunction.html"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 StyleBox[").",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["  ",
  FontWeight->"Bold"],
 "If ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " is analytic on the whole complex plane then ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " is said to be entire. "
}], "Text"],

Cell["\<\
\tPoints of nonanalyticity for a function are called singular points. They \
are important for certain applications in physics and engineering.\
\>", "Text"],

Cell["\<\
\tOur definition of the derivative for complex functions is formally the same \
as for real functions and is the natural extension from real variables to \
complex variables.  The basic differentiation formulas are identical to those \
for real functions, and we obtain the same rules for differentiating powers, \
sums, products, quotients, and compositions of functions.  We can easily \
establish the proof of the differentiation formulas by using the limit \
theorems.\
\>", "Text"],

Cell[TextData[StyleBox["The Rules for Differentiation.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "\tSuppose that ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["g(z)",
  FontFamily->"Courier New"],
 " are differentiable.  From Equation ",
 StyleBox["(3-2)",
  FontColor->RGBColor[0, 0, 1]],
 " and the technique exhibited in the solution to Example 3.1 we can \
establish the following rules, which are virtually identical to those for \
real-valued functions.  \n\n",
 Cell[BoxData[GridBox[{
    {
     StyleBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"3", "-", "4"}], ")"}], " ", "\[IndentingNewLine]", " "}],
      FontFamily->"Times New Roman",
      FontWeight->"Plain",
      FontColor->RGBColor[0, 0, 0.996109]], "           ", 
     StyleBox[
      RowBox[{
       RowBox[{
        RowBox[{
         StyleBox[
          FractionBox["d", "dz"],
          FontFamily->"Times New Roman"], 
         StyleBox["C",
          FontFamily->"Courier New",
          FontWeight->"Plain"]}], 
        StyleBox[" ",
         FontFamily->"Courier New",
         FontWeight->"Plain"], 
        StyleBox["=",
         FontFamily->"Courier New",
         FontWeight->"Plain"], 
        StyleBox[" ",
         FontFamily->"Courier New",
         FontWeight->"Plain"], 
        StyleBox["0",
         FontFamily->"Courier New",
         FontWeight->"Plain"]}], 
       StyleBox[" ",
        FontFamily->"Times New Roman",
        FontWeight->"Plain"], 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontWeight->"Plain"], 
       StyleBox[" ",
        FontFamily->"Times New Roman",
        FontWeight->"Plain"], 
       RowBox[{
        StyleBox["where",
         FontFamily->"Times New Roman"], 
        StyleBox[" ",
         FontFamily->"Times New Roman"], 
        StyleBox["C",
         FontFamily->"Courier New",
         FontWeight->"Plain"], 
        StyleBox[" ",
         FontFamily->"Times New Roman"], 
        StyleBox["is",
         FontFamily->"Times New Roman"], 
        StyleBox[" ",
         FontFamily->"Times New Roman"], 
        StyleBox["a",
         FontFamily->"Times New Roman"], 
        StyleBox[" ",
         FontFamily->"Times New Roman"], 
        StyleBox["constant",
         FontFamily->"Times New Roman"]}], 
       StyleBox[" ",
        FontFamily->"Times New Roman"], 
       StyleBox[",",
        FontFamily->"Times New Roman"], 
       StyleBox["                                                           ",
        
        FontFamily->"Times New Roman"]}],
      FontSize->12,
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]]},
    {
     RowBox[{
      StyleBox[
       RowBox[{"(", 
        RowBox[{"3", "-", "5"}], ")"}],
       FontFamily->"Times New Roman",
       FontWeight->"Plain",
       FontColor->RGBColor[0, 0, 0.996109]], 
      StyleBox[" ",
       FontFamily->"Times New Roman",
       FontWeight->"Plain",
       FontColor->RGBColor[0, 0, 0.996109]], "\[IndentingNewLine]"}], 
     "           ", 
     RowBox[{
      RowBox[{
       RowBox[{
        FractionBox["d", "dz"], 
        SuperscriptBox["z", "n"]}], " ", "=", " ", 
       RowBox[{"n", " ", 
        SuperscriptBox["z", 
         RowBox[{"n", "-", "1"}]]}]}], 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox[" ",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      RowBox[{
       StyleBox["where",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], " ", "n", " ", 
       StyleBox["is",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], 
       StyleBox[" ",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], 
       StyleBox["a",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], 
       StyleBox[" ",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], 
       StyleBox["positive",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], 
       StyleBox[" ",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], 
       StyleBox["integer",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]]}], 
      StyleBox[" ",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox["                            ",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]]}]},
    {
     RowBox[{
      StyleBox[
       RowBox[{"(", 
        RowBox[{"3", "-", "6"}], ")"}],
       FontFamily->"Times New Roman",
       FontWeight->"Plain",
       FontColor->RGBColor[0, 0, 0.996109]], 
      StyleBox["  ",
       FontFamily->"Times New Roman",
       FontWeight->"Plain",
       FontColor->RGBColor[0, 0, 0.996109]], "\[IndentingNewLine]"}], 
     "           ", 
     RowBox[{
      RowBox[{
       RowBox[{
        FractionBox["d", "dz"], "[", 
        RowBox[{"C", " ", "f", 
         RowBox[{"(", "z", ")"}]}], "]"}], " ", "=", " ", 
       RowBox[{"C", " ", 
        RowBox[{"f", "'"}], 
        RowBox[{"(", "z", ")"}]}]}], 
      StyleBox[" ",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      "                                                 "}]},
    {
     RowBox[{
      StyleBox[
       RowBox[{"(", 
        RowBox[{"3", "-", "7"}], ")"}],
       FontFamily->"Times New Roman",
       FontWeight->"Plain",
       FontColor->RGBColor[0, 0, 0.996109]], 
      StyleBox["  ",
       FontFamily->"Times New Roman",
       FontWeight->"Plain",
       FontColor->RGBColor[0, 0, 0.996109]], "\[IndentingNewLine]"}], 
     "           ", 
     RowBox[{
      RowBox[{
       RowBox[{
        FractionBox["d", "dz"], "[", 
        RowBox[{
         RowBox[{"f", 
          RowBox[{"(", "z", ")"}]}], "+", 
         RowBox[{"g", 
          RowBox[{"(", "z", ")"}]}]}], "]"}], " ", "=", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"f", "'"}], 
         RowBox[{"(", "z", ")"}]}], "+", 
        RowBox[{
         RowBox[{"g", "'"}], 
         RowBox[{"(", "z", ")"}]}]}]}], 
      StyleBox[" ",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox[
       RowBox[{
        StyleBox["                                  ",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], " "}]]}]},
    {
     RowBox[{
      StyleBox[
       RowBox[{"(", 
        RowBox[{"3", "-", "8"}], ")"}],
       FontFamily->"Times New Roman",
       FontWeight->"Plain",
       FontColor->RGBColor[0, 0, 0.996109]], 
      StyleBox["  ",
       FontFamily->"Times New Roman",
       FontWeight->"Plain",
       FontColor->RGBColor[0, 0, 0.996109]], "\[IndentingNewLine]"}], 
     "           ", 
     RowBox[{
      RowBox[{
       RowBox[{
        FractionBox["d", "dz"], "[", 
        RowBox[{"f", 
         RowBox[{"(", "z", ")"}], "g", 
         RowBox[{"(", "z", ")"}]}], "]"}], " ", "=", " ", 
       RowBox[{
        RowBox[{"f", 
         RowBox[{"(", "z", ")"}], " ", 
         RowBox[{"g", "'"}], 
         RowBox[{"(", "z", ")"}]}], "+", 
        RowBox[{"g", 
         RowBox[{"(", "z", ")"}], " ", 
         RowBox[{"f", "'"}], 
         RowBox[{"(", "z", ")"}]}]}]}], 
      StyleBox[" ",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox["      ",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]]}]},
    {
     RowBox[{
      StyleBox[
       RowBox[{"(", 
        RowBox[{"3", "-", "9"}], ")"}],
       FontFamily->"Times New Roman",
       FontWeight->"Plain",
       FontColor->RGBColor[0, 0, 0.996109]], 
      StyleBox["  ",
       FontFamily->"Times New Roman",
       FontWeight->"Plain",
       FontColor->RGBColor[0, 0, 0.996109]], "\[IndentingNewLine]"}], 
     "           ", 
     StyleBox[
      RowBox[{
       StyleBox[
        RowBox[{
         RowBox[{
          FractionBox["d", "dz"], 
          FractionBox[
           RowBox[{"f", 
            RowBox[{"(", "z", ")"}]}], 
           RowBox[{"g", 
            RowBox[{"(", "z", ")"}]}]]}], "  ", "=", " ", 
         FractionBox[
          RowBox[{
           RowBox[{"g", 
            RowBox[{"(", "z", ")"}], " ", 
            RowBox[{"f", "'"}], 
            RowBox[{"(", "z", ")"}]}], " ", "-", " ", 
           RowBox[{"f", 
            RowBox[{"(", "z", ")"}], " ", 
            RowBox[{"g", "'"}], 
            RowBox[{"(", "z", ")"}]}]}], 
          SuperscriptBox[
           RowBox[{"[", 
            RowBox[{"g", 
             RowBox[{"(", "z", ")"}]}], "]"}], "2"]]}],
        FontFamily->"Times New Roman"], 
       StyleBox[" ",
        FontFamily->"Times New Roman",
        FontWeight->"Plain"], 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontWeight->"Plain"], 
       StyleBox[" ",
        FontFamily->"Times New Roman",
        FontWeight->"Plain"], 
       RowBox[{
        StyleBox[
         RowBox[{
          StyleBox["provided",
           FontFamily->"Times New Roman"], 
          StyleBox[" ",
           FontFamily->"Times New Roman"], 
          StyleBox["that",
           FontFamily->"Times New Roman"], 
          StyleBox[" ",
           FontFamily->"Courier New",
           FontWeight->"Plain"], 
          StyleBox["g",
           FontFamily->"Courier New",
           FontWeight->"Plain"], 
          StyleBox[
           RowBox[{"(", "z", ")"}],
           FontFamily->"Courier New",
           FontWeight->"Plain"]}],
         FontFamily->"Times New Roman"], 
        StyleBox["\[NotEqual]",
         FontFamily->"Courier New",
         FontWeight->"Plain"], 
        StyleBox["0",
         FontFamily->"Courier New",
         FontWeight->"Plain"]}], 
       StyleBox[" ",
        FontFamily->"Times New Roman"], 
       StyleBox[",",
        FontFamily->"Times New Roman"]}],
      FontSize->12,
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]]},
    {
     StyleBox[
      RowBox[{"(", 
       RowBox[{"3", "-", "10"}], ")"}],
      FontFamily->"Times New Roman",
      FontWeight->"Plain",
      FontColor->RGBColor[0, 0, 0.996109]], "           ", 
     RowBox[{
      RowBox[{
       FractionBox["d", "dz"], "f", 
       RowBox[{"(", 
        RowBox[{"g", 
         RowBox[{"(", "z", ")"}]}], ")"}]}], " ", "=", " ", 
      RowBox[{
       RowBox[{"f", "'"}], "f", 
       RowBox[{"(", 
        RowBox[{"g", 
         RowBox[{"(", "z", ")"}]}], ")"}], " ", 
       RowBox[{"g", "'"}], 
       RowBox[{
        RowBox[{"(", "z", ")"}], 
        StyleBox[" ",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], 
        StyleBox[".",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], 
        StyleBox[
         RowBox[{
          StyleBox["                                       ",
           FontFamily->"Times New Roman",
           FontSize->12,
           FontSlant->"Plain",
           FontVariations->{"StrikeThrough"->False,
           "Underline"->False},
           FontColor->GrayLevel[0]], " "}]]}]}]}]}
   }]]],
 "  "
}], "Text"],

Cell[TextData[{
 "Important particular cases of Equations ",
 StyleBox["(3-9)",
  FontColor->RGBColor[0, 0, 1]],
 " and ",
 StyleBox["(3-10)",
  FontColor->RGBColor[0, 0, 1]],
 ", respectively, are  \n\n",
 Cell[BoxData[GridBox[{
    {
     RowBox[{
      StyleBox[
       RowBox[{"(", 
        RowBox[{"3", "-", "11"}], ")"}],
       FontFamily->"Times New Roman",
       FontWeight->"Plain",
       FontColor->RGBColor[0, 0, 0.996109]], "\[IndentingNewLine]"}], 
     "           ", 
     RowBox[{
      RowBox[{
       RowBox[{
        FractionBox["d", "dz"], 
        FractionBox["1", 
         SuperscriptBox["z", "n"]]}], "  ", "=", " ", 
       FractionBox[
        RowBox[{"-", "n"}], 
        SuperscriptBox["z", 
         RowBox[{"n", "+", "1"}]]]}], 
      StyleBox[" ",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox[" ",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox[
       RowBox[{
        RowBox[{
         StyleBox["for",
          FontFamily->"Times New Roman"], 
         StyleBox[" ",
          FontFamily->"Courier New"], 
         StyleBox["z",
          FontFamily->"Courier New"]}], 
        StyleBox["\[NotEqual]",
         FontFamily->"Courier New"], 
        StyleBox["0",
         FontFamily->"Courier New"]}],
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox[" ",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      RowBox[{
       StyleBox["and",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], " ", "n", " ", 
       StyleBox["is",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], 
       StyleBox[" ",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], 
       StyleBox["a",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], 
       StyleBox[" ",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], 
       StyleBox["positive",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], 
       StyleBox[" ",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], 
       StyleBox["integer",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]]}], 
      StyleBox[" ",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox["                              ",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]]}]},
    {
     StyleBox[
      RowBox[{"(", 
       RowBox[{"3", "-", "12"}], ")"}],
      FontFamily->"Times New Roman",
      FontWeight->"Plain",
      FontColor->RGBColor[0, 0, 0.996109]], "           ", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{
         FractionBox["d", "dz"], "[", 
         RowBox[{"f", 
          RowBox[{"(", "z", ")"}]}], "]"}], "n"], " ", "=", " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"n", " ", "[", 
          RowBox[{"f", 
           RowBox[{"(", "z", ")"}]}], "]"}], 
         RowBox[{"n", "-", "1"}]], " ", 
        RowBox[{"f", "'"}], 
        RowBox[{"(", "z", ")"}]}]}], 
      StyleBox[" ",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox[" ",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      RowBox[{
       StyleBox["where",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], " ", "n", " ", 
       StyleBox["is",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], 
       StyleBox[" ",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], 
       StyleBox["a",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], 
       StyleBox[" ",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], 
       StyleBox["positive",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], 
       StyleBox[" ",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], 
       StyleBox[
        RowBox[{"integer", " ", "."}],
        FontFamily->"Times New Roman",
        FontSize->12,
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]]}]}]}
   }]]],
 "  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration for the Rules for Differentiation.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell["\<\
Enter the functions and differentiate.
Find the derivative of a scalar multiple.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "a", ",", "b", ",", "f", ",", "F", ",", "g1", ",", "g2", ",", "g3", ",", 
      "g4", ",", "g5", ",", "z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"c", " ", "=", " ", 
     RowBox[{"a", " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", "b"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"g1", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"c", " ", 
      RowBox[{"f", "[", "z", "]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"g1", "'"}], "[", "z", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Derivative of a scalar multiple.\>\"", "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< F[z] = \>\"", ",", 
      RowBox[{"g1", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< F[z] = \>\"", ",", 
      RowBox[{"Expand", "[", 
       RowBox[{"g1", "[", "z", "]"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F'[z] = \>\"", ",", 
      RowBox[{
       RowBox[{"g1", "'"}], "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F'[z] = \>\"", ",", 
      RowBox[{"Expand", "[", 
       RowBox[{
        RowBox[{"g1", "'"}], "[", "z", "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399019647796875*^9},
 AspectRatioFixed->True],

Cell["Find the derivative of a linear combination.", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"g2", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["a", "1"], "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          SubscriptBox["b", "1"]}]}], ")"}], " ", 
       RowBox[{"f", "[", "z", "]"}]}], " ", "+", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["a", "2"], "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          SubscriptBox["b", "2"]}]}], ")"}], " ", 
       RowBox[{"g", "[", "z", "]"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"g2", "'"}], "[", "z", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<Derivative of a linear combination.\>\"", "]"}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< F[z] = \>\"", ",", 
      RowBox[{"g2", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< F[z] = \>\"", ",", 
      RowBox[{"Expand", "[", 
       RowBox[{"g2", "[", "z", "]"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F'[z] = \>\"", ",", 
      RowBox[{
       RowBox[{"g2", "'"}], "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F'[z] = \>\"", ",", 
      RowBox[{"Expand", "[", 
       RowBox[{
        RowBox[{"g2", "'"}], "[", "z", "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399019652015625*^9},
 AspectRatioFixed->True],

Cell["Find the derivative of a product of two functions.", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"g3", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{
      RowBox[{"f", "[", "z", "]"}], " ", 
      RowBox[{"g", "[", "z", "]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"g3", "'"}], "[", "z", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<Derivative of the product of two functions.\>\"", 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< F[z] = \>\"", ",", 
      RowBox[{"g3", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F'[z] = \>\"", ",", 
      RowBox[{
       RowBox[{"g3", "'"}], "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399019659234375*^9},
 AspectRatioFixed->True],

Cell["Find the derivative of the quotient of two functions.", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"g4", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox[
      RowBox[{"f", "[", "z", "]"}], 
      RowBox[{"g", "[", "z", "]"}]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<Derivative of the quotient of two functions.\>\"", 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< F[z] = \>\"", ",", 
      RowBox[{"g4", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F'[z] = \>\"", ",", 
      RowBox[{"Together", "[", 
       RowBox[{
        RowBox[{"g4", "'"}], "[", "z", "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399019663984375*^9}],

Cell["Find the derivative of the composition of two functions.", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"g5", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"f", "[", 
      RowBox[{"g", "[", "z", "]"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"g5", "'"}], "[", "z", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<Derivative of the composition of two functions.\>\"", 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< F[z] = \>\"", ",", 
      RowBox[{"g5", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F'[z] = \>\"", ",", 
      RowBox[{"Together", "[", 
       RowBox[{
        RowBox[{"g5", "'"}], "[", "z", "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.3990196675625*^9},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 3.3.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  If we use Equation ",
 StyleBox["(3-12)",
  FontColor->RGBColor[0, 0, 1]],
 " with  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    SuperscriptBox["z", "2"], "+", 
    RowBox[{"\[ImaginaryI]", " ", "2", "z"}], "+", "3"}]}]]],
 ",  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"f", "'"}], 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    RowBox[{"2", "z"}], "+", " ", 
    RowBox[{"2", "\[ImaginaryI]"}]}]}]]],
 ",  then we get  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     FractionBox["d", "dz"], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["z", "2"], "+", 
        RowBox[{"\[ImaginaryI]", " ", "2", "z"}], "+", "3"}], ")"}], "4"]}], 
    " ", "=", " ", 
    RowBox[{"4", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["z", "2"], "+", 
        RowBox[{"\[ImaginaryI]", " ", "2", "z"}], "+", "3"}], ")"}], "3"], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", "z"}], "+", " ", 
       RowBox[{"2", "\[ImaginaryI]"}]}], ")"}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                                       ", 
   RowBox[{"=", " ", 
    RowBox[{"8", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["z", "2"], "+", 
        RowBox[{"\[ImaginaryI]", " ", "2", "z"}], "+", "3"}], ")"}], "3"], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"z", "+", " ", "\[ImaginaryI]"}], ")"}], 
      StyleBox[" ",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox[".",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox["  ",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]]}]}]}]}]}]],
 "  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 3.3.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "g", ",", "w", ",", "z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{
      SuperscriptBox["z", "2"], " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", "2", "z"}], " ", "+", " ", "3"}]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "z_", "]"}], " ", "=", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"f", "[", "z", "]"}], ")"}], "4"]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"g", "[", "w_", "]"}], "=", 
     SuperscriptBox["w", "4"]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f(z) = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f'(z) = \>\"", ",", 
      RowBox[{
       RowBox[{"f", "'"}], "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< g(w) = \>\"", ",", 
      RowBox[{"g", "[", "w", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<g'(w) = \>\"", ",", 
      RowBox[{
       RowBox[{"g", "'"}], "[", "w", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<g'(f(z)) = \>\"", ",", 
      RowBox[{
       RowBox[{"g", "'"}], "[", 
       RowBox[{"f", "[", "z", "]"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< F(z) = \>\"", ",", 
      RowBox[{"F", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F'(z) = \>\"", ",", 
      RowBox[{
       RowBox[{"F", "'"}], "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<F'(z) = g'[f[z] f'[z]\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F'(z) = \>\"", ",", 
      RowBox[{
       RowBox[{
        RowBox[{"g", "'"}], "[", 
        RowBox[{"f", "[", "z", "]"}], "]"}], 
       RowBox[{
        RowBox[{"f", "'"}], "[", "z", "]"}]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.3990196756875*^9}],

Cell[TextData[{
 StyleBox["Aside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  This can be ",
 "compared",
 " with expanding F[z] and calculating the derivative"
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< F(z) = \>\"", ",", 
      RowBox[{"F", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"H", "[", "z_", "]"}], "=", 
     RowBox[{"Expand", "[", 
      RowBox[{"F", "[", "z", "]"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< F(z) = \>\"", ",", 
      RowBox[{"H", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F'(z) = \>\"", ",", 
      RowBox[{
       RowBox[{"H", "'"}], "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<F'(z) = g'[f[z] f'[z]\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F'(z) = \>\"", ",", 
      RowBox[{
       RowBox[{
        RowBox[{"g", "'"}], "[", 
        RowBox[{"f", "[", "z", "]"}], "]"}], 
       RowBox[{
        RowBox[{"f", "'"}], "[", "z", "]"}]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F'(z) = \>\"", ",", 
      RowBox[{"Expand", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"g", "'"}], "[", 
         RowBox[{"f", "[", "z", "]"}], "]"}], 
        RowBox[{
         RowBox[{"f", "'"}], "[", "z", "]"}]}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39901967975*^9}]
}, Closed]],

Cell[TextData[{
 "\tThe proofs of the rules given in Equations  through ",
 StyleBox["(3-10)",
  FontColor->RGBColor[0, 0, 1]],
 " depend on the validity of extending theorems for real functions to their \
complex companions.  Equation ",
 StyleBox["(3-8)",
  FontColor->RGBColor[0, 0, 1]],
 ", for example, relies on Theorem 3.1. "
}], "Text"],

Cell[TextData[{
 StyleBox["Theorem 3.1.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  If ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " is differentiable at  ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 "  then ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " is continuous at  ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "Proof.  From Equation (3-1), we obtain  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    UnderscriptBox["lim", 
     RowBox[{"z", " ", "\[Rule]", " ", 
      SubscriptBox["z", "0"]}]], " ", 
    FractionBox[
     RowBox[{
      RowBox[{"f", 
       RowBox[{"(", "z", ")"}]}], " ", "-", " ", 
      RowBox[{"f", 
       RowBox[{"(", 
        SubscriptBox["z", "0"], ")"}]}]}], 
     RowBox[{"z", " ", "-", " ", 
      SubscriptBox["z", "0"]}]]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"f", "'"}], 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}]}]]],
 ".  \n\nUsing the multiplicative property of limits given by Formula ",
 StyleBox["(2-19)",
  FontColor->RGBColor[0, 0, 1]],
 ", we get\n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"z", " ", "\[Rule]", " ", 
       SubscriptBox["z", "0"]}]], " ", 
     RowBox[{"[", 
      RowBox[{
       RowBox[{"f", 
        RowBox[{"(", "z", ")"}]}], " ", "-", " ", 
       RowBox[{"f", 
        RowBox[{"(", 
         SubscriptBox["z", "0"], ")"}]}]}], "]"}]}], "  ", "=", "  ", 
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"z", " ", "\[Rule]", " ", 
       SubscriptBox["z", "0"]}]], " ", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"f", 
         RowBox[{"(", "z", ")"}]}], " ", "-", " ", 
        RowBox[{"f", 
         RowBox[{"(", 
          SubscriptBox["z", "0"], ")"}]}]}], 
       RowBox[{"z", " ", "-", " ", 
        SubscriptBox["z", "0"]}]], 
      RowBox[{"(", 
       RowBox[{"z", " ", "-", " ", 
        SubscriptBox["z", "0"]}], ")"}]}]}]}], "\n"}], "\[IndentingNewLine]", 
 
  RowBox[{"                                                    ", 
   RowBox[{"=", "  ", 
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"z", " ", "\[Rule]", " ", 
       SubscriptBox["z", "0"]}]], " ", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"f", 
         RowBox[{"(", "z", ")"}]}], " ", "-", " ", 
        RowBox[{"f", 
         RowBox[{"(", 
          SubscriptBox["z", "0"], ")"}]}]}], 
       RowBox[{"z", " ", "-", " ", 
        SubscriptBox["z", "0"]}]], "  ", 
      RowBox[{
       UnderscriptBox["lim", 
        RowBox[{"z", " ", "\[Rule]", " ", 
         SubscriptBox["z", "0"]}]], 
       RowBox[{"(", 
        RowBox[{"z", " ", "-", " ", 
         SubscriptBox["z", "0"]}], ")"}]}]}]}]}], 
   "\[IndentingNewLine]"}], "\n", 
  RowBox[{"                                                    ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{
      RowBox[{"f", "'"}], 
      RowBox[{"(", 
       SubscriptBox["z", "0"], ")"}], "*", "0"}], "  ", "=", "  ", 
     RowBox[{"0", 
      StyleBox[" ",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox[".",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]]}]}]}]}]}]],
 "  \n\n This result implies that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    UnderscriptBox["lim", 
     RowBox[{"z", " ", "\[Rule]", " ", 
      SubscriptBox["z", "0"]}]], " ", 
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}]}], " ", "=", " ", 
   RowBox[{"f", 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}]}]]],
 ",  which is equivalent to showing that ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " is continuous at ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 ". "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 3.1 is also in the book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
 "\tWe can establish Equation ",
 StyleBox["(3-8)",
  FontColor->RGBColor[0, 0, 1]],
 " from Theorem 3.1.  Letting ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"h", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}], "g", 
    RowBox[{"(", "z", ")"}]}]}]]],
 " and using Definition 3.1, we write   \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"h", "'"}], 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"z", " ", "\[Rule]", " ", 
       SubscriptBox["z", "0"]}]], " ", 
     FractionBox[
      RowBox[{
       RowBox[{"h", 
        RowBox[{"(", "z", ")"}]}], " ", "-", " ", 
       RowBox[{"h", 
        RowBox[{"(", 
         SubscriptBox["z", "0"], ")"}]}]}], 
      RowBox[{"z", " ", "-", " ", 
       SubscriptBox["z", "0"]}]]}], "=", " ", 
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"z", " ", "\[Rule]", " ", 
       SubscriptBox["z", "0"]}]], " ", 
     FractionBox[
      RowBox[{
       RowBox[{"f", 
        RowBox[{"(", "z", ")"}], "g", 
        RowBox[{"(", "z", ")"}]}], " ", "-", " ", 
       RowBox[{"f", 
        RowBox[{"(", 
         SubscriptBox["z", "0"], ")"}], " ", "g", 
        RowBox[{"(", 
         SubscriptBox["z", "0"], ")"}]}]}], 
      RowBox[{"z", " ", "-", " ", 
       SubscriptBox["z", "0"]}]]}]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "If we subtract and add the term ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", 
    SubscriptBox["z", "0"], ")"}], "g", 
   RowBox[{"(", "z", ")"}]}]]],
 " in the numerator, we get\n\n\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"h", "'"}], 
     RowBox[{"(", 
      SubscriptBox["z", "0"], ")"}]}], " ", "=", " ", 
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"z", " ", "\[Rule]", " ", 
       SubscriptBox["z", "0"]}]], " ", 
     FractionBox[
      RowBox[{
       RowBox[{"f", 
        RowBox[{"(", "z", ")"}], "g", 
        RowBox[{"(", "z", ")"}]}], " ", "-", 
       RowBox[{"f", 
        RowBox[{"(", 
         SubscriptBox["z", "0"], ")"}], "g", 
        RowBox[{"(", "z", ")"}]}], "+", 
       RowBox[{"f", 
        RowBox[{"(", 
         SubscriptBox["z", "0"], ")"}], "g", 
        RowBox[{"(", "z", ")"}]}], "-", " ", 
       RowBox[{"f", 
        RowBox[{"(", 
         SubscriptBox["z", "0"], ")"}], " ", "g", 
        RowBox[{"(", 
         SubscriptBox["z", "0"], ")"}]}]}], 
      RowBox[{"z", " ", "-", " ", 
       SubscriptBox["z", "0"]}]]}]}], "\[IndentingNewLine]"}], "\n", 
  RowBox[{"                ", 
   RowBox[{
    RowBox[{"=", " ", 
     RowBox[{
      RowBox[{
       UnderscriptBox["lim", 
        RowBox[{"z", " ", "\[Rule]", " ", 
         SubscriptBox["z", "0"]}]], " ", 
       FractionBox[
        RowBox[{
         RowBox[{"f", 
          RowBox[{"(", "z", ")"}], "g", 
          RowBox[{"(", "z", ")"}]}], " ", "-", 
         RowBox[{"f", 
          RowBox[{"(", 
           SubscriptBox["z", "0"], ")"}], "g", 
          RowBox[{"(", "z", ")"}]}]}], 
        RowBox[{"z", " ", "-", " ", 
         SubscriptBox["z", "0"]}]]}], " ", "+", "  ", 
      RowBox[{
       UnderscriptBox["lim", 
        RowBox[{"z", " ", "\[Rule]", " ", 
         SubscriptBox["z", "0"]}]], " ", 
       FractionBox[
        RowBox[{
         RowBox[{"f", 
          RowBox[{"(", 
           SubscriptBox["z", "0"], ")"}], "g", 
          RowBox[{"(", "z", ")"}]}], "-", " ", 
         RowBox[{"f", 
          RowBox[{"(", 
           SubscriptBox["z", "0"], ")"}], " ", "g", 
          RowBox[{"(", 
           SubscriptBox["z", "0"], ")"}]}]}], 
        RowBox[{"z", " ", "-", " ", 
         SubscriptBox["z", "0"]}]]}]}]}], "\[IndentingNewLine]"}]}], "\n", 
  RowBox[{"                ", 
   RowBox[{
    RowBox[{"=", " ", 
     RowBox[{
      RowBox[{
       UnderscriptBox["lim", 
        RowBox[{"z", " ", "\[Rule]", " ", 
         SubscriptBox["z", "0"]}]], " ", 
       FractionBox[
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"f", 
            RowBox[{"(", "z", ")"}]}], " ", "-", 
           RowBox[{"f", 
            RowBox[{"(", 
             SubscriptBox["z", "0"], ")"}]}]}], ")"}], "g", 
         RowBox[{"(", "z", ")"}]}], 
        RowBox[{"z", " ", "-", " ", 
         SubscriptBox["z", "0"]}]]}], " ", "+", "  ", 
      RowBox[{
       UnderscriptBox["lim", 
        RowBox[{"z", " ", "\[Rule]", " ", 
         SubscriptBox["z", "0"]}]], " ", 
       FractionBox[
        RowBox[{"f", 
         RowBox[{"(", 
          SubscriptBox["z", "0"], ")"}], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"g", 
            RowBox[{"(", "z", ")"}]}], "-", " ", 
           RowBox[{"f", 
            RowBox[{"(", 
             SubscriptBox["z", "0"], ")"}], " ", "g", 
            RowBox[{"(", 
             SubscriptBox["z", "0"], ")"}]}]}], ")"}]}], 
        RowBox[{"z", " ", "-", " ", 
         SubscriptBox["z", "0"]}]]}]}]}], "\[IndentingNewLine]"}]}], "\n", 
  RowBox[{"                ", 
   RowBox[{"=", " ", 
    RowBox[{
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", " ", 
        SubscriptBox["z", "0"]}]], " ", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"f", 
          RowBox[{"(", "z", ")"}]}], " ", "-", 
         RowBox[{"f", 
          RowBox[{"(", 
           SubscriptBox["z", "0"], ")"}]}]}], 
        RowBox[{"z", " ", "-", " ", 
         SubscriptBox["z", "0"]}]], 
       RowBox[{
        UnderscriptBox["lim", 
         RowBox[{"z", " ", "\[Rule]", " ", 
          SubscriptBox["z", "0"]}]], " ", 
        RowBox[{"g", 
         RowBox[{"(", "z", ")"}]}]}]}]}], " ", "+", "  ", 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", " ", 
        SubscriptBox["z", "0"]}]], " ", 
      RowBox[{"f", 
       RowBox[{"(", 
        SubscriptBox["z", "0"], ")"}], " ", 
       RowBox[{
        UnderscriptBox["lim", 
         RowBox[{"z", " ", "\[Rule]", " ", 
          SubscriptBox["z", "0"]}]], " ", 
        FractionBox[
         RowBox[{
          RowBox[{"g", 
           RowBox[{"(", "z", ")"}]}], "-", " ", 
          RowBox[{"f", 
           RowBox[{"(", 
            SubscriptBox["z", "0"], ")"}], " ", "g", 
           RowBox[{"(", 
            SubscriptBox["z", "0"], ")"}]}]}], 
         RowBox[{"z", " ", "-", " ", 
          SubscriptBox["z", "0"]}]]}]}]}]}]}]}]}]],
 "   "
}], "Text"],

Cell[TextData[{
 "Using the definition of the derivative given by Equation ",
 StyleBox["(3-1)",
  FontColor->RGBColor[0, 0, 1]],
 " and the continuity of ",
 Cell[BoxData[
  RowBox[{"g", 
   RowBox[{"(", "z", ")"}]}]]],
 ", we obtain  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"h", "'"}], 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "'"}], 
     RowBox[{"(", 
      SubscriptBox["z", "0"], ")"}], " ", "g", 
     RowBox[{"(", 
      SubscriptBox["z", "0"], ")"}]}], "+", " ", 
    RowBox[{"f", 
     RowBox[{"(", 
      SubscriptBox["z", "0"], ")"}], " ", 
     RowBox[{"g", "'"}], 
     RowBox[{"(", 
      SubscriptBox["z", "0"], ")"}]}]}]}]]],
 ",  which is what we wanted to establish.  We leave the proofs of the other \
rules as exercises."
}], "Text"],

Cell[TextData[{
 "\tThe rule for differentiating polynomials carries over to the complex case \
as well.  If we let P(z) be a polynomial of degree n, so   \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"P", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["a", "0"], " ", "+", " ", 
      RowBox[{
       SubscriptBox["a", "1"], "z"}], " ", "+", " ", 
      RowBox[{
       SubscriptBox["a", "2"], 
       SuperscriptBox["z", "2"]}], " ", "+", " ", 
      RowBox[{
       SubscriptBox["a", "3"], 
       SuperscriptBox["z", "3"]}], " ", "+"}], "..."}], " ", "+", " ", 
    RowBox[{
     SubscriptBox["a", "n"], 
     SuperscriptBox["z", "n"]}]}]}]]],
 ",  \n\nthen mathematical induction, along with Equations ",
 StyleBox["(3-5)",
  FontColor->RGBColor[0, 0, 1]],
 " and ",
 StyleBox["(3-7)",
  FontColor->RGBColor[0, 0, 1]],
 ", gives  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"P", "'"}], 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["a", "1"], " ", "+", " ", 
      RowBox[{"2", 
       SubscriptBox["a", "2"], "z"}], " ", "+", " ", 
      RowBox[{"3", 
       SubscriptBox["a", "3"], 
       SuperscriptBox["z", "2"]}], " ", "+"}], "..."}], " ", "+", " ", 
    RowBox[{
     SubscriptBox["a", 
      RowBox[{"n", "-", "1"}]], 
     SuperscriptBox["z", 
      RowBox[{"n", "-", "1"}]]}]}]}]]],
 ".  \n\nAgain, we leave the proof of this result as an exercise."
}], "Text"],

Cell[TextData[{
 "\tWe can use the differentiation rules as aids in determining when \
functions are analytic.  For example, Equation ",
 StyleBox["(3-9)",
  FontColor->RGBColor[0, 0, 1]],
 " tells us that if ",
 Cell[BoxData[
  RowBox[{"P", 
   RowBox[{"(", "z", ")"}], " ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], " ", "Q", 
   RowBox[{"(", "z", ")"}]}]]],
 " are polynomials, then their quotient  ",
 Cell[BoxData[
  FractionBox[
   RowBox[{"P", 
    RowBox[{"(", "z", ")"}]}], 
   RowBox[{"Q", 
    RowBox[{"(", "z", ")"}]}]]]],
 "   is analytic at all points where ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Q", 
    RowBox[{"(", "z", ")"}]}], "\[NotEqual]", "0"}]]],
 ".  This condition implies that the function ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   FractionBox["1", "z"]}]]],
 "  is analytic for all ",
 Cell[BoxData[
  RowBox[{"z", "\[NotEqual]", "0"}]]],
 ".  \n\n\tThe square root function is more complicated.  If  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{"|", "z", 
    SuperscriptBox["|", 
     FractionBox["1", "2"]]}]}]]],
 Cell[BoxData[
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{"\[ImaginaryI]", " ", 
    FractionBox[
     RowBox[{"Arg", 
      RowBox[{"(", "z", ")"}]}], "2"]}]]]],
 ",  then ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", "z", ")"}]}]]],
 " is analytic at all points except ",
 Cell[BoxData[
  RowBox[{"z", "=", "0"}]]],
 "  (because ",
 Cell[BoxData[
  RowBox[{"Arg", 
   RowBox[{"(", "0", ")"}]}]]],
 " is undefined) and at points that lie along the negative ",
 StyleBox["x",
  FontFamily->"Courier New"],
 " axis.  The argument function, and therefore the function ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " itself, are not continuous at points that lie along the negative ",
 StyleBox["x",
  FontFamily->"Courier New"],
 " axis."
}], "Text"],

Cell[TextData[{
 "\tWe close this section with a complex extension of a famous theorem, which \
is attributed to ",
 StyleBox[ButtonBox["Guillaume Fran\[CCedilla]ois Antoine Marquis de L'H\
\[OHat]pital",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/De_L'\
Hopital.html"], None}],
  FontVariations->{"Underline"->True}],
 " (1661-1704).  The proof of will be given in Chapter 7.  "
}], "Text"],

Cell[TextData[{
 StyleBox["Theorem 3.2, (",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["L'H\[OHat]pital's Rule",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/LHospitalsRule.html"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 StyleBox[").",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Assume that ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["g(z)",
  FontFamily->"Courier New"],
 " are both analytic at ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 ".  If ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}], "=", "0"}]]],
 ", ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"g", 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}], "=", "0"}]]],
 ", and ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"g", "'"}], 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}], "\[NotEqual]", "0"}]]],
 "  then  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    UnderscriptBox["lim", 
     RowBox[{"z", "\[Rule]", 
      SubscriptBox["z", "0"]}]], " ", 
    FractionBox[
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], 
     RowBox[{"g", 
      RowBox[{"(", "z", ")"}]}]]}], "=", 
   FractionBox[
    RowBox[{
     RowBox[{"f", "'"}], 
     RowBox[{"(", 
      SubscriptBox["z", "0"], ")"}]}], 
    RowBox[{
     RowBox[{"g", "'"}], 
     RowBox[{"(", 
      SubscriptBox["z", "0"], ")"}]}]]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 StyleBox["Proof of Theorem 3.2.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]],
 "  ",
 "We defer the proof until Chapter 7, where we will learn some amazing things \
about analytic functions.  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration for L'Hospital's Rule.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " can do it all, however care must be taken with the higher derivative \
cases.  Make the assumption that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}], "=", 
   RowBox[{
    RowBox[{"0", "  ", "and", "  ", "g", 
     RowBox[{"(", 
      SubscriptBox["z", "0"], ")"}]}], "=", "0"}]}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "g", ",", "lim", ",", "z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", 
      SubscriptBox["z", "0"], "]"}], " ", "=", " ", "0"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"g", "[", 
      SubscriptBox["z", "0"], "]"}], " ", "=", " ", "0"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"lim", " ", "=", " ", 
     RowBox[{"Limit", "[", 
      RowBox[{
       FractionBox[
        RowBox[{"f", "[", "Z", "]"}], 
        RowBox[{"g", "[", "Z", "]"}]], ",", " ", 
       RowBox[{"Z", "\[Rule]", 
        SubscriptBox["z", "0"]}], ",", " ", 
       RowBox[{"Analytic", "\[Rule]", "True"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<     f[\!\(\*SubscriptBox[\(z\), \(0\)]\)] = \>\"", ",", 
      RowBox[{"f", "[", 
       SubscriptBox["z", "0"], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<     g[\!\(\*SubscriptBox[\(z\), \(0\)]\)] = \>\"", ",", 
      RowBox[{"g", "[", 
       SubscriptBox["z", "0"], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<    f'[\!\(\*SubscriptBox[\(z\), \(0\)]\)] = \>\"", ",", 
      RowBox[{
       RowBox[{"f", "'"}], "[", 
       SubscriptBox["z", "0"], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<    g'[\!\(\*SubscriptBox[\(z\), \(0\)]\)] = \>\"", ",", 
      RowBox[{
       RowBox[{"g", "'"}], "[", 
       SubscriptBox["z", "0"], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<    \!\(\*FractionBox[\(f[\*SubscriptBox[\(z\), \(0\)]]\), \
\(g[\*SubscriptBox[\(z\), \(0\)]]\)]\) = \>\"", ",", 
      RowBox[{"f", "[", 
       SubscriptBox["z", "0"], "]"}], ",", "\"\</\>\"", ",", 
      RowBox[{"g", "[", 
       SubscriptBox["z", "0"], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<    \!\(\*FractionBox[\(f[\*SubscriptBox[\(z\), \(0\)]]\), \
\(g[\*SubscriptBox[\(z\), \(0\)]]\)]\) = \>\"", ",", 
      FractionBox[
       RowBox[{"f", "[", 
        SubscriptBox["z", "0"], "]"}], 
       RowBox[{"g", "[", 
        SubscriptBox["z", "0"], "]"}]]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(lim\), \(z \[Rule] \*SubscriptBox[\(z\), \(0\
\)]\)]\) \!\(\*FractionBox[\(f[z]\), \(g[z]\)]\) = \>\"", ",", "lim"}], "]"}],
     ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399019698734375*^9}],

Cell[TextData[{
 "Now, make the second additional assumption that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"f", "'"}], 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}], "=", 
   RowBox[{
    RowBox[{"0", "  ", 
     StyleBox["and",
      FontFamily->"Times New Roman"], "  ", 
     RowBox[{"g", "'"}], 
     RowBox[{"(", 
      SubscriptBox["z", "0"], ")"}]}], "=", "0"}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "g", ",", "lim", ",", "z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", 
      SubscriptBox["z", "0"], "]"}], " ", "=", " ", "0"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"g", "[", 
      SubscriptBox["z", "0"], "]"}], " ", "=", " ", "0"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"f", "'"}], "[", 
      SubscriptBox["z", "0"], "]"}], " ", "=", " ", "0"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"g", "'"}], "[", 
      SubscriptBox["z", "0"], "]"}], " ", "=", " ", "0"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"lim", " ", "=", " ", 
     RowBox[{"Limit", "[", 
      RowBox[{
       FractionBox[
        RowBox[{"f", "[", "Z", "]"}], 
        RowBox[{"g", "[", "Z", "]"}]], ",", " ", 
       RowBox[{"Z", "\[Rule]", 
        SubscriptBox["z", "0"]}], ",", " ", 
       RowBox[{"Analytic", "\[Rule]", "True"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<      f[\!\(\*SubscriptBox[\(z\), \(0\)]\)] = \>\"", ",", 
      RowBox[{"f", "[", 
       SubscriptBox["z", "0"], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<      g[\!\(\*SubscriptBox[\(z\), \(0\)]\)] = \>\"", ",", 
      RowBox[{"g", "[", 
       SubscriptBox["z", "0"], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<     f'[\!\(\*SubscriptBox[\(z\), \(0\)]\)] = \>\"", ",", 
      RowBox[{
       RowBox[{"f", "'"}], "[", 
       SubscriptBox["z", "0"], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<     g'[\!\(\*SubscriptBox[\(z\), \(0\)]\)] = \>\"", ",", 
      RowBox[{
       RowBox[{"g", "'"}], "[", 
       SubscriptBox["z", "0"], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<    f''[\!\(\*SubscriptBox[\(z\), \(0\)]\)] = \>\"", ",", 
      RowBox[{
       RowBox[{
        RowBox[{"f", "'"}], "'"}], "[", 
       SubscriptBox["z", "0"], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<    g''[\!\(\*SubscriptBox[\(z\), \(0\)]\)] = \>\"", ",", 
      RowBox[{
       RowBox[{
        RowBox[{"g", "'"}], "'"}], "[", 
       SubscriptBox["z", "0"], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<     \!\(\*FractionBox[\(f[\*SubscriptBox[\(z\), \(0\)]]\), \
\(g[\*SubscriptBox[\(z\), \(0\)]]\)]\) = \>\"", ",", 
      RowBox[{"f", "[", 
       SubscriptBox["z", "0"], "]"}], ",", "\"\</\>\"", ",", 
      RowBox[{"g", "[", 
       SubscriptBox["z", "0"], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<    \!\(\*FractionBox[\(\(f'\)[\*SubscriptBox[\(z\), \(0\)]]\), \
\(\(g'\)[\*SubscriptBox[\(z\), \(0\)]]\)]\) = \>\"", ",", 
      RowBox[{
       RowBox[{"f", "'"}], "[", 
       SubscriptBox["z", "0"], "]"}], ",", "\"\</\>\"", ",", 
      RowBox[{
       RowBox[{"g", "'"}], "[", 
       SubscriptBox["z", "0"], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<      \!\(\*FractionBox[\(f[\*SubscriptBox[\(z\), \(0\)]]\), \
\(g[\*SubscriptBox[\(z\), \(0\)]]\)]\) = \>\"", ",", 
      FractionBox[
       RowBox[{"f", "[", 
        SubscriptBox["z", "0"], "]"}], 
       RowBox[{"g", "[", 
        SubscriptBox["z", "0"], "]"}]]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<  \!\(\*UnderscriptBox[\(lim\), \(z \[Rule] \*SubscriptBox[\(z\), \
\(0\)]\)]\) \!\(\*FractionBox[\(f[z]\), \(g[z]\)]\) = \>\"", ",", "lim"}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39901970490625*^9}],

Cell[TextData[{
 "The third additional assumption is that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"f", "''"}], 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}], "=", 
   RowBox[{
    RowBox[{"0", "  ", 
     StyleBox["and",
      FontFamily->"Times New Roman"], "  ", 
     RowBox[{"g", "''"}], 
     RowBox[{"(", 
      SubscriptBox["z", "0"], ")"}]}], "=", "0"}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "g", ",", "lim", ",", "z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", 
      SubscriptBox["z", "0"], "]"}], " ", "=", " ", "0"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"g", "[", 
      SubscriptBox["z", "0"], "]"}], " ", "=", " ", "0"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"f", "'"}], "[", 
      SubscriptBox["z", "0"], "]"}], " ", "=", " ", "0"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"g", "'"}], "[", 
      SubscriptBox["z", "0"], "]"}], " ", "=", " ", "0"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"f", "''"}], "[", 
      SubscriptBox["z", "0"], "]"}], " ", "=", " ", "0"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"g", "''"}], "[", 
      SubscriptBox["z", "0"], "]"}], " ", "=", " ", "0"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"lim", " ", "=", " ", 
     RowBox[{"Limit", "[", 
      RowBox[{
       FractionBox[
        RowBox[{"f", "[", "Z", "]"}], 
        RowBox[{"g", "[", "Z", "]"}]], ",", " ", 
       RowBox[{"Z", "\[Rule]", 
        SubscriptBox["z", "0"]}], ",", " ", 
       RowBox[{"Analytic", "\[Rule]", "True"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<       f[\!\(\*SubscriptBox[\(z\), \(0\)]\)] = \>\"", ",", 
      RowBox[{"f", "[", 
       SubscriptBox["z", "0"], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<       g[\!\(\*SubscriptBox[\(z\), \(0\)]\)] = \>\"", ",", 
      RowBox[{"g", "[", 
       SubscriptBox["z", "0"], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<      f'[\!\(\*SubscriptBox[\(z\), \(0\)]\)] = \>\"", ",", 
      RowBox[{
       RowBox[{"f", "'"}], "[", 
       SubscriptBox["z", "0"], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<      g'[\!\(\*SubscriptBox[\(z\), \(0\)]\)] = \>\"", ",", 
      RowBox[{
       RowBox[{"g", "'"}], "[", 
       SubscriptBox["z", "0"], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<     f''[\!\(\*SubscriptBox[\(z\), \(0\)]\)] = \>\"", ",", 
      RowBox[{
       RowBox[{
        RowBox[{"f", "'"}], "'"}], "[", 
       SubscriptBox["z", "0"], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<     g''[\!\(\*SubscriptBox[\(z\), \(0\)]\)] = \>\"", ",", 
      RowBox[{
       RowBox[{
        RowBox[{"g", "'"}], "'"}], "[", 
       SubscriptBox["z", "0"], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<    f'''[\!\(\*SubscriptBox[\(z\), \(0\)]\)] = \>\"", ",", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"f", "'"}], "'"}], "'"}], "[", 
       SubscriptBox["z", "0"], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<    g'''[\!\(\*SubscriptBox[\(z\), \(0\)]\)] = \>\"", ",", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"g", "'"}], "'"}], "'"}], "[", 
       SubscriptBox["z", "0"], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<      \!\(\*FractionBox[\(f[\*SubscriptBox[\(z\), \(0\)]]\), \
\(g[\*SubscriptBox[\(z\), \(0\)]]\)]\) = \>\"", ",", 
      RowBox[{"f", "[", 
       SubscriptBox["z", "0"], "]"}], ",", "\"\</\>\"", ",", 
      RowBox[{"g", "[", 
       SubscriptBox["z", "0"], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<     \!\(\*FractionBox[\(\(f'\)[\*SubscriptBox[\(z\), \(0\)]]\), \(\
\(g'\)[\*SubscriptBox[\(z\), \(0\)]]\)]\) = \>\"", ",", 
      RowBox[{
       RowBox[{"f", "'"}], "[", 
       SubscriptBox["z", "0"], "]"}], ",", "\"\</\>\"", ",", 
      RowBox[{
       RowBox[{"g", "'"}], "[", 
       SubscriptBox["z", "0"], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<    \!\(\*FractionBox[\(\(f''\)[\*SubscriptBox[\(z\), \(0\)]]\), \(\
\(g''\)[\*SubscriptBox[\(z\), \(0\)]]\)]\) = \>\"", ",", 
      RowBox[{
       RowBox[{"f", "''"}], "[", 
       SubscriptBox["z", "0"], "]"}], ",", "\"\</\>\"", ",", 
      RowBox[{
       RowBox[{"g", "''"}], "[", 
       SubscriptBox["z", "0"], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<       \!\(\*FractionBox[\(f[\*SubscriptBox[\(z\), \(0\)]]\), \
\(g[\*SubscriptBox[\(z\), \(0\)]]\)]\) = \>\"", ",", 
      FractionBox[
       RowBox[{"f", "[", 
        SubscriptBox["z", "0"], "]"}], 
       RowBox[{"g", "[", 
        SubscriptBox["z", "0"], "]"}]]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<   \!\(\*UnderscriptBox[\(lim\), \(z \[Rule] \*SubscriptBox[\(z\), \
\(0\)]\)]\) \!\(\*FractionBox[\(f[z]\), \(g[z]\)]\) = \>\"", ",", "lim"}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.3990197154375*^9}]
}, Closed]],

Cell[TextData[{
 StyleBox["Extra Example 2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Use L'Hopital's rule to find  ",
 Cell[BoxData[
  RowBox[{
   UnderscriptBox["lim", 
    RowBox[{"z", "\[Rule]", 
     RowBox[{"1", "+", "\[ImaginaryI]"}]}]], 
   FractionBox[
    RowBox[{
     SuperscriptBox["z", "2"], " ", "+", " ", "z", " ", "-", " ", "1", " ", 
     "-", " ", 
     RowBox[{"3", "\[ImaginaryI]"}]}], 
    RowBox[{
     SuperscriptBox["z", "2"], " ", "-", " ", 
     RowBox[{"2", "z"}], " ", "+", " ", "2"}]]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Extra Example 2.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "g", ",", "lim", ",", "z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{
      SuperscriptBox["z", "2"], " ", "+", " ", "z", " ", "-", " ", "1", " ", 
      "-", " ", 
      RowBox[{"3", "\[ImaginaryI]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"g", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{
      SuperscriptBox["z", "2"], " ", "-", " ", 
      RowBox[{"2", "z"}], " ", "+", " ", "2"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<g[z] = \>\"", ",", 
      RowBox[{"g", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39901972825*^9}],

Cell[TextData[{
 "Direct substitution of   ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{"1", "+", "\[ImaginaryI]"}]}]]],
 "  is indeterminate."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*FractionBox[\(f[1 + \[ImaginaryI]]\), \(g[1 + \
\[ImaginaryI]]\)]\) = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"1", "+", "\[ImaginaryI]"}], "]"}], ",", "\"\</\>\"", ",", 
      RowBox[{"g", "[", 
       RowBox[{"1", "+", "\[ImaginaryI]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*FractionBox[\(f[1 + \[ImaginaryI]]\), \(g[1 + \
\[ImaginaryI]]\)]\) = \>\"", ",", 
      FractionBox[
       RowBox[{"f", "[", 
        RowBox[{"1", "+", "\[ImaginaryI]"}], "]"}], 
       RowBox[{"g", "[", 
        RowBox[{"1", "+", "\[ImaginaryI]"}], "]"}]]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39901973165625*^9}],

Cell[TextData[{
 "Find the limit as  ",
 Cell[BoxData[
  RowBox[{"z", "\[Rule]", 
   RowBox[{"1", "+", "\[ImaginaryI]"}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"lim", " ", "=", " ", 
     RowBox[{"Limit", "[", 
      RowBox[{
       FractionBox[
        RowBox[{"f", "[", "z", "]"}], 
        RowBox[{"g", "[", "z", "]"}]], ",", 
       RowBox[{"z", "\[Rule]", 
        RowBox[{"1", "+", "\[ImaginaryI]"}]}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(lim\), \(z \[Rule] 1 + i\)]\) \
\!\(\*FractionBox[\(f[z]\), \(g[z]\)]\) = \!\(\*UnderscriptBox[\(lim\), \(z \
\[Rule] 1 + i\)]\) \>\"", ",", 
      FractionBox[
       RowBox[{"f", "[", "z", "]"}], 
       RowBox[{"g", "[", "z", "]"}]]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(lim\), \(z \[Rule] 1 + i\)]\) \
\!\(\*FractionBox[\(f[z]\), \(g[z]\)]\) = \!\(\*UnderscriptBox[\(lim\), \(z \
\[Rule] 1 + i\)]\) \>\"", ",", 
      FractionBox[
       RowBox[{"Factor", "[", 
        RowBox[{"f", "[", "z", "]"}], "]"}], 
       RowBox[{"Factor", "[", 
        RowBox[{"g", "[", "z", "]"}], "]"}]]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<           = \!\(\*UnderscriptBox[\(lim\), \(z \[Rule] 1 + i\)]\) \
\>\"", ",", 
      RowBox[{"Cancel", "[", 
       FractionBox[
        RowBox[{"f", "[", "z", "]"}], 
        RowBox[{"g", "[", "z", "]"}]], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<           =  \>\"", ",", "lim"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399019736015625*^9}],

Cell["Which agrees with the L'Hopital rule computation.", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"lim", " ", "=", " ", 
     RowBox[{"Limit", "[", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"f", "'"}], "[", "z", "]"}], 
        RowBox[{
         RowBox[{"g", "'"}], "[", "z", "]"}]], ",", 
       RowBox[{"z", "\[Rule]", 
        RowBox[{"1", "+", "\[ImaginaryI]"}]}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(lim\), \(z \[Rule] 1 + i\)]\) \
\!\(\*FractionBox[\(\(f'\)[z]\), \(\(g'\)[z]\)]\) = \
\!\(\*UnderscriptBox[\(lim\), \(z \[Rule] 1 + i\)]\) \>\"", ",", 
      FractionBox[
       RowBox[{
        RowBox[{"f", "'"}], "[", "z", "]"}], 
       RowBox[{
        RowBox[{"g", "'"}], "[", "z", "]"}]]}], "]"}], ";"}], " ", "\n", 
   RowBox[{"Print", "[", 
    RowBox[{"\"\<            = \>\"", ",", "lim"}], "]"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399019740640625*^9}],

Cell[TextData[{
 "Which agrees with evaluation of the quotient  ",
 Cell[BoxData[
  FractionBox[
   RowBox[{
    RowBox[{"f", "'"}], "[", 
    RowBox[{"1", "+", "\[ImaginaryI]"}], "]"}], 
   RowBox[{
    RowBox[{"g", "'"}], "[", 
    RowBox[{"1", "+", "\[ImaginaryI]"}], "]"}]]]],
 "."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  f'[1+\[ImaginaryI]] = \>\"", ",", 
      RowBox[{
       RowBox[{"f", "'"}], "[", 
       RowBox[{"1", "+", "\[ImaginaryI]"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  g'[1+\[ImaginaryI]] = \>\"", ",", 
      RowBox[{
       RowBox[{"g", "'"}], "[", 
       RowBox[{"1", "+", "\[ImaginaryI]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*FractionBox[\(\(f'\)[1 + \[ImaginaryI]]\), \(\(g'\)[1 + \
\[ImaginaryI]]\)]\) = (\>\"", ",", 
      RowBox[{
       RowBox[{"f", "'"}], "[", 
       RowBox[{"1", "+", "\[ImaginaryI]"}], "]"}], ",", "\"\<)/\>\"", ",", 
      RowBox[{
       RowBox[{"g", "'"}], "[", 
       RowBox[{"1", "+", "\[ImaginaryI]"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*FractionBox[\(\(f'\)[1 + \[ImaginaryI]]\), \(\(g'\)[1 + \
\[ImaginaryI]]\)]\) = \>\"", ",", 
      FractionBox[
       RowBox[{
        RowBox[{"f", "'"}], "[", 
        RowBox[{"1", "+", "\[ImaginaryI]"}], "]"}], 
       RowBox[{
        RowBox[{"g", "'"}], "[", 
        RowBox[{"1", "+", "\[ImaginaryI]"}], "]"}]]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399019744796875*^9}]
}, Closed]],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Analytic Functions",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/AnalyticFunBib.html"], None}],
 
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Mean Value Theorem and Rolle's Theorem",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/MeanValueBib.html"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Polya Vector Field",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/PolyaFieldBib.html"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/complex.html"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2008 John H. Mathews, Russell W. \
Howell",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/"], None}],
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[0, 1, 0]]], "Text",
 CellChangeTimes->{{3.399019518546875*^9, 3.39901951865625*^9}}]
},
CellGrouping->Manual,
WindowSize->{976, 605},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "CHAPTER 1"->{
  Cell[568, 21, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"],
  Cell[92647, 2995, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"],
  Cell[106382, 3479, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"CHAPTER 1", 130806, 4232}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"],
Cell[905, 32, 130, 2, 29, "Text"],
Cell[1038, 36, 879, 14, 137, "Text"],
Cell[1920, 52, 138, 2, 29, "Text"],
Cell[2061, 56, 3099, 118, 240, "Text"],
Cell[5163, 176, 327, 13, 29, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[5515, 193, 159, 4, 29, "Text",
 Evaluatable->False],
Cell[5677, 199, 1117, 30, 147, "Input"],
Cell[6797, 231, 409, 11, 72, "Input"],
Cell[7209, 244, 972, 24, 120, "Input"],
Cell[8184, 270, 404, 11, 72, "Input"],
Cell[8591, 283, 946, 25, 119, "Input"],
Cell[9540, 310, 408, 11, 72, "Input"]
}, Closed]],
Cell[9963, 324, 333, 13, 26, "Text",
 Evaluatable->False],
Cell[10299, 339, 2575, 86, 290, "Text"],
Cell[CellGroupData[{
Cell[12899, 429, 156, 4, 29, "Text",
 Evaluatable->False],
Cell[13058, 435, 86, 2, 29, "Text",
 Evaluatable->False],
Cell[13147, 439, 601, 17, 112, "Input"],
Cell[13751, 458, 91, 2, 29, "Text",
 Evaluatable->False],
Cell[13845, 462, 933, 24, 161, "Input"],
Cell[14781, 488, 259, 10, 29, "Text",
 Evaluatable->False],
Cell[15043, 500, 1336, 34, 194, "Input"],
Cell[16382, 536, 135, 4, 29, "Text",
 Evaluatable->False],
Cell[16520, 542, 1080, 26, 178, "Input"],
Cell[17603, 570, 333, 11, 29, "Text",
 Evaluatable->False],
Cell[17939, 583, 2112, 53, 306, "Input"],
Cell[20054, 638, 536, 20, 47, "Text"]
}, Closed]],
Cell[20605, 661, 1045, 35, 68, "Text"],
Cell[21653, 698, 411, 19, 29, "Text",
 Evaluatable->False],
Cell[22067, 719, 6044, 184, 284, "Text"],
Cell[28114, 905, 5803, 177, 269, "Text"],
Cell[33920, 1084, 754, 30, 47, "Text"],
Cell[CellGroupData[{
Cell[34699, 1118, 156, 4, 29, "Text",
 Evaluatable->False],
Cell[34858, 1124, 736, 20, 112, "Input"],
Cell[35597, 1146, 202, 7, 29, "Text",
 Evaluatable->False],
Cell[35802, 1155, 2971, 72, 312, "Input"],
Cell[38776, 1229, 96, 2, 29, "Text",
 Evaluatable->False],
Cell[38875, 1233, 794, 18, 106, "Input"],
Cell[39672, 1253, 239, 8, 29, "Text",
 Evaluatable->False],
Cell[39914, 1263, 3093, 77, 323, "Input"],
Cell[43010, 1342, 96, 2, 29, "Text",
 Evaluatable->False],
Cell[43109, 1346, 815, 19, 107, "Input"],
Cell[43927, 1367, 422, 18, 29, "Text",
 Evaluatable->False],
Cell[44352, 1387, 1094, 25, 120, "Input"],
Cell[45449, 1414, 425, 20, 29, "Text",
 Evaluatable->False],
Cell[45877, 1436, 458, 14, 92, "Input"],
Cell[46338, 1452, 284, 12, 29, "Text"]
}, Closed]],
Cell[46637, 1467, 599, 18, 44, "Text"],
Cell[47239, 1487, 799, 19, 83, "Text"],
Cell[48041, 1508, 1267, 50, 47, "Text"],
Cell[49311, 1560, 450, 17, 47, "Text"],
Cell[49764, 1579, 615, 22, 29, "Text"],
Cell[50382, 1603, 167, 3, 29, "Text"],
Cell[50552, 1608, 496, 8, 65, "Text"],
Cell[51051, 1618, 164, 4, 29, "Text",
 Evaluatable->False],
Cell[51218, 1624, 14679, 476, 327, "Text"],
Cell[65900, 2102, 8301, 270, 111, "Text"],
Cell[CellGroupData[{
Cell[74226, 2376, 181, 4, 29, "Text",
 Evaluatable->False],
Cell[74410, 2382, 104, 3, 47, "Text"],
Cell[74517, 2387, 1629, 47, 252, "Input"],
Cell[76149, 2436, 60, 0, 29, "Text"],
Cell[76212, 2438, 1712, 52, 212, "Input"],
Cell[77927, 2492, 66, 0, 29, "Text"],
Cell[77996, 2494, 877, 27, 152, "Input"],
Cell[78876, 2523, 69, 0, 29, "Text"],
Cell[78948, 2525, 805, 24, 150, "Input"],
Cell[79756, 2551, 72, 0, 29, "Text"],
Cell[79831, 2553, 893, 27, 152, "Input"]
}, Closed]],
Cell[80739, 2583, 2420, 85, 108, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[83184, 2672, 156, 4, 29, "Text",
 Evaluatable->False],
Cell[83343, 2678, 2644, 80, 372, "Input"],
Cell[85990, 2760, 189, 7, 29, "Text"],
Cell[86182, 2769, 1652, 51, 212, "Input"]
}, Closed]],
Cell[87849, 2823, 344, 9, 44, "Text"],
Cell[88196, 2834, 417, 19, 29, "Text",
 Evaluatable->False],
Cell[88616, 2855, 3684, 124, 284, "Text"],
Cell[CellGroupData[{
Cell[92325, 2983, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[92469, 2989, 175, 4, 29, "Text",
 Evaluatable->False],
Cell[92647, 2995, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"]
}, Closed]],
Cell[92996, 3007, 1418, 50, 73, "Text"],
Cell[94417, 3059, 5038, 160, 220, "Text"],
Cell[99458, 3221, 842, 30, 47, "Text"],
Cell[100303, 3253, 1518, 49, 173, "Text"],
Cell[101824, 3304, 2093, 74, 117, "Text"],
Cell[103920, 3380, 458, 11, 47, "Text"],
Cell[104381, 3393, 1550, 65, 76, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[105956, 3462, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[106100, 3468, 279, 9, 29, "Text",
 Evaluatable->False],
Cell[106382, 3479, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"]
}, Closed]],
Cell[CellGroupData[{
Cell[106753, 3493, 169, 4, 26, "Text",
 Evaluatable->False],
Cell[106925, 3499, 427, 15, 29, "Text"],
Cell[107355, 3516, 2908, 79, 383, "Input"],
Cell[110266, 3597, 461, 18, 29, "Text",
 Evaluatable->False],
Cell[110730, 3617, 4274, 119, 521, "Input"],
Cell[115007, 3738, 455, 18, 29, "Text",
 Evaluatable->False],
Cell[115465, 3758, 5601, 158, 638, "Input"]
}, Closed]],
Cell[121081, 3919, 603, 21, 38, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[121709, 3944, 159, 4, 29, "Text",
 Evaluatable->False],
Cell[121871, 3950, 983, 28, 152, "Input"],
Cell[122857, 3980, 206, 8, 29, "Text",
 Evaluatable->False],
Cell[123066, 3990, 866, 24, 129, "Input"],
Cell[123935, 4016, 190, 8, 29, "Text",
 Evaluatable->False],
Cell[124128, 4026, 1662, 46, 221, "Input"],
Cell[125793, 4074, 111, 2, 29, "Text",
 Evaluatable->False],
Cell[125907, 4078, 987, 28, 147, "Input"],
Cell[126897, 4108, 343, 13, 42, "Text",
 Evaluatable->False],
Cell[127243, 4123, 1530, 45, 189, "Input"]
}, Closed]],
Cell[128788, 4171, 281, 7, 26, "Text"],
Cell[129072, 4180, 275, 7, 29, "Text"],
Cell[129350, 4189, 291, 6, 29, "Text"],
Cell[129644, 4197, 272, 6, 29, "Text"],
Cell[129919, 4205, 249, 5, 29, "Text"],
Cell[130171, 4212, 319, 7, 29, "Text"]
}
]
*)

(* End of internal cache information *)
