(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    476539,      19628]
NotebookOptionsPosition[    470926,      19457]
NotebookOutlinePosition[    471655,      19488]
CellTagsIndexPosition[    471580,      19483]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["Section 3.3  Harmonic Functions",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
 "\tLet  ",
 Cell[BoxData[
  RowBox[{"\[Phi]", 
   RowBox[{"(", 
    RowBox[{"x", ",", "y"}], ")"}]}]]],
 "  be a real-valued function of the two real variables x and y defined on a \
domain D.  (Recall that a domain is a connected open set.)  The partial \
differential equation \n\n",
 StyleBox["(3-26)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["\[Phi]", "xx"], 
     RowBox[{"(", 
      RowBox[{"x", ",", "y"}], ")"}]}], "+", 
    RowBox[{
     SubscriptBox["\[Phi]", "yy"], 
     RowBox[{"(", 
      RowBox[{"x", ",", "y"}], ")"}]}]}], "=", "0"}]]],
 "  \n\nis known as ",
 StyleBox[ButtonBox["Laplace's equation",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/LaplacesEquation.html"], None}],
  FontVariations->{"Underline"->True}],
 " and is sometimes referred to as the potential equation.  If ",
 Cell[BoxData[
  RowBox[{"\[Phi]", ",", 
   SubscriptBox["\[Phi]", "x"], ",", 
   SubscriptBox["\[Phi]", "y"], ",", 
   SubscriptBox["\[Phi]", "xx"], ",", 
   SubscriptBox["\[Phi]", "xy"], ",", 
   RowBox[{
    SubscriptBox["\[Phi]", "yx"], 
    StyleBox["and",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], " ", 
    SubscriptBox["\[Phi]", "yy"]}]}]]],
 " are all continuous and if ",
 Cell[BoxData[
  RowBox[{"\[Phi]", 
   RowBox[{"(", 
    RowBox[{"x", ",", "y"}], ")"}]}]]],
 " satisfies ",
 StyleBox[ButtonBox["Laplace's",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Laplace.\
html"], None}],
  FontVariations->{"Underline"->True}],
 " equation, then ",
 Cell[BoxData[
  RowBox[{"\[Phi]", 
   RowBox[{"(", 
    RowBox[{"x", ",", "y"}], ")"}]}]]],
 " is called a ",
 StyleBox[ButtonBox["harmonic function",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/HarmonicFunction.html"], None}],
  FontVariations->{"Underline"->True}],
 ". "
}], "Text"],

Cell[TextData[{
 "\tHarmonic functions are important in the areas of applied mathematics, \
engineering, and mathematical physics.  In calculus we might have been asked \
to show that the functions ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["x", "3"], "-", 
   RowBox[{"3", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]]],
 " and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"3", " ", 
    SuperscriptBox["x", "2"], " ", "y"}], "-", 
   SuperscriptBox["y", "3"]}]]],
 " are harmonic (and also that the functions  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[ExponentialE]", "x"], " ", "cos", " ", "y"}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[ExponentialE]", "x"], " ", "sin", " ", "y"}]]],
 "  are harmonic).  Harmonic functions are used to solve problems involving \
steady state temperatures, two-dimensional electrostatics, and ideal fluid \
flow.  In Chapter 11 we will see how complex analysis techniques can be used \
to solve some problems involving harmonic functions.  For example, the \
function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Phi]", 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], " ", "=", 
   RowBox[{
    FractionBox["1", "\[Pi]"], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"arctan", 
       FractionBox["y", 
        RowBox[{"x", "-", "1"}]]}], " ", "-", " ", 
      RowBox[{"arctan", 
       FractionBox["y", 
        RowBox[{"x", "+", "1"}]]}]}], ")"}]}]}]]],
 "  is harmonic in the upper half plane and takes on the boundary values   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Phi]", 
    RowBox[{"(", 
     RowBox[{"x", ",", "0"}], ")"}]}], "=", 
   RowBox[{
    RowBox[{"1", "  ", 
     StyleBox["when",
      FontFamily->"Times New Roman"]}], " ", "|", "x", "|", 
    RowBox[{"<", "1"}]}]}]]],
 "  and   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Phi]", 
    RowBox[{"(", 
     RowBox[{"x", ",", "0"}], ")"}]}], "=", 
   RowBox[{
    RowBox[{"0", "  ", 
     StyleBox["when",
      FontFamily->"Times New Roman"]}], " ", "|", "x", "|", 
    RowBox[{">", "1"}]}]}]]],
 ",  as shown in Figure 3.A. "
}], "Text"],

Cell[TextData[{
 "\t\t",
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.192308 0.00961519 0.192308 [
[.11538 -0.0125 -6 -9 ]
[.11538 -0.0125 6 0 ]
[.30769 -0.0125 -6 -9 ]
[.30769 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69231 -0.0125 -3 -9 ]
[.69231 -0.0125 3 0 ]
[.88462 -0.0125 -3 -9 ]
[.88462 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00962 -6 -4.5 ]
[-0.0125 .00962 0 4.5 ]
[-0.0125 .10577 -18 -4.5 ]
[-0.0125 .10577 0 4.5 ]
[-0.0125 .20192 -6 -4.5 ]
[-0.0125 .20192 0 4.5 ]
[-0.0125 .29808 -18 -4.5 ]
[-0.0125 .29808 0 4.5 ]
[-0.0125 .39423 -6 -4.5 ]
[-0.0125 .39423 0 4.5 ]
[-0.0125 .49038 -18 -4.5 ]
[-0.0125 .49038 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .5 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11538 0 m
.11538 .00625 L
s
[(-2)] .11538 -0.0125 0 1 Mshowa
.30769 0 m
.30769 .00625 L
s
[(-1)] .30769 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69231 0 m
.69231 .00625 L
s
[(1)] .69231 -0.0125 0 1 Mshowa
.88462 0 m
.88462 .00625 L
s
[(2)] .88462 -0.0125 0 1 Mshowa
.125 Mabswid
.15385 0 m
.15385 .00375 L
s
.19231 0 m
.19231 .00375 L
s
.23077 0 m
.23077 .00375 L
s
.26923 0 m
.26923 .00375 L
s
.34615 0 m
.34615 .00375 L
s
.38462 0 m
.38462 .00375 L
s
.42308 0 m
.42308 .00375 L
s
.46154 0 m
.46154 .00375 L
s
.53846 0 m
.53846 .00375 L
s
.57692 0 m
.57692 .00375 L
s
.61538 0 m
.61538 .00375 L
s
.65385 0 m
.65385 .00375 L
s
.73077 0 m
.73077 .00375 L
s
.76923 0 m
.76923 .00375 L
s
.80769 0 m
.80769 .00375 L
s
.84615 0 m
.84615 .00375 L
s
.07692 0 m
.07692 .00375 L
s
.03846 0 m
.03846 .00375 L
s
.92308 0 m
.92308 .00375 L
s
.96154 0 m
.96154 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00962 m
.00625 .00962 L
s
[(0)] -0.0125 .00962 1 0 Mshowa
0 .10577 m
.00625 .10577 L
s
[(0.5)] -0.0125 .10577 1 0 Mshowa
0 .20192 m
.00625 .20192 L
s
[(1)] -0.0125 .20192 1 0 Mshowa
0 .29808 m
.00625 .29808 L
s
[(1.5)] -0.0125 .29808 1 0 Mshowa
0 .39423 m
.00625 .39423 L
s
[(2)] -0.0125 .39423 1 0 Mshowa
0 .49038 m
.00625 .49038 L
s
[(2.5)] -0.0125 .49038 1 0 Mshowa
.125 Mabswid
0 .02885 m
.00375 .02885 L
s
0 .04808 m
.00375 .04808 L
s
0 .06731 m
.00375 .06731 L
s
0 .08654 m
.00375 .08654 L
s
0 .125 m
.00375 .125 L
s
0 .14423 m
.00375 .14423 L
s
0 .16346 m
.00375 .16346 L
s
0 .18269 m
.00375 .18269 L
s
0 .22115 m
.00375 .22115 L
s
0 .24038 m
.00375 .24038 L
s
0 .25962 m
.00375 .25962 L
s
0 .27885 m
.00375 .27885 L
s
0 .31731 m
.00375 .31731 L
s
0 .33654 m
.00375 .33654 L
s
0 .35577 m
.00375 .35577 L
s
0 .375 m
.00375 .375 L
s
0 .41346 m
.00375 .41346 L
s
0 .43269 m
.00375 .43269 L
s
0 .45192 m
.00375 .45192 L
s
0 .47115 m
.00375 .47115 L
s
.25 Mabswid
0 0 m
0 .5 L
s
.11538 .49375 m
.11538 .5 L
s
.30769 .49375 m
.30769 .5 L
s
.5 .49375 m
.5 .5 L
s
.69231 .49375 m
.69231 .5 L
s
.88462 .49375 m
.88462 .5 L
s
.125 Mabswid
.15385 .49625 m
.15385 .5 L
s
.19231 .49625 m
.19231 .5 L
s
.23077 .49625 m
.23077 .5 L
s
.26923 .49625 m
.26923 .5 L
s
.34615 .49625 m
.34615 .5 L
s
.38462 .49625 m
.38462 .5 L
s
.42308 .49625 m
.42308 .5 L
s
.46154 .49625 m
.46154 .5 L
s
.53846 .49625 m
.53846 .5 L
s
.57692 .49625 m
.57692 .5 L
s
.61538 .49625 m
.61538 .5 L
s
.65385 .49625 m
.65385 .5 L
s
.73077 .49625 m
.73077 .5 L
s
.76923 .49625 m
.76923 .5 L
s
.80769 .49625 m
.80769 .5 L
s
.84615 .49625 m
.84615 .5 L
s
.07692 .49625 m
.07692 .5 L
s
.03846 .49625 m
.03846 .5 L
s
.92308 .49625 m
.92308 .5 L
s
.96154 .49625 m
.96154 .5 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.99375 .00962 m
1 .00962 L
s
.99375 .10577 m
1 .10577 L
s
.99375 .20192 m
1 .20192 L
s
.99375 .29808 m
1 .29808 L
s
.99375 .39423 m
1 .39423 L
s
.99375 .49038 m
1 .49038 L
s
.125 Mabswid
.99625 .02885 m
1 .02885 L
s
.99625 .04808 m
1 .04808 L
s
.99625 .06731 m
1 .06731 L
s
.99625 .08654 m
1 .08654 L
s
.99625 .125 m
1 .125 L
s
.99625 .14423 m
1 .14423 L
s
.99625 .16346 m
1 .16346 L
s
.99625 .18269 m
1 .18269 L
s
.99625 .22115 m
1 .22115 L
s
.99625 .24038 m
1 .24038 L
s
.99625 .25962 m
1 .25962 L
s
.99625 .27885 m
1 .27885 L
s
.99625 .31731 m
1 .31731 L
s
.99625 .33654 m
1 .33654 L
s
.99625 .35577 m
1 .35577 L
s
.99625 .375 m
1 .375 L
s
.99625 .41346 m
1 .41346 L
s
.99625 .43269 m
1 .43269 L
s
.99625 .45192 m
1 .45192 L
s
.99625 .47115 m
1 .47115 L
s
.25 Mabswid
1 0 m
1 .5 L
s
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 .951 0 r
.01923 .49038 m
.98077 .49038 L
.98077 .00962 L
.01923 .00962 L
F
0 g
.5 Mabswid
1 .366 0 r
.01923 .20633 m
.0301 .19344 L
.04277 .1793 L
.04751 .17423 L
.05627 .16516 L
.07063 .15102 L
.07579 .14614 L
.08598 .13688 L
.1024 .12274 L
.10407 .12135 L
.12011 .1086 L
.13235 .09936 L
.13919 .09446 L
.1599 .08032 L
.16063 .07983 L
.18272 .06618 L
.18891 .06248 L
.20803 .05204 L
.21719 .04711 L
.23675 .0379 L
.24548 .03356 L
.27002 .02376 L
.27376 .02188 L
.30204 .01209 L
.30523 .00962 L
.01923 .00962 L
F
0 g
.01923 .20633 m
.0301 .19344 L
.04277 .1793 L
.04751 .17423 L
.05627 .16516 L
.07063 .15102 L
.07579 .14614 L
.08598 .13688 L
.1024 .12274 L
.10407 .12135 L
.12011 .1086 L
.13235 .09936 L
.13919 .09446 L
.1599 .08032 L
.16063 .07983 L
.18272 .06618 L
.18891 .06248 L
.20803 .05204 L
.21719 .04711 L
.23675 .0379 L
.24548 .03356 L
.27002 .02376 L
.27376 .02188 L
.30204 .01209 L
.30523 .00962 L
s
.463 1 0 r
.25433 .49038 m
.24548 .47988 L
.24258 .47624 L
.23209 .4621 L
.22272 .44796 L
.21719 .43881 L
.21435 .43382 L
.2069 .41968 L
.2003 .40554 L
.1945 .3914 L
.18945 .37726 L
.18891 .37564 L
.18511 .36312 L
.18146 .34898 L
.17848 .33484 L
.17614 .3207 L
.17442 .30656 L
.17333 .29242 L
.17286 .27828 L
.17299 .26414 L
.17374 .25 L
.1751 .23586 L
.17709 .22172 L
.17972 .20758 L
.18299 .19344 L
.18693 .1793 L
.18891 .17291 L
.19158 .16516 L
.19697 .15102 L
.20314 .13688 L
.21011 .12274 L
.21719 .10978 L
.2179 .1086 L
.22681 .09446 L
.23675 .08032 L
.24548 .06869 L
.24765 .06618 L
.26075 .05204 L
.27376 .03796 L
.27384 .0379 L
.28596 .02376 L
.30204 .01515 L
.30815 .00962 L
.98077 .00962 L
.98077 .49038 L
F
0 g
.25433 .49038 m
.24548 .47988 L
.24258 .47624 L
.23209 .4621 L
.22272 .44796 L
.21719 .43881 L
.21435 .43382 L
.2069 .41968 L
.2003 .40554 L
.1945 .3914 L
.18945 .37726 L
.18891 .37564 L
.18511 .36312 L
.18146 .34898 L
.17848 .33484 L
.17614 .3207 L
.17442 .30656 L
.17333 .29242 L
.17286 .27828 L
.17299 .26414 L
.17374 .25 L
.1751 .23586 L
.17709 .22172 L
.17972 .20758 L
.18299 .19344 L
.18693 .1793 L
.18891 .17291 L
.19158 .16516 L
.19697 .15102 L
.20314 .13688 L
.21011 .12274 L
.21719 .10978 L
.2179 .1086 L
.22681 .09446 L
.23675 .08032 L
.24548 .06869 L
.24765 .06618 L
.26075 .05204 L
.27376 .03796 L
.27384 .0379 L
.28596 .02376 L
.30204 .01515 L
.30815 .00962 L
s
0 1 .122 r
.6891 .00962 m
.69796 .01932 L
.70375 .02376 L
.70746 .0379 L
.71622 .05204 L
.72256 .06618 L
.72624 .07617 L
.72742 .08032 L
.73119 .09446 L
.73411 .1086 L
.73616 .12274 L
.73734 .13688 L
.73767 .15102 L
.73716 .16516 L
.7358 .1793 L
.73357 .19344 L
.73046 .20758 L
.72642 .22172 L
.72624 .22226 L
.7214 .23586 L
.71534 .25 L
.70815 .26414 L
.69969 .27828 L
.69796 .28092 L
.68983 .29242 L
.6783 .30656 L
.66968 .3158 L
.66476 .3207 L
.64866 .33484 L
.6414 .34041 L
.6291 .34898 L
.61312 .3584 L
.60411 .36312 L
.58484 .37138 L
.56814 .37726 L
.55656 .38021 L
.52828 .38535 L
.5 .38704 L
.47172 .38535 L
.44344 .38021 L
.43186 .37726 L
.41516 .37138 L
.39589 .36312 L
.38688 .3584 L
.3709 .34898 L
.3586 .34041 L
.35134 .33484 L
.33524 .3207 L
.33032 .3158 L
.3217 .30656 L
.31017 .29242 L
.30204 .28092 L
.30031 .27828 L
.29185 .26414 L
.28466 .25 L
.2786 .23586 L
.27376 .22226 L
.27358 .22172 L
.26954 .20758 L
.26643 .19344 L
.2642 .1793 L
.26284 .16516 L
.26233 .15102 L
.26266 .13688 L
.26384 .12274 L
.26589 .1086 L
.26881 .09446 L
.27258 .08032 L
.27376 .07617 L
.27744 .06618 L
.28378 .05204 L
.29254 .0379 L
.29625 .02376 L
.30204 .01932 L
.3109 .00962 L
F
0 g
.6891 .00962 m
.69796 .01932 L
.70375 .02376 L
.70746 .0379 L
.71622 .05204 L
.72256 .06618 L
.72624 .07617 L
.72742 .08032 L
.73119 .09446 L
.73411 .1086 L
.73616 .12274 L
.73734 .13688 L
.73767 .15102 L
.73716 .16516 L
.7358 .1793 L
.73357 .19344 L
.73046 .20758 L
.72642 .22172 L
.72624 .22226 L
.7214 .23586 L
.71534 .25 L
.70815 .26414 L
.69969 .27828 L
.69796 .28092 L
.68983 .29242 L
.6783 .30656 L
.66968 .3158 L
.66476 .3207 L
.64866 .33484 L
.6414 .34041 L
.6291 .34898 L
.61312 .3584 L
.60411 .36312 L
.58484 .37138 L
.56814 .37726 L
.55656 .38021 L
.52828 .38535 L
.5 .38704 L
.47172 .38535 L
.44344 .38021 L
.43186 .37726 L
.41516 .37138 L
.39589 .36312 L
.38688 .3584 L
.3709 .34898 L
.3586 .34041 L
.35134 .33484 L
.33524 .3207 L
.33032 .3158 L
.3217 .30656 L
Mistroke
.31017 .29242 L
.30204 .28092 L
.30031 .27828 L
.29185 .26414 L
.28466 .25 L
.2786 .23586 L
.27376 .22226 L
.27358 .22172 L
.26954 .20758 L
.26643 .19344 L
.2642 .1793 L
.26284 .16516 L
.26233 .15102 L
.26266 .13688 L
.26384 .12274 L
.26589 .1086 L
.26881 .09446 L
.27258 .08032 L
.27376 .07617 L
.27744 .06618 L
.28378 .05204 L
.29254 .0379 L
.29625 .02376 L
.30204 .01932 L
.3109 .00962 L
Mfstroke
0 1 .707 r
.68644 .00962 m
.69589 .02376 L
.69796 .02761 L
.69876 .0379 L
.70087 .05204 L
.70196 .06618 L
.70197 .08032 L
.70094 .09446 L
.69888 .1086 L
.69796 .1133 L
.69577 .12274 L
.69156 .13688 L
.68619 .15102 L
.67954 .16516 L
.67145 .1793 L
.66968 .18207 L
.66179 .19344 L
.65014 .20758 L
.6414 .21664 L
.63607 .22172 L
.61867 .23586 L
.61312 .2397 L
.59633 .25 L
.58484 .25564 L
.56378 .26414 L
.55656 .26623 L
.52828 .27232 L
.5 .2743 L
.47172 .27232 L
.44344 .26623 L
.43622 .26414 L
.41516 .25564 L
.40367 .25 L
.38688 .2397 L
.38133 .23586 L
.36393 .22172 L
.3586 .21664 L
.34986 .20758 L
.33821 .19344 L
.33032 .18207 L
.32855 .1793 L
.32046 .16516 L
.31381 .15102 L
.30844 .13688 L
.30423 .12274 L
.30204 .1133 L
.30112 .1086 L
.29906 .09446 L
.29803 .08032 L
.29804 .06618 L
.29913 .05204 L
.30124 .0379 L
.30204 .02761 L
.30411 .02376 L
.31356 .00962 L
F
0 g
.68644 .00962 m
.69589 .02376 L
.69796 .02761 L
.69876 .0379 L
.70087 .05204 L
.70196 .06618 L
.70197 .08032 L
.70094 .09446 L
.69888 .1086 L
.69796 .1133 L
.69577 .12274 L
.69156 .13688 L
.68619 .15102 L
.67954 .16516 L
.67145 .1793 L
.66968 .18207 L
.66179 .19344 L
.65014 .20758 L
.6414 .21664 L
.63607 .22172 L
.61867 .23586 L
.61312 .2397 L
.59633 .25 L
.58484 .25564 L
.56378 .26414 L
.55656 .26623 L
.52828 .27232 L
.5 .2743 L
.47172 .27232 L
.44344 .26623 L
.43622 .26414 L
.41516 .25564 L
.40367 .25 L
.38688 .2397 L
.38133 .23586 L
.36393 .22172 L
.3586 .21664 L
.34986 .20758 L
.33821 .19344 L
.33032 .18207 L
.32855 .1793 L
.32046 .16516 L
.31381 .15102 L
.30844 .13688 L
.30423 .12274 L
.30204 .1133 L
.30112 .1086 L
.29906 .09446 L
.29803 .08032 L
.29804 .06618 L
Mistroke
.29913 .05204 L
.30124 .0379 L
.30204 .02761 L
.30411 .02376 L
.31356 .00962 L
Mfstroke
0 .707 1 r
.68382 .00962 m
.68977 .02376 L
.69128 .0379 L
.68796 .05204 L
.68398 .06618 L
.67893 .08032 L
.6726 .09446 L
.66968 .10011 L
.66495 .1086 L
.65562 .12274 L
.6442 .13688 L
.6414 .13995 L
.63047 .15102 L
.61312 .16513 L
.61309 .16516 L
.59065 .1793 L
.58484 .1822 L
.55656 .19342 L
.55649 .19344 L
.52828 .19983 L
.5 .20192 L
.47172 .19983 L
.44351 .19344 L
.44344 .19342 L
.41516 .1822 L
.40935 .1793 L
.38691 .16516 L
.38688 .16513 L
.36953 .15102 L
.3586 .13995 L
.3558 .13688 L
.34438 .12274 L
.33505 .1086 L
.33032 .10011 L
.3274 .09446 L
.32107 .08032 L
.31602 .06618 L
.31204 .05204 L
.30872 .0379 L
.31023 .02376 L
.31618 .00962 L
F
0 g
.68382 .00962 m
.68977 .02376 L
.69128 .0379 L
.68796 .05204 L
.68398 .06618 L
.67893 .08032 L
.6726 .09446 L
.66968 .10011 L
.66495 .1086 L
.65562 .12274 L
.6442 .13688 L
.6414 .13995 L
.63047 .15102 L
.61312 .16513 L
.61309 .16516 L
.59065 .1793 L
.58484 .1822 L
.55656 .19342 L
.55649 .19344 L
.52828 .19983 L
.5 .20192 L
.47172 .19983 L
.44351 .19344 L
.44344 .19342 L
.41516 .1822 L
.40935 .1793 L
.38691 .16516 L
.38688 .16513 L
.36953 .15102 L
.3586 .13995 L
.3558 .13688 L
.34438 .12274 L
.33505 .1086 L
.33032 .10011 L
.3274 .09446 L
.32107 .08032 L
.31602 .06618 L
.31204 .05204 L
.30872 .0379 L
.31023 .02376 L
.31618 .00962 L
s
0 .122 1 r
.68121 .00962 m
.68374 .02376 L
.68213 .0379 L
.67304 .05204 L
.66968 .05709 L
.66386 .06618 L
.65242 .08032 L
.6414 .09167 L
.63862 .09446 L
.6219 .1086 L
.61312 .11473 L
.60061 .12274 L
.58484 .13067 L
.57075 .13688 L
.55656 .14126 L
.52828 .14735 L
.5 .14933 L
.47172 .14735 L
.44344 .14126 L
.42925 .13688 L
.41516 .13067 L
.39939 .12274 L
.38688 .11473 L
.3781 .1086 L
.36138 .09446 L
.3586 .09167 L
.34758 .08032 L
.33614 .06618 L
.33032 .05709 L
.32696 .05204 L
.31787 .0379 L
.31626 .02376 L
.31879 .00962 L
F
0 g
.68121 .00962 m
.68374 .02376 L
.68213 .0379 L
.67304 .05204 L
.66968 .05709 L
.66386 .06618 L
.65242 .08032 L
.6414 .09167 L
.63862 .09446 L
.6219 .1086 L
.61312 .11473 L
.60061 .12274 L
.58484 .13067 L
.57075 .13688 L
.55656 .14126 L
.52828 .14735 L
.5 .14933 L
.47172 .14735 L
.44344 .14126 L
.42925 .13688 L
.41516 .13067 L
.39939 .12274 L
.38688 .11473 L
.3781 .1086 L
.36138 .09446 L
.3586 .09167 L
.34758 .08032 L
.33614 .06618 L
.33032 .05709 L
.32696 .05204 L
.31787 .0379 L
.31626 .02376 L
.31879 .00962 L
s
.463 0 1 r
.67855 .00962 m
.67747 .02376 L
.66968 .03631 L
.66811 .0379 L
.65367 .05204 L
.6414 .06096 L
.6346 .06618 L
.61312 .07896 L
.61079 .08032 L
.58484 .09194 L
.57881 .09446 L
.55656 .10077 L
.52828 .10591 L
.5 .1076 L
.47172 .10591 L
.44344 .10077 L
.42119 .09446 L
.41516 .09194 L
.38921 .08032 L
.38688 .07896 L
.3654 .06618 L
.3586 .06096 L
.34633 .05204 L
.33189 .0379 L
.33032 .03631 L
.32253 .02376 L
.32145 .00962 L
F
0 g
.67855 .00962 m
.67747 .02376 L
.66968 .03631 L
.66811 .0379 L
.65367 .05204 L
.6414 .06096 L
.6346 .06618 L
.61312 .07896 L
.61079 .08032 L
.58484 .09194 L
.57881 .09446 L
.55656 .10077 L
.52828 .10591 L
.5 .1076 L
.47172 .10591 L
.44344 .10077 L
.42119 .09446 L
.41516 .09194 L
.38921 .08032 L
.38688 .07896 L
.3654 .06618 L
.3586 .06096 L
.34633 .05204 L
.33189 .0379 L
.33032 .03631 L
.32253 .02376 L
.32145 .00962 L
s
1 0 .951 r
.67579 .00962 m
.67045 .02376 L
.66968 .0246 L
.64565 .0379 L
.6414 .03996 L
.61312 .05192 L
.61286 .05204 L
.58484 .06091 L
.5626 .06618 L
.55656 .06717 L
.52828 .07087 L
.5 .0721 L
.47172 .07087 L
.44344 .06717 L
.4374 .06618 L
.41516 .06091 L
.38714 .05204 L
.38688 .05192 L
.3586 .03996 L
.35435 .0379 L
.33032 .0246 L
.32955 .02376 L
.32421 .00962 L
F
0 g
.67579 .00962 m
.67045 .02376 L
.66968 .0246 L
.64565 .0379 L
.6414 .03996 L
.61312 .05192 L
.61286 .05204 L
.58484 .06091 L
.5626 .06618 L
.55656 .06717 L
.52828 .07087 L
.5 .0721 L
.47172 .07087 L
.44344 .06717 L
.4374 .06618 L
.41516 .06091 L
.38714 .05204 L
.38688 .05192 L
.3586 .03996 L
.35435 .0379 L
.33032 .0246 L
.32955 .02376 L
.32421 .00962 L
s
1 0 .366 r
.67288 .00962 m
.66968 .01718 L
.64205 .02376 L
.6414 .0238 L
.61312 .0297 L
.58484 .03426 L
.55656 .0375 L
.5521 .0379 L
.52828 .03943 L
.5 .04007 L
.47172 .03943 L
.4479 .0379 L
.44344 .0375 L
.41516 .03426 L
.38688 .0297 L
.3586 .0238 L
.35795 .02376 L
.33032 .01718 L
.32712 .00962 L
F
0 g
.67288 .00962 m
.66968 .01718 L
.64205 .02376 L
.6414 .0238 L
.61312 .0297 L
.58484 .03426 L
.55656 .0375 L
.5521 .0379 L
.52828 .03943 L
.5 .04007 L
.47172 .03943 L
.4479 .0379 L
.44344 .0375 L
.41516 .03426 L
.38688 .0297 L
.3586 .0238 L
.35795 .02376 L
.33032 .01718 L
.32712 .00962 L
s
1 .951 0 r
.74567 .49038 m
.75452 .47988 L
.75742 .47624 L
.76791 .4621 L
.77728 .44796 L
.78281 .43881 L
.78565 .43382 L
.7931 .41968 L
.7997 .40554 L
.8055 .3914 L
.81055 .37726 L
.81109 .37564 L
.81489 .36312 L
.81854 .34898 L
.82152 .33484 L
.82386 .3207 L
.82558 .30656 L
.82667 .29242 L
.82714 .27828 L
.82701 .26414 L
.82626 .25 L
.8249 .23586 L
.82291 .22172 L
.82028 .20758 L
.81701 .19344 L
.81307 .1793 L
.81109 .17291 L
.80842 .16516 L
.80303 .15102 L
.79686 .13688 L
.78989 .12274 L
.78281 .10978 L
.7821 .1086 L
.77319 .09446 L
.76325 .08032 L
.75452 .06869 L
.75235 .06618 L
.73925 .05204 L
.72624 .03796 L
.72616 .0379 L
.71404 .02376 L
.69796 .01515 L
.69185 .00962 L
.98077 .00962 L
.98077 .49038 L
F
0 g
.74567 .49038 m
.75452 .47988 L
.75742 .47624 L
.76791 .4621 L
.77728 .44796 L
.78281 .43881 L
.78565 .43382 L
.7931 .41968 L
.7997 .40554 L
.8055 .3914 L
.81055 .37726 L
.81109 .37564 L
.81489 .36312 L
.81854 .34898 L
.82152 .33484 L
.82386 .3207 L
.82558 .30656 L
.82667 .29242 L
.82714 .27828 L
.82701 .26414 L
.82626 .25 L
.8249 .23586 L
.82291 .22172 L
.82028 .20758 L
.81701 .19344 L
.81307 .1793 L
.81109 .17291 L
.80842 .16516 L
.80303 .15102 L
.79686 .13688 L
.78989 .12274 L
.78281 .10978 L
.7821 .1086 L
.77319 .09446 L
.76325 .08032 L
.75452 .06869 L
.75235 .06618 L
.73925 .05204 L
.72624 .03796 L
.72616 .0379 L
.71404 .02376 L
.69796 .01515 L
.69185 .00962 L
s
1 .366 0 r
.98077 .20633 m
.9699 .19344 L
.95723 .1793 L
.95249 .17423 L
.94373 .16516 L
.92937 .15102 L
.92421 .14614 L
.91402 .13688 L
.8976 .12274 L
.89593 .12135 L
.87989 .1086 L
.86765 .09936 L
.86081 .09446 L
.8401 .08032 L
.83937 .07983 L
.81728 .06618 L
.81109 .06248 L
.79197 .05204 L
.78281 .04711 L
.76325 .0379 L
.75452 .03356 L
.72998 .02376 L
.72624 .02188 L
.69796 .01209 L
.69477 .00962 L
.98077 .00962 L
F
0 g
.98077 .20633 m
.9699 .19344 L
.95723 .1793 L
.95249 .17423 L
.94373 .16516 L
.92937 .15102 L
.92421 .14614 L
.91402 .13688 L
.8976 .12274 L
.89593 .12135 L
.87989 .1086 L
.86765 .09936 L
.86081 .09446 L
.8401 .08032 L
.83937 .07983 L
.81728 .06618 L
.81109 .06248 L
.79197 .05204 L
.78281 .04711 L
.76325 .0379 L
.75452 .03356 L
.72998 .02376 L
.72624 .02188 L
.69796 .01209 L
.69477 .00962 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 144},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
  ImageRangeCache->{{{0, 287}, {143, 0}} -> {-3, 0, 0, 0}}],
 StyleBox["     ",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .57775 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.06865e-017 1.00535 -0.195673 1.00535 [
[.05728 .13356 -5.87166 -9 ]
[.05728 .13356 6.12834 0 ]
[.1604 .10256 -5.90122 -9 ]
[.1604 .10256 6.09878 0 ]
[.26623 .07075 -2.96583 -9 ]
[.26623 .07075 3.03417 0 ]
[.37489 .03809 -2.9815 -9 ]
[.37489 .03809 3.0185 0 ]
[.48649 .00455 -2.99765 -9 ]
[.48649 .00455 3.00235 0 ]
[.26695 .00792 -4.94305 -12.5625 ]
[.26695 .00792 5.05695 0 ]
[.73174 .06537 -3.03311 -9 ]
[.73174 .06537 2.96689 0 ]
[.90881 .13864 -3.0585 -9 ]
[.90881 .13864 2.9415 0 ]
[.77619 .02128 -5.06604 -12.5625 ]
[.77619 .02128 4.93396 0 ]
[-0.01183 .42036 -6 -5.92278 ]
[-0.01183 .42036 0 3.07722 ]
[ 0 0 0 0 ]
[ 1 .57775 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.00641 .16132 m
.54345 0 L
s
.05701 .14612 m
.05688 .1524 L
s
[(-2)] .05728 .13356 -0.02139 1 Mshowa
.16019 .11513 m
.16009 .12141 L
s
[(-1)] .1604 .10256 -0.01646 1 Mshowa
.26609 .08332 m
.26602 .0896 L
s
[(0)] .26623 .07075 -0.01139 1 Mshowa
.37481 .05066 m
.37477 .05694 L
s
[(1)] .37489 .03809 -0.00617 1 Mshowa
.48648 .01711 m
.48647 .0234 L
s
[(2)] .48649 .00455 -0.00078 1 Mshowa
gsave
.26695 .00792 -65.943 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.54345 0 m
.99372 .18623 L
s
.73188 .07793 m
.73195 .08422 L
s
[(1)] .73174 .06537 .01104 1 Mshowa
.90905 .15121 m
.90917 .15749 L
s
[(2)] .90881 .13864 .0195 1 Mshowa
gsave
.77619 .02128 -66.066 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.00641 .16132 m
0 .43064 L
s
.00015 .42415 m
.00615 .42604 L
s
[(1)] -0.01183 .42036 1 .31617 Mshowa
0 0 m
1 0 L
1 .57775 L
0 .57775 L
closepath
clip
newpath
.5 Mabswid
1 .909 0 r
.43831 .35237 .46708 .36234 .4795 .36066 .45074 .35079 Metetra
1 .948 0 r
.45074 .35079 .4795 .36066 .49197 .35902 .46322 .34928 Metetra
1 .989 0 r
.46322 .34928 .49197 .35902 .50446 .35744 .47573 .34783 Metetra
.969 1 0 r
.47573 .34783 .50446 .35744 .517 .3559 .48828 .34645 Metetra
.925 1 0 r
.48828 .34645 .517 .3559 .52958 .35439 .50087 .34511 Metetra
.881 1 0 r
.50087 .34511 .52958 .35439 .5422 .35289 .51351 .34381 Metetra
.836 1 0 r
.51351 .34381 .5422 .35289 .55486 .35141 .52618 .34253 Metetra
.791 1 0 r
.52618 .34253 .55486 .35141 .56756 .34991 .53889 .34125 Metetra
.746 1 0 r
.53889 .34125 .56756 .34991 .5803 .34838 .55165 .33996 Metetra
.702 1 0 r
.55165 .33996 .5803 .34838 .59308 .3468 .56445 .33861 Metetra
.66 1 0 r
.56445 .33861 .59308 .3468 .6059 .34515 .57728 .3372 Metetra
.619 1 0 r
.57728 .3372 .6059 .34515 .61876 .3434 .59016 .33568 Metetra
.581 1 0 r
.59016 .33568 .61876 .3434 .63166 .34153 .60308 .33403 Metetra
.545 1 0 r
.60308 .33403 .63166 .34153 .6446 .33952 .61604 .33222 Metetra
.514 1 0 r
.61604 .33222 .6446 .33952 .65758 .33734 .62904 .33022 Metetra
.487 1 0 r
.62904 .33022 .65758 .33734 .6706 .33497 .64208 .328 Metetra
.465 1 0 r
.64208 .328 .6706 .33497 .68366 .3324 .65516 .32554 Metetra
.447 1 0 r
.65516 .32554 .68366 .3324 .69676 .32961 .66828 .32283 Metetra
.436 1 0 r
.66828 .32283 .69676 .32961 .70989 .32659 .68144 .31984 Metetra
.43 1 0 r
.68144 .31984 .70989 .32659 .72307 .32332 .69463 .31657 Metetra
.43 1 0 r
.69463 .31657 .72307 .32332 .73628 .31982 .70787 .31301 Metetra
.436 1 0 r
.70787 .31301 .73628 .31982 .74953 .31607 .72114 .30918 Metetra
.447 1 0 r
.72114 .30918 .74953 .31607 .76282 .31209 .73445 .30506 Metetra
.465 1 0 r
.73445 .30506 .76282 .31209 .77615 .30788 .7478 .30068 Metetra
.487 1 0 r
.7478 .30068 .77615 .30788 .78951 .30345 .76119 .29605 Metetra
.514 1 0 r
.76119 .29605 .78951 .30345 .80291 .29884 .77461 .29119 Metetra
.545 1 0 r
.77461 .29119 .80291 .29884 .81635 .29404 .78807 .28614 Metetra
.581 1 0 r
.78807 .28614 .81635 .29404 .82983 .28909 .80157 .2809 Metetra
.619 1 0 r
.80157 .2809 .82983 .28909 .84334 .28401 .81511 .27553 Metetra
.66 1 0 r
.81511 .27553 .84334 .28401 .8569 .27882 .82868 .27003 Metetra
.702 1 0 r
.82868 .27003 .8569 .27882 .87049 .27354 .84229 .26446 Metetra
.746 1 0 r
.84229 .26446 .87049 .27354 .88412 .2682 .85595 .25882 Metetra
.791 1 0 r
.85595 .25882 .88412 .2682 .89779 .26282 .86964 .25314 Metetra
.836 1 0 r
.86964 .25314 .89779 .26282 .9115 .25742 .88337 .24746 Metetra
.881 1 0 r
.88337 .24746 .9115 .25742 .92525 .25201 .89715 .24179 Metetra
.925 1 0 r
.89715 .24179 .92525 .25201 .93905 .24661 .91096 .23614 Metetra
.969 1 0 r
.91096 .23614 .93905 .24661 .95288 .24123 .92482 .23053 Metetra
1 .989 0 r
.92482 .23053 .95288 .24123 .96676 .23589 .93872 .22498 Metetra
1 .948 0 r
.93872 .22498 .96676 .23589 .98068 .23058 .95267 .21948 Metetra
1 .909 0 r
.95267 .21948 .98068 .23058 .99464 .22532 .96665 .21404 Metetra
1 .912 0 r
.40927 .34217 .43831 .35237 .45074 .35079 .42171 .3407 Metetra
1 .954 0 r
.42171 .3407 .45074 .35079 .46322 .34928 .4342 .33931 Metetra
1 .999 0 r
.4342 .33931 .46322 .34928 .47573 .34783 .44672 .33802 Metetra
.955 1 0 r
.44672 .33802 .47573 .34783 .48828 .34645 .45929 .33681 Metetra
.907 1 0 r
.45929 .33681 .48828 .34645 .50087 .34511 .47189 .33567 Metetra
.858 1 0 r
.47189 .33567 .50087 .34511 .51351 .34381 .48454 .33459 Metetra
.807 1 0 r
.48454 .33459 .51351 .34381 .52618 .34253 .49723 .33356 Metetra
.756 1 0 r
.49723 .33356 .52618 .34253 .53889 .34125 .50996 .33254 Metetra
.705 1 0 r
.50996 .33254 .53889 .34125 .55165 .33996 .52272 .33152 Metetra
.655 1 0 r
.52272 .33152 .55165 .33996 .56445 .33861 .53554 .33047 Metetra
.605 1 0 r
.53554 .33047 .56445 .33861 .57728 .3372 .54839 .32934 Metetra
.558 1 0 r
.54839 .32934 .57728 .3372 .59016 .33568 .56128 .32811 Metetra
.513 1 0 r
.56128 .32811 .59016 .33568 .60308 .33403 .57422 .32673 Metetra
.472 1 0 r
.57422 .32673 .60308 .33403 .61604 .33222 .5872 .32517 Metetra
.435 1 0 r
.5872 .32517 .61604 .33222 .62904 .33022 .60022 .3234 Metetra
.403 1 0 r
.60022 .3234 .62904 .33022 .64208 .328 .61328 .32137 Metetra
.377 1 0 r
.61328 .32137 .64208 .328 .65516 .32554 .62638 .31906 Metetra
.357 1 0 r
.62638 .31906 .65516 .32554 .66828 .32283 .63952 .31645 Metetra
.343 1 0 r
.63952 .31645 .66828 .32283 .68144 .31984 .6527 .31351 Metetra
.336 1 0 r
.6527 .31351 .68144 .31984 .69463 .31657 .66592 .31024 Metetra
.336 1 0 r
.66592 .31024 .69463 .31657 .70787 .31301 .67918 .30664 Metetra
.343 1 0 r
.67918 .30664 .70787 .31301 .72114 .30918 .69247 .30269 Metetra
.357 1 0 r
.69247 .30269 .72114 .30918 .73445 .30506 .7058 .29841 Metetra
.377 1 0 r
.7058 .29841 .73445 .30506 .7478 .30068 .71918 .29383 Metetra
.403 1 0 r
.71918 .29383 .7478 .30068 .76119 .29605 .73258 .28895 Metetra
.435 1 0 r
.73258 .28895 .76119 .29605 .77461 .29119 .74603 .28381 Metetra
.472 1 0 r
.74603 .28381 .77461 .29119 .78807 .28614 .75951 .27844 Metetra
.513 1 0 r
.75951 .27844 .78807 .28614 .80157 .2809 .77303 .27287 Metetra
.558 1 0 r
.77303 .27287 .80157 .2809 .81511 .27553 .78659 .26714 Metetra
.605 1 0 r
.78659 .26714 .81511 .27553 .82868 .27003 .80018 .26129 Metetra
.655 1 0 r
.80018 .26129 .82868 .27003 .84229 .26446 .81382 .25535 Metetra
.705 1 0 r
.81382 .25535 .84229 .26446 .85595 .25882 .82749 .24937 Metetra
.756 1 0 r
.82749 .24937 .85595 .25882 .86964 .25314 .84121 .24336 Metetra
.807 1 0 r
.84121 .24336 .86964 .25314 .88337 .24746 .85496 .23736 Metetra
.858 1 0 r
.85496 .23736 .88337 .24746 .89715 .24179 .86876 .23139 Metetra
.907 1 0 r
.86876 .23139 .89715 .24179 .91096 .23614 .8826 .22547 Metetra
.955 1 0 r
.8826 .22547 .91096 .23614 .92482 .23053 .89648 .21961 Metetra
1 .999 0 r
.89648 .21961 .92482 .23053 .93872 .22498 .9104 .21382 Metetra
1 .954 0 r
.9104 .21382 .93872 .22498 .95267 .21948 .92437 .20812 Metetra
1 .912 0 r
.92437 .20812 .95267 .21948 .96665 .21404 .93838 .2025 Metetra
1 .91 0 r
.37996 .3317 .40927 .34217 .42171 .3407 .39241 .33033 Metetra
1 .956 0 r
.39241 .33033 .42171 .3407 .4342 .33931 .40491 .32909 Metetra
.996 1 0 r
.40491 .32909 .4342 .33931 .44672 .33802 .41744 .32796 Metetra
.945 1 0 r
.41744 .32796 .44672 .33802 .45929 .33681 .43002 .32694 Metetra
.891 1 0 r
.43002 .32694 .45929 .33681 .47189 .33567 .44264 .32603 Metetra
.836 1 0 r
.44264 .32603 .47189 .33567 .48454 .33459 .4553 .32521 Metetra
.779 1 0 r
.4553 .32521 .48454 .33459 .49723 .33356 .46799 .32446 Metetra
.721 1 0 r
.46799 .32446 .49723 .33356 .50996 .33254 .48074 .32375 Metetra
.663 1 0 r
.48074 .32375 .50996 .33254 .52272 .33152 .49352 .32307 Metetra
.605 1 0 r
.49352 .32307 .52272 .33152 .53554 .33047 .50635 .32236 Metetra
.547 1 0 r
.50635 .32236 .53554 .33047 .54839 .32934 .51921 .32159 Metetra
.492 1 0 r
.51921 .32159 .54839 .32934 .56128 .32811 .53213 .32071 Metetra
.44 1 0 r
.53213 .32071 .56128 .32811 .57422 .32673 .54508 .31967 Metetra
.391 1 0 r
.54508 .31967 .57422 .32673 .5872 .32517 .55808 .31844 Metetra
.347 1 0 r
.55808 .31844 .5872 .32517 .60022 .3234 .57111 .31695 Metetra
.31 1 0 r
.57111 .31695 .60022 .3234 .61328 .32137 .58419 .31516 Metetra
.278 1 0 r
.58419 .31516 .61328 .32137 .62638 .31906 .59731 .31305 Metetra
.254 1 0 r
.59731 .31305 .62638 .31906 .63952 .31645 .61048 .31057 Metetra
.238 1 0 r
.61048 .31057 .63952 .31645 .6527 .31351 .62368 .30771 Metetra
.229 1 0 r
.62368 .30771 .6527 .31351 .66592 .31024 .63692 .30445 Metetra
.229 1 0 r
.63692 .30445 .66592 .31024 .67918 .30664 .6502 .30078 Metetra
.238 1 0 r
.6502 .30078 .67918 .30664 .69247 .30269 .66351 .2967 Metetra
.254 1 0 r
.66351 .2967 .69247 .30269 .7058 .29841 .67687 .29224 Metetra
.278 1 0 r
.67687 .29224 .7058 .29841 .71918 .29383 .69026 .2874 Metetra
.31 1 0 r
.69026 .2874 .71918 .29383 .73258 .28895 .70369 .28222 Metetra
.347 1 0 r
.70369 .28222 .73258 .28895 .74603 .28381 .71716 .27673 Metetra
.391 1 0 r
.71716 .27673 .74603 .28381 .75951 .27844 .73066 .27098 Metetra
.44 1 0 r
.73066 .27098 .75951 .27844 .77303 .27287 .74421 .265 Metetra
.492 1 0 r
.74421 .265 .77303 .27287 .78659 .26714 .75778 .25885 Metetra
.547 1 0 r
.75778 .25885 .78659 .26714 .80018 .26129 .7714 .25257 Metetra
.605 1 0 r
.7714 .25257 .80018 .26129 .81382 .25535 .78506 .24622 Metetra
.663 1 0 r
.78506 .24622 .81382 .25535 .82749 .24937 .79875 .23982 Metetra
.721 1 0 r
.79875 .23982 .82749 .24937 .84121 .24336 .81249 .23343 Metetra
.779 1 0 r
.81249 .23343 .84121 .24336 .85496 .23736 .82627 .22707 Metetra
.836 1 0 r
.82627 .22707 .85496 .23736 .86876 .23139 .84009 .22076 Metetra
.891 1 0 r
.84009 .22076 .86876 .23139 .8826 .22547 .85395 .21454 Metetra
.945 1 0 r
.85395 .21454 .8826 .22547 .89648 .21961 .86785 .20841 Metetra
.996 1 0 r
.86785 .20841 .89648 .21961 .9104 .21382 .8818 .20238 Metetra
1 .956 0 r
.8818 .20238 .9104 .21382 .92437 .20812 .89579 .19647 Metetra
1 .91 0 r
.89579 .19647 .92437 .20812 .93838 .2025 .90982 .19066 Metetra
1 .904 0 r
.35037 .32091 .37996 .3317 .39241 .33033 .36284 .31965 Metetra
1 .953 0 r
.36284 .31965 .39241 .33033 .40491 .32909 .37534 .31855 Metetra
.994 1 0 r
.37534 .31855 .40491 .32909 .41744 .32796 .38789 .31759 Metetra
.938 1 0 r
.38789 .31759 .41744 .32796 .43002 .32694 .40047 .31679 Metetra
.879 1 0 r
.40047 .31679 .43002 .32694 .44264 .32603 .4131 .31612 Metetra
.818 1 0 r
.4131 .31612 .44264 .32603 .4553 .32521 .42577 .31559 Metetra
.753 1 0 r
.42577 .31559 .4553 .32521 .46799 .32446 .43848 .31517 Metetra
.687 1 0 r
.43848 .31517 .46799 .32446 .48074 .32375 .45123 .31484 Metetra
.62 1 0 r
.45123 .31484 .48074 .32375 .49352 .32307 .46403 .31456 Metetra
.553 1 0 r
.46403 .31456 .49352 .32307 .50635 .32236 .47687 .31428 Metetra
.486 1 0 r
.47687 .31428 .50635 .32236 .51921 .32159 .48975 .31395 Metetra
.421 1 0 r
.48975 .31395 .51921 .32159 .53213 .32071 .50268 .31351 Metetra
.359 1 0 r
.50268 .31351 .53213 .32071 .54508 .31967 .51565 .31291 Metetra
.301 1 0 r
.51565 .31291 .54508 .31967 .55808 .31844 .52866 .31207 Metetra
.249 1 0 r
.52866 .31207 .55808 .31844 .57111 .31695 .54172 .31095 Metetra
.204 1 0 r
.54172 .31095 .57111 .31695 .58419 .31516 .55481 .30948 Metetra
.167 1 0 r
.55481 .30948 .58419 .31516 .59731 .31305 .56795 .30761 Metetra
.138 1 0 r
.56795 .30761 .59731 .31305 .61048 .31057 .58114 .30531 Metetra
.118 1 0 r
.58114 .30531 .61048 .31057 .62368 .30771 .59436 .30254 Metetra
.108 1 0 r
.59436 .30254 .62368 .30771 .63692 .30445 .60762 .2993 Metetra
.108 1 0 r
.60762 .2993 .63692 .30445 .6502 .30078 .62092 .29556 Metetra
.118 1 0 r
.62092 .29556 .6502 .30078 .66351 .2967 .63427 .29134 Metetra
.138 1 0 r
.63427 .29134 .66351 .2967 .67687 .29224 .64764 .28664 Metetra
.167 1 0 r
.64764 .28664 .67687 .29224 .69026 .2874 .66106 .2815 Metetra
.204 1 0 r
.66106 .2815 .69026 .2874 .70369 .28222 .67451 .27595 Metetra
.249 1 0 r
.67451 .27595 .70369 .28222 .71716 .27673 .688 .27004 Metetra
.301 1 0 r
.688 .27004 .71716 .27673 .73066 .27098 .70153 .26381 Metetra
.359 1 0 r
.70153 .26381 .73066 .27098 .74421 .265 .71509 .25734 Metetra
.421 1 0 r
.71509 .25734 .74421 .265 .75778 .25885 .72869 .25067 Metetra
.486 1 0 r
.72869 .25067 .75778 .25885 .7714 .25257 .74233 .24388 Metetra
.553 1 0 r
.74233 .24388 .7714 .25257 .78506 .24622 .75601 .23702 Metetra
.62 1 0 r
.75601 .23702 .78506 .24622 .79875 .23982 .76973 .23015 Metetra
.687 1 0 r
.76973 .23015 .79875 .23982 .81249 .23343 .78348 .2233 Metetra
.753 1 0 r
.78348 .2233 .81249 .23343 .82627 .22707 .79728 .21653 Metetra
.818 1 0 r
.79728 .21653 .82627 .22707 .84009 .22076 .81112 .20986 Metetra
.879 1 0 r
.81112 .20986 .84009 .22076 .85395 .21454 .825 .2033 Metetra
.938 1 0 r
.825 .2033 .85395 .21454 .86785 .20841 .83893 .19688 Metetra
.994 1 0 r
.83893 .19688 .86785 .20841 .8818 .20238 .8529 .1906 Metetra
1 .953 0 r
.8529 .1906 .8818 .20238 .89579 .19647 .86691 .18447 Metetra
1 .904 0 r
.86691 .18447 .89579 .19647 .90982 .19066 .88097 .17847 Metetra
1 .892 0 r
.32051 .30976 .35037 .32091 .36284 .31965 .33298 .3086 Metetra
1 .945 0 r
.33298 .3086 .36284 .31965 .37534 .31855 .3455 .30763 Metetra
.998 1 0 r
.3455 .30763 .37534 .31855 .38789 .31759 .35805 .30685 Metetra
.937 1 0 r
.35805 .30685 .38789 .31759 .40047 .31679 .37065 .30627 Metetra
.872 1 0 r
.37065 .30627 .40047 .31679 .4131 .31612 .38328 .30588 Metetra
.803 1 0 r
.38328 .30588 .4131 .31612 .42577 .31559 .39596 .30568 Metetra
.731 1 0 r
.39596 .30568 .42577 .31559 .43848 .31517 .40868 .30565 Metetra
.656 1 0 r
.40868 .30565 .43848 .31517 .45123 .31484 .42144 .30575 Metetra
.578 1 0 r
.42144 .30575 .45123 .31484 .46403 .31456 .43425 .30595 Metetra
.5 1 0 r
.43425 .30595 .46403 .31456 .47687 .31428 .4471 .30619 Metetra
.421 1 0 r
.4471 .30619 .47687 .31428 .48975 .31395 .45999 .30642 Metetra
.344 1 0 r
.45999 .30642 .48975 .31395 .50268 .31351 .47293 .30654 Metetra
.271 1 0 r
.47293 .30654 .50268 .31351 .51565 .31291 .48592 .30648 Metetra
.202 1 0 r
.48592 .30648 .51565 .31291 .52866 .31207 .49895 .30616 Metetra
.139 1 0 r
.49895 .30616 .52866 .31207 .54172 .31095 .51202 .3055 Metetra
.085 1 0 r
.51202 .3055 .54172 .31095 .55481 .30948 .52514 .30443 Metetra
.04 1 0 r
.52514 .30443 .55481 .30948 .56795 .30761 .5383 .30288 Metetra
.005 1 0 r
.5383 .30288 .56795 .30761 .58114 .30531 .5515 .30081 Metetra
0 1 .019 r
.5515 .30081 .58114 .30531 .59436 .30254 .56474 .29818 Metetra
0 1 .031 r
.56474 .29818 .59436 .30254 .60762 .2993 .57803 .29496 Metetra
0 1 .031 r
.57803 .29496 .60762 .2993 .62092 .29556 .59135 .29114 Metetra
0 1 .019 r
.59135 .29114 .62092 .29556 .63427 .29134 .60472 .28674 Metetra
.005 1 0 r
.60472 .28674 .63427 .29134 .64764 .28664 .61812 .28176 Metetra
.04 1 0 r
.61812 .28176 .64764 .28664 .66106 .2815 .63156 .27625 Metetra
.085 1 0 r
.63156 .27625 .66106 .2815 .67451 .27595 .64503 .27024 Metetra
.139 1 0 r
.64503 .27024 .67451 .27595 .688 .27004 .65855 .2638 Metetra
.202 1 0 r
.65855 .2638 .688 .27004 .70153 .26381 .6721 .25699 Metetra
.271 1 0 r
.6721 .25699 .70153 .26381 .71509 .25734 .68568 .2499 Metetra
.344 1 0 r
.68568 .2499 .71509 .25734 .72869 .25067 .6993 .2426 Metetra
.421 1 0 r
.6993 .2426 .72869 .25067 .74233 .24388 .71296 .23518 Metetra
.5 1 0 r
.71296 .23518 .74233 .24388 .75601 .23702 .72666 .22772 Metetra
.578 1 0 r
.72666 .22772 .75601 .23702 .76973 .23015 .7404 .22028 Metetra
.656 1 0 r
.7404 .22028 .76973 .23015 .78348 .2233 .75418 .21292 Metetra
.731 1 0 r
.75418 .21292 .78348 .2233 .79728 .21653 .768 .20568 Metetra
.803 1 0 r
.768 .20568 .79728 .21653 .81112 .20986 .78186 .19859 Metetra
.872 1 0 r
.78186 .19859 .81112 .20986 .825 .2033 .79577 .19168 Metetra
.937 1 0 r
.79577 .19168 .825 .2033 .83893 .19688 .80972 .18495 Metetra
.998 1 0 r
.80972 .18495 .83893 .19688 .8529 .1906 .82371 .17841 Metetra
1 .945 0 r
.82371 .17841 .8529 .1906 .86691 .18447 .83775 .17206 Metetra
1 .892 0 r
.83775 .17206 .86691 .18447 .88097 .17847 .85183 .16588 Metetra
1 .874 0 r
.29036 .29818 .32051 .30976 .33298 .3086 .30285 .29711 Metetra
1 .93 0 r
.30285 .29711 .33298 .3086 .3455 .30763 .31537 .29626 Metetra
1 .99 0 r
.31537 .29626 .3455 .30763 .35805 .30685 .32794 .29566 Metetra
.943 1 0 r
.32794 .29566 .35805 .30685 .37065 .30627 .34054 .2953 Metetra
.872 1 0 r
.34054 .2953 .37065 .30627 .38328 .30588 .35318 .29521 Metetra
.795 1 0 r
.35318 .29521 .38328 .30588 .39596 .30568 .36587 .29537 Metetra
.714 1 0 r
.36587 .29537 .39596 .30568 .40868 .30565 .37859 .29577 Metetra
.628 1 0 r
.37859 .29577 .40868 .30565 .42144 .30575 .39136 .29639 Metetra
.538 1 0 r
.39136 .29639 .42144 .30575 .43425 .30595 .40418 .29718 Metetra
.447 1 0 r
.40418 .29718 .43425 .30595 .4471 .30619 .41704 .29807 Metetra
.354 1 0 r
.41704 .29807 .4471 .30619 .45999 .30642 .42994 .29898 Metetra
.262 1 0 r
.42994 .29898 .45999 .30642 .47293 .30654 .44289 .29982 Metetra
.174 1 0 r
.44289 .29982 .47293 .30654 .48592 .30648 .45589 .30046 Metetra
.091 1 0 r
.45589 .30046 .48592 .30648 .49895 .30616 .46893 .3008 Metetra
.015 1 0 r
.46893 .3008 .49895 .30616 .51202 .3055 .48202 .30074 Metetra
0 1 .051 r
.48202 .30074 .51202 .3055 .52514 .30443 .49515 .30018 Metetra
0 1 .106 r
.49515 .30018 .52514 .30443 .5383 .30288 .50833 .29904 Metetra
0 1 .148 r
.50833 .29904 .5383 .30288 .5515 .30081 .52155 .29726 Metetra
0 1 .177 r
.52155 .29726 .5515 .30081 .56474 .29818 .53482 .2948 Metetra
0 1 .192 r
.53482 .2948 .56474 .29818 .57803 .29496 .54813 .29162 Metetra
0 1 .192 r
.54813 .29162 .57803 .29496 .59135 .29114 .56147 .28772 Metetra
0 1 .177 r
.56147 .28772 .59135 .29114 .60472 .28674 .57486 .28309 Metetra
0 1 .148 r
.57486 .28309 .60472 .28674 .61812 .28176 .58829 .27778 Metetra
0 1 .106 r
.58829 .27778 .61812 .28176 .63156 .27625 .60175 .2718 Metetra
0 1 .051 r
.60175 .2718 .63156 .27625 .64503 .27024 .61525 .26522 Metetra
.015 1 0 r
.61525 .26522 .64503 .27024 .65855 .2638 .62879 .25811 Metetra
.091 1 0 r
.62879 .25811 .65855 .2638 .6721 .25699 .64236 .25058 Metetra
.174 1 0 r
.64236 .25058 .6721 .25699 .68568 .2499 .65597 .24271 Metetra
.262 1 0 r
.65597 .24271 .68568 .2499 .6993 .2426 .66962 .23463 Metetra
.354 1 0 r
.66962 .23463 .6993 .2426 .71296 .23518 .6833 .22644 Metetra
.447 1 0 r
.6833 .22644 .71296 .23518 .72666 .22772 .69702 .21824 Metetra
.538 1 0 r
.69702 .21824 .72666 .22772 .7404 .22028 .71078 .21013 Metetra
.628 1 0 r
.71078 .21013 .7404 .22028 .75418 .21292 .72458 .20216 Metetra
.714 1 0 r
.72458 .20216 .75418 .21292 .768 .20568 .73842 .19439 Metetra
.795 1 0 r
.73842 .19439 .768 .20568 .78186 .19859 .7523 .18685 Metetra
.872 1 0 r
.7523 .18685 .78186 .19859 .79577 .19168 .76623 .17956 Metetra
.943 1 0 r
.76623 .17956 .79577 .19168 .80972 .18495 .7802 .17253 Metetra
1 .99 0 r
.7802 .17253 .80972 .18495 .82371 .17841 .79422 .16573 Metetra
1 .93 0 r
.79422 .16573 .82371 .17841 .83775 .17206 .80828 .15917 Metetra
1 .874 0 r
.80828 .15917 .83775 .17206 .85183 .16588 .82239 .15283 Metetra
1 .847 0 r
.25994 .28612 .29036 .29818 .30285 .29711 .27243 .2851 Metetra
1 .905 0 r
.27243 .2851 .30285 .29711 .31537 .29626 .28496 .28435 Metetra
1 .97 0 r
.28496 .28435 .31537 .29626 .32794 .29566 .29753 .2839 Metetra
.959 1 0 r
.29753 .2839 .32794 .29566 .34054 .2953 .31014 .28376 Metetra
.881 1 0 r
.31014 .28376 .34054 .2953 .35318 .29521 .32279 .28396 Metetra
.797 1 0 r
.32279 .28396 .35318 .29521 .36587 .29537 .33548 .28451 Metetra
.705 1 0 r
.33548 .28451 .36587 .29537 .37859 .29577 .34822 .28541 Metetra
.607 1 0 r
.34822 .28541 .37859 .29577 .39136 .29639 .36099 .28664 Metetra
.503 1 0 r
.36099 .28664 .39136 .29639 .40418 .29718 .37381 .28814 Metetra
.395 1 0 r
.37381 .28814 .40418 .29718 .41704 .29807 .38667 .28983 Metetra
.285 1 0 r
.38667 .28983 .41704 .29807 .42994 .29898 .39958 .29162 Metetra
.175 1 0 r
.39958 .29162 .42994 .29898 .44289 .29982 .41254 .29336 Metetra
.068 1 0 r
.41254 .29336 .44289 .29982 .45589 .30046 .42555 .29491 Metetra
0 1 .033 r
.42555 .29491 .45589 .30046 .46893 .3008 .4386 .29612 Metetra
0 1 .126 r
.4386 .29612 .46893 .3008 .48202 .30074 .4517 .29683 Metetra
0 1 .207 r
.4517 .29683 .48202 .30074 .49515 .30018 .46485 .29693 Metetra
0 1 .274 r
.46485 .29693 .49515 .30018 .50833 .29904 .47805 .29631 Metetra
0 1 .325 r
.47805 .29631 .50833 .29904 .52155 .29726 .49129 .2949 Metetra
0 1 .361 r
.49129 .2949 .52155 .29726 .53482 .2948 .50458 .29265 Metetra
0 1 .378 r
.50458 .29265 .53482 .2948 .54813 .29162 .51791 .28953 Metetra
0 1 .378 r
.51791 .28953 .54813 .29162 .56147 .28772 .53128 .28552 Metetra
0 1 .361 r
.53128 .28552 .56147 .28772 .57486 .28309 .54469 .28064 Metetra
0 1 .325 r
.54469 .28064 .57486 .28309 .58829 .27778 .55814 .2749 Metetra
0 1 .274 r
.55814 .2749 .58829 .27778 .60175 .2718 .57163 .26835 Metetra
0 1 .207 r
.57163 .26835 .60175 .2718 .61525 .26522 .58516 .26105 Metetra
0 1 .126 r
.58516 .26105 .61525 .26522 .62879 .25811 .59872 .25311 Metetra
0 1 .033 r
.59872 .25311 .62879 .25811 .64236 .25058 .61232 .24464 Metetra
.068 1 0 r
.61232 .24464 .64236 .25058 .65597 .24271 .62595 .2358 Metetra
.175 1 0 r
.62595 .2358 .65597 .24271 .66962 .23463 .63962 .22672 Metetra
.285 1 0 r
.63962 .22672 .66962 .23463 .6833 .22644 .65333 .21757 Metetra
.395 1 0 r
.65333 .21757 .6833 .22644 .69702 .21824 .66707 .20847 Metetra
.503 1 0 r
.66707 .20847 .69702 .21824 .71078 .21013 .68085 .19955 Metetra
.607 1 0 r
.68085 .19955 .71078 .21013 .72458 .20216 .69467 .19089 Metetra
.705 1 0 r
.69467 .19089 .72458 .20216 .73842 .19439 .70854 .18254 Metetra
.797 1 0 r
.70854 .18254 .73842 .19439 .7523 .18685 .72244 .17452 Metetra
.881 1 0 r
.72244 .17452 .7523 .18685 .76623 .17956 .73639 .16684 Metetra
.959 1 0 r
.73639 .16684 .76623 .17956 .7802 .17253 .75039 .1595 Metetra
1 .97 0 r
.75039 .1595 .7802 .17253 .79422 .16573 .76443 .15247 Metetra
1 .905 0 r
.76443 .15247 .79422 .16573 .80828 .15917 .77851 .14573 Metetra
1 .847 0 r
.77851 .14573 .80828 .15917 .82239 .15283 .79265 .13926 Metetra
1 .81 0 r
.22924 .27352 .25994 .28612 .27243 .2851 .24174 .2725 Metetra
1 .87 0 r
.24174 .2725 .27243 .2851 .28496 .28435 .25427 .2718 Metetra
1 .938 0 r
.25427 .2718 .28496 .28435 .29753 .2839 .26685 .27145 Metetra
.987 1 0 r
.26685 .27145 .29753 .2839 .31014 .28376 .27946 .2715 Metetra
.903 1 0 r
.27946 .2715 .31014 .28376 .32279 .28396 .29212 .27198 Metetra
.81 1 0 r
.29212 .27198 .32279 .28396 .33548 .28451 .30481 .27293 Metetra
.707 1 0 r
.30481 .27293 .33548 .28451 .34822 .28541 .31755 .27437 Metetra
.595 1 0 r
.31755 .27437 .34822 .28541 .36099 .28664 .33032 .27629 Metetra
.475 1 0 r
.33032 .27629 .36099 .28664 .37381 .28814 .34314 .27865 Metetra
.347 1 0 r
.34314 .27865 .37381 .28814 .38667 .28983 .35601 .28135 Metetra
.215 1 0 r
.35601 .28135 .38667 .28983 .39958 .29162 .36892 .28427 Metetra
.082 1 0 r
.36892 .28427 .39958 .29162 .41254 .29336 .38188 .2872 Metetra
0 1 .049 r
.38188 .2872 .41254 .29336 .42555 .29491 .39489 .28994 Metetra
0 1 .174 r
.39489 .28994 .42555 .29491 .4386 .29612 .40795 .29227 Metetra
0 1 .287 r
.40795 .29227 .4386 .29612 .4517 .29683 .42106 .29399 Metetra
0 1 .387 r
.42106 .29399 .4517 .29683 .46485 .29693 .43422 .29492 Metetra
0 1 .469 r
.43422 .29492 .46485 .29693 .47805 .29631 .44744 .29496 Metetra
0 1 .532 r
.44744 .29496 .47805 .29631 .49129 .2949 .4607 .29401 Metetra
0 1 .575 r
.4607 .29401 .49129 .2949 .50458 .29265 .47401 .29202 Metetra
0 1 .597 r
.47401 .29202 .50458 .29265 .51791 .28953 .48736 .28898 Metetra
0 1 .597 r
.48736 .28898 .51791 .28953 .53128 .28552 .50076 .28486 Metetra
0 1 .575 r
.50076 .28486 .53128 .28552 .54469 .28064 .5142 .27966 Metetra
0 1 .532 r
.5142 .27966 .54469 .28064 .55814 .2749 .52768 .27342 Metetra
0 1 .469 r
.52768 .27342 .55814 .2749 .57163 .26835 .54119 .26616 Metetra
0 1 .387 r
.54119 .26616 .57163 .26835 .58516 .26105 .55475 .25797 Metetra
0 1 .287 r
.55475 .25797 .58516 .26105 .59872 .25311 .56834 .24896 Metetra
0 1 .174 r
.56834 .24896 .59872 .25311 .61232 .24464 .58196 .2393 Metetra
0 1 .049 r
.58196 .2393 .61232 .24464 .62595 .2358 .59562 .22917 Metetra
.082 1 0 r
.59562 .22917 .62595 .2358 .63962 .22672 .60931 .21881 Metetra
.215 1 0 r
.60931 .21881 .63962 .22672 .65333 .21757 .62304 .20844 Metetra
.347 1 0 r
.62304 .20844 .65333 .21757 .66707 .20847 .63681 .19824 Metetra
.475 1 0 r
.63681 .19824 .66707 .20847 .68085 .19955 .65061 .18836 Metetra
.595 1 0 r
.65061 .18836 .68085 .19955 .69467 .19089 .66446 .1789 Metetra
.707 1 0 r
.66446 .1789 .69467 .19089 .70854 .18254 .67834 .16991 Metetra
.81 1 0 r
.67834 .16991 .70854 .18254 .72244 .17452 .69227 .1614 Metetra
.903 1 0 r
.69227 .1614 .72244 .17452 .73639 .16684 .70625 .15335 Metetra
.987 1 0 r
.70625 .15335 .73639 .16684 .75039 .1595 .72027 .14574 Metetra
1 .938 0 r
.72027 .14574 .75039 .1595 .76443 .15247 .73433 .13851 Metetra
1 .87 0 r
.73433 .13851 .76443 .15247 .77851 .14573 .74844 .13164 Metetra
1 .81 0 r
.74844 .13164 .77851 .14573 .79265 .13926 .7626 .12508 Metetra
1 .762 0 r
.19825 .2603 .22924 .27352 .24174 .2725 .21076 .25923 Metetra
1 .822 0 r
.21076 .25923 .24174 .2725 .25427 .2718 .2233 .2585 Metetra
1 .891 0 r
.2233 .2585 .25427 .2718 .26685 .27145 .23588 .25818 Metetra
1 .97 0 r
.23588 .25818 .26685 .27145 .27946 .2715 .2485 .25834 Metetra
.941 1 0 r
.2485 .25834 .27946 .2715 .29212 .27198 .26116 .25904 Metetra
.84 1 0 r
.26116 .25904 .29212 .27198 .30481 .27293 .27385 .26036 Metetra
.727 1 0 r
.27385 .26036 .30481 .27293 .31755 .27437 .28659 .26236 Metetra
.6 1 0 r
.28659 .26236 .31755 .27437 .33032 .27629 .29936 .26506 Metetra
.46 1 0 r
.29936 .26506 .33032 .27629 .34314 .27865 .31217 .26844 Metetra
.308 1 0 r
.31217 .26844 .34314 .27865 .35601 .28135 .32503 .27242 Metetra
.148 1 0 r
.32503 .27242 .35601 .28135 .36892 .28427 .33794 .27681 Metetra
0 1 .016 r
.33794 .27681 .36892 .28427 .38188 .2872 .3509 .28134 Metetra
0 1 .178 r
.3509 .28134 .38188 .2872 .39489 .28994 .36391 .28568 Metetra
0 1 .333 r
.36391 .28568 .39489 .28994 .40795 .29227 .37697 .28951 Metetra
0 1 .475 r
.37697 .28951 .40795 .29227 .42106 .29399 .39009 .29253 Metetra
0 1 .598 r
.39009 .29253 .42106 .29399 .43422 .29492 .40326 .29453 Metetra
0 1 .699 r
.40326 .29453 .43422 .29492 .44744 .29496 .41649 .29536 Metetra
0 1 .776 r
.41649 .29536 .44744 .29496 .4607 .29401 .42977 .29496 Metetra
0 1 .828 r
.42977 .29496 .4607 .29401 .47401 .29202 .4431 .29328 Metetra
0 1 .854 r
.4431 .29328 .47401 .29202 .48736 .28898 .45647 .29033 Metetra
0 1 .854 r
.45647 .29033 .48736 .28898 .50076 .28486 .4699 .28608 Metetra
0 1 .828 r
.4699 .28608 .50076 .28486 .5142 .27966 .48337 .28054 Metetra
0 1 .776 r
.48337 .28054 .5142 .27966 .52768 .27342 .49688 .27371 Metetra
0 1 .699 r
.49688 .27371 .52768 .27342 .54119 .26616 .51042 .2656 Metetra
0 1 .598 r
.51042 .2656 .54119 .26616 .55475 .25797 .52401 .2563 Metetra
0 1 .475 r
.52401 .2563 .55475 .25797 .56834 .24896 .53763 .24591 Metetra
0 1 .333 r
.53763 .24591 .56834 .24896 .58196 .2393 .55128 .23467 Metetra
0 1 .178 r
.55128 .23467 .58196 .2393 .59562 .22917 .56497 .22285 Metetra
0 1 .016 r
.56497 .22285 .59562 .22917 .60931 .21881 .57869 .21079 Metetra
.148 1 0 r
.57869 .21079 .60931 .21881 .62304 .20844 .59244 .19883 Metetra
.308 1 0 r
.59244 .19883 .62304 .20844 .63681 .19824 .60623 .18725 Metetra
.46 1 0 r
.60623 .18725 .63681 .19824 .65061 .18836 .62006 .17624 Metetra
.6 1 0 r
.62006 .17624 .65061 .18836 .66446 .1789 .63393 .1659 Metetra
.727 1 0 r
.63393 .1659 .66446 .1789 .67834 .16991 .64784 .15625 Metetra
.84 1 0 r
.64784 .15625 .67834 .16991 .69227 .1614 .66179 .14727 Metetra
.941 1 0 r
.66179 .14727 .69227 .1614 .70625 .15335 .67579 .13891 Metetra
1 .97 0 r
.67579 .13891 .70625 .15335 .72027 .14574 .68983 .13109 Metetra
1 .891 0 r
.68983 .13109 .72027 .14574 .73433 .13851 .70392 .12375 Metetra
1 .822 0 r
.70392 .12375 .73433 .13851 .74844 .13164 .71806 .11683 Metetra
1 .762 0 r
.71806 .11683 .74844 .13164 .7626 .12508 .73224 .11025 Metetra
1 .701 0 r
.16698 .24643 .19825 .2603 .21076 .25923 .17949 .2452 Metetra
1 .76 0 r
.17949 .2452 .21076 .25923 .2233 .2585 .19204 .24434 Metetra
1 .828 0 r
.19204 .24434 .2233 .2585 .23588 .25818 .20463 .24394 Metetra
1 .907 0 r
.20463 .24394 .23588 .25818 .2485 .25834 .21725 .24408 Metetra
1 .999 0 r
.21725 .24408 .2485 .25834 .26116 .25904 .22991 .24488 Metetra
.894 1 0 r
.22991 .24488 .26116 .25904 .27385 .26036 .24261 .24647 Metetra
.77 1 0 r
.24261 .24647 .27385 .26036 .28659 .26236 .25534 .24896 Metetra
.628 1 0 r
.25534 .24896 .28659 .26236 .29936 .26506 .26811 .25248 Metetra
.466 1 0 r
.26811 .25248 .29936 .26506 .31217 .26844 .28091 .25706 Metetra
.285 1 0 r
.28091 .25706 .31217 .26844 .32503 .27242 .29376 .26265 Metetra
.09 1 0 r
.29376 .26265 .32503 .27242 .33794 .27681 .30665 .26903 Metetra
0 1 .115 r
.30665 .26903 .33794 .27681 .3509 .28134 .31959 .27577 Metetra
0 1 .321 r
.31959 .27577 .3509 .28134 .36391 .28568 .33259 .28236 Metetra
0 1 .517 r
.33259 .28236 .36391 .28568 .37697 .28951 .34564 .28823 Metetra
0 1 .695 r
.34564 .28823 .37697 .28951 .39009 .29253 .35876 .29295 Metetra
0 1 .848 r
.35876 .29295 .39009 .29253 .40326 .29453 .37194 .29624 Metetra
0 1 .972 r
.37194 .29624 .40326 .29453 .41649 .29536 .38518 .298 Metetra
0 .935 1 r
.38518 .298 .41649 .29536 .42977 .29496 .39848 .29819 Metetra
0 .874 1 r
.39848 .29819 .42977 .29496 .4431 .29328 .41183 .29684 Metetra
0 .843 1 r
.41183 .29684 .4431 .29328 .45647 .29033 .42523 .29398 Metetra
0 .843 1 r
.42523 .29398 .45647 .29033 .4699 .28608 .43868 .28961 Metetra
0 .874 1 r
.43868 .28961 .4699 .28608 .48337 .28054 .45218 .28371 Metetra
0 .935 1 r
.45218 .28371 .48337 .28054 .49688 .27371 .46572 .27624 Metetra
0 1 .972 r
.46572 .27624 .49688 .27371 .51042 .2656 .47931 .26718 Metetra
0 1 .848 r
.47931 .26718 .51042 .2656 .52401 .2563 .49293 .25651 Metetra
0 1 .695 r
.49293 .25651 .52401 .2563 .53763 .24591 .50658 .24436 Metetra
0 1 .517 r
.50658 .24436 .53763 .24591 .55128 .23467 .52027 .23098 Metetra
0 1 .321 r
.52027 .23098 .55128 .23467 .56497 .22285 .53399 .21682 Metetra
0 1 .115 r
.53399 .21682 .56497 .22285 .57869 .21079 .54774 .20243 Metetra
.09 1 0 r
.54774 .20243 .57869 .21079 .59244 .19883 .56152 .18837 Metetra
.285 1 0 r
.56152 .18837 .59244 .19883 .60623 .18725 .57534 .17505 Metetra
.466 1 0 r
.57534 .17505 .60623 .18725 .62006 .17624 .58919 .16272 Metetra
.628 1 0 r
.58919 .16272 .62006 .17624 .63393 .1659 .60308 .15145 Metetra
.77 1 0 r
.60308 .15145 .63393 .1659 .64784 .15625 .61702 .1412 Metetra
.894 1 0 r
.61702 .1412 .64784 .15625 .66179 .14727 .631 .13186 Metetra
1 .999 0 r
.631 .13186 .66179 .14727 .67579 .13891 .64502 .1233 Metetra
1 .907 0 r
.64502 .1233 .67579 .13891 .68983 .13109 .65909 .11541 Metetra
1 .828 0 r
.65909 .11541 .68983 .13109 .70392 .12375 .6732 .10808 Metetra
1 .76 0 r
.6732 .10808 .70392 .12375 .71806 .11683 .68736 .1012 Metetra
1 .701 0 r
.68736 .1012 .71806 .11683 .73224 .11025 .70157 .0947 Metetra
1 .626 0 r
.13542 .23186 .16698 .24643 .17949 .2452 .14794 .23036 Metetra
1 .681 0 r
.14794 .23036 .17949 .2452 .19204 .24434 .1605 .22924 Metetra
1 .746 0 r
.1605 .22924 .19204 .24434 .20463 .24394 .1731 .22858 Metetra
1 .823 0 r
.1731 .22858 .20463 .24394 .21725 .24408 .18573 .22852 Metetra
1 .914 0 r
.18573 .22852 .21725 .24408 .22991 .24488 .19839 .2292 Metetra
.977 1 0 r
.19839 .2292 .22991 .24488 .24261 .24647 .21109 .23082 Metetra
.847 1 0 r
.21109 .23082 .24261 .24647 .25534 .24896 .22382 .23362 Metetra
.691 1 0 r
.22382 .23362 .25534 .24896 .26811 .25248 .23657 .23785 Metetra
.506 1 0 r
.23657 .23785 .26811 .25248 .28091 .25706 .24936 .24373 Metetra
.291 1 0 r
.24936 .24373 .28091 .25706 .29376 .26265 .26218 .25136 Metetra
.048 1 0 r
.26218 .25136 .29376 .26265 .30665 .26903 .27504 .26049 Metetra
0 1 .214 r
.27504 .26049 .30665 .26903 .31959 .27577 .28795 .27049 Metetra
0 1 .481 r
.28795 .27049 .31959 .27577 .33259 .28236 .30092 .28036 Metetra
0 1 .735 r
.30092 .28036 .33259 .28236 .34564 .28823 .31395 .2891 Metetra
0 1 .961 r
.31395 .2891 .34564 .28823 .35876 .29295 .32706 .29601 Metetra
0 .85 1 r
.32706 .29601 .35876 .29295 .37194 .29624 .34025 .3008 Metetra
0 .7 1 r
.34025 .3008 .37194 .29624 .38518 .298 .3535 .30348 Metetra
0 .591 1 r
.3535 .30348 .38518 .298 .39848 .29819 .36681 .30421 Metetra
0 .52 1 r
.36681 .30421 .39848 .29819 .41183 .29684 .38018 .30312 Metetra
0 .485 1 r
.38018 .30312 .41183 .29684 .42523 .29398 .39361 .30033 Metetra
0 .485 1 r
.39361 .30033 .42523 .29398 .43868 .28961 .40709 .29586 Metetra
0 .52 1 r
.40709 .29586 .43868 .28961 .45218 .28371 .42063 .28968 Metetra
0 .591 1 r
.42063 .28968 .45218 .28371 .46572 .27624 .4342 .28166 Metetra
0 .7 1 r
.4342 .28166 .46572 .27624 .47931 .26718 .44782 .27162 Metetra
0 .85 1 r
.44782 .27162 .47931 .26718 .49293 .25651 .46149 .25941 Metetra
0 1 .961 r
.46149 .25941 .49293 .25651 .50658 .24436 .47519 .245 Metetra
0 1 .735 r
.47519 .245 .50658 .24436 .52027 .23098 .48892 .22866 Metetra
0 1 .481 r
.48892 .22866 .52027 .23098 .53399 .21682 .50268 .21108 Metetra
0 1 .214 r
.50268 .21108 .53399 .21682 .54774 .20243 .51646 .1933 Metetra
.048 1 0 r
.51646 .1933 .54774 .20243 .56152 .18837 .53028 .17632 Metetra
.291 1 0 r
.53028 .17632 .56152 .18837 .57534 .17505 .54412 .16083 Metetra
.506 1 0 r
.54412 .16083 .57534 .17505 .58919 .16272 .558 .14707 Metetra
.691 1 0 r
.558 .14707 .58919 .16272 .60308 .15145 .57192 .13497 Metetra
.847 1 0 r
.57192 .13497 .60308 .15145 .61702 .1412 .58588 .12431 Metetra
.977 1 0 r
.58588 .12431 .61702 .1412 .631 .13186 .59989 .11484 Metetra
1 .914 0 r
.59989 .11484 .631 .13186 .64502 .1233 .61394 .10632 Metetra
1 .823 0 r
.61394 .10632 .64502 .1233 .65909 .11541 .62803 .09856 Metetra
1 .746 0 r
.62803 .09856 .65909 .11541 .6732 .10808 .64217 .09139 Metetra
1 .681 0 r
.64217 .09139 .6732 .10808 .68736 .1012 .65635 .08471 Metetra
1 .626 0 r
.65635 .08471 .68736 .1012 .70157 .0947 .67058 .0784 Metetra
1 .538 0 r
.10357 .21662 .13542 .23186 .14794 .23036 .11611 .21472 Metetra
1 .586 0 r
.11611 .21472 .14794 .23036 .1605 .22924 .12868 .21316 Metetra
1 .643 0 r
.12868 .21316 .1605 .22924 .1731 .22858 .14129 .21204 Metetra
1 .712 0 r
.14129 .21204 .1731 .22858 .18573 .22852 .15393 .2115 Metetra
1 .797 0 r
.15393 .2115 .18573 .22852 .19839 .2292 .1666 .21171 Metetra
1 .901 0 r
.1666 .21171 .19839 .2292 .21109 .23082 .1793 .21296 Metetra
.969 1 0 r
.1793 .21296 .21109 .23082 .22382 .23362 .19203 .21559 Metetra
.807 1 0 r
.19203 .21559 .22382 .23362 .23657 .23785 .20478 .22011 Metetra
.602 1 0 r
.20478 .22011 .23657 .23785 .24936 .24373 .21755 .2271 Metetra
.349 1 0 r
.21755 .2271 .24936 .24373 .26218 .25136 .23033 .23711 Metetra
.043 1 0 r
.23033 .23711 .26218 .25136 .27504 .26049 .24313 .25024 Metetra
0 1 .303 r
.24313 .25024 .27504 .26049 .28795 .27049 .25597 .26546 Metetra
0 1 .664 r
.25597 .26546 .28795 .27049 .30092 .28036 .26888 .28061 Metetra
0 .996 1 r
.26888 .28061 .30092 .28036 .31395 .2891 .28187 .2935 Metetra
0 .705 1 r
.28187 .2935 .31395 .2891 .32706 .29601 .29497 .30305 Metetra
0 .474 1 r
.29497 .30305 .32706 .29601 .34025 .3008 .30815 .30924 Metetra
0 .301 1 r
.30815 .30924 .34025 .3008 .3535 .30348 .32141 .31256 Metetra
0 .179 1 r
.32141 .31256 .3535 .30348 .36681 .30421 .33475 .31351 Metetra
0 .102 1 r
.33475 .31351 .36681 .30421 .38018 .30312 .34814 .31248 Metetra
0 .065 1 r
.34814 .31248 .38018 .30312 .39361 .30033 .3616 .30969 Metetra
0 .065 1 r
.3616 .30969 .39361 .30033 .40709 .29586 .37511 .30521 Metetra
0 .102 1 r
.37511 .30521 .40709 .29586 .42063 .28968 .38868 .29896 Metetra
0 .179 1 r
.38868 .29896 .42063 .28968 .4342 .28166 .40229 .29069 Metetra
0 .301 1 r
.40229 .29069 .4342 .28166 .44782 .27162 .41596 .28 Metetra
0 .474 1 r
.41596 .28 .44782 .27162 .46149 .25941 .42967 .26635 Metetra
0 .705 1 r
.42967 .26635 .46149 .25941 .47519 .245 .44342 .24923 Metetra
0 .996 1 r
.44342 .24923 .47519 .245 .48892 .22866 .45721 .22862 Metetra
0 1 .664 r
.45721 .22862 .48892 .22866 .50268 .21108 .47102 .20559 Metetra
0 1 .303 r
.47102 .20559 .50268 .21108 .51646 .1933 .48486 .18239 Metetra
.043 1 0 r
.48486 .18239 .51646 .1933 .53028 .17632 .49871 .16123 Metetra
.349 1 0 r
.49871 .16123 .53028 .17632 .54412 .16083 .51259 .14318 Metetra
.602 1 0 r
.51259 .14318 .54412 .16083 .558 .14707 .5265 .12818 Metetra
.807 1 0 r
.5265 .12818 .558 .14707 .57192 .13497 .54045 .11568 Metetra
.969 1 0 r
.54045 .11568 .57192 .13497 .58588 .12431 .55444 .1051 Metetra
1 .901 0 r
.55444 .1051 .58588 .12431 .59989 .11484 .56846 .09592 Metetra
1 .797 0 r
.56846 .09592 .59989 .11484 .61394 .10632 .58254 .08779 Metetra
1 .712 0 r
.58254 .08779 .61394 .10632 .62803 .09856 .59665 .08044 Metetra
1 .643 0 r
.59665 .08044 .62803 .09856 .64217 .09139 .61082 .07367 Metetra
1 .586 0 r
.61082 .07367 .64217 .09139 .65635 .08471 .62503 .06735 Metetra
1 .538 0 r
.62503 .06735 .65635 .08471 .67058 .0784 .63928 .06137 Metetra
1 .436 0 r
.07143 .20076 .10357 .21662 .11611 .21472 .08398 .19833 Metetra
1 .474 0 r
.08398 .19833 .11611 .21472 .12868 .21316 .09657 .19616 Metetra
1 .519 0 r
.09657 .19616 .12868 .21316 .14129 .21204 .1092 .19434 Metetra
1 .575 0 r
.1092 .19434 .14129 .21204 .15393 .2115 .12186 .19298 Metetra
1 .645 0 r
.12186 .19298 .15393 .2115 .1666 .21171 .13455 .19228 Metetra
1 .735 0 r
.13455 .19228 .1666 .21171 .1793 .21296 .14726 .19251 Metetra
1 .85 0 r
.14726 .19251 .1793 .21296 .19203 .21559 .16001 .19412 Metetra
.996 1 0 r
.16001 .19412 .19203 .21559 .20478 .22011 .17276 .19783 Metetra
.788 1 0 r
.17276 .19783 .20478 .22011 .21755 .2271 .18552 .2048 Metetra
.504 1 0 r
.18552 .2048 .21755 .2271 .23033 .23711 .19826 .21679 Metetra
.12 1 0 r
.19826 .21679 .23033 .23711 .24313 .25024 .21096 .23566 Metetra
0 1 .363 r
.21096 .23566 .24313 .25024 .25597 .26546 .22365 .26062 Metetra
0 1 .89 r
.22365 .26062 .25597 .26546 .26888 .28061 .23642 .28563 Metetra
0 .633 1 r
.23642 .28563 .26888 .28061 .28187 .2935 .24934 .30453 Metetra
0 .26 1 r
.24934 .30453 .28187 .2935 .29497 .30305 .26241 .3164 Metetra
.007 0 1 r
.26241 .3164 .29497 .30305 .30815 .30924 .27561 .32296 Metetra
.191 0 1 r
.27561 .32296 .30815 .30924 .32141 .31256 .28889 .32593 Metetra
.312 0 1 r
.28889 .32593 .32141 .31256 .33475 .31351 .30226 .32641 Metetra
.385 0 1 r
.30226 .32641 .33475 .31351 .34814 .31248 .31568 .32503 Metetra
.42 0 1 r
.31568 .32503 .34814 .31248 .3616 .30969 .32917 .32212 Metetra
.42 0 1 r
.32917 .32212 .3616 .30969 .37511 .30521 .34271 .31776 Metetra
.385 0 1 r
.34271 .31776 .37511 .30521 .38868 .29896 .35631 .31185 Metetra
.312 0 1 r
.35631 .31185 .38868 .29896 .40229 .29069 .36996 .30405 Metetra
.191 0 1 r
.36996 .30405 .40229 .29069 .41596 .28 .38367 .29371 Metetra
.007 0 1 r
.38367 .29371 .41596 .28 .42967 .26635 .39743 .27969 Metetra
0 .26 1 r
.39743 .27969 .42967 .26635 .44342 .24923 .41125 .2602 Metetra
0 .633 1 r
.41125 .2602 .44342 .24923 .45721 .22862 .42512 .23345 Metetra
0 1 .89 r
.42512 .23345 .45721 .22862 .47102 .20559 .43902 .2003 Metetra
0 1 .363 r
.43902 .2003 .47102 .20559 .48486 .18239 .45293 .16703 Metetra
.12 1 0 r
.45293 .16703 .48486 .18239 .49871 .16123 .46684 .13987 Metetra
.504 1 0 r
.46684 .13987 .49871 .16123 .51259 .14318 .48076 .11967 Metetra
.788 1 0 r
.48076 .11967 .51259 .14318 .5265 .12818 .4947 .10458 Metetra
.996 1 0 r
.4947 .10458 .5265 .12818 .54045 .11568 .50867 .09281 Metetra
1 .85 0 r
.50867 .09281 .54045 .11568 .55444 .1051 .52268 .08318 Metetra
1 .735 0 r
.52268 .08318 .55444 .1051 .56846 .09592 .53673 .07495 Metetra
1 .645 0 r
.53673 .07495 .56846 .09592 .58254 .08779 .55083 .06768 Metetra
1 .575 0 r
.55083 .06768 .58254 .08779 .59665 .08044 .56497 .06107 Metetra
1 .519 0 r
.56497 .06107 .59665 .08044 .61082 .07367 .57915 .05494 Metetra
1 .474 0 r
.57915 .05494 .61082 .07367 .62503 .06735 .59338 .04917 Metetra
1 .436 0 r
.59338 .04917 .62503 .06735 .63928 .06137 .60766 .04366 Metetra
1 .324 0 r
.039 .18438 .07143 .20076 .08398 .19833 .05157 .18131 Metetra
1 .348 0 r
.05157 .18131 .08398 .19833 .09657 .19616 .06418 .17838 Metetra
1 .377 0 r
.06418 .17838 .09657 .19616 .1092 .19434 .07682 .17564 Metetra
1 .414 0 r
.07682 .17564 .1092 .19434 .12186 .19298 .08951 .17316 Metetra
1 .461 0 r
.08951 .17316 .12186 .19298 .13455 .19228 .10223 .17106 Metetra
1 .522 0 r
.10223 .17106 .13455 .19228 .14726 .19251 .11498 .16954 Metetra
1 .605 0 r
.11498 .16954 .14726 .19251 .16001 .19412 .12775 .16892 Metetra
1 .721 0 r
.12775 .16892 .16001 .19412 .17276 .19783 .14055 .16984 Metetra
1 .891 0 r
.14055 .16984 .17276 .19783 .18552 .2048 .15334 .17362 Metetra
.843 1 0 r
.15334 .17362 .18552 .2048 .19826 .21679 .16609 .18337 Metetra
.402 1 0 r
.16609 .18337 .19826 .21679 .21096 .23566 .17868 .20704 Metetra
0 1 .325 r
.17868 .20704 .21096 .23566 .22365 .26062 .19098 .25591 Metetra
0 .777 1 r
.19098 .25591 .22365 .26062 .23642 .28563 .20337 .30514 Metetra
0 .054 1 r
.20337 .30514 .23642 .28563 .24934 .30453 .21622 .32927 Metetra
.38 0 1 r
.21622 .32927 .24934 .30453 .26241 .3164 .22933 .33926 Metetra
.635 0 1 r
.22933 .33926 .26241 .3164 .27561 .32296 .24258 .34305 Metetra
.789 0 1 r
.24258 .34305 .27561 .32296 .28889 .32593 .25592 .34374 Metetra
.884 0 1 r
.25592 .34374 .28889 .32593 .30226 .32641 .26932 .34266 Metetra
.94 0 1 r
.26932 .34266 .30226 .32641 .31568 .32503 .28279 .34039 Metetra
.965 0 1 r
.28279 .34039 .31568 .32503 .32917 .32212 .29631 .33718 Metetra
.965 0 1 r
.29631 .33718 .32917 .32212 .34271 .31776 .30988 .33312 Metetra
.94 0 1 r
.30988 .33312 .34271 .31776 .35631 .31185 .32351 .32811 Metetra
.884 0 1 r
.32351 .32811 .35631 .31185 .36996 .30405 .33719 .3219 Metetra
.789 0 1 r
.33719 .3219 .36996 .30405 .38367 .29371 .35093 .31387 Metetra
.635 0 1 r
.35093 .31387 .38367 .29371 .39743 .27969 .36472 .30268 Metetra
.38 0 1 r
.36472 .30268 .39743 .27969 .41125 .2602 .37859 .28513 Metetra
0 .054 1 r
.37859 .28513 .41125 .2602 .42512 .23345 .39257 .25306 Metetra
0 .777 1 r
.39257 .25306 .42512 .23345 .43902 .2003 .40667 .19513 Metetra
0 1 .325 r
.40667 .19513 .43902 .2003 .45293 .16703 .42074 .13726 Metetra
.402 1 0 r
.42074 .13726 .45293 .16703 .46684 .13987 .43471 .10502 Metetra
.843 1 0 r
.43471 .10502 .46684 .13987 .48076 .11967 .44865 .08698 Metetra
1 .891 0 r
.44865 .08698 .48076 .11967 .4947 .10458 .46261 .07506 Metetra
1 .721 0 r
.46261 .07506 .4947 .10458 .50867 .09281 .47659 .06605 Metetra
1 .605 0 r
.47659 .06605 .50867 .09281 .52268 .08318 .49062 .05862 Metetra
1 .522 0 r
.49062 .05862 .52268 .08318 .53673 .07495 .50469 .05211 Metetra
1 .461 0 r
.50469 .05211 .53673 .07495 .55083 .06768 .5188 .04619 Metetra
1 .414 0 r
.5188 .04619 .55083 .06768 .56497 .06107 .53296 .04065 Metetra
1 .377 0 r
.53296 .04065 .56497 .06107 .57915 .05494 .54717 .03539 Metetra
1 .348 0 r
.54717 .03539 .57915 .05494 .59338 .04917 .56142 .03032 Metetra
1 .324 0 r
.56142 .03032 .59338 .04917 .60766 .04366 .57573 .02538 Metetra
1 .204 0 r
.00626 .16765 .039 .18438 .05157 .18131 .01885 .16388 Metetra
1 .212 0 r
.01885 .16388 .05157 .18131 .06418 .17838 .03149 .1601 Metetra
1 .222 0 r
.03149 .1601 .06418 .17838 .07682 .17564 .04416 .1563 Metetra
1 .235 0 r
.04416 .1563 .07682 .17564 .08951 .17316 .05688 .15249 Metetra
1 .252 0 r
.05688 .15249 .08951 .17316 .10223 .17106 .06963 .14867 Metetra
1 .274 0 r
.06963 .14867 .10223 .17106 .11498 .16954 .08243 .14483 Metetra
1 .304 0 r
.08243 .14483 .11498 .16954 .12775 .16892 .09527 .14099 Metetra
1 .349 0 r
.09527 .14099 .12775 .16892 .14055 .16984 .10815 .13713 Metetra
1 .417 0 r
.10815 .13713 .14055 .16984 .15334 .17362 .12107 .13326 Metetra
1 .535 0 r
.12107 .13326 .15334 .17362 .16609 .18337 .13403 .12938 Metetra
1 .763 0 r
.13403 .12938 .16609 .18337 .17868 .20704 .14704 .12548 Metetra
.08 1 0 r
.14704 .12548 .17868 .20704 .19098 .25591 .15795 .25125 Metetra
0 .071 1 r
.15795 .25125 .19098 .25591 .20337 .30514 .16904 .379 Metetra
1 0 .915 r
.16904 .379 .20337 .30514 .21622 .32927 .18233 .37545 Metetra
1 0 .69 r
.18233 .37545 .21622 .32927 .22933 .33926 .19566 .37189 Metetra
1 0 .576 r
.19566 .37189 .22933 .33926 .24258 .34305 .20904 .36832 Metetra
1 0 .513 r
.20904 .36832 .24258 .34305 .25592 .34374 .22247 .36473 Metetra
1 0 .476 r
.22247 .36473 .25592 .34374 .26932 .34266 .23593 .36113 Metetra
1 0 .455 r
.23593 .36113 .26932 .34266 .28279 .34039 .24945 .35752 Metetra
1 0 .446 r
.24945 .35752 .28279 .34039 .29631 .33718 .26301 .35389 Metetra
1 0 .446 r
.26301 .35389 .29631 .33718 .30988 .33312 .27661 .35026 Metetra
1 0 .455 r
.27661 .35026 .30988 .33312 .32351 .32811 .29026 .34661 Metetra
1 0 .476 r
.29026 .34661 .32351 .32811 .33719 .3219 .30395 .34295 Metetra
1 0 .513 r
.30395 .34295 .33719 .3219 .35093 .31387 .3177 .33928 Metetra
1 0 .576 r
.3177 .33928 .35093 .31387 .36472 .30268 .33148 .33559 Metetra
1 0 .69 r
.33148 .33559 .36472 .30268 .37859 .28513 .34532 .33189 Metetra
1 0 .915 r
.34532 .33189 .37859 .28513 .39257 .25306 .3592 .32818 Metetra
0 .071 1 r
.3592 .32818 .39257 .25306 .40667 .19513 .37395 .19 Metetra
.08 1 0 r
.37395 .19 .40667 .19513 .42074 .13726 .38857 .05312 Metetra
1 .763 0 r
.38857 .05312 .42074 .13726 .43471 .10502 .40242 .04897 Metetra
1 .535 0 r
.40242 .04897 .43471 .10502 .44865 .08698 .41631 .04481 Metetra
1 .417 0 r
.41631 .04481 .44865 .08698 .46261 .07506 .43025 .04063 Metetra
1 .349 0 r
.43025 .04063 .46261 .07506 .47659 .06605 .44423 .03644 Metetra
1 .304 0 r
.44423 .03644 .47659 .06605 .49062 .05862 .45826 .03224 Metetra
1 .274 0 r
.45826 .03224 .49062 .05862 .50469 .05211 .47234 .02802 Metetra
1 .252 0 r
.47234 .02802 .50469 .05211 .5188 .04619 .48647 .02379 Metetra
1 .235 0 r
.48647 .02379 .5188 .04619 .53296 .04065 .50065 .01954 Metetra
1 .222 0 r
.50065 .01954 .53296 .04065 .54717 .03539 .51487 .01528 Metetra
1 .212 0 r
.51487 .01528 .54717 .03539 .56142 .03032 .52914 .011 Metetra
1 .204 0 r
.52914 .011 .56142 .03032 .57573 .02538 .54346 .00671 Metetra
0 g
.25 Mabswid
.00641 .16132 m
.54345 0 L
s
.05701 .14612 m
.05688 .1524 L
s
[(-2)] .05728 .13356 -0.02139 1 Mshowa
.16019 .11513 m
.16009 .12141 L
s
[(-1)] .1604 .10256 -0.01646 1 Mshowa
.26609 .08332 m
.26602 .0896 L
s
[(0)] .26623 .07075 -0.01139 1 Mshowa
.37481 .05066 m
.37477 .05694 L
s
[(1)] .37489 .03809 -0.00617 1 Mshowa
.48648 .01711 m
.48647 .0234 L
s
[(2)] .48649 .00455 -0.00078 1 Mshowa
gsave
.26695 .00792 -65.943 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{249.25, 144},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
  ImageRangeCache->{{{0, 248.25}, {143, 0}} -> {0, 0, 0, 0}}],
 StyleBox["\n\t\tFigure 3.A",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  The harmonic function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Phi]", 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], " ", "=", 
   RowBox[{
    FractionBox["1", "\[Pi]"], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"arctan", 
       FractionBox["y", 
        RowBox[{"x", "-", "1"}]]}], " ", "-", " ", 
      RowBox[{"arctan", 
       FractionBox["y", 
        RowBox[{"x", "+", "1"}]]}]}], ")"}]}]}]]],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"ExploreHarmonic", " ", ":=", " ", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         SubscriptBox["\[Phi]", "x"], " ", "=", " ", 
         RowBox[{"Together", "[", 
          RowBox[{
           SubscriptBox["\[PartialD]", "x"], " ", 
           RowBox[{"\[Phi]", "[", 
            RowBox[{"x", ",", "y"}], "]"}]}], "]"}]}], ";", " ", 
        "\[IndentingNewLine]", 
        RowBox[{
         SubscriptBox["\[Phi]", "xx"], " ", "=", " ", 
         RowBox[{"Together", "[", 
          RowBox[{
           SubscriptBox["\[PartialD]", 
            RowBox[{"x", ",", "x"}]], " ", 
           RowBox[{"\[Phi]", "[", 
            RowBox[{"x", ",", "y"}], "]"}]}], "]"}]}], ";", "  ", 
        "\[IndentingNewLine]", 
        RowBox[{
         SubscriptBox["\[Phi]", "y"], " ", "=", " ", 
         RowBox[{"Together", "[", 
          RowBox[{
           SubscriptBox["\[PartialD]", "y"], " ", 
           RowBox[{"\[Phi]", "[", 
            RowBox[{"x", ",", "y"}], "]"}]}], "]"}]}], ";", " ", 
        "\[IndentingNewLine]", 
        RowBox[{
         SubscriptBox["\[Phi]", "yy"], " ", "=", " ", 
         RowBox[{"Together", "[", 
          RowBox[{
           SubscriptBox["\[PartialD]", 
            RowBox[{"y", ",", "y"}]], " ", 
           RowBox[{"\[Phi]", "[", 
            RowBox[{"x", ",", "y"}], "]"}]}], "]"}]}], ";", " ", 
        "\[IndentingNewLine]", 
        RowBox[{"Print", "[", 
         RowBox[{"\"\<  \[Phi][x,y] = \>\"", " ", ",", 
          RowBox[{"\[Phi]", "[", 
           RowBox[{"x", ",", "y"}], "]"}]}], " ", "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"Print", "[", 
         RowBox[{
         "\"\< \!\(\*SubscriptBox[\(\[Phi]\), \(x\)]\)[x,y] = \>\"", " ", ",",
           
          SubscriptBox["\[Phi]", "x"]}], " ", "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"Print", "[", 
         RowBox[{
         "\"\<\!\(\*SubscriptBox[\(\[Phi]\), \(xx\)]\)[x,y] = \>\"", " ", ",",
           
          SubscriptBox["\[Phi]", "xx"]}], " ", "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"Print", "[", 
         RowBox[{
         "\"\< \!\(\*SubscriptBox[\(\[Phi]\), \(y\)]\)[x,y] = \>\"", " ", ",",
           
          SubscriptBox["\[Phi]", "y"]}], " ", "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"Print", "[", 
         RowBox[{
         "\"\<\!\(\*SubscriptBox[\(\[Phi]\), \(yy\)]\)[x,y] = \>\"", " ", ",",
           
          SubscriptBox["\[Phi]", "yy"]}], " ", "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"Print", "[", 
         RowBox[{
         "\"\<\!\(\*SubscriptBox[\(\[Phi]\), \(xx\)]\)[x,y] + \
\!\(\*SubscriptBox[\(\[Phi]\), \(yy\)]\)[x,y] = (\>\"", " ", ",", 
          SubscriptBox["\[Phi]", "xx"], ",", "\"\<) + (\>\"", ",", 
          SubscriptBox["\[Phi]", "yy"], " ", ",", "\"\<)\>\""}], "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"Print", "[", 
         RowBox[{
         "\"\<\!\(\*SubscriptBox[\(\[Phi]\), \(xx\)]\)[x,y] + \
\!\(\*SubscriptBox[\(\[Phi]\), \(yy\)]\)[x,y] = \>\"", " ", ",", 
          RowBox[{
           SubscriptBox["\[Phi]", "xx"], " ", "+", " ", 
           SubscriptBox["\[Phi]", "yy"]}]}], " ", "]"}], ";"}]}], " ", 
      "]"}]}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399020946609375*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[Phi]", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", " ", 
     RowBox[{
      SuperscriptBox["x", "3"], "-", 
      RowBox[{"3", " ", "x", " ", 
       SuperscriptBox["y", "2"]}]}]}], ";"}], "\[IndentingNewLine]", 
   "ExploreHarmonic", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39902095096875*^9, 3.3990209589375*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[Phi]", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", " ", 
     RowBox[{
      RowBox[{"3", " ", 
       SuperscriptBox["x", "2"], " ", "y"}], "-", 
      SuperscriptBox["y", "3"]}]}], ";"}], "\[IndentingNewLine]", 
   "ExploreHarmonic", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39902096021875*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[Phi]", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", " ", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", "x"], " ", 
      RowBox[{"Cos", "[", "y", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
   "ExploreHarmonic", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39902096415625*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[Phi]", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", " ", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", "x"], " ", 
      RowBox[{"Sin", "[", "y", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
   "ExploreHarmonic", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399020967359375*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[Phi]", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", 
     RowBox[{
      FractionBox["1", "\[Pi]"], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"ArcTan", "[", 
         FractionBox["y", 
          RowBox[{"x", "-", "1"}]], "]"}], "-", 
        RowBox[{"ArcTan", "[", 
         FractionBox["y", 
          RowBox[{"x", "+", "1"}]], "]"}]}], ")"}]}]}], ";"}], 
   "\[IndentingNewLine]", "ExploreHarmonic", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399020970671875*^9}]
}, Closed]],

Cell["\<\
These pairs of functions are not chosen at random, and there is an intimate \
relationship between them.  We begin with an important theorem relating \
analytic and harmonic functions.\
\>", "Text"],

Cell[TextData[{
 StyleBox["Theorem 3.8.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Let  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", 
      RowBox[{"x", "+", "iy"}], ")"}]}], "=", " ", 
    RowBox[{
     RowBox[{"u", 
      RowBox[{"(", 
       RowBox[{"x", 
        StyleBox[",",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], "y"}], ")"}]}], "+", 
     RowBox[{"\[ImaginaryI]", " ", "v", 
      RowBox[{"(", 
       RowBox[{"x", 
        StyleBox[",",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], "y"}], ")"}]}]}]}]}]]],
 "  be an analytic function on a domain ",
 StyleBox["D",
  FontFamily->"Courier New"],
 ".  Then both  ",
 Cell[BoxData[
  RowBox[{"u", 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{"v", 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 "  are harmonic functions on ",
 StyleBox["D",
  FontFamily->"Courier New"],
 ".  In other words, the real and imaginary parts of an analytic function are \
harmonic."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "Proof.  In Corollary 6.3 we will show that, if f(z) is analytic, then all \
partial derivatives of u and v are continuous.  Using that result here, we \
see that, as ",
 StyleBox["f",
  FontFamily->"Courier New"],
 " is analytic, ",
 StyleBox["u",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["v",
  FontFamily->"Courier New"],
 " satisfy the Cauchy-Riemann equations \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["u", "x"], 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], "=", 
   RowBox[{
    SubscriptBox["v", "y"], 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}]}]]],
 "   and   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["u", "y"], 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], "=", 
   RowBox[{
    RowBox[{"-", 
     SubscriptBox["v", "x"]}], 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}]}]]],
 ".  \n\nTaking the partial derivative with respect to ",
 StyleBox["x",
  FontFamily->"Courier New"],
 " of each side of these equations gives  \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["u", "xx"], 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], "=", 
   RowBox[{
    SubscriptBox["v", "yx"], 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}]}]]],
 "   and   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["u", "yx"], 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], "=", 
   RowBox[{
    RowBox[{"-", 
     SubscriptBox["v", "xx"]}], 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}]}]]],
 ".  \n\n\nSimilarly, taking the partial derivative of each side with respect \
to ",
 StyleBox["y",
  FontFamily->"Courier New"],
 " yields  \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["u", "xy"], 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], "=", 
   RowBox[{
    SubscriptBox["v", "yy"], 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}]}]]],
 "   and   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["u", "yy"], 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], "=", 
   RowBox[{
    RowBox[{"-", 
     SubscriptBox["v", "xy"]}], 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}]}]]],
 ".  \n\n\nThe partial derivatives ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["u", "xy"], ",", 
   SubscriptBox["u", "yx"], ",", 
   RowBox[{
    SubscriptBox["v", "xy"], " ", 
    StyleBox["and",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], " ", 
    SubscriptBox["v", "yx"]}]}]]],
 " are all continuous, so we use a theorem from the calculus of real \
functions that states that the mixed partial derivatives are equal; that is,  \
\n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["u", "xy"], 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], "=", 
   RowBox[{
    SubscriptBox["u", "yx"], 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}]}]]],
 "   and   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["v", "xy"], 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], "=", 
   RowBox[{
    SubscriptBox["v", "yx"], 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}]}]]],
 ".  \n\n\nCombining all these results finally gives \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["u", "xx"], 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}], "+", 
    RowBox[{
     SubscriptBox["u", "yy"], 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["v", "yx"], 
      RowBox[{"(", 
       RowBox[{"x", 
        StyleBox[",",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], "y"}], ")"}]}], "-", 
     RowBox[{
      SubscriptBox["v", "xy"], 
      RowBox[{"(", 
       RowBox[{"x", 
        StyleBox[",",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], "y"}], ")"}]}]}], " ", "=", " ", 
    "0"}]}]]],
 ",  and  \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["v", "xx"], 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}], "+", 
    RowBox[{
     SubscriptBox["v", "yy"], 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", " ", 
       SubscriptBox["u", "yx"]}], 
      RowBox[{"(", 
       RowBox[{"x", 
        StyleBox[",",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], "y"}], ")"}]}], "+", " ", 
     RowBox[{
      SubscriptBox["u", "xy"], 
      RowBox[{"(", 
       RowBox[{"x", 
        StyleBox[",",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], "y"}], ")"}]}]}], " ", "=", " ", 
    "0"}]}]]],
 ".  \n\nTherefore both ",
 StyleBox["u",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["v",
  FontFamily->"Courier New"],
 " are harmonic functions on ",
 StyleBox["D",
  FontFamily->"Courier New"],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 3.8 is also in the book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
 "\tIf we have a function ",
 Cell[BoxData[
  RowBox[{"u", 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 " that is harmonic on the domain ",
 StyleBox["D",
  FontFamily->"Courier New"],
 " and if we can find another harmonic function ",
 Cell[BoxData[
  RowBox[{"v", 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 " such that the partial derivatives for ",
 StyleBox["u",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["v",
  FontFamily->"Courier New"],
 " satisfy the Cauchy-Riemann equations throughout ",
 StyleBox["D",
  FontFamily->"Courier New"],
 ", then we say that ",
 Cell[BoxData[
  RowBox[{"v", 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 "is a harmonic conjugate of ",
 Cell[BoxData[
  RowBox[{"u", 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 ".  It then follows that the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", " ", 
   RowBox[{
    RowBox[{"u", 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", "v", 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}]}]}]]],
 "  is analytic on ",
 StyleBox["D",
  FontFamily->"Courier New"],
 "."
}], "Text"],

Cell[TextData[{
 StyleBox["Example 3.11.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  If  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"u", 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], "=", 
   RowBox[{
    SuperscriptBox["x", "2"], "-", 
    SuperscriptBox["y", "2"]}]}]]],
 ",  then  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["u", "xx"], 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}], "+", 
    RowBox[{
     SubscriptBox["u", "yy"], 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}]}], "=", 
   RowBox[{
    RowBox[{"2", "-", "2"}], "=", "0"}]}]]],
 ";   hence u is a harmonic function for all ",
 StyleBox["z",
  FontFamily->"Courier New"],
 ".  We find that ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"v", 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], "=", 
   RowBox[{"2", " ", "x", " ", "y"}]}]]],
 " is also a harmonic function and that \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["u", "x"], 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["v", "y"], 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}], " ", "=", " ", 
    RowBox[{"2", "x"}]}]}]]],
 ",   and   \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["u", "y"], 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"-", " ", 
      SubscriptBox["v", "x"]}], 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{"-", " ", "2"}], "y"}]}]}]]],
 ".\n\nTherefore ",
 StyleBox["v",
  FontFamily->"Courier New"],
 " is a harmonic conjugate of ",
 StyleBox["u",
  FontFamily->"Courier New"],
 ", and the function ",
 StyleBox["f",
  FontFamily->"Courier New"],
 " given by  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
    RowBox[{
     SuperscriptBox["x", "2"], "-", 
     SuperscriptBox["y", "2"], " ", "+", " ", 
     RowBox[{"\[ImaginaryI]", " ", "2", " ", "x", " ", "y"}]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"            ", 
   RowBox[{"=", " ", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"x", "+", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"], "  ", "=", "  ", 
     SuperscriptBox["z", "2"]}]}]}]}]],
 "  \n\nis an analytic function."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Explore ",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 StyleBox["Solution 3.11.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell["\<\
Enter the functions u[x,y] and v[x,y] and show that the Cauchy-Riemann \
equations hold.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "u", ",", "Ux", ",", "Uy", ",", "v", ",", "Vx", ",", "Vy", ",", "w", ",",
       "x", ",", "y", ",", "z", ",", "Z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"TagSet", "[", 
     RowBox[{"x", ",", 
      RowBox[{"Im", "[", "x", "]"}], ",", "0"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"TagSet", "[", 
     RowBox[{"y", ",", 
      RowBox[{"Im", "[", "y", "]"}], ",", "0"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"TagSet", "[", 
     RowBox[{"x", ",", 
      RowBox[{"Re", "[", "x", "]"}], ",", "x"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"TagSet", "[", 
     RowBox[{"y", ",", 
      RowBox[{"Re", "[", "y", "]"}], ",", "y"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"u", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", " ", 
     RowBox[{
      SuperscriptBox["x", "2"], "-", 
      SuperscriptBox["y", "2"]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"v", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", " ", 
     RowBox[{"2", " ", "x", " ", "y"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Ux", " ", "=", " ", 
     RowBox[{
      SubscriptBox["\[PartialD]", "x"], " ", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Uy", " ", "=", " ", 
     RowBox[{
      SubscriptBox["\[PartialD]", "y"], " ", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Vx", " ", "=", " ", 
     RowBox[{
      SubscriptBox["\[PartialD]", "x"], " ", 
      RowBox[{"v", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Vy", " ", "=", " ", 
     RowBox[{
      SubscriptBox["\[PartialD]", "y"], " ", 
      RowBox[{"v", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< u[x,y] = \>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< v[x,y] = \>\"", ",", 
      RowBox[{"v", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(u\), \(x\)]\)[x,y] = \>\"", ",", "Ux"}], "]"}],
     ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(u\), \(y\)]\)[x,y] = \>\"", ",", "Uy"}], "]"}],
     ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(v\), \(x\)]\)[x,y] = \>\"", ",", "Vx"}], "]"}],
     ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(v\), \(y\)]\)[x,y] = \>\"", ",", "Vy"}], "]"}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Is \!\(\*SubscriptBox[\(u\), \(x\)]\)[x,y] =  \
\!\(\*SubscriptBox[\(v\), \(y\)]\)[x,y] ?      \>\"", ",", 
      RowBox[{"Ux", "\[Equal]", "Vy"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Is \!\(\*SubscriptBox[\(u\), \(y\)]\)[x,y] = \
-\!\(\*SubscriptBox[\(v\), \(x\)]\)[x,y] ?      \>\"", ",", 
      RowBox[{"Uy", "\[Equal]", 
       RowBox[{"-", "Vx"}]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39902092634375*^9}],

Cell[TextData[{
 "The Cauchy-Riemann equations hold, therefore  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", 
     RowBox[{"x", "+", 
      RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "=", 
   RowBox[{
    RowBox[{"u", 
     RowBox[{"(", 
      RowBox[{"x", ",", "y"}], ")"}]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", "v", 
     RowBox[{"(", 
      RowBox[{"x", ",", "y"}], ")"}]}]}]}]]],
 "  is analytic.  It follows that both  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"u", 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], "=", 
   RowBox[{
    RowBox[{"Re", "[", 
     RowBox[{"f", 
      RowBox[{"(", 
       RowBox[{"x", "+", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "]"}], "=", " ", 
    RowBox[{
     SuperscriptBox["x", "2"], "-", 
     SuperscriptBox["y", "2"]}]}]}]]],
 "  and   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"v", 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], "=", 
   RowBox[{
    RowBox[{"Im", "[", 
     RowBox[{"f", 
      RowBox[{"(", 
       RowBox[{"x", "+", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "]"}], "=", " ", 
    RowBox[{"2", " ", "x", " ", "y"}]}]}]]],
 " are harmonic functions.\n\n",
 StyleBox["Aside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  The underlying complex function is  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], "=", 
   SuperscriptBox["z", "2"]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", 
     SuperscriptBox["z", "2"]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Z", " ", "=", " ", 
     RowBox[{"x", " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", "y"}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  w = f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  w = f[z] = \>\"", ",", 
      RowBox[{"f", "[", "Z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  w = f[z] = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"f", "[", "Z", "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<  f[\>\"", ",", "Z", ",", 
      "\"\<] = u[x,y] + \[ImaginaryI] v[x,y]\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  f[\>\"", ",", "Z", ",", "\"\<] = (\>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}], ",", "\"\<) + \[ImaginaryI](\>\"", ",",
       " ", 
      RowBox[{"v", "[", 
       RowBox[{"x", ",", "y"}], "]"}], ",", "\"\<)\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  f[\>\"", ",", "Z", ",", "\"\<] = \>\"", ",", 
      RowBox[{
       RowBox[{"u", "[", 
        RowBox[{"x", ",", "y"}], "]"}], "+", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"v", "[", 
         RowBox[{"x", ",", "y"}], "]"}]}]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.3990209308125*^9}]
}, Closed]],

Cell["\<\
\tTheorem 3.8 makes the construction of harmonic functions from known \
analytic functions an easy task.\
\>", "Text"],

Cell[TextData[{
 StyleBox["Example 3.12.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 " The function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    SuperscriptBox["z", "3"], " ", "=", " ", 
    RowBox[{
     SuperscriptBox["x", "3"], "-", 
     RowBox[{"3", " ", "x", " ", 
      SuperscriptBox["y", "2"]}], "+", 
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", 
         SuperscriptBox["x", "2"], " ", "y"}], "-", 
        SuperscriptBox["y", "3"]}], ")"}]}]}]}]}]]],
 "  is analytic for all values of z, hence it follows that  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"u", 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"Re", "[", 
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], "]"}], " ", "=", " ", 
    RowBox[{
     SuperscriptBox["x", "3"], "-", 
     RowBox[{"3", " ", "x", " ", 
      SuperscriptBox["y", "2"]}]}]}]}]]],
 "  \nis harmonic, and\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"v", 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"Im", "[", 
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], "]"}], " ", "=", " ", 
    RowBox[{
     RowBox[{"3", " ", 
      SuperscriptBox["x", "2"], " ", "y"}], "-", 
     SuperscriptBox["y", "3"]}]}]}]]],
 "  \n\t\t\nis a harmonic conjugate of u(x,y)."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Explore ",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 StyleBox["Solution 3.12.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell["\<\
Enter the functions u[x,y] and v[x,y] and show that the Cauchy-Riemann \
equations hold.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "u", ",", "Ux", ",", "Uy", ",", "v", ",", "Vx", ",", "Vy", ",", "w", ",",
       "x", ",", "y", ",", "z", ",", "Z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"TagSet", "[", 
     RowBox[{"x", ",", 
      RowBox[{"Im", "[", "x", "]"}], ",", "0"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"TagSet", "[", 
     RowBox[{"y", ",", 
      RowBox[{"Im", "[", "y", "]"}], ",", "0"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"TagSet", "[", 
     RowBox[{"x", ",", 
      RowBox[{"Re", "[", "x", "]"}], ",", "x"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"TagSet", "[", 
     RowBox[{"y", ",", 
      RowBox[{"Re", "[", "y", "]"}], ",", "y"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"u", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", " ", 
     RowBox[{
      SuperscriptBox["x", "3"], "-", 
      RowBox[{"3", " ", "x", " ", 
       SuperscriptBox["y", "2"]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"v", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", " ", 
     RowBox[{
      RowBox[{"3", " ", 
       SuperscriptBox["x", "2"], " ", "y"}], "-", 
      SuperscriptBox["y", "3"]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Ux", " ", "=", " ", 
     RowBox[{
      SubscriptBox["\[PartialD]", "x"], " ", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Uy", " ", "=", " ", 
     RowBox[{
      SubscriptBox["\[PartialD]", "y"], " ", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Vx", " ", "=", " ", 
     RowBox[{
      SubscriptBox["\[PartialD]", "x"], " ", 
      RowBox[{"v", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Vy", " ", "=", " ", 
     RowBox[{
      SubscriptBox["\[PartialD]", "y"], " ", 
      RowBox[{"v", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< u[x,y] = \>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< v[x,y] = \>\"", ",", 
      RowBox[{"v", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(u\), \(x\)]\)[x,y] = \>\"", ",", "Ux"}], "]"}],
     ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(u\), \(y\)]\)[x,y] = \>\"", ",", "Uy"}], "]"}],
     ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(v\), \(x\)]\)[x,y] = \>\"", ",", "Vx"}], "]"}],
     ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(v\), \(y\)]\)[x,y] = \>\"", ",", "Vy"}], "]"}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Is \!\(\*SubscriptBox[\(u\), \(x\)]\)[x,y] =  \
\!\(\*SubscriptBox[\(v\), \(y\)]\)[x,y] ?      \>\"", ",", 
      RowBox[{"Ux", "\[Equal]", "Vy"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Is \!\(\*SubscriptBox[\(u\), \(y\)]\)[x,y] = \
-\!\(\*SubscriptBox[\(v\), \(x\)]\)[x,y] ?      \>\"", ",", 
      RowBox[{"Uy", "\[Equal]", 
       RowBox[{"-", "Vx"}]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399020911421875*^9}],

Cell[TextData[{
 "The Cauchy-Riemann equations hold, therefore  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", 
     RowBox[{"x", "+", 
      RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"u", 
      RowBox[{"(", 
       RowBox[{"x", ",", "y"}], ")"}]}], "+", 
     RowBox[{"\[ImaginaryI]", " ", "v", 
      RowBox[{"(", 
       RowBox[{"x", ",", "y"}], ")"}]}]}], "=", " ", 
    RowBox[{
     SuperscriptBox["x", "3"], "-", 
     RowBox[{"3", " ", "x", " ", 
      SuperscriptBox["y", "2"]}], "+", 
     RowBox[{"\[ImaginaryI]", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", 
         SuperscriptBox["x", "2"], " ", "y"}], "-", 
        SuperscriptBox["y", "3"]}], ")"}]}]}]}]}]]],
 "  is analytic.  It follows that both  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"u", 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], "=", 
   RowBox[{
    RowBox[{"Re", "[", 
     RowBox[{"f", 
      RowBox[{"(", 
       RowBox[{"x", "+", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "]"}], "=", " ", 
    RowBox[{
     SuperscriptBox["x", "3"], "-", 
     RowBox[{"3", " ", "x", " ", 
      SuperscriptBox["y", "2"]}]}]}]}]]],
 "  and   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"v", 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], "=", 
   RowBox[{
    RowBox[{"Im", "[", 
     RowBox[{"f", 
      RowBox[{"(", 
       RowBox[{"x", "+", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "]"}], "=", " ", 
    RowBox[{
     RowBox[{"3", " ", 
      SuperscriptBox["x", "2"], " ", "y"}], "-", 
     SuperscriptBox["y", "3"]}]}]}]]],
 " are harmonic functions.\n\n",
 StyleBox["Aside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  The underlying complex function is  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], "=", 
   SuperscriptBox["z", "3"]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", 
     SuperscriptBox["z", "3"]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Z", " ", "=", " ", 
     RowBox[{"x", " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", "y"}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  w = f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  w = f[z] = \>\"", ",", 
      RowBox[{"f", "[", "Z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  w = f[z] = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"f", "[", "Z", "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<f[\>\"", ",", "Z", ",", 
      "\"\<] = u[x,y] + \[ImaginaryI] v[x,y]\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[\>\"", ",", "Z", ",", "\"\<] = (\>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}], ",", "\"\<) + \[ImaginaryI](\>\"", ",",
       " ", 
      RowBox[{"v", "[", 
       RowBox[{"x", ",", "y"}], "]"}], ",", "\"\<)\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[\>\"", ",", "Z", ",", "\"\<] = \>\"", ",", 
      RowBox[{
       RowBox[{"u", "[", 
        RowBox[{"x", ",", "y"}], "]"}], "+", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"v", "[", 
         RowBox[{"x", ",", "y"}], "]"}]}]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399020916265625*^9}]
}, Closed]],

Cell[TextData[{
 "\tFigures 3.2 and 3.3 show the graphs of these two functions.  The partial \
derivatives are  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["u", "x"], 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], "=", 
   RowBox[{
    RowBox[{"3", " ", 
     SuperscriptBox["x", "2"]}], "-", 
    RowBox[{"3", " ", 
     SuperscriptBox["y", "2"]}]}]}]]],
 ",   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["u", "y"], 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], "=", 
   RowBox[{
    RowBox[{"-", "6"}], " ", "x", " ", "y"}]}]]],
 ",   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["v", "x"], 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], "=", 
   RowBox[{"6", " ", "x", " ", "y"}]}]]],
 ",  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["v", "y"], 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], "=", 
   RowBox[{
    RowBox[{"3", " ", 
     SuperscriptBox["x", "2"]}], "-", 
    RowBox[{"3", " ", 
     SuperscriptBox["y", "2"]}]}]}]]],
 ".  They satisfy the Cauchy-Riemann equations because they are the real and \
imaginary parts of an analytic function.  At the point ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}], "=", 
   RowBox[{"(", 
    RowBox[{"2", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], 
     RowBox[{"-", "1"}]}], ")"}]}]]],
 ",  we have  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["u", "x"], 
    RowBox[{"(", 
     RowBox[{"2", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      RowBox[{"-", "1"}]}], ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["v", "y"], 
     RowBox[{"(", 
      RowBox[{"2", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], 
       RowBox[{"-", "1"}]}], ")"}]}], "=", "9"}]}]]],
 ",  and these partial derivatives appear along the edges of the surfaces for \
u and v where ",
 Cell[BoxData[
  RowBox[{"x", "=", 
   RowBox[{
    RowBox[{"2", " ", 
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], " ", "y"}], "=", 
    RowBox[{"-", "1"}]}]}]]],
 ".  Similarly,  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["u", "y"], 
    RowBox[{"(", 
     RowBox[{"2", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      RowBox[{"-", "1"}]}], ")"}]}], " ", "=", "12"}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["v", "x"], 
    RowBox[{"(", 
     RowBox[{"2", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      RowBox[{"-", "1"}]}], ")"}]}], "=", 
   RowBox[{"-", "12"}]}]]],
 "  also appear along the edges of the surfaces for ",
 StyleBox["u",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["v",
  FontFamily->"Courier New"],
 " where ",
 Cell[BoxData[
  RowBox[{"x", "=", 
   RowBox[{
    RowBox[{"2", " ", 
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], " ", "y"}], "=", 
    RowBox[{"-", "1"}]}]}]]],
 "."
}], "Text"],

Cell[TextData[{
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .83604 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
3.29597e-017 1.0317 -0.068013 1.0317 [
[.17348 .16592 -11.0614 -9 ]
[.17348 .16592 .9386 0 ]
[.33816 .10893 -5.35223 -9 ]
[.33816 .10893 .64777 0 ]
[.50828 .05007 -5.17376 -9 ]
[.50828 .05007 .82624 0 ]
[.29838 .05818 -8.92039 -12.5625 ]
[.29838 .05818 1.07961 0 ]
[.70343 -0.00421 0 -6.05261 ]
[.70343 -0.00421 12 2.94739 ]
[.85696 .22678 0 -5.93481 ]
[.85696 .22678 6 3.06519 ]
[.9924 .43055 0 -5.83362 ]
[.9924 .43055 6 3.16638 ]
[.9184 .20719 0 -8.284 ]
[.9184 .20719 16 4.2785 ]
[.00631 .27685 -12 -2.96564 ]
[.00631 .27685 0 6.03436 ]
[-0.00068 .34832 -6 -2.99676 ]
[-0.00068 .34832 0 6.00324 ]
[-0.00786 .42182 -6 -3.02881 ]
[-0.00786 .42182 0 5.97119 ]
[-0.06184 .36875 -10 -4.18298 ]
[-0.06184 .36875 0 8.37952 ]
[ 0 0 0 0 ]
[ 1 .83604 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.0226 .2307 m
.69124 0 L
s
.18179 .17577 m
.18595 .1807 L
s
[(-1)] .17348 .16592 .84357 1 Mshowa
.34612 .11908 m
.3501 .12415 L
s
[(0)] .33816 .10893 .78408 1 Mshowa
.51585 .06052 m
.51963 .06574 L
s
[(1)] .50828 .05007 .72459 1 Mshowa
gsave
.29838 .05818 -69.9204 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.69124 0 m
.98003 .43421 L
s
.69124 0 m
.68515 .0021 L
s
[(-1)] .70343 -0.00421 -1 .34502 Mshowa
.84468 .2307 m
.83853 .23266 L
s
[(0)] .85696 .22678 -1 .31885 Mshowa
.98003 .43421 m
.97385 .43604 L
s
[(1)] .9924 .43055 -1 .29636 Mshowa
gsave
.9184 .20719 -61 -12.284 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.0226 .2307 m
0 .46297 L
s
.01852 .27268 m
.02462 .2706 L
s
[(-5)] .00631 .27685 1 -0.34097 Mshowa
.01155 .34423 m
.01767 .34219 L
s
[(0)] -0.00068 .34832 1 -0.33405 Mshowa
.00439 .41781 m
.01052 .41581 L
s
[(5)] -0.00786 .42182 1 -0.32693 Mshowa
gsave
-0.06184 .36875 -71 -8.18298 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(u) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.0226 .2307 m
0 .46297 L
s
0 .46297 m
.36381 .83604 L
s
.36381 .83604 m
.36973 .61508 L
s
.36973 .61508 m
.0226 .2307 L
s
.69124 0 m
.98003 .43421 L
s
.98003 .43421 m
1 .66097 L
s
1 .66097 m
.69984 .23724 L
s
.69984 .23724 m
.69124 0 L
s
.0226 .2307 m
0 .46297 L
s
0 .46297 m
.69984 .23724 L
s
.69984 .23724 m
.69124 0 L
s
.69124 0 m
.0226 .2307 L
s
.36973 .61508 m
.98003 .43421 L
s
.98003 .43421 m
1 .66097 L
s
1 .66097 m
.36381 .83604 L
s
.36381 .83604 m
.36973 .61508 L
s
0 0 m
1 0 L
1 .83604 L
0 .83604 L
closepath
clip
newpath
.5 Mabswid
.835 .888 .835 r
.34567 .64984 .36756 .6959 .40894 .71277 .38695 .66948 Metetra
.866 .921 .866 r
.38695 .66948 .40894 .71277 .45124 .71822 .42924 .67781 Metetra
.886 .941 .886 r
.42924 .67781 .45124 .71822 .49419 .71392 .47228 .67645 Metetra
.898 .954 .898 r
.47228 .67645 .49419 .71392 .53759 .7017 .51585 .66719 Metetra
.907 .964 .907 r
.51585 .66719 .53759 .7017 .58129 .68348 .55979 .65194 Metetra
.913 .971 .913 r
.55979 .65194 .58129 .68348 .62518 .66122 .60399 .63263 Metetra
.919 .976 .919 r
.60399 .63263 .62518 .66122 .66922 .63689 .64842 .61124 Metetra
.922 .98 .922 r
.64842 .61124 .66922 .63689 .71345 .61246 .69308 .58974 Metetra
.925 .982 .925 r
.69308 .58974 .71345 .61246 .75794 .58988 .73805 .57009 Metetra
.923 .98 .923 r
.73805 .57009 .75794 .58988 .80285 .57109 .78349 .55424 Metetra
.909 .965 .909 r
.78349 .55424 .80285 .57109 .84841 .55802 .82963 .54417 Metetra
.855 .908 .855 r
.82963 .54417 .84841 .55802 .89491 .55268 .87674 .5419 Metetra
.66 .701 .66 r
.87674 .5419 .89491 .55268 .94272 .55715 .92521 .54959 Metetra
.168 .178 .168 r
.92521 .54959 .94272 .55715 .99232 .57369 .97553 .56954 Metetra
.82 .871 .82 r
.32349 .60671 .34567 .64984 .38695 .66948 .36467 .62867 Metetra
.86 .913 .86 r
.36467 .62867 .38695 .66948 .42924 .67781 .40695 .63939 Metetra
.883 .938 .883 r
.40695 .63939 .42924 .67781 .47228 .67645 .45007 .64048 Metetra
.897 .953 .897 r
.45007 .64048 .47228 .67645 .51585 .66719 .49381 .6337 Metetra
.906 .963 .906 r
.49381 .6337 .51585 .66719 .55979 .65194 .53798 .62092 Metetra
.913 .97 .913 r
.53798 .62092 .55979 .65194 .60399 .63263 .58248 .60409 Metetra
.917 .975 .917 r
.58248 .60409 .60399 .63263 .64842 .61124 .62726 .58516 Metetra
.92 .978 .92 r
.62726 .58516 .64842 .61124 .69308 .58974 .67232 .56612 Metetra
.921 .979 .921 r
.67232 .56612 .69308 .58974 .73805 .57009 .71774 .54893 Metetra
.918 .975 .918 r
.71774 .54893 .73805 .57009 .78349 .55424 .76367 .53556 Metetra
.903 .959 .903 r
.76367 .53556 .78349 .55424 .82963 .54417 .81032 .52802 Metetra
.852 .906 .852 r
.81032 .52802 .82963 .54417 .87674 .5419 .85799 .52837 Metetra
.69 .733 .69 r
.85799 .52837 .87674 .5419 .92521 .54959 .90706 .5388 Metetra
.281 .299 .281 r
.90706 .5388 .92521 .54959 .97553 .56954 .95801 .5617 Metetra
.799 .849 .799 r
.30096 .56649 .32349 .60671 .36467 .62867 .34205 .59031 Metetra
.851 .904 .851 r
.34205 .59031 .36467 .62867 .40695 .63939 .38435 .60296 Metetra
.879 .934 .879 r
.38435 .60296 .40695 .63939 .45007 .64048 .42755 .60601 Metetra
.895 .951 .895 r
.42755 .60601 .45007 .64048 .49381 .6337 .47145 .60121 Metetra
.905 .962 .905 r
.47145 .60121 .49381 .6337 .53798 .62092 .51585 .59043 Metetra
.912 .969 .912 r
.51585 .59043 .53798 .62092 .58248 .60409 .56063 .57558 Metetra
.916 .973 .916 r
.56063 .57558 .58248 .60409 .62726 .58516 .60574 .55864 Metetra
.918 .976 .918 r
.60574 .55864 .62726 .58516 .67232 .56612 .65117 .54157 Metetra
.918 .976 .918 r
.65117 .54157 .67232 .56612 .71774 .54893 .697 .52636 Metetra
.914 .971 .914 r
.697 .52636 .71774 .54893 .76367 .53556 .74337 .515 Metetra
.898 .954 .898 r
.74337 .515 .76367 .53556 .81032 .52802 .79049 .50952 Metetra
.851 .905 .851 r
.79049 .50952 .81032 .52802 .85799 .52837 .83866 .51201 Metetra
.717 .762 .717 r
.83866 .51201 .85799 .52837 .90706 .5388 .88825 .5247 Metetra
.388 .413 .388 r
.88825 .5247 .90706 .5388 .95801 .5617 .93977 .55003 Metetra
.77 .818 .77 r
.27803 .52914 .30096 .56649 .34205 .59031 .31907 .55438 Metetra
.84 .893 .84 r
.31907 .55438 .34205 .59031 .38435 .60296 .36138 .56849 Metetra
.875 .929 .875 r
.36138 .56849 .38435 .60296 .42755 .60601 .40469 .57303 Metetra
.894 .949 .894 r
.40469 .57303 .42755 .60601 .47145 .60121 .44874 .56974 Metetra
.904 .961 .904 r
.44874 .56974 .47145 .60121 .51585 .59043 .49337 .56045 Metetra
.911 .968 .911 r
.49337 .56045 .51585 .59043 .56063 .57558 .53843 .5471 Metetra
.915 .972 .915 r
.53843 .5471 .56063 .57558 .60574 .55864 .58385 .53165 Metetra
.917 .974 .917 r
.58385 .53165 .60574 .55864 .65117 .54157 .62963 .51608 Metetra
.916 .973 .916 r
.62963 .51608 .65117 .54157 .697 .52636 .67584 .50237 Metetra
.91 .967 .91 r
.67584 .50237 .697 .52636 .74337 .515 .72261 .49254 Metetra
.894 .95 .894 r
.72261 .49254 .74337 .515 .79049 .50952 .77015 .48863 Metetra
.852 .905 .852 r
.77015 .48863 .79049 .50952 .83866 .51201 .81876 .49276 Metetra
.742 .789 .742 r
.81876 .49276 .83866 .51201 .88825 .5247 .86881 .5072 Metetra
.483 .513 .483 r
.86881 .5072 .88825 .5247 .93977 .55003 .9208 .53442 Metetra
.731 .777 .731 r
.25466 .49465 .27803 .52914 .31907 .55438 .29567 .52087 Metetra
.826 .878 .826 r
.29567 .52087 .31907 .55438 .36138 .56849 .33802 .53598 Metetra
.87 .924 .87 r
.33802 .53598 .36138 .56849 .40469 .57303 .38144 .54154 Metetra
.892 .948 .892 r
.38144 .54154 .40469 .57303 .44874 .56974 .42567 .53926 Metetra
.904 .96 .904 r
.42567 .53926 .44874 .56974 .49337 .56045 .47052 .53099 Metetra
.91 .967 .91 r
.47052 .53099 .49337 .56045 .53843 .5471 .51585 .51865 Metetra
.914 .971 .914 r
.51585 .51865 .53843 .5471 .58385 .53165 .56158 .5042 Metetra
.915 .972 .915 r
.56158 .5042 .58385 .53165 .62963 .51608 .60769 .48963 Metetra
.914 .971 .914 r
.60769 .48963 .62963 .51608 .67584 .50237 .65426 .47693 Metetra
.907 .964 .907 r
.65426 .47693 .67584 .50237 .72261 .49254 .70139 .46813 Metetra
.892 .947 .892 r
.70139 .46813 .72261 .49254 .77015 .48863 .74931 .46529 Metetra
.854 .908 .854 r
.74931 .46529 .77015 .48863 .81876 .49276 .7983 .47055 Metetra
.765 .812 .765 r
.7983 .47055 .81876 .49276 .86881 .5072 .84874 .4862 Metetra
.563 .598 .563 r
.84874 .4862 .86881 .5072 .9208 .53442 .90113 .51477 Metetra
.678 .72 .678 r
.2308 .463 .25466 .49465 .29567 .52087 .2718 .48977 Metetra
.809 .86 .809 r
.2718 .48977 .29567 .52087 .33802 .53598 .31422 .50544 Metetra
.865 .919 .865 r
.31422 .50544 .33802 .53598 .38144 .54154 .35777 .51154 Metetra
.891 .946 .891 r
.35777 .51154 .38144 .54154 .42567 .53926 .4022 .50979 Metetra
.904 .96 .904 r
.4022 .50979 .42567 .53926 .47052 .53099 .44728 .50204 Metetra
.91 .967 .91 r
.44728 .50204 .47052 .53099 .51585 .51865 .49288 .49021 Metetra
.914 .971 .914 r
.49288 .49021 .51585 .51865 .56158 .5042 .53891 .47627 Metetra
.914 .971 .914 r
.53891 .47627 .56158 .5042 .60769 .48963 .58535 .4622 Metetra
.912 .969 .912 r
.58535 .4622 .60769 .48963 .65426 .47693 .63224 .45001 Metetra
.906 .962 .906 r
.63224 .45001 .65426 .47693 .70139 .46813 .67972 .44174 Metetra
.891 .946 .891 r
.67972 .44174 .70139 .46813 .74931 .46529 .72797 .43945 Metetra
.858 .911 .858 r
.72797 .43945 .74931 .46529 .7983 .47055 .77729 .44532 Metetra
.784 .833 .784 r
.77729 .44532 .7983 .47055 .84874 .4862 .82806 .46164 Metetra
.629 .668 .629 r
.82806 .46164 .84874 .4862 .90113 .51477 .88077 .49098 Metetra
.608 .646 .608 r
.20639 .43421 .2308 .463 .2718 .48977 .24742 .4611 Metetra
.788 .837 .788 r
.24742 .4611 .2718 .48977 .31422 .50544 .28994 .47686 Metetra
.86 .913 .86 r
.28994 .47686 .31422 .50544 .35777 .51154 .33366 .48303 Metetra
.89 .946 .89 r
.33366 .48303 .35777 .51154 .4022 .50979 .37829 .48133 Metetra
.904 .961 .904 r
.37829 .48133 .4022 .50979 .44728 .50204 .42363 .4736 Metetra
.911 .968 .911 r
.42363 .4736 .44728 .50204 .49288 .49021 .46952 .46178 Metetra
.914 .971 .914 r
.46952 .46178 .49288 .49021 .53891 .47627 .51585 .44783 Metetra
.914 .971 .914 r
.51585 .44783 .53891 .47627 .58535 .4622 .5626 .43376 Metetra
.911 .968 .911 r
.5626 .43376 .58535 .4622 .63224 .45001 .60981 .42158 Metetra
.905 .961 .905 r
.60981 .42158 .63224 .45001 .67972 .44174 .65759 .41332 Metetra
.891 .946 .891 r
.65759 .41332 .67972 .44174 .72797 .43945 .70615 .41108 Metetra
.862 .916 .862 r
.70615 .41108 .72797 .43945 .77729 .44532 .75575 .41701 Metetra
.802 .852 .802 r
.75575 .41701 .77729 .44532 .82806 .46164 .80679 .43346 Metetra
.682 .724 .682 r
.80679 .43346 .82806 .46164 .88077 .49098 .85975 .46297 Metetra
.519 .552 .519 r
.18137 .40829 .20639 .43421 .24742 .4611 .22247 .43486 Metetra
.763 .811 .763 r
.22247 .43486 .24742 .4611 .28994 .47686 .26514 .45025 Metetra
.854 .908 .854 r
.26514 .45025 .28994 .47686 .33366 .48303 .30905 .45601 Metetra
.89 .946 .89 r
.30905 .45601 .33366 .48303 .37829 .48133 .35393 .45386 Metetra
.905 .962 .905 r
.35393 .45386 .37829 .48133 .42363 .4736 .39955 .44566 Metetra
.912 .969 .912 r
.39955 .44566 .42363 .4736 .46952 .46178 .44573 .43335 Metetra
.915 .972 .915 r
.44573 .43335 .46952 .46178 .51585 .44783 .49237 .4189 Metetra
.914 .971 .914 r
.49237 .4189 .51585 .44783 .5626 .43376 .53943 .40432 Metetra
.911 .968 .911 r
.53943 .40432 .5626 .43376 .60981 .42158 .58694 .39162 Metetra
.905 .961 .905 r
.58694 .39162 .60981 .42158 .65759 .41332 .63502 .38287 Metetra
.892 .947 .892 r
.63502 .38287 .65759 .41332 .70615 .41108 .68385 .38013 Metetra
.866 .92 .866 r
.68385 .38013 .70615 .41108 .75575 .41701 .7337 .3856 Metetra
.817 .868 .817 r
.7337 .3856 .75575 .41701 .80679 .43346 .78495 .40159 Metetra
.724 .769 .724 r
.78495 .40159 .80679 .43346 .85975 .46297 .83808 .43069 Metetra
.416 .442 .416 r
.15566 .38526 .18137 .40829 .22247 .43486 .1969 .41107 Metetra
.736 .782 .736 r
.1969 .41107 .22247 .43486 .26514 .45025 .23976 .42564 Metetra
.85 .903 .85 r
.23976 .42564 .26514 .45025 .30905 .45601 .28392 .4305 Metetra
.891 .947 .891 r
.28392 .4305 .30905 .45601 .35393 .45386 .32908 .42741 Metetra
.907 .964 .907 r
.32908 .42741 .35393 .45386 .39955 .44566 .375 .41822 Metetra
.914 .971 .914 r
.375 .41822 .39955 .44566 .44573 .43335 .4215 .4049 Metetra
.916 .973 .916 r
.4215 .4049 .44573 .43335 .49237 .4189 .46847 .38944 Metetra
.915 .972 .915 r
.46847 .38944 .49237 .4189 .53943 .40432 .51585 .37383 Metetra
.912 .969 .912 r
.51585 .37383 .53943 .40432 .58694 .39162 .56366 .36011 Metetra
.905 .962 .905 r
.56366 .36011 .58694 .39162 .63502 .38287 .61202 .35033 Metetra
.893 .949 .893 r
.61202 .35033 .63502 .38287 .68385 .38013 .66109 .34658 Metetra
.871 .926 .871 r
.66109 .34658 .68385 .38013 .7337 .3856 .71115 .35102 Metetra
.831 .883 .831 r
.71115 .35102 .7337 .3856 .78495 .40159 .76256 .366 Metetra
.757 .804 .757 r
.76256 .366 .78495 .40159 .83808 .43069 .81581 .39407 Metetra
.305 .324 .305 r
.12922 .36516 .15566 .38526 .1969 .41107 .17064 .38978 Metetra
.706 .75 .706 r
.17064 .38978 .1969 .41107 .23976 .42564 .21375 .40303 Metetra
.847 .9 .847 r
.21375 .40303 .23976 .42564 .28392 .4305 .25821 .40651 Metetra
.894 .949 .894 r
.25821 .40651 .28392 .4305 .32908 .42741 .3037 .40196 Metetra
.91 .967 .91 r
.3037 .40196 .32908 .42741 .375 .41822 .34997 .39129 Metetra
.916 .974 .916 r
.34997 .39129 .375 .41822 .4215 .4049 .39682 .37644 Metetra
.918 .975 .918 r
.39682 .37644 .4215 .4049 .46847 .38944 .44413 .35944 Metetra
.917 .974 .917 r
.44413 .35944 .46847 .38944 .51585 .37383 .49184 .34229 Metetra
.913 .97 .913 r
.49184 .34229 .51585 .37383 .56366 .36011 .53996 .32703 Metetra
.907 .963 .907 r
.53996 .32703 .56366 .36011 .61202 .35033 .58859 .3157 Metetra
.895 .951 .895 r
.58859 .3157 .61202 .35033 .66109 .34658 .63789 .31039 Metetra
.876 .931 .876 r
.63789 .31039 .66109 .34658 .71115 .35102 .68812 .31327 Metetra
.842 .895 .842 r
.68812 .31327 .71115 .35102 .76256 .366 .73965 .32666 Metetra
.783 .832 .783 r
.73965 .32666 .76256 .366 .81581 .39407 .79295 .3531 Metetra
.198 .211 .198 r
.10195 .34805 .12922 .36516 .17064 .38978 .14363 .37101 Metetra
.678 .72 .678 r
.14363 .37101 .17064 .38978 .21375 .40303 .18706 .38247 Metetra
.847 .9 .847 r
.18706 .38247 .21375 .40303 .25821 .40651 .23187 .38405 Metetra
.897 .954 .897 r
.23187 .38405 .25821 .40651 .3037 .40196 .27775 .37754 Metetra
.914 .971 .914 r
.27775 .37754 .3037 .40196 .34997 .39129 .32441 .36485 Metetra
.919 .977 .919 r
.32441 .36485 .34997 .39129 .39682 .37644 .37166 .34796 Metetra
.92 .978 .92 r
.37166 .34796 .39682 .37644 .44413 .35944 .41935 .32889 Metetra
.918 .976 .918 r
.41935 .32889 .44413 .35944 .49184 .34229 .46741 .30967 Metetra
.915 .972 .915 r
.46741 .30967 .49184 .34229 .53996 .32703 .51585 .29234 Metetra
.908 .965 .908 r
.51585 .29234 .53996 .32703 .58859 .3157 .56474 .27894 Metetra
.898 .954 .898 r
.56474 .27894 .58859 .3157 .63789 .31039 .61426 .27154 Metetra
.881 .936 .881 r
.61426 .27154 .63789 .31039 .68812 .31327 .66464 .27231 Metetra
.852 .905 .852 r
.66464 .27231 .68812 .31327 .73965 .32666 .71626 .28354 Metetra
.804 .855 .804 r
.71626 .28354 .73965 .32666 .79295 .3531 .76956 .30774 Metetra
.106 .112 .106 r
.07378 .334 .10195 .34805 .14363 .37101 .1158 .35481 Metetra
.653 .694 .653 r
.1158 .35481 .14363 .37101 .18706 .38247 .15962 .36398 Metetra
.849 .902 .849 r
.15962 .36398 .18706 .38247 .23187 .38405 .20486 .36316 Metetra
.903 .959 .903 r
.20486 .36316 .23187 .38405 .27775 .37754 .25119 .35415 Metetra
.919 .976 .919 r
.25119 .35415 .27775 .37754 .32441 .36485 .29831 .33891 Metetra
.923 .98 .923 r
.29831 .33891 .32441 .36485 .37166 .34796 .346 .31944 Metetra
.923 .98 .923 r
.346 .31944 .37166 .34796 .41935 .32889 .39411 .29778 Metetra
.92 .978 .92 r
.39411 .29778 .41935 .32889 .46741 .30967 .44255 .27596 Metetra
.916 .974 .916 r
.44255 .27596 .46741 .30967 .51585 .29234 .49132 .25604 Metetra
.91 .967 .91 r
.49132 .25604 .51585 .29234 .56474 .27894 .54049 .24003 Metetra
.9 .957 .9 r
.54049 .24003 .56474 .27894 .61426 .27154 .59022 .23002 Metetra
.885 .94 .885 r
.59022 .23002 .61426 .27154 .66464 .27231 .64074 .22814 Metetra
.861 .914 .861 r
.64074 .22814 .66464 .27231 .71626 .28354 .6924 .23664 Metetra
.821 .873 .821 r
.6924 .23664 .71626 .28354 .76956 .30774 .74566 .25802 Metetra
.04462 .32307 .07378 .334 .1158 .35481 .08707 .34126 Metetra
.637 .677 .637 r
.08707 .34126 .1158 .35481 .15962 .36398 .13137 .34762 Metetra
.855 .908 .855 r
.13137 .34762 .15962 .36398 .20486 .36316 .17713 .34385 Metetra
.909 .966 .909 r
.17713 .34385 .20486 .36316 .25119 .35415 .22398 .3318 Metetra
.923 .981 .923 r
.22398 .3318 .25119 .35415 .29831 .33891 .27163 .31347 Metetra
.926 .984 .926 r
.27163 .31347 .29831 .33891 .346 .31944 .31982 .29087 Metetra
.925 .983 .925 r
.31982 .29087 .346 .31944 .39411 .29778 .36839 .26608 Metetra
.922 .98 .922 r
.36839 .26608 .39411 .29778 .44255 .27596 .41726 .24114 Metetra
.918 .975 .918 r
.41726 .24114 .44255 .27596 .49132 .25604 .46639 .21809 Metetra
.912 .969 .912 r
.46639 .21809 .49132 .25604 .54049 .24003 .51585 .19897 Metetra
.903 .959 .903 r
.51585 .19897 .54049 .24003 .59022 .23002 .56579 .18582 Metetra
.889 .944 .889 r
.56579 .18582 .59022 .23002 .64074 .22814 .61644 .18074 Metetra
.868 .922 .868 r
.61644 .18074 .64074 .22814 .6924 .23664 .66813 .18598 Metetra
.835 .887 .835 r
.66813 .18598 .6924 .23664 .74566 .25802 .7213 .20396 Metetra
.013 .014 .013 r
.01436 .31538 .04462 .32307 .08707 .34126 .05735 .33042 Metetra
.631 .67 .631 r
.05735 .33042 .08707 .34126 .13137 .34762 .10224 .33343 Metetra
.863 .917 .863 r
.10224 .33343 .13137 .34762 .17713 .34385 .14861 .32616 Metetra
.916 .973 .916 r
.14861 .32616 .17713 .34385 .22398 .3318 .19608 .31051 Metetra
.928 .986 .928 r
.19608 .31051 .22398 .3318 .27163 .31347 .24433 .28852 Metetra
.93 .988 .93 r
.24433 .28852 .27163 .31347 .31982 .29087 .29309 .26225 Metetra
.928 .986 .928 r
.29309 .26225 .31982 .29087 .36839 .26608 .34219 .23378 Metetra
.924 .982 .924 r
.34219 .23378 .36839 .26608 .41726 .24114 .39152 .20518 Metetra
.92 .977 .92 r
.39152 .20518 .41726 .24114 .46639 .21809 .44105 .17849 Metetra
.913 .97 .913 r
.44105 .17849 .46639 .21809 .51585 .19897 .49083 .15573 Metetra
.905 .961 .905 r
.49083 .15573 .51585 .19897 .56579 .18582 .54099 .13892 Metetra
.892 .948 .892 r
.54099 .13892 .56579 .18582 .61644 .18074 .59176 .13014 Metetra
.874 .928 .874 r
.59176 .13014 .61644 .18074 .66813 .18598 .64346 .13158 Metetra
.846 .899 .846 r
.64346 .13158 .66813 .18598 .7213 .20396 .69652 .1456 Metetra
0 g
.25 Mabswid
.69124 0 m
.98003 .43421 L
s
.98003 .43421 m
1 .66097 L
s
1 .66097 m
.69984 .23724 L
s
.69984 .23724 m
.69124 0 L
s
.0226 .2307 m
0 .46297 L
s
0 .46297 m
.69984 .23724 L
s
.69984 .23724 m
.69124 0 L
s
.69124 0 m
.0226 .2307 L
s
.0226 .2307 m
.69124 0 L
s
.18179 .17577 m
.18595 .1807 L
s
[(-1)] .17348 .16592 .84357 1 Mshowa
.34612 .11908 m
.3501 .12415 L
s
[(0)] .33816 .10893 .78408 1 Mshowa
.51585 .06052 m
.51963 .06574 L
s
[(1)] .50828 .05007 .72459 1 Mshowa
gsave
.29838 .05818 -69.9204 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{257, 214.813},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
  ImageRangeCache->{{{0, 256}, {213.813, 0}} -> {0, 0, 0, 0}}],
 StyleBox["     ",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
3.1984e-017 1.04977 -0.0679587 1.04977 [
[.17646 .18758 -11.7989 -9 ]
[.17646 .18758 .20112 0 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.50253 .05935 -5.27396 -9 ]
[.50253 .05935 .72604 0 ]
[.29165 .07573 -9.31117 -12.5625 ]
[.29165 .07573 .68883 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 12 2.73794 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.91861 .21225 0 -8.41865 ]
[.91861 .21225 16 4.14385 ]
[.01529 .3204 -12 -2.78907 ]
[.01529 .3204 0 6.21093 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00166 .42665 -6 -2.87938 ]
[-0.00166 .42665 0 6.12062 ]
[-0.05457 .39542 -10 -3.95494 ]
[-0.05457 .39542 0 8.60756 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.18558 .19702 m
.19014 .20174 L
s
[(-1)] .17646 .18758 .96648 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.51046 .06981 m
.51442 .07504 L
s
[(1)] .50253 .05935 .75799 1 Mshowa
gsave
.29165 .07573 -70.3112 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(-1)] .70096 -0.00478 -1 .39157 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(1)] .98191 .42546 -1 .30087 Mshowa
gsave
.91861 .21225 -61 -12.4187 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.03716 .25514 m
0 .48963 L
s
.02756 .31573 m
.03369 .3134 L
s
[(-5)] .01529 .3204 1 -0.38021 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.01068 .4222 m
.01686 .41998 L
s
[(5)] -0.00166 .42665 1 -0.36014 Mshowa
gsave
-0.05457 .39542 -71 -7.95494 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(v) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.925 .983 .925 r
.375 .77837 .39787 .81114 .43762 .76848 .41503 .73996 Metetra
.93 .988 .93 r
.41503 .73996 .43762 .76848 .47715 .73086 .45493 .7058 Metetra
.933 .991 .933 r
.45493 .7058 .47715 .73086 .51665 .69812 .49485 .67578 Metetra
.934 .992 .934 r
.49485 .67578 .51665 .69812 .55627 .67013 .53493 .64981 Metetra
.93 .988 .93 r
.53493 .64981 .55627 .67013 .59617 .64682 .57532 .62784 Metetra
.922 .98 .922 r
.57532 .62784 .59617 .64682 .63653 .62814 .61618 .60983 Metetra
.908 .965 .908 r
.61618 .60983 .63653 .62814 .67752 .61408 .65765 .59579 Metetra
.889 .945 .889 r
.65765 .59579 .67752 .61408 .71934 .60468 .69991 .58575 Metetra
.867 .921 .867 r
.69991 .58575 .71934 .60468 .76218 .60001 .74313 .57977 Metetra
.844 .896 .844 r
.74313 .57977 .76218 .60001 .80625 .60019 .7875 .57794 Metetra
.822 .873 .822 r
.7875 .57794 .80625 .60019 .85179 .60538 .83323 .58039 Metetra
.803 .854 .803 r
.83323 .58039 .85179 .60538 .89906 .6158 .88055 .58729 Metetra
.789 .838 .789 r
.88055 .58729 .89906 .6158 .94836 .63172 .9297 .59885 Metetra
.778 .827 .778 r
.9297 .59885 .94836 .63172 1 .6535 .98097 .61534 Metetra
.922 .98 .922 r
.35174 .74388 .375 .77837 .41503 .73996 .39198 .70975 Metetra
.927 .985 .927 r
.39198 .70975 .41503 .73996 .45493 .7058 .43219 .67908 Metetra
.93 .988 .93 r
.43219 .67908 .45493 .7058 .49485 .67578 .47249 .65181 Metetra
.93 .989 .93 r
.47249 .65181 .49485 .67578 .53493 .64981 .51301 .62788 Metetra
.927 .985 .927 r
.51301 .62788 .53493 .64981 .57532 .62784 .55387 .60726 Metetra
.92 .978 .92 r
.55387 .60726 .57532 .62784 .61618 .60983 .59521 .58993 Metetra
.909 .966 .909 r
.59521 .58993 .61618 .60983 .65765 .59579 .63715 .5759 Metetra
.894 .95 .894 r
.63715 .5759 .65765 .59579 .69991 .58575 .67985 .5652 Metetra
.878 .933 .878 r
.67985 .5652 .69991 .58575 .74313 .57977 .72346 .55786 Metetra
.861 .915 .861 r
.72346 .55786 .74313 .57977 .7875 .57794 .76814 .55397 Metetra
.846 .899 .846 r
.76814 .55397 .7875 .57794 .83323 .58039 .81407 .55362 Metetra
.833 .885 .833 r
.81407 .55362 .83323 .58039 .88055 .58729 .86144 .55694 Metetra
.822 .873 .822 r
.86144 .55694 .88055 .58729 .9297 .59885 .91046 .56407 Metetra
.813 .863 .813 r
.91046 .56407 .9297 .59885 .98097 .61534 .96138 .5752 Metetra
.919 .977 .919 r
.3281 .70786 .35174 .74388 .39198 .70975 .36848 .67799 Metetra
.924 .982 .924 r
.36848 .67799 .39198 .70975 .43219 .67908 .40894 .65084 Metetra
.927 .985 .927 r
.40894 .65084 .43219 .67908 .47249 .65181 .44958 .62634 Metetra
.927 .985 .927 r
.44958 .62634 .47249 .65181 .51301 .62788 .4905 .60447 Metetra
.924 .982 .924 r
.4905 .60447 .51301 .62788 .55387 .60726 .5318 .58521 Metetra
.918 .976 .918 r
.5318 .58521 .55387 .60726 .59521 .58993 .5736 .56856 Metetra
.909 .966 .909 r
.5736 .56856 .59521 .58993 .63715 .5759 .61601 .55453 Metetra
.898 .954 .898 r
.61601 .55453 .63715 .5759 .67985 .5652 .65916 .54314 Metetra
.886 .942 .886 r
.65916 .54314 .67985 .5652 .72346 .55786 .70316 .53441 Metetra
.875 .929 .875 r
.70316 .53441 .72346 .55786 .76814 .55397 .74816 .52842 Metetra
.864 .918 .864 r
.74816 .52842 .76814 .55397 .81407 .55362 .7943 .52521 Metetra
.855 .909 .855 r
.7943 .52521 .81407 .55362 .86144 .55694 .84174 .52488 Metetra
.847 .9 .847 r
.84174 .52488 .86144 .55694 .91046 .56407 .89067 .52752 Metetra
.839 .892 .839 r
.89067 .52752 .91046 .56407 .96138 .5752 .94127 .53327 Metetra
.916 .973 .916 r
.30405 .67044 .3281 .70786 .36848 .67799 .34451 .64485 Metetra
.92 .977 .92 r
.34451 .64485 .36848 .67799 .40894 .65084 .38516 .62121 Metetra
.923 .98 .923 r
.38516 .62121 .40894 .65084 .44958 .62634 .4261 .5995 Metetra
.923 .981 .923 r
.4261 .5995 .44958 .62634 .4905 .60447 .46738 .57971 Metetra
.921 .978 .921 r
.46738 .57971 .4905 .60447 .5318 .58521 .50911 .56183 Metetra
.916 .973 .916 r
.50911 .56183 .5318 .58521 .5736 .56856 .55136 .54586 Metetra
.909 .966 .909 r
.55136 .54586 .5736 .56856 .61601 .55453 .59423 .53181 Metetra
.901 .957 .901 r
.59423 .53181 .61601 .55453 .65916 .54314 .63782 .5197 Metetra
.893 .949 .893 r
.63782 .5197 .65916 .54314 .70316 .53441 .68223 .50956 Metetra
.885 .941 .885 r
.68223 .50956 .70316 .53441 .74816 .52842 .72756 .5014 Metetra
.879 .934 .879 r
.72756 .5014 .74816 .52842 .7943 .52521 .77394 .49528 Metetra
.873 .927 .873 r
.77394 .49528 .7943 .52521 .84174 .52488 .82148 .49125 Metetra
.867 .921 .867 r
.82148 .49125 .84174 .52488 .89067 .52752 .87033 .48937 Metetra
.86 .914 .86 r
.87033 .48937 .89067 .52752 .94127 .53327 .92064 .48972 Metetra
.911 .968 .911 r
.2796 .63181 .30405 .67044 .34451 .64485 .32007 .61047 Metetra
.915 .972 .915 r
.32007 .61047 .34451 .64485 .38516 .62121 .36086 .59035 Metetra
.918 .975 .918 r
.36086 .59035 .38516 .62121 .4261 .5995 .40203 .57144 Metetra
.918 .976 .918 r
.40203 .57144 .4261 .5995 .46738 .57971 .44365 .55374 Metetra
.917 .974 .917 r
.44365 .55374 .46738 .57971 .50911 .56183 .48577 .53724 Metetra
.913 .97 .913 r
.48577 .53724 .50911 .56183 .55136 .54586 .52847 .52195 Metetra
.908 .965 .908 r
.52847 .52195 .55136 .54586 .59423 .53181 .5718 .50788 Metetra
.903 .959 .903 r
.5718 .50788 .59423 .53181 .63782 .5197 .61584 .49503 Metetra
.898 .954 .898 r
.61584 .49503 .63782 .5197 .68223 .50956 .66066 .48342 Metetra
.894 .95 .894 r
.66066 .48342 .68223 .50956 .72756 .5014 .70635 .47307 Metetra
.89 .946 .89 r
.70635 .47307 .72756 .5014 .77394 .49528 .75298 .46399 Metetra
.886 .942 .886 r
.75298 .46399 .77394 .49528 .82148 .49125 .80066 .45622 Metetra
.882 .937 .882 r
.80066 .45622 .82148 .49125 .87033 .48937 .84947 .44978 Metetra
.877 .932 .877 r
.84947 .44978 .87033 .48937 .92064 .48972 .89953 .4447 Metetra
.905 .961 .905 r
.25474 .59211 .2796 .63181 .32007 .61047 .29513 .57501 Metetra
.909 .966 .909 r
.29513 .57501 .32007 .61047 .36086 .59035 .336 .55841 Metetra
.912 .969 .912 r
.336 .55841 .36086 .59035 .40203 .57144 .37737 .54231 Metetra
.913 .97 .913 r
.37737 .54231 .40203 .57144 .44365 .55374 .41928 .52671 Metetra
.912 .969 .912 r
.41928 .52671 .44365 .55374 .48577 .53724 .46178 .5116 Metetra
.91 .967 .91 r
.46178 .5116 .48577 .53724 .52847 .52195 .5049 .49698 Metetra
.907 .964 .907 r
.5049 .49698 .52847 .52195 .5718 .50788 .54869 .48287 Metetra
.905 .961 .905 r
.54869 .48287 .5718 .50788 .61584 .49503 .59319 .46926 Metetra
.902 .959 .902 r
.59319 .46926 .61584 .49503 .66066 .48342 .63844 .45616 Metetra
.901 .957 .901 r
.63844 .45616 .66066 .48342 .70635 .47307 .68451 .44356 Metetra
.899 .956 .899 r
.68451 .44356 .70635 .47307 .75298 .46399 .73143 .43148 Metetra
.898 .954 .898 r
.73143 .43148 .75298 .46399 .80066 .45622 .77927 .41992 Metetra
.895 .951 .895 r
.77927 .41992 .80066 .45622 .84947 .44978 .82809 .40889 Metetra
.891 .946 .891 r
.82809 .40889 .84947 .44978 .89953 .4447 .87794 .39839 Metetra
.896 .952 .896 r
.22944 .55152 .25474 .59211 .29513 .57501 .26969 .53863 Metetra
.901 .958 .901 r
.26969 .53863 .29513 .57501 .336 .55841 .31056 .52554 Metetra
.905 .961 .905 r
.31056 .52554 .336 .55841 .37737 .54231 .35208 .51225 Metetra
.907 .963 .907 r
.35208 .51225 .37737 .54231 .41928 .52671 .39426 .49875 Metetra
.907 .964 .907 r
.39426 .49875 .41928 .52671 .46178 .5116 .43711 .48503 Metetra
.907 .963 .907 r
.43711 .48503 .46178 .5116 .5049 .49698 .48064 .47109 Metetra
.906 .963 .906 r
.48064 .47109 .5049 .49698 .54869 .48287 .52489 .45693 Metetra
.906 .963 .906 r
.52489 .45693 .54869 .48287 .59319 .46926 .56985 .44253 Metetra
.906 .963 .906 r
.56985 .44253 .59319 .46926 .63844 .45616 .61556 .4279 Metetra
.907 .963 .907 r
.61556 .4279 .63844 .45616 .68451 .44356 .66203 .41302 Metetra
.907 .964 .907 r
.66203 .41302 .68451 .44356 .73143 .43148 .70928 .39789 Metetra
.907 .963 .907 r
.70928 .39789 .73143 .43148 .77927 .41992 .75733 .38251 Metetra
.905 .961 .905 r
.75733 .38251 .77927 .41992 .82809 .40889 .80619 .36687 Metetra
.901 .958 .901 r
.80619 .36687 .82809 .40889 .87794 .39839 .8559 .35095 Metetra
.886 .941 .886 r
.20368 .51018 .22944 .55152 .26969 .53863 .24371 .50148 Metetra
.891 .947 .891 r
.24371 .50148 .26969 .53863 .31056 .52554 .28453 .49189 Metetra
.896 .952 .896 r
.28453 .49189 .31056 .52554 .35208 .51225 .32614 .48141 Metetra
.899 .955 .899 r
.32614 .48141 .35208 .51225 .39426 .49875 .36854 .47002 Metetra
.901 .958 .901 r
.36854 .47002 .39426 .49875 .43711 .48503 .41171 .4577 Metetra
.903 .96 .903 r
.41171 .4577 .43711 .48503 .48064 .47109 .45566 .44443 Metetra
.905 .962 .905 r
.45566 .44443 .48064 .47109 .52489 .45693 .50036 .4302 Metetra
.907 .964 .907 r
.50036 .4302 .52489 .45693 .56985 .44253 .54581 .41499 Metetra
.91 .966 .91 r
.54581 .41499 .56985 .44253 .61556 .4279 .592 .39879 Metetra
.912 .969 .912 r
.592 .39879 .61556 .4279 .66203 .41302 .6389 .38159 Metetra
.914 .971 .914 r
.6389 .38159 .66203 .41302 .70928 .39789 .68651 .36338 Metetra
.914 .971 .914 r
.68651 .36338 .70928 .39789 .75733 .38251 .73481 .34414 Metetra
.913 .97 .913 r
.73481 .34414 .75733 .38251 .80619 .36687 .78378 .32386 Metetra
.91 .967 .91 r
.78378 .32386 .80619 .36687 .8559 .35095 .8334 .30255 Metetra
.871 .926 .871 r
.17743 .46827 .20368 .51018 .24371 .50148 .21715 .46371 Metetra
.878 .933 .878 r
.21715 .46371 .24371 .50148 .28453 .49189 .25785 .45761 Metetra
.885 .94 .885 r
.25785 .45761 .28453 .49189 .32614 .48141 .2995 .44995 Metetra
.89 .946 .89 r
.2995 .44995 .32614 .48141 .36854 .47002 .34208 .44067 Metetra
.895 .951 .895 r
.34208 .44067 .36854 .47002 .41171 .4577 .38556 .42974 Metetra
.899 .955 .899 r
.38556 .42974 .41171 .4577 .45566 .44443 .4299 .41713 Metetra
.904 .96 .904 r
.4299 .41713 .45566 .44443 .50036 .4302 .47507 .40282 Metetra
.908 .965 .908 r
.47507 .40282 .50036 .4302 .54581 .41499 .52102 .38678 Metetra
.913 .97 .913 r
.52102 .38678 .54581 .41499 .592 .39879 .56771 .36898 Metetra
.916 .974 .916 r
.56771 .36898 .592 .39879 .6389 .38159 .6151 .34942 Metetra
.919 .977 .919 r
.6151 .34942 .6389 .38159 .68651 .36338 .66312 .32808 Metetra
.92 .978 .92 r
.66312 .32808 .68651 .36338 .73481 .34414 .71173 .30495 Metetra
.92 .977 .92 r
.71173 .30495 .73481 .34414 .78378 .32386 .76086 .28003 Metetra
.917 .975 .917 r
.76086 .28003 .78378 .32386 .8334 .30255 .81046 .25333 Metetra
.851 .905 .851 r
.15064 .42592 .17743 .46827 .21715 .46371 .18998 .42547 Metetra
.861 .915 .861 r
.18998 .42547 .21715 .46371 .25785 .45761 .23049 .42286 Metetra
.871 .925 .871 r
.23049 .42286 .25785 .45761 .2995 .44995 .27213 .418 Metetra
.879 .934 .879 r
.27213 .418 .2995 .44995 .34208 .44067 .31485 .41084 Metetra
.887 .942 .887 r
.31485 .41084 .34208 .44067 .38556 .42974 .35861 .40131 Metetra
.895 .951 .895 r
.35861 .40131 .38556 .42974 .4299 .41713 .40334 .38937 Metetra
.902 .958 .902 r
.40334 .38937 .4299 .41713 .47507 .40282 .44898 .37496 Metetra
.909 .966 .909 r
.44898 .37496 .47507 .40282 .52102 .38678 .49545 .35805 Metetra
.915 .973 .915 r
.49545 .35805 .52102 .38678 .56771 .36898 .54268 .33862 Metetra
.921 .978 .921 r
.54268 .33862 .56771 .36898 .6151 .34942 .59058 .31666 Metetra
.924 .982 .924 r
.59058 .31666 .6151 .34942 .66312 .32808 .63907 .29214 Metetra
.926 .984 .926 r
.63907 .29214 .66312 .32808 .71173 .30495 .68805 .26509 Metetra
.925 .983 .925 r
.68805 .26509 .71173 .30495 .76086 .28003 .73741 .23551 Metetra
.923 .981 .923 r
.73741 .23551 .76086 .28003 .81046 .25333 .78707 .20344 Metetra
.825 .876 .825 r
.12328 .38329 .15064 .42592 .18998 .42547 .16215 .38692 Metetra
.839 .891 .839 r
.16215 .38692 .18998 .42547 .23049 .42286 .20239 .38777 Metetra
.852 .905 .852 r
.20239 .38777 .23049 .42286 .27213 .418 .24396 .38573 Metetra
.865 .919 .865 r
.24396 .38573 .27213 .418 .31485 .41084 .28678 .38069 Metetra
.878 .932 .878 r
.28678 .38069 .31485 .41084 .35861 .40131 .3308 .37257 Metetra
.889 .945 .889 r
.3308 .37257 .35861 .40131 .40334 .38937 .37591 .36128 Metetra
.9 .956 .9 r
.37591 .36128 .40334 .38937 .44898 .37496 .42203 .34676 Metetra
.91 .967 .91 r
.42203 .34676 .44898 .37496 .49545 .35805 .46905 .32896 Metetra
.918 .975 .918 r
.46905 .32896 .49545 .35805 .54268 .33862 .51685 .30786 Metetra
.924 .982 .924 r
.51685 .30786 .54268 .33862 .59058 .31666 .56532 .28345 Metetra
.928 .986 .928 r
.56532 .28345 .59058 .31666 .63907 .29214 .61433 .25572 Metetra
.93 .988 .93 r
.61433 .25572 .63907 .29214 .68805 .26509 .66375 .2247 Metetra
.93 .988 .93 r
.66375 .2247 .68805 .26509 .73741 .23551 .71342 .19045 Metetra
.927 .985 .927 r
.71342 .19045 .73741 .23551 .78707 .20344 .76322 .15303 Metetra
.787 .836 .787 r
.09529 .34052 .12328 .38329 .16215 .38692 .13359 .3482 Metetra
.808 .858 .808 r
.13359 .3482 .16215 .38692 .20239 .38777 .17349 .35251 Metetra
.828 .88 .828 r
.17349 .35251 .20239 .38777 .24396 .38573 .21492 .35328 Metetra
.848 .9 .848 r
.21492 .35328 .24396 .38573 .28678 .38069 .25781 .35038 Metetra
.866 .92 .866 r
.25781 .35038 .28678 .38069 .3308 .37257 .30205 .34366 Metetra
.883 .938 .883 r
.30205 .34366 .3308 .37257 .37591 .36128 .34754 .33302 Metetra
.898 .954 .898 r
.34754 .33302 .37591 .36128 .42203 .34676 .39415 .31838 Metetra
.91 .967 .91 r
.39415 .31838 .42203 .34676 .46905 .32896 .44174 .29967 Metetra
.92 .978 .92 r
.44174 .29967 .46905 .32896 .51685 .30786 .49017 .27685 Metetra
.927 .985 .927 r
.49017 .27685 .51685 .30786 .56532 .28345 .53927 .24994 Metetra
.932 .99 .932 r
.53927 .24994 .56532 .28345 .61433 .25572 .58887 .21895 Metetra
.934 .992 .934 r
.58887 .21895 .61433 .25572 .66375 .2247 .6388 .18393 Metetra
.933 .992 .933 r
.6388 .18393 .66375 .2247 .71342 .19045 .68887 .14499 Metetra
.931 .989 .931 r
.68887 .14499 .71342 .19045 .76322 .15303 .7389 .10224 Metetra
.735 .781 .735 r
.06661 .29776 .09529 .34052 .13359 .3482 .10425 .30946 Metetra
.766 .813 .766 r
.10425 .30946 .13359 .3482 .17349 .35251 .14372 .31722 Metetra
.796 .846 .796 r
.14372 .31722 .17349 .35251 .21492 .35328 .18495 .32082 Metetra
.825 .876 .825 r
.18495 .32082 .21492 .35328 .25781 .35038 .22785 .32006 Metetra
.852 .905 .852 r
.22785 .32006 .25781 .35038 .30205 .34366 .2723 .31475 Metetra
.875 .93 .875 r
.2723 .31475 .30205 .34366 .34754 .33302 .31816 .30477 Metetra
.895 .951 .895 r
.31816 .30477 .34754 .33302 .39415 .31838 .36527 .28998 Metetra
.911 .968 .911 r
.36527 .28998 .39415 .31838 .44174 .29967 .41347 .27032 Metetra
.922 .98 .922 r
.41347 .27032 .44174 .29967 .49017 .27685 .46257 .24575 Metetra
.93 .988 .93 r
.46257 .24575 .49017 .27685 .53927 .24994 .51236 .21629 Metetra
.935 .993 .935 r
.51236 .21629 .53927 .24994 .58887 .21895 .56263 .18198 Metetra
.937 .995 .937 r
.56263 .18198 .58887 .21895 .6388 .18393 .61316 .14292 Metetra
.936 .994 .936 r
.61316 .14292 .6388 .18393 .68887 .14499 .66372 .09926 Metetra
.933 .991 .933 r
.66372 .09926 .68887 .14499 .7389 .10224 .71408 .05119 Metetra
.664 .705 .664 r
.03716 .25514 .06661 .29776 .10425 .30946 .07403 .27083 Metetra
.708 .753 .708 r
.07403 .27083 .10425 .30946 .14372 .31722 .11299 .28205 Metetra
.753 .8 .753 r
.11299 .28205 .14372 .31722 .18495 .32082 .15395 .28849 Metetra
.796 .845 .796 r
.15395 .28849 .18495 .32082 .22785 .32006 .19681 .28988 Metetra
.834 .886 .834 r
.19681 .28988 .22785 .32006 .2723 .31475 .24144 .28601 Metetra
.866 .92 .866 r
.24144 .28601 .2723 .31475 .31816 .30477 .28766 .27667 Metetra
.891 .947 .891 r
.28766 .27667 .31816 .30477 .36527 .28998 .3353 .26173 Metetra
.911 .967 .911 r
.3353 .26173 .36527 .28998 .41347 .27032 .38414 .24109 Metetra
.924 .982 .924 r
.38414 .24109 .41347 .27032 .46257 .24575 .43396 .21471 Metetra
.933 .991 .933 r
.43396 .21471 .46257 .24575 .51236 .21629 .48452 .18264 Metetra
.937 .996 .937 r
.48452 .18264 .51236 .21629 .56263 .18198 .53554 .14495 Metetra
.939 .997 .939 r
.53554 .14495 .56263 .18198 .61316 .14292 .58677 .1018 Metetra
.938 .996 .938 r
.58677 .1018 .61316 .14292 .66372 .09926 .63793 .05339 Metetra
.935 .993 .935 r
.63793 .05339 .66372 .09926 .71408 .05119 .68874 0 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.18558 .19702 m
.19014 .20174 L
s
[(-1)] .17646 .18758 .96648 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.51046 .06981 m
.51442 .07504 L
s
[(1)] .50253 .05935 .75799 1 Mshowa
gsave
.29165 .07573 -70.3112 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{257, 214.813},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
  ImageRangeCache->{{{0, 256}, {213.813, 0}} -> {0, 0, 0, 0}}],
 "  ",
 StyleBox["\n\tFigure 3.2",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"u", 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], "=", 
   RowBox[{
    SuperscriptBox["x", "3"], "-", 
    RowBox[{"3", " ", "x", " ", 
     SuperscriptBox["y", "2"]}]}]}]]],
 ".  \t\t\t",
 StyleBox["Figure 3.3",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"v", 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], "=", 
   RowBox[{
    RowBox[{"3", " ", 
     SuperscriptBox["x", "2"], " ", "y"}], "-", 
    SuperscriptBox["y", "3"]}]}]]],
 "."
}], "Text"],

Cell[TextData[{
 "\tWe can use complex analysis to show easily that certain combinations of \
harmonic functions are harmonic.  For example, if ",
 StyleBox["v",
  FontFamily->"Courier New"],
 " is a harmonic conjugate of ",
 StyleBox["u",
  FontFamily->"Courier New"],
 ", then their product  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Phi]", 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], " ", "=", 
   RowBox[{"u", 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}], "v", 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}]}]]],
 " is a harmonic function. This can be verified directly by computing the \
partial derivatives and showing that Laplace's equation ",
 StyleBox["(3-26)",
  FontColor->RGBColor[0, 0, 1]],
 " holds, but the details are tedious.  If we use complex variable techniques \
instead, we can start with the fact that ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    RowBox[{"u", 
     RowBox[{"(", 
      RowBox[{"x", ",", "y"}], ")"}]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", "v", 
     RowBox[{"(", 
      RowBox[{"x", ",", "y"}], ")"}]}]}]}]]],
 " is an analytic function.  Then we observe that the square of ",
 StyleBox["f",
  FontFamily->"Courier New"],
 " is also an analytic function, which is\n\n\t\t",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox[
    RowBox[{"[", 
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], "]"}], "2"], "=", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"[", 
      RowBox[{"u", 
       RowBox[{"(", 
        RowBox[{"x", ",", "y"}], ")"}]}], "]"}], "2"], "-", 
    SuperscriptBox[
     RowBox[{"[", 
      RowBox[{"v", 
       RowBox[{"(", 
        RowBox[{"x", ",", "y"}], ")"}]}], "]"}], "2"], "+", 
    RowBox[{"\[ImaginaryI]", " ", "2", " ", "u", 
     RowBox[{"(", 
      RowBox[{"x", ",", "y"}], ")"}], "v", 
     RowBox[{"(", 
      RowBox[{"x", ",", "y"}], ")"}]}]}]}]]],
 ".  \n\n\tWe then know immediately that the imaginary part,  ",
 Cell[BoxData[
  RowBox[{"2", " ", "u", 
   RowBox[{"(", 
    RowBox[{"x", ",", "y"}], ")"}], "v", 
   RowBox[{"(", 
    RowBox[{"x", ",", "y"}], ")"}]}]]],
 ",   is a harmonic function by Theorem 3.8.   Since a constant multiple of a \
harmonic function is harmonic, it follows that ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Phi]", 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], " ", "=", 
   RowBox[{"u", 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}], "v", 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}]}]]],
 " is harmonic.  It is left as an exercise to show that if ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["u", "1"], 
   RowBox[{"(", 
    RowBox[{"x", ",", "y"}], ")"}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["u", "2"], 
   RowBox[{"(", 
    RowBox[{"x", ",", "y"}], ")"}]}]]],
 " are two harmonic functions that are ",
 StyleBox["not",
  FontColor->RGBColor[1, 0, 1]],
 " related in the preceding fashion, then their product need ",
 StyleBox["not",
  FontColor->RGBColor[1, 0, 1]],
 " be harmonic. "
}], "Text"],

Cell[TextData[{
 StyleBox["Theorem 3.9 (Construction of a Conjugate).",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Let  ",
 Cell[BoxData[
  RowBox[{"u", 
   RowBox[{"(", 
    RowBox[{"x", ",", "y"}], ")"}]}]]],
 "  be harmonic in an ",
 Cell[BoxData["\[Epsilon]"]],
 "-neighborhood of the point ",
 Cell[BoxData[
  RowBox[{"(", 
   RowBox[{
    SubscriptBox["x", "0"], ",", 
    SubscriptBox["y", "0"]}], ")"}]]],
 ".  Then there exists a conjugate harmonic function  ",
 Cell[BoxData[
  RowBox[{"v", 
   RowBox[{"(", 
    RowBox[{"x", ",", "y"}], ")"}]}]]],
 "  defined in this neighborhood such that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    RowBox[{"u", 
     RowBox[{"(", 
      RowBox[{"x", ",", "y"}], ")"}]}], "+", 
    RowBox[{"i", " ", "v", 
     RowBox[{"(", 
      RowBox[{"x", ",", "y"}], ")"}]}]}]}]]],
 " is an analytic function."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "Proof.  A conjugate harmonic function ",
 StyleBox["v",
  FontFamily->"Courier New"],
 " will satisfy the Cauchy-Riemann equations ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["u", "x"], 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], "=", 
   RowBox[{
    SubscriptBox["v", "y"], 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["u", "y"], 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], "=", 
   RowBox[{
    RowBox[{"-", 
     SubscriptBox["v", "x"]}], 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}]}]]],
 ".  Assuming that such a function exists, we determine what it would have to \
look like by using a two-step process.  First, we integrate ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["v", "y"], 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 " (which should equal ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["u", "x"], 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 ") with respect to y and get \n\n",
 StyleBox["(3-27)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"v", 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{"\[Integral]", " ", 
      RowBox[{
       SubscriptBox["v", "y"], 
       RowBox[{"(", 
        RowBox[{"x", 
         StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontVariations->{"StrikeThrough"->False,
          "Underline"->False},
          FontColor->GrayLevel[0]], "y"}], ")"}], 
       RowBox[{"\[DifferentialD]", "y"}]}]}], " ", "+", " ", 
     RowBox[{"C", 
      RowBox[{"(", "x", ")"}]}]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"v", 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"\[Integral]", " ", 
     RowBox[{
      SubscriptBox["u", "x"], 
      RowBox[{"(", 
       RowBox[{"x", 
        StyleBox[",",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], "y"}], ")"}], 
      RowBox[{"\[DifferentialD]", "y"}]}]}], " ", "+", " ", 
    RowBox[{"C", 
     RowBox[{"(", "x", ")"}]}]}]}]}]],
 " \n\nwhere ",
 Cell[BoxData[
  RowBox[{"C", 
   RowBox[{"(", "x", ")"}]}]]],
 " is a function of ",
 StyleBox["x",
  FontFamily->"Courier New"],
 " alone that is yet to be determined.  Second, we compute ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"C", "'"}], 
   RowBox[{"(", "x", ")"}]}]]],
 " by differentiating both sides of this equation with respect to ",
 StyleBox["x",
  FontFamily->"Courier New"],
 " and replacing  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["v", "x"], 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 "  with  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"-", 
    SubscriptBox["u", "y"]}], 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 "  on the left side, which gives  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"    ", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["v", "x"], 
      RowBox[{"(", 
       RowBox[{"x", 
        StyleBox[",",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], "y"}], ")"}]}], "  ", "=", " ", 
     RowBox[{
      RowBox[{
       FractionBox["d", "dx"], " ", 
       RowBox[{"\[Integral]", " ", 
        RowBox[{
         SubscriptBox["u", "x"], 
         RowBox[{"(", 
          RowBox[{"x", 
           StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontVariations->{"StrikeThrough"->False,
            "Underline"->False},
            FontColor->GrayLevel[0]], "y"}], ")"}], 
         RowBox[{"\[DifferentialD]", "y"}]}]}]}], " ", "+", " ", 
      RowBox[{
       RowBox[{"C", "'"}], 
       RowBox[{"(", "x", ")"}]}]}]}], "\[IndentingNewLine]", "\n", 
    RowBox[{
     RowBox[{
      RowBox[{"-", " ", 
       SubscriptBox["u", "y"]}], 
      RowBox[{"(", 
       RowBox[{"x", 
        StyleBox[",",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], "y"}], ")"}]}], "  ", "=", " ", 
     RowBox[{
      RowBox[{
       FractionBox["d", "dx"], " ", 
       RowBox[{"\[Integral]", " ", 
        RowBox[{
         SubscriptBox["u", "x"], 
         RowBox[{"(", 
          RowBox[{"x", 
           StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontVariations->{"StrikeThrough"->False,
            "Underline"->False},
            FontColor->GrayLevel[0]], "y"}], ")"}], 
         RowBox[{"\[DifferentialD]", "y"}]}]}]}], " ", "+", " ", 
      RowBox[{
       RowBox[{"C", "'"}], 
       RowBox[{"(", "x", ")"}]}]}]}]}]}]]],
 "\n\nIt can be shown (we omit the details) that because ",
 StyleBox["u",
  FontFamily->"Courier New"],
 " is harmonic, all terms except those involving ",
 StyleBox["x",
  FontFamily->"Courier New"],
 " in the last equation will cancel, revealing a formula for ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"C", "'"}], 
   RowBox[{"(", "x", ")"}]}]]],
 " involving ",
 StyleBox["x",
  FontFamily->"Courier New"],
 " alone.  Elementary integration of the single-variable function ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"C", "'"}], 
   RowBox[{"(", "x", ")"}]}]]],
 " can then be used to discover ",
 Cell[BoxData[
  RowBox[{"C", 
   RowBox[{"(", "x", ")"}]}]]],
 " .  We finally observe that the function ",
 StyleBox["v",
  FontFamily->"Courier New"],
 " so created indeed has the properties we seek."
}], "Text"],

Cell[TextData[{
 "\tThe functions  ",
 Cell[BoxData[
  RowBox[{"C", 
   RowBox[{"(", "x", ")"}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{"v", 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 " are computed with the formulas:\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"C", 
    RowBox[{"(", "x", ")"}]}], " ", "=", " ", 
   RowBox[{"\[Integral]", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", " ", 
         SubscriptBox["u", "y"]}], 
        RowBox[{"(", 
         RowBox[{"x", 
          StyleBox[",",
           FontFamily->"Times New Roman",
           FontSize->12,
           FontWeight->"Plain",
           FontSlant->"Plain",
           FontVariations->{"StrikeThrough"->False,
           "Underline"->False},
           FontColor->GrayLevel[0]], "y"}], ")"}]}], " ", "-", " ", 
       RowBox[{
        FractionBox["d", "dx"], 
        RowBox[{"(", 
         RowBox[{"\[Integral]", " ", 
          RowBox[{
           SubscriptBox["u", "x"], 
           RowBox[{"(", 
            RowBox[{"x", 
             StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontVariations->{"StrikeThrough"->False,
              "Underline"->False},
              FontColor->GrayLevel[0]], "y"}], ")"}], 
           RowBox[{"\[DifferentialD]", "y"}]}]}], ")"}]}]}], ")"}], 
     RowBox[{"\[DifferentialD]", "x"}]}]}]}]]],
 ",   and     \n\t\t\t\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"v", 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"\[Integral]", " ", 
     RowBox[{
      SubscriptBox["u", "x"], 
      RowBox[{"(", 
       RowBox[{"x", 
        StyleBox[",",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], "y"}], ")"}], 
      RowBox[{"\[DifferentialD]", "y"}]}]}], " ", "+", " ", 
    RowBox[{"C", 
     RowBox[{"(", "x", ")"}]}]}]}]]],
 ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 3.9 is in the book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"]
}, Closed]],

Cell["\<\
\tTechnically we should always specify the domain of function when defining \
it.  When no such specification is given, it is assumed that the domain is \
the entire complex plane, or the largest set for which the expression \
defining the function makes sense.\
\>", "Text"],

Cell[TextData[{
 StyleBox["Method.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[" ",
  FontSize->18,
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["Construction of the Harmonic Conjugate of u(x,y).",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Execute this cell to activate the",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 StyleBox[" ",
  FontColor->RGBColor[0, 1, 0]],
 StyleBox["construction of the harmonic conjugate subroutine.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"u", "=", 
     RowBox[{"v", "=", 
      RowBox[{"x", "=", 
       RowBox[{"y", "=", "0"}]}]}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "con", ",", "lap", ",", "u", ",", "v", ",", "v1", ",", "v2", ",", "v3", 
      ",", "x", ",", "y"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"con", "[", "u0_", "]"}], " ", ":=", " ", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"lap", " ", "=", " ", 
         RowBox[{"Simplify", "[", 
          RowBox[{
           RowBox[{
            SubscriptBox["\[PartialD]", 
             RowBox[{"x", ",", "x"}]], 
            RowBox[{"u", "[", 
             RowBox[{"x", ",", "y"}], "]"}]}], " ", "+", " ", 
           RowBox[{
            SubscriptBox["\[PartialD]", 
             RowBox[{"y", ",", "y"}]], 
            RowBox[{"u", "[", 
             RowBox[{"x", ",", "y"}], "]"}]}]}], "]"}]}], ";", " ", 
        "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"lap", "=!=", "0"}], ",", 
          RowBox[{
           RowBox[{"Print", "[", "\"\<u[x,y] was NOT harmonic\>\"", "]"}], 
           ";", " ", "\[IndentingNewLine]", 
           RowBox[{"Print", "[", 
            RowBox[{"\"\<u(x,y) = \>\"", ",", 
             RowBox[{"u", "[", 
              RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";", " ", 
           "\[IndentingNewLine]", 
           RowBox[{
           "Print", "[", 
            "\"\<\!\(\*SubscriptBox[\(u\), \(xx\)]\) + \!\(\*SubscriptBox[\(u\
\), \(yy\)]\) = \>\"", "]"}], ";", "  ", "\[IndentingNewLine]", 
           RowBox[{"Return", "[", 
            RowBox[{"Print", "[", 
             RowBox[{"Expand", "[", "lap", "]"}], "]"}], "]"}]}]}], "]"}], 
        ";", " ", "\[IndentingNewLine]", 
        RowBox[{"v1", " ", "=", 
         RowBox[{"\[Integral]", 
          RowBox[{
           RowBox[{
            SubscriptBox["\[PartialD]", "x"], " ", 
            RowBox[{"u", "[", 
             RowBox[{"x", ",", "y"}], "]"}]}], 
           RowBox[{"\[DifferentialD]", "y"}]}]}]}], ";", " ", 
        "\[IndentingNewLine]", 
        RowBox[{"v2", " ", "=", " ", 
         RowBox[{
          RowBox[{"-", " ", 
           RowBox[{
            SubscriptBox["\[PartialD]", "y"], " ", 
            RowBox[{"u", "[", 
             RowBox[{"x", ",", "y"}], "]"}]}]}], " ", "-", " ", 
          RowBox[{
           SubscriptBox["\[PartialD]", "x"], " ", "v1"}]}]}], ";", " ", 
        "\[IndentingNewLine]", 
        RowBox[{"v3", " ", "=", 
         RowBox[{"\[Integral]", 
          RowBox[{"v2", 
           RowBox[{"\[DifferentialD]", "x"}]}]}]}], ";", " ", 
        "\[IndentingNewLine]", 
        RowBox[{"Return", "[", 
         RowBox[{"v1", " ", "+", " ", "v3"}], "]"}], ";"}]}], "  ", "]"}]}], 
    ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{3.399020887453125*^9},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 3.13.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Show that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"u", 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], "=", 
   RowBox[{
    RowBox[{"x", " ", 
     SuperscriptBox["y", "3"]}], "-", 
    RowBox[{
     SuperscriptBox["x", "3"], " ", "y"}]}]}]]],
 "  is a harmonic function and find the harmonic conjugate  ",
 Cell[BoxData[
  RowBox[{"v", 
   RowBox[{"(", 
    RowBox[{"x", ",", "y"}], ")"}]}]]],
 "."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "Solution.  We follow the construction process of Theorem 3.9.  The first \
partial derivatives are\n\n",
 StyleBox["(3-28)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["u", "x"], 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], "=", 
   RowBox[{
    SuperscriptBox["y", "3"], "-", 
    RowBox[{"3", " ", 
     SuperscriptBox["x", "2"], " ", "y"}]}]}]]],
 "   and   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["u", "y"], 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], "=", 
   RowBox[{
    RowBox[{"3", " ", "x", " ", 
     SuperscriptBox["y", "2"]}], "-", 
    SuperscriptBox["x", "3"]}]}]]],
 ".  \n\nTo verify that ",
 StyleBox["u",
  FontFamily->"Courier New"],
 " is harmonic, we compute the second partial derivatives and note that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["u", "xx"], 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}], "+", 
    RowBox[{
     SubscriptBox["u", "yy"], 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "6"}], " ", "x", " ", "y"}], "+", 
     RowBox[{"6", " ", "x", " ", "y"}]}], " ", "=", " ", "0"}]}]]],
 ",  so ",
 StyleBox["u",
  FontFamily->"Courier New"],
 " satisfies Laplace's Equation ",
 StyleBox["(3-26)",
  FontColor->RGBColor[0, 0, 1]],
 ".  To construct ",
 StyleBox["v",
  FontFamily->"Courier New"],
 ", we start with Equation ",
 StyleBox["(3-27)",
  FontColor->RGBColor[0, 0, 1]],
 " and the first of Equations ",
 StyleBox["(3-28)",
  FontColor->RGBColor[0, 0, 1]],
 " to get  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"v", 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{"\[Integral]", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["y", "3"], "-", 
         RowBox[{"3", " ", 
          SuperscriptBox["x", "2"], " ", "y"}]}], ")"}], 
       RowBox[{"\[DifferentialD]", "y"}]}]}], " ", "+", " ", 
     RowBox[{"C", 
      RowBox[{"(", "x", ")"}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                  ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], 
      SuperscriptBox["y", "4"]}], "-", 
     RowBox[{
      FractionBox["3", "2"], 
      SuperscriptBox["x", "2"], " ", 
      SuperscriptBox["y", "2"]}], "+", " ", 
     RowBox[{"C", 
      RowBox[{"(", "x", ")"}]}]}]}]}]}]]
}], "Text"],

Cell[TextData[{
 "Differentiating the left and right sides of this equation with respect to x \
and using  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     SubscriptBox["u", "y"]}], 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], "=", 
   RowBox[{
    SubscriptBox["v", "x"], 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}]}]]],
 "  and Equations ",
 StyleBox["(3-28)",
  FontColor->RGBColor[0, 0, 1]],
 " on the left side yields\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", " ", "3"}], " ", "x", " ", 
     SuperscriptBox["y", "2"]}], "+", 
    SuperscriptBox["x", "3"]}], " ", "=", " ", 
   RowBox[{"0", " ", "-", " ", 
    RowBox[{"3", "x", " ", 
     SuperscriptBox["y", "2"]}], " ", "+", "  ", 
    RowBox[{
     RowBox[{"C", "'"}], 
     RowBox[{"(", "x", ")"}]}]}]}]]],
 "\n\nwhich implies that\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"C", "'"}], 
    RowBox[{"(", "x", ")"}]}], "  ", "=", "  ", 
   SuperscriptBox["x", "3"]}]]],
 ",  \n\nthen an easy integration yields  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"C", 
    RowBox[{"(", "x", ")"}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     FractionBox["1", "4"], 
     SuperscriptBox["x", "4"]}], "+", "C"}]}]]],
 ",  where C is a constant.  Now we substitute ",
 Cell[BoxData[
  RowBox[{"C", 
   RowBox[{"(", "x", ")"}]}]]],
 " and obtain the desired solution \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"v", 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     FractionBox["1", "4"], 
     SuperscriptBox["x", "4"]}], "+", " ", 
    RowBox[{
     FractionBox["1", "4"], 
     SuperscriptBox["y", "4"]}], "-", 
    RowBox[{
     FractionBox["3", "2"], 
     SuperscriptBox["x", "2"], " ", 
     SuperscriptBox["y", "2"]}], "+", " ", "C"}]}]]],
 ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Explore ",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 StyleBox["Solution 3.13.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell["Enter the function u[x,y], do a step by step construction.", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"u", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", " ", 
     RowBox[{
      RowBox[{"x", " ", 
       SuperscriptBox["y", "3"]}], " ", "-", " ", 
      RowBox[{
       SuperscriptBox["x", "3"], " ", "y"}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", "c", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"c", "[", "x_", "]"}], "=", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", " ", 
          RowBox[{
           SubscriptBox["\[PartialD]", "y"], " ", 
           RowBox[{"u", "[", 
            RowBox[{"x", ",", "y"}], "]"}]}]}], " ", "-", " ", 
         RowBox[{
          SubscriptBox["\[PartialD]", "x"], "  ", 
          RowBox[{"(", 
           RowBox[{"\[Integral]", 
            RowBox[{
             RowBox[{
              SubscriptBox["\[PartialD]", "x"], " ", 
              RowBox[{"u", "[", 
               RowBox[{"x", ",", "y"}], "]"}]}], 
             RowBox[{"\[DifferentialD]", "y"}]}]}], ")"}]}]}], ")"}], 
       RowBox[{"\[DifferentialD]", "x"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{
     RowBox[{"v", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", " ", 
     RowBox[{
      RowBox[{"\[Integral]", 
       RowBox[{
        RowBox[{
         SubscriptBox["\[PartialD]", "x"], 
         RowBox[{"u", "[", 
          RowBox[{"x", ",", "y"}], "]"}]}], 
        RowBox[{"\[DifferentialD]", "y"}]}]}], " ", "+", " ", 
      RowBox[{"c", "[", "x", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< u[x,y] = \>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(u\), \(x\)]\)[x,y] = \>\"", ",", 
      RowBox[{
       SubscriptBox["\[PartialD]", "x"], 
       RowBox[{"u", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(u\), \(y\)]\)[x,y] = \>\"", ",", 
      RowBox[{
       SubscriptBox["\[PartialD]", "y"], 
       RowBox[{"u", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Construct the function c[x]\>\"", "]"}], ";"}],
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<c[x] = \[Integral](- \!\(\*SubscriptBox[\(\[PartialD]\), \
\(y\)]\)u[x,y] - \!\(\*SubscriptBox[\(\[PartialD]\), \(x\)]\)(\[Integral]\!\(\
\*SubscriptBox[\(\[PartialD]\), \(x\)]\) u[x,y]\[DifferentialD]y))\
\[DifferentialD]x\>\"", " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<c[x] = \[Integral](- \!\(\*SubscriptBox[\(\[PartialD]\), \
\(y\)]\)(\>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}], ",", 
      "\"\<) - \!\(\*SubscriptBox[\(\[PartialD]\), \
\(x\)]\)(\[Integral]\!\(\*SubscriptBox[\(\[PartialD]\), \(x\)]\)(\>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}], ",", 
      "\"\<)\[DifferentialD]y))\[DifferentialD]x\>\""}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<c[x] = \[Integral](- (\>\"", ",", 
      RowBox[{
       SubscriptBox["\[PartialD]", "y"], 
       RowBox[{"u", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}], ",", 
      "\"\<) - \!\(\*SubscriptBox[\(\[PartialD]\), \(x\)]\)(\>\"", ",", 
      RowBox[{"\[Integral]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[PartialD]", "x"], 
          RowBox[{"u", "[", 
           RowBox[{"x", ",", "y"}], "]"}]}], ")"}], 
        RowBox[{"\[DifferentialD]", "y"}]}]}], ",", 
      "\"\<))\[DifferentialD]x\>\""}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<c[x] = \[Integral](\>\"", ",", 
      RowBox[{"-", " ", 
       RowBox[{
        SubscriptBox["\[PartialD]", "y"], 
        RowBox[{"u", "[", 
         RowBox[{"x", ",", "y"}], "]"}]}]}], ",", "\"\< - (\>\"", ",", 
      RowBox[{
       SubscriptBox["\[PartialD]", "x"], 
       RowBox[{"(", 
        RowBox[{"\[Integral]", 
         RowBox[{
          RowBox[{
           SubscriptBox["\[PartialD]", "x"], 
           RowBox[{"(", 
            RowBox[{"u", "[", 
             RowBox[{"x", ",", "y"}], "]"}], ")"}]}], 
          RowBox[{"\[DifferentialD]", "y"}]}]}], ")"}]}], " ", ",", 
      "\"\<))\[DifferentialD]x\>\""}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<c[x] = \[Integral](\>\"", ",", 
      RowBox[{
       RowBox[{"-", " ", 
        RowBox[{
         SubscriptBox["\[PartialD]", "y"], 
         RowBox[{"u", "[", 
          RowBox[{"x", ",", "y"}], "]"}]}]}], " ", "-", " ", 
       RowBox[{
        SubscriptBox["\[PartialD]", "x"], 
        RowBox[{"(", 
         RowBox[{"\[Integral]", 
          RowBox[{
           RowBox[{
            SubscriptBox["\[PartialD]", "x"], " ", 
            RowBox[{"u", "[", 
             RowBox[{"x", ",", "y"}], "]"}]}], 
           RowBox[{"\[DifferentialD]", "y"}]}]}], ")"}]}]}], ",", 
      "\"\<)\[DifferentialD]x\>\""}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<c[x] = \>\"", ",", 
      RowBox[{"\[Integral]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", " ", 
           RowBox[{
            SubscriptBox["\[PartialD]", "y"], 
            RowBox[{"u", "[", 
             RowBox[{"x", ",", "y"}], "]"}]}]}], " ", "-", " ", 
          RowBox[{
           SubscriptBox["\[PartialD]", "x"], 
           RowBox[{"(", 
            RowBox[{"\[Integral]", 
             RowBox[{
              RowBox[{
               SubscriptBox["\[PartialD]", "x"], " ", 
               RowBox[{"u", "[", 
                RowBox[{"x", ",", "y"}], "]"}]}], 
              RowBox[{"\[DifferentialD]", "y"}]}]}], ")"}]}]}], ")"}], 
        RowBox[{"\[DifferentialD]", "x"}]}]}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Now construct v[x,y]\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<v[x,y] = \[Integral]\!\(\*SubscriptBox[\(\[PartialD]\), \
\(y\)]\)v[x,y]\[DifferentialD]y + c[x]\>\"", " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<v[x,y] = \[Integral]\!\(\*SubscriptBox[\(\[PartialD]\), \
\(x\)]\)u[x,y]\[DifferentialD]y + c[x]\>\"", " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<v[x,y] = \[Integral]\!\(\*SubscriptBox[\(\[PartialD]\), \(x\)]\)(\>\
\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}], ",", "\"\<)\[DifferentialD]y + (\>\"", 
      ",", 
      RowBox[{"c", "[", "x", "]"}], ",", "\"\<)\>\""}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<v[x,y] = \[Integral](\>\"", ",", 
      RowBox[{
       SubscriptBox["\[PartialD]", "x"], 
       RowBox[{"u", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}], ",", 
      "\"\<)\[DifferentialD]y + (\>\"", ",", 
      RowBox[{"c", "[", "x", "]"}], ",", "\"\<)\>\""}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<v[x,y] = (\>\"", ",", 
      RowBox[{"\[Integral]", 
       RowBox[{
        RowBox[{
         SubscriptBox["\[PartialD]", "x"], 
         RowBox[{"u", "[", 
          RowBox[{"x", ",", "y"}], "]"}]}], 
        RowBox[{"\[DifferentialD]", "y"}]}]}], ",", "\"\<) + (\>\"", ",", 
      RowBox[{"c", "[", "x", "]"}], ",", "\"\<)\>\"", ",", "\"\<+ C\>\""}], 
     " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<v[x,y] = \>\"", ",", 
      RowBox[{
       RowBox[{"\[Integral]", 
        RowBox[{
         RowBox[{
          SubscriptBox["\[PartialD]", "x"], 
          RowBox[{"u", "[", 
           RowBox[{"x", ",", "y"}], "]"}]}], 
         RowBox[{"\[DifferentialD]", "y"}]}]}], " ", "+", " ", 
       RowBox[{"c", "[", "x", "]"}]}], ",", "\"\<+ C\>\""}], " ", "]"}], 
    ";"}], "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{
  3.399020661046875*^9, {3.3990208115*^9, 3.39902081521875*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"gr1", "=", 
    RowBox[{"ContourPlot", "[", 
     RowBox[{
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", 
        RowBox[{"-", "2.5"}], ",", "2.5"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"y", ",", 
        RowBox[{"-", "2.5"}], ",", "2.5"}], "}"}], ",", 
      RowBox[{"PlotPoints", "\[Rule]", "35"}], ",", 
      RowBox[{"Ticks", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Range", "[", 
          RowBox[{
           RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}], ",", 
         RowBox[{"Range", "[", 
          RowBox[{"0", ",", "2", ",", "1"}], "]"}]}], "}"}]}], ",", 
      RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
      RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Contour plot for\>\"", "]"}], ";"}], " ", "\n",
    
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<u[x,y] = \>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}], ",", "\"\< = C\>\""}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399020665578125*^9, 3.39902066825*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"gr2", "=", 
    RowBox[{"ContourPlot", "[", 
     RowBox[{
      RowBox[{"v", "[", 
       RowBox[{"x", ",", "y"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", 
        RowBox[{"-", "2.5"}], ",", "2.5"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"y", ",", 
        RowBox[{"-", "2.5"}], ",", "2.5"}], "}"}], ",", 
      RowBox[{"PlotPoints", "\[Rule]", "35"}], ",", 
      RowBox[{"Ticks", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Range", "[", 
          RowBox[{
           RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}], ",", 
         RowBox[{"Range", "[", 
          RowBox[{"0", ",", "2", ",", "1"}], "]"}]}], "}"}]}], ",", 
      RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
      RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Contour plot for\>\"", "]"}], ";"}], " ", "\n",
    
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<v[x,y] = \>\"", ",", 
      RowBox[{"v", "[", 
       RowBox[{"x", ",", "y"}], "]"}], ",", "\"\< = C\>\""}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39902067925*^9, 3.399020683265625*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"gr3", "=", 
    RowBox[{"ContourPlot", "[", 
     RowBox[{
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", 
        RowBox[{"-", "2.5"}], ",", "2.5"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"y", ",", 
        RowBox[{"-", "2.5"}], ",", "2.5"}], "}"}], ",", 
      RowBox[{"PlotPoints", "\[Rule]", "75"}], ",", 
      RowBox[{"ContourShading", "\[Rule]", "False"}]}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"gr4", "=", 
    RowBox[{"ContourPlot", "[", 
     RowBox[{
      RowBox[{"v", "[", 
       RowBox[{"x", ",", "y"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", 
        RowBox[{"-", "2.5"}], ",", "2.5"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"y", ",", 
        RowBox[{"-", "2.5"}], ",", "2.5"}], "}"}], ",", 
      RowBox[{"PlotPoints", "\[Rule]", "75"}], ",", 
      RowBox[{"ContourShading", "\[Rule]", "False"}]}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"gr3", ",", "gr4", ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "2", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}]}], "]"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<u[x,y] = \>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}], ",", "\"\< = C,  and\>\""}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<v[x,y] = \>\"", ",", 
      RowBox[{"v", "[", 
       RowBox[{"x", ",", "y"}], "]"}], ",", "\"\< = C\>\""}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39902083940625*^9, 3.39902085234375*^9}, {
  3.3997976848903775`*^9, 3.399797697374752*^9}, {3.400259332734375*^9, 
  3.400259348*^9}}],

Cell[TextData[{
 "We are done!\n\n",
 StyleBox["Aside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  We can also construct v[x,y] by the following alternative method."
}], "Text"],

Cell["\<\
Enter the function u[x,y], and determine if it is a harmonic function.  If \
so, proceed with the construction of the harmonic conjugate v[x,y].\
\>", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "F", ",", "u", ",", "v", ",", "x", ",", "y"}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"u", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", " ", 
     RowBox[{
      RowBox[{"x", " ", 
       SuperscriptBox["y", "3"]}], " ", "-", " ", 
      RowBox[{
       SuperscriptBox["x", "3"], " ", "y"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"v", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", " ", 
     RowBox[{"con", "[", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<u(x,y) = \>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Using the subroutine to construct\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<the harmonic conjugate we get:\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<v(x,y) = \>\"", ",", 
      RowBox[{"v", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.3990208636875*^9}],

Cell["\<\
Form the analytic function  f[z] = u[x,y]+ i v[x,y]  and verify that the \
Cauchy-Riemann equations hold.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Ux", " ", "=", " ", 
     RowBox[{
      SubscriptBox["\[PartialD]", "x"], " ", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Uy", " ", "=", " ", 
     RowBox[{
      SubscriptBox["\[PartialD]", "y"], " ", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Vx", " ", "=", " ", 
     RowBox[{
      SubscriptBox["\[PartialD]", "x"], " ", 
      RowBox[{"v", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Vy", " ", "=", " ", 
     RowBox[{
      SubscriptBox["\[PartialD]", "y"], " ", 
      RowBox[{"v", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}]}], ";"}], " ", "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], "=", 
     RowBox[{
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}], " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"v", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<   f[z] = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<   f[z] = u[x,y] + \[ImaginaryI] v[x,y]\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< u[x,y] = \>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< v[x,y] = \>\"", ",", 
      RowBox[{"v", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(u\), \(x\)]\)[x,y] = \>\"", ",", "Ux"}], "]"}],
     ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(u\), \(y\)]\)[x,y] = \>\"", ",", "Uy"}], "]"}],
     ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(v\), \(x\)]\)[x,y] = \>\"", ",", "Vx"}], "]"}],
     ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(v\), \(y\)]\)[x,y] = \>\"", ",", "Vy"}], "]"}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Is \!\(\*SubscriptBox[\(u\), \(x\)]\)[x,y] =  \
\!\(\*SubscriptBox[\(v\), \(y\)]\)[x,y] ?      \>\"", ",", 
      RowBox[{"Ux", "\[Equal]", "Vy"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Is \!\(\*SubscriptBox[\(u\), \(y\)]\)[x,y] = \
-\!\(\*SubscriptBox[\(v\), \(x\)]\)[x,y] ?      \>\"", ",", 
      RowBox[{"Uy", "\[Equal]", 
       RowBox[{"-", "Vx"}]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399020869453125*^9}],

Cell[TextData[{
 "Therefore  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"v", "[", 
    RowBox[{"x", ",", "y"}], "]"}], "=", 
   RowBox[{
    FractionBox[
     SuperscriptBox["x", "4"], "4"], "-", 
    FractionBox[
     RowBox[{"3", " ", 
      SuperscriptBox["x", "2"], " ", 
      SuperscriptBox["y", "2"]}], "2"], "+", 
    FractionBox[
     SuperscriptBox["y", "4"], "4"]}]}]]],
 " is the harmonic conjugate of  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"u", "[", 
    RowBox[{"x", ",", "y"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox["x", "3"]}], " ", "y"}], "+", 
    RowBox[{"x", " ", 
     SuperscriptBox["y", "3"]}]}]}]]],
 ".  \n",
 StyleBox["\nAside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  We can use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to get the standard form of an analytic function.  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "z_", "]"}], "=", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{
       RowBox[{"f", "[", 
        RowBox[{"x", ",", "y"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"x", "\[Rule]", 
          FractionBox[
           RowBox[{"z", "+", 
            RowBox[{"Conjugate", "[", "z", "]"}]}], "2"]}], ",", 
         RowBox[{"y", "\[Rule]", 
          FractionBox[
           RowBox[{"z", "-", 
            RowBox[{"Conjugate", "[", "z", "]"}]}], 
           RowBox[{"2", "\[ImaginaryI]"}]]}]}], "}"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "z_", "]"}], "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"F", "[", "z", "]"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"W", "=", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{
       RowBox[{"f", "[", 
        RowBox[{"x", ",", "y"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"x", "\[Rule]", 
          FractionBox[
           RowBox[{"z", "+", 
            OverscriptBox[
             RowBox[{"z", " "}], "_"]}], "2"]}], ",", 
         RowBox[{"y", "\[Rule]", 
          FractionBox[
           RowBox[{"z", "-", 
            OverscriptBox[
             RowBox[{"z", " "}], "_"]}], 
           RowBox[{"2", "\[ImaginaryI]"}]]}]}], "}"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<f[z] = u[x,y] + \[ImaginaryI] v[x,y]\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", "W"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"F", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399020874703125*^9}]
}, Closed]],

Cell[TextData[{
 "\tContour plots for the families of curves  ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"u", 
     RowBox[{"(", 
      RowBox[{"x", ",", "y"}], ")"}]}], "=", 
    RowBox[{"C", ":", " ", 
     RowBox[{
      StyleBox["C",
       FontSize->14], "  ", 
      StyleBox["is",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox[" ",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox["a",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox[" ",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox["real",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox[" ",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox["constant",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]]}]}]}], "}"}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"v", 
     RowBox[{"(", 
      RowBox[{"x", ",", "y"}], ")"}]}], "=", 
    RowBox[{
     StyleBox["C",
      FontSize->14], ":", " ", 
     RowBox[{
      StyleBox["C",
       FontSize->14], "  ", 
      StyleBox["is",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox[" ",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox["a",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox[" ",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox["real",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox[" ",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox["constant",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]]}]}]}], "}"}]]],
 "  are shown in Figures 3.B.  "
}], "Text"],

Cell[TextData[{
 "\t",
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.192308 0.5 0.192308 [
[.11538 -0.0125 -6 -9 ]
[.11538 -0.0125 6 0 ]
[.30769 -0.0125 -6 -9 ]
[.30769 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69231 -0.0125 -3 -9 ]
[.69231 -0.0125 3 0 ]
[.88462 -0.0125 -3 -9 ]
[.88462 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .11538 -12 -4.5 ]
[-0.0125 .11538 0 4.5 ]
[-0.0125 .30769 -12 -4.5 ]
[-0.0125 .30769 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .69231 -6 -4.5 ]
[-0.0125 .69231 0 4.5 ]
[-0.0125 .88462 -6 -4.5 ]
[-0.0125 .88462 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11538 0 m
.11538 .00625 L
s
[(-2)] .11538 -0.0125 0 1 Mshowa
.30769 0 m
.30769 .00625 L
s
[(-1)] .30769 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69231 0 m
.69231 .00625 L
s
[(1)] .69231 -0.0125 0 1 Mshowa
.88462 0 m
.88462 .00625 L
s
[(2)] .88462 -0.0125 0 1 Mshowa
.125 Mabswid
.15385 0 m
.15385 .00375 L
s
.19231 0 m
.19231 .00375 L
s
.23077 0 m
.23077 .00375 L
s
.26923 0 m
.26923 .00375 L
s
.34615 0 m
.34615 .00375 L
s
.38462 0 m
.38462 .00375 L
s
.42308 0 m
.42308 .00375 L
s
.46154 0 m
.46154 .00375 L
s
.53846 0 m
.53846 .00375 L
s
.57692 0 m
.57692 .00375 L
s
.61538 0 m
.61538 .00375 L
s
.65385 0 m
.65385 .00375 L
s
.73077 0 m
.73077 .00375 L
s
.76923 0 m
.76923 .00375 L
s
.80769 0 m
.80769 .00375 L
s
.84615 0 m
.84615 .00375 L
s
.07692 0 m
.07692 .00375 L
s
.03846 0 m
.03846 .00375 L
s
.92308 0 m
.92308 .00375 L
s
.96154 0 m
.96154 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .11538 m
.00625 .11538 L
s
[(-2)] -0.0125 .11538 1 0 Mshowa
0 .30769 m
.00625 .30769 L
s
[(-1)] -0.0125 .30769 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .69231 m
.00625 .69231 L
s
[(1)] -0.0125 .69231 1 0 Mshowa
0 .88462 m
.00625 .88462 L
s
[(2)] -0.0125 .88462 1 0 Mshowa
.125 Mabswid
0 .15385 m
.00375 .15385 L
s
0 .19231 m
.00375 .19231 L
s
0 .23077 m
.00375 .23077 L
s
0 .26923 m
.00375 .26923 L
s
0 .34615 m
.00375 .34615 L
s
0 .38462 m
.00375 .38462 L
s
0 .42308 m
.00375 .42308 L
s
0 .46154 m
.00375 .46154 L
s
0 .53846 m
.00375 .53846 L
s
0 .57692 m
.00375 .57692 L
s
0 .61538 m
.00375 .61538 L
s
0 .65385 m
.00375 .65385 L
s
0 .73077 m
.00375 .73077 L
s
0 .76923 m
.00375 .76923 L
s
0 .80769 m
.00375 .80769 L
s
0 .84615 m
.00375 .84615 L
s
0 .07692 m
.00375 .07692 L
s
0 .03846 m
.00375 .03846 L
s
0 .92308 m
.00375 .92308 L
s
0 .96154 m
.00375 .96154 L
s
.25 Mabswid
0 0 m
0 1 L
s
.11538 .99375 m
.11538 1 L
s
.30769 .99375 m
.30769 1 L
s
.5 .99375 m
.5 1 L
s
.69231 .99375 m
.69231 1 L
s
.88462 .99375 m
.88462 1 L
s
.125 Mabswid
.15385 .99625 m
.15385 1 L
s
.19231 .99625 m
.19231 1 L
s
.23077 .99625 m
.23077 1 L
s
.26923 .99625 m
.26923 1 L
s
.34615 .99625 m
.34615 1 L
s
.38462 .99625 m
.38462 1 L
s
.42308 .99625 m
.42308 1 L
s
.46154 .99625 m
.46154 1 L
s
.53846 .99625 m
.53846 1 L
s
.57692 .99625 m
.57692 1 L
s
.61538 .99625 m
.61538 1 L
s
.65385 .99625 m
.65385 1 L
s
.73077 .99625 m
.73077 1 L
s
.76923 .99625 m
.76923 1 L
s
.80769 .99625 m
.80769 1 L
s
.84615 .99625 m
.84615 1 L
s
.07692 .99625 m
.07692 1 L
s
.03846 .99625 m
.03846 1 L
s
.92308 .99625 m
.92308 1 L
s
.96154 .99625 m
.96154 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .11538 m
1 .11538 L
s
.99375 .30769 m
1 .30769 L
s
.99375 .5 m
1 .5 L
s
.99375 .69231 m
1 .69231 L
s
.99375 .88462 m
1 .88462 L
s
.125 Mabswid
.99625 .15385 m
1 .15385 L
s
.99625 .19231 m
1 .19231 L
s
.99625 .23077 m
1 .23077 L
s
.99625 .26923 m
1 .26923 L
s
.99625 .34615 m
1 .34615 L
s
.99625 .38462 m
1 .38462 L
s
.99625 .42308 m
1 .42308 L
s
.99625 .46154 m
1 .46154 L
s
.99625 .53846 m
1 .53846 L
s
.99625 .57692 m
1 .57692 L
s
.99625 .61538 m
1 .61538 L
s
.99625 .65385 m
1 .65385 L
s
.99625 .73077 m
1 .73077 L
s
.99625 .76923 m
1 .76923 L
s
.99625 .80769 m
1 .80769 L
s
.99625 .84615 m
1 .84615 L
s
.99625 .07692 m
1 .07692 L
s
.99625 .03846 m
1 .03846 L
s
.99625 .92308 m
1 .92308 L
s
.99625 .96154 m
1 .96154 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 1 1 r
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
0 1 .879 r
.01923 .49923 m
.04751 .49908 L
.07579 .49888 L
.10407 .49862 L
.13235 .49828 L
.16063 .49781 L
.18891 .49716 L
.21719 .49623 L
.24548 .49482 L
.27376 .49263 L
.30204 .489 L
.33032 .48243 L
.3534 .47172 L
.3586 .47064 L
.37525 .44344 L
.37516 .41516 L
.36298 .38688 L
.3586 .37724 L
.34431 .3586 L
.33032 .3377 L
.32167 .33032 L
.30204 .30697 L
.29651 .30204 L
.27376 .27719 L
.27004 .27376 L
.24548 .24795 L
.24286 .24548 L
.21719 .21902 L
.21529 .21719 L
.18891 .1903 L
.18748 .18891 L
.16063 .16171 L
.15953 .16063 L
.13235 .1332 L
.13149 .13235 L
.10407 .10475 L
.10338 .10407 L
.07579 .07635 L
.07523 .07579 L
.04751 .04797 L
.04705 .04751 L
.01923 .01963 L
F
0 g
.01923 .49923 m
.04751 .49908 L
.07579 .49888 L
.10407 .49862 L
.13235 .49828 L
.16063 .49781 L
.18891 .49716 L
.21719 .49623 L
.24548 .49482 L
.27376 .49263 L
.30204 .489 L
.33032 .48243 L
.3534 .47172 L
.3586 .47064 L
.37525 .44344 L
.37516 .41516 L
.36298 .38688 L
.3586 .37724 L
.34431 .3586 L
.33032 .3377 L
.32167 .33032 L
.30204 .30697 L
.29651 .30204 L
.27376 .27719 L
.27004 .27376 L
.24548 .24795 L
.24286 .24548 L
.21719 .21902 L
.21529 .21719 L
.18891 .1903 L
.18748 .18891 L
.16063 .16171 L
.15953 .16063 L
.13235 .1332 L
.13149 .13235 L
.10407 .10475 L
.10338 .10407 L
.07579 .07635 L
.07523 .07579 L
.04751 .04797 L
.04705 .04751 L
.01923 .01963 L
s
0 .879 1 r
.01923 .98037 m
.04705 .95249 L
.04751 .95203 L
.07523 .92421 L
.07579 .92365 L
.10338 .89593 L
.10407 .89525 L
.13149 .86765 L
.13235 .8668 L
.15953 .83937 L
.16063 .83829 L
.18748 .81109 L
.18891 .8097 L
.21529 .78281 L
.21719 .78098 L
.24286 .75452 L
.24548 .75205 L
.27004 .72624 L
.27376 .72281 L
.29651 .69796 L
.30204 .69303 L
.32167 .66968 L
.33032 .6623 L
.34431 .6414 L
.3586 .62276 L
.36298 .61312 L
.37516 .58484 L
.37525 .55656 L
.3586 .52936 L
.3534 .52828 L
.33032 .51757 L
.30204 .511 L
.27376 .50737 L
.24548 .50518 L
.21719 .50377 L
.18891 .50284 L
.16063 .50219 L
.13235 .50172 L
.10407 .50138 L
.07579 .50112 L
.04751 .50092 L
.01923 .50077 L
F
0 g
.01923 .98037 m
.04705 .95249 L
.04751 .95203 L
.07523 .92421 L
.07579 .92365 L
.10338 .89593 L
.10407 .89525 L
.13149 .86765 L
.13235 .8668 L
.15953 .83937 L
.16063 .83829 L
.18748 .81109 L
.18891 .8097 L
.21529 .78281 L
.21719 .78098 L
.24286 .75452 L
.24548 .75205 L
.27004 .72624 L
.27376 .72281 L
.29651 .69796 L
.30204 .69303 L
.32167 .66968 L
.33032 .6623 L
.34431 .6414 L
.3586 .62276 L
.36298 .61312 L
.37516 .58484 L
.37525 .55656 L
.3586 .52936 L
.3534 .52828 L
.33032 .51757 L
.30204 .511 L
.27376 .50737 L
.24548 .50518 L
.21719 .50377 L
.18891 .50284 L
.16063 .50219 L
.13235 .50172 L
.10407 .50138 L
.07579 .50112 L
.04751 .50092 L
.01923 .50077 L
s
0 1 .537 r
.01923 .48769 m
.04751 .48522 L
.07579 .48205 L
.10407 .4779 L
.13235 .47232 L
.13493 .47172 L
.16063 .46464 L
.18891 .45356 L
.2071 .44344 L
.21719 .43643 L
.23784 .41516 L
.24548 .40545 L
.25185 .38688 L
.25572 .3586 L
.25221 .33032 L
.24548 .30829 L
.24293 .30204 L
.22876 .27376 L
.21719 .25377 L
.21115 .24548 L
.19074 .21719 L
.18891 .2147 L
.16819 .18891 L
.16063 .17957 L
.14423 .16063 L
.13235 .14685 L
.11922 .13235 L
.10407 .11549 L
.09343 .10407 L
.07579 .08498 L
.06706 .07579 L
.04751 .05503 L
.04037 .04751 L
.01923 .02566 L
F
0 g
.01923 .48769 m
.04751 .48522 L
.07579 .48205 L
.10407 .4779 L
.13235 .47232 L
.13493 .47172 L
.16063 .46464 L
.18891 .45356 L
.2071 .44344 L
.21719 .43643 L
.23784 .41516 L
.24548 .40545 L
.25185 .38688 L
.25572 .3586 L
.25221 .33032 L
.24548 .30829 L
.24293 .30204 L
.22876 .27376 L
.21719 .25377 L
.21115 .24548 L
.19074 .21719 L
.18891 .2147 L
.16819 .18891 L
.16063 .17957 L
.14423 .16063 L
.13235 .14685 L
.11922 .13235 L
.10407 .11549 L
.09343 .10407 L
.07579 .08498 L
.06706 .07579 L
.04751 .05503 L
.04037 .04751 L
.01923 .02566 L
s
0 .537 1 r
.01923 .97434 m
.04037 .95249 L
.04751 .94497 L
.06706 .92421 L
.07579 .91502 L
.09343 .89593 L
.10407 .88451 L
.11922 .86765 L
.13235 .85315 L
.14423 .83937 L
.16063 .82043 L
.16819 .81109 L
.18891 .7853 L
.19074 .78281 L
.21115 .75452 L
.21719 .74623 L
.22876 .72624 L
.24293 .69796 L
.24548 .69171 L
.25221 .66968 L
.25572 .6414 L
.25185 .61312 L
.24548 .59455 L
.23784 .58484 L
.21719 .56357 L
.2071 .55656 L
.18891 .54644 L
.16063 .53536 L
.13493 .52828 L
.13235 .52768 L
.10407 .5221 L
.07579 .51795 L
.04751 .51478 L
.01923 .51231 L
F
0 g
.01923 .97434 m
.04037 .95249 L
.04751 .94497 L
.06706 .92421 L
.07579 .91502 L
.09343 .89593 L
.10407 .88451 L
.11922 .86765 L
.13235 .85315 L
.14423 .83937 L
.16063 .82043 L
.16819 .81109 L
.18891 .7853 L
.19074 .78281 L
.21115 .75452 L
.21719 .74623 L
.22876 .72624 L
.24293 .69796 L
.24548 .69171 L
.25221 .66968 L
.25572 .6414 L
.25185 .61312 L
.24548 .59455 L
.23784 .58484 L
.21719 .56357 L
.2071 .55656 L
.18891 .54644 L
.16063 .53536 L
.13493 .52828 L
.13235 .52768 L
.10407 .5221 L
.07579 .51795 L
.04751 .51478 L
.01923 .51231 L
s
.061 0 1 r
.01923 .96058 m
.02653 .95249 L
.04751 .92794 L
.05062 .92421 L
.07386 .89593 L
.07579 .89357 L
.09579 .86765 L
.10407 .85666 L
.11611 .83937 L
.13235 .81464 L
.13445 .81109 L
.15019 .78281 L
.16063 .7608 L
.16292 .75452 L
.17188 .72624 L
.17652 .69796 L
.17595 .66968 L
.16904 .6414 L
.16063 .62295 L
.15389 .61312 L
.13235 .58956 L
.1266 .58484 L
.10407 .56961 L
.07752 .55656 L
.07579 .55584 L
.04751 .54567 L
.01923 .53792 L
F
0 g
.01923 .96058 m
.02653 .95249 L
.04751 .92794 L
.05062 .92421 L
.07386 .89593 L
.07579 .89357 L
.09579 .86765 L
.10407 .85666 L
.11611 .83937 L
.13235 .81464 L
.13445 .81109 L
.15019 .78281 L
.16063 .7608 L
.16292 .75452 L
.17188 .72624 L
.17652 .69796 L
.17595 .66968 L
.16904 .6414 L
.16063 .62295 L
.15389 .61312 L
.13235 .58956 L
.1266 .58484 L
.10407 .56961 L
.07752 .55656 L
.07579 .55584 L
.04751 .54567 L
.01923 .53792 L
s
.061 1 0 r
.01923 .46208 m
.04751 .45433 L
.07579 .44416 L
.07752 .44344 L
.10407 .43039 L
.1266 .41516 L
.13235 .41044 L
.15389 .38688 L
.16063 .37705 L
.16904 .3586 L
.17595 .33032 L
.17652 .30204 L
.17188 .27376 L
.16292 .24548 L
.16063 .2392 L
.15019 .21719 L
.13445 .18891 L
.13235 .18536 L
.11611 .16063 L
.10407 .14334 L
.09579 .13235 L
.07579 .10643 L
.07386 .10407 L
.05062 .07579 L
.04751 .07206 L
.02653 .04751 L
.01923 .03942 L
F
0 g
.01923 .46208 m
.04751 .45433 L
.07579 .44416 L
.07752 .44344 L
.10407 .43039 L
.1266 .41516 L
.13235 .41044 L
.15389 .38688 L
.16063 .37705 L
.16904 .3586 L
.17595 .33032 L
.17652 .30204 L
.17188 .27376 L
.16292 .24548 L
.16063 .2392 L
.15019 .21719 L
.13445 .18891 L
.13235 .18536 L
.11611 .16063 L
.10407 .14334 L
.09579 .13235 L
.07579 .10643 L
.07386 .10407 L
.05062 .07579 L
.04751 .07206 L
.02653 .04751 L
.01923 .03942 L
s
.915 1 0 r
.01923 .42095 m
.02955 .41516 L
.04751 .40335 L
.06713 .38688 L
.07579 .37799 L
.09054 .3586 L
.10407 .33216 L
.10473 .33032 L
.11204 .30204 L
.1139 .27376 L
.11117 .24548 L
.10451 .21719 L
.10407 .21556 L
.09436 .18891 L
.08125 .16063 L
.07579 .15 L
.06558 .13235 L
.04778 .10407 L
.04751 .10366 L
.02824 .07579 L
.01923 .06358 L
F
0 g
.01923 .42095 m
.02955 .41516 L
.04751 .40335 L
.06713 .38688 L
.07579 .37799 L
.09054 .3586 L
.10407 .33216 L
.10473 .33032 L
.11204 .30204 L
.1139 .27376 L
.11117 .24548 L
.10451 .21719 L
.10407 .21556 L
.09436 .18891 L
.08125 .16063 L
.07579 .15 L
.06558 .13235 L
.04778 .10407 L
.04751 .10366 L
.02824 .07579 L
.01923 .06358 L
s
.915 0 1 r
.01923 .93642 m
.02824 .92421 L
.04751 .89634 L
.04778 .89593 L
.06558 .86765 L
.07579 .85 L
.08125 .83937 L
.09436 .81109 L
.10407 .78444 L
.10451 .78281 L
.11117 .75452 L
.1139 .72624 L
.11204 .69796 L
.10473 .66968 L
.10407 .66784 L
.09054 .6414 L
.07579 .62201 L
.06713 .61312 L
.04751 .59665 L
.02955 .58484 L
.01923 .57905 L
F
0 g
.01923 .93642 m
.02824 .92421 L
.04751 .89634 L
.04778 .89593 L
.06558 .86765 L
.07579 .85 L
.08125 .83937 L
.09436 .81109 L
.10407 .78444 L
.10451 .78281 L
.11117 .75452 L
.1139 .72624 L
.11204 .69796 L
.10473 .66968 L
.10407 .66784 L
.09054 .6414 L
.07579 .62201 L
.06713 .61312 L
.04751 .59665 L
.02955 .58484 L
.01923 .57905 L
s
1 0 0 r
.01923 .35749 m
.03831 .33032 L
.04751 .31157 L
.0509 .30204 L
.05775 .27376 L
.05983 .24548 L
.05782 .21719 L
.05223 .18891 L
.04751 .17119 L
.04349 .16063 L
.03198 .13235 L
.01923 .10652 L
F
0 g
.01923 .35749 m
.03831 .33032 L
.04751 .31157 L
.0509 .30204 L
.05775 .27376 L
.05983 .24548 L
.05782 .21719 L
.05223 .18891 L
.04751 .17119 L
.04349 .16063 L
.03198 .13235 L
.01923 .10652 L
s
1 0 0 r
.01923 .89348 m
.03198 .86765 L
.04349 .83937 L
.04751 .82881 L
.05223 .81109 L
.05782 .78281 L
.05983 .75452 L
.05775 .72624 L
.0509 .69796 L
.04751 .68843 L
.03831 .66968 L
.01923 .64251 L
F
0 g
.01923 .89348 m
.03198 .86765 L
.04349 .83937 L
.04751 .82881 L
.05223 .81109 L
.05782 .78281 L
.05983 .75452 L
.05775 .72624 L
.0509 .69796 L
.04751 .68843 L
.03831 .66968 L
.01923 .64251 L
s
0 .879 1 r
.49923 .01923 m
.49908 .04751 L
.49888 .07579 L
.49862 .10407 L
.49828 .13235 L
.49781 .16063 L
.49716 .18891 L
.49623 .21719 L
.49482 .24548 L
.49263 .27376 L
.489 .30204 L
.48243 .33032 L
.47172 .3534 L
.47064 .3586 L
.44344 .37525 L
.41516 .37516 L
.38688 .36298 L
.37724 .3586 L
.3586 .34431 L
.3377 .33032 L
.33032 .32167 L
.30697 .30204 L
.30204 .29651 L
.27719 .27376 L
.27376 .27004 L
.24795 .24548 L
.24548 .24286 L
.21902 .21719 L
.21719 .21529 L
.1903 .18891 L
.18891 .18748 L
.16171 .16063 L
.16063 .15953 L
.1332 .13235 L
.13235 .13149 L
.10475 .10407 L
.10407 .10338 L
.07635 .07579 L
.07579 .07523 L
.04797 .04751 L
.04751 .04705 L
.01963 .01923 L
F
0 g
.49923 .01923 m
.49908 .04751 L
.49888 .07579 L
.49862 .10407 L
.49828 .13235 L
.49781 .16063 L
.49716 .18891 L
.49623 .21719 L
.49482 .24548 L
.49263 .27376 L
.489 .30204 L
.48243 .33032 L
.47172 .3534 L
.47064 .3586 L
.44344 .37525 L
.41516 .37516 L
.38688 .36298 L
.37724 .3586 L
.3586 .34431 L
.3377 .33032 L
.33032 .32167 L
.30697 .30204 L
.30204 .29651 L
.27719 .27376 L
.27376 .27004 L
.24795 .24548 L
.24548 .24286 L
.21902 .21719 L
.21719 .21529 L
.1903 .18891 L
.18891 .18748 L
.16171 .16063 L
.16063 .15953 L
.1332 .13235 L
.13235 .13149 L
.10475 .10407 L
.10407 .10338 L
.07635 .07579 L
.07579 .07523 L
.04797 .04751 L
.04751 .04705 L
.01963 .01923 L
s
0 1 .879 r
.49923 .98077 m
.49908 .95249 L
.49888 .92421 L
.49862 .89593 L
.49828 .86765 L
.49781 .83937 L
.49716 .81109 L
.49623 .78281 L
.49482 .75452 L
.49263 .72624 L
.489 .69796 L
.48243 .66968 L
.47172 .6466 L
.47064 .6414 L
.44344 .62475 L
.41516 .62484 L
.38688 .63702 L
.37724 .6414 L
.3586 .65569 L
.3377 .66968 L
.33032 .67833 L
.30697 .69796 L
.30204 .70349 L
.27719 .72624 L
.27376 .72996 L
.24795 .75452 L
.24548 .75714 L
.21902 .78281 L
.21719 .78471 L
.1903 .81109 L
.18891 .81252 L
.16171 .83937 L
.16063 .84047 L
.1332 .86765 L
.13235 .86851 L
.10475 .89593 L
.10407 .89662 L
.07635 .92421 L
.07579 .92477 L
.04797 .95249 L
.04751 .95295 L
.01963 .98077 L
F
0 g
.49923 .98077 m
.49908 .95249 L
.49888 .92421 L
.49862 .89593 L
.49828 .86765 L
.49781 .83937 L
.49716 .81109 L
.49623 .78281 L
.49482 .75452 L
.49263 .72624 L
.489 .69796 L
.48243 .66968 L
.47172 .6466 L
.47064 .6414 L
.44344 .62475 L
.41516 .62484 L
.38688 .63702 L
.37724 .6414 L
.3586 .65569 L
.3377 .66968 L
.33032 .67833 L
.30697 .69796 L
.30204 .70349 L
.27719 .72624 L
.27376 .72996 L
.24795 .75452 L
.24548 .75714 L
.21902 .78281 L
.21719 .78471 L
.1903 .81109 L
.18891 .81252 L
.16171 .83937 L
.16063 .84047 L
.1332 .86765 L
.13235 .86851 L
.10475 .89593 L
.10407 .89662 L
.07635 .92421 L
.07579 .92477 L
.04797 .95249 L
.04751 .95295 L
.01963 .98077 L
s
0 .537 1 r
.48769 .01923 m
.48522 .04751 L
.48205 .07579 L
.4779 .10407 L
.47232 .13235 L
.47172 .13493 L
.46464 .16063 L
.45356 .18891 L
.44344 .2071 L
.43643 .21719 L
.41516 .23784 L
.40545 .24548 L
.38688 .25185 L
.3586 .25572 L
.33032 .25221 L
.30829 .24548 L
.30204 .24293 L
.27376 .22876 L
.25377 .21719 L
.24548 .21115 L
.21719 .19074 L
.2147 .18891 L
.18891 .16819 L
.17957 .16063 L
.16063 .14423 L
.14685 .13235 L
.13235 .11922 L
.11549 .10407 L
.10407 .09343 L
.08498 .07579 L
.07579 .06706 L
.05503 .04751 L
.04751 .04037 L
.02566 .01923 L
F
0 g
.48769 .01923 m
.48522 .04751 L
.48205 .07579 L
.4779 .10407 L
.47232 .13235 L
.47172 .13493 L
.46464 .16063 L
.45356 .18891 L
.44344 .2071 L
.43643 .21719 L
.41516 .23784 L
.40545 .24548 L
.38688 .25185 L
.3586 .25572 L
.33032 .25221 L
.30829 .24548 L
.30204 .24293 L
.27376 .22876 L
.25377 .21719 L
.24548 .21115 L
.21719 .19074 L
.2147 .18891 L
.18891 .16819 L
.17957 .16063 L
.16063 .14423 L
.14685 .13235 L
.13235 .11922 L
.11549 .10407 L
.10407 .09343 L
.08498 .07579 L
.07579 .06706 L
.05503 .04751 L
.04751 .04037 L
.02566 .01923 L
s
0 1 .537 r
.48769 .98077 m
.48522 .95249 L
.48205 .92421 L
.4779 .89593 L
.47232 .86765 L
.47172 .86507 L
.46464 .83937 L
.45356 .81109 L
.44344 .7929 L
.43643 .78281 L
.41516 .76216 L
.40545 .75452 L
.38688 .74815 L
.3586 .74428 L
.33032 .74779 L
.30829 .75452 L
.30204 .75707 L
.27376 .77124 L
.25377 .78281 L
.24548 .78885 L
.21719 .80926 L
.2147 .81109 L
.18891 .83181 L
.17957 .83937 L
.16063 .85577 L
.14685 .86765 L
.13235 .88078 L
.11549 .89593 L
.10407 .90657 L
.08498 .92421 L
.07579 .93294 L
.05503 .95249 L
.04751 .95963 L
.02566 .98077 L
F
0 g
.48769 .98077 m
.48522 .95249 L
.48205 .92421 L
.4779 .89593 L
.47232 .86765 L
.47172 .86507 L
.46464 .83937 L
.45356 .81109 L
.44344 .7929 L
.43643 .78281 L
.41516 .76216 L
.40545 .75452 L
.38688 .74815 L
.3586 .74428 L
.33032 .74779 L
.30829 .75452 L
.30204 .75707 L
.27376 .77124 L
.25377 .78281 L
.24548 .78885 L
.21719 .80926 L
.2147 .81109 L
.18891 .83181 L
.17957 .83937 L
.16063 .85577 L
.14685 .86765 L
.13235 .88078 L
.11549 .89593 L
.10407 .90657 L
.08498 .92421 L
.07579 .93294 L
.05503 .95249 L
.04751 .95963 L
.02566 .98077 L
s
.061 0 1 r
.46208 .01923 m
.45433 .04751 L
.44416 .07579 L
.44344 .07752 L
.43039 .10407 L
.41516 .1266 L
.41044 .13235 L
.38688 .15389 L
.37705 .16063 L
.3586 .16904 L
.33032 .17595 L
.30204 .17652 L
.27376 .17188 L
.24548 .16292 L
.2392 .16063 L
.21719 .15019 L
.18891 .13445 L
.18536 .13235 L
.16063 .11611 L
.14334 .10407 L
.13235 .09579 L
.10643 .07579 L
.10407 .07386 L
.07579 .05062 L
.07206 .04751 L
.04751 .02653 L
.03942 .01923 L
F
0 g
.46208 .01923 m
.45433 .04751 L
.44416 .07579 L
.44344 .07752 L
.43039 .10407 L
.41516 .1266 L
.41044 .13235 L
.38688 .15389 L
.37705 .16063 L
.3586 .16904 L
.33032 .17595 L
.30204 .17652 L
.27376 .17188 L
.24548 .16292 L
.2392 .16063 L
.21719 .15019 L
.18891 .13445 L
.18536 .13235 L
.16063 .11611 L
.14334 .10407 L
.13235 .09579 L
.10643 .07579 L
.10407 .07386 L
.07579 .05062 L
.07206 .04751 L
.04751 .02653 L
.03942 .01923 L
s
.061 1 0 r
.46208 .98077 m
.45433 .95249 L
.44416 .92421 L
.44344 .92248 L
.43039 .89593 L
.41516 .8734 L
.41044 .86765 L
.38688 .84611 L
.37705 .83937 L
.3586 .83096 L
.33032 .82405 L
.30204 .82348 L
.27376 .82812 L
.24548 .83708 L
.2392 .83937 L
.21719 .84981 L
.18891 .86555 L
.18536 .86765 L
.16063 .88389 L
.14334 .89593 L
.13235 .90421 L
.10643 .92421 L
.10407 .92614 L
.07579 .94938 L
.07206 .95249 L
.04751 .97347 L
.03942 .98077 L
F
0 g
.46208 .98077 m
.45433 .95249 L
.44416 .92421 L
.44344 .92248 L
.43039 .89593 L
.41516 .8734 L
.41044 .86765 L
.38688 .84611 L
.37705 .83937 L
.3586 .83096 L
.33032 .82405 L
.30204 .82348 L
.27376 .82812 L
.24548 .83708 L
.2392 .83937 L
.21719 .84981 L
.18891 .86555 L
.18536 .86765 L
.16063 .88389 L
.14334 .89593 L
.13235 .90421 L
.10643 .92421 L
.10407 .92614 L
.07579 .94938 L
.07206 .95249 L
.04751 .97347 L
.03942 .98077 L
s
.915 0 1 r
.42095 .01923 m
.41516 .02955 L
.40335 .04751 L
.38688 .06713 L
.37799 .07579 L
.3586 .09054 L
.33216 .10407 L
.33032 .10473 L
.30204 .11204 L
.27376 .1139 L
.24548 .11117 L
.21719 .10451 L
.21556 .10407 L
.18891 .09436 L
.16063 .08125 L
.15 .07579 L
.13235 .06558 L
.10407 .04778 L
.10366 .04751 L
.07579 .02824 L
.06358 .01923 L
F
0 g
.42095 .01923 m
.41516 .02955 L
.40335 .04751 L
.38688 .06713 L
.37799 .07579 L
.3586 .09054 L
.33216 .10407 L
.33032 .10473 L
.30204 .11204 L
.27376 .1139 L
.24548 .11117 L
.21719 .10451 L
.21556 .10407 L
.18891 .09436 L
.16063 .08125 L
.15 .07579 L
.13235 .06558 L
.10407 .04778 L
.10366 .04751 L
.07579 .02824 L
.06358 .01923 L
s
.915 1 0 r
.42095 .98077 m
.41516 .97045 L
.40335 .95249 L
.38688 .93287 L
.37799 .92421 L
.3586 .90946 L
.33216 .89593 L
.33032 .89527 L
.30204 .88796 L
.27376 .8861 L
.24548 .88883 L
.21719 .89549 L
.21556 .89593 L
.18891 .90564 L
.16063 .91875 L
.15 .92421 L
.13235 .93442 L
.10407 .95222 L
.10366 .95249 L
.07579 .97176 L
.06358 .98077 L
F
0 g
.42095 .98077 m
.41516 .97045 L
.40335 .95249 L
.38688 .93287 L
.37799 .92421 L
.3586 .90946 L
.33216 .89593 L
.33032 .89527 L
.30204 .88796 L
.27376 .8861 L
.24548 .88883 L
.21719 .89549 L
.21556 .89593 L
.18891 .90564 L
.16063 .91875 L
.15 .92421 L
.13235 .93442 L
.10407 .95222 L
.10366 .95249 L
.07579 .97176 L
.06358 .98077 L
s
1 0 0 r
.35749 .01923 m
.33032 .03831 L
.31157 .04751 L
.30204 .0509 L
.27376 .05775 L
.24548 .05983 L
.21719 .05782 L
.18891 .05223 L
.17119 .04751 L
.16063 .04349 L
.13235 .03198 L
.10652 .01923 L
F
0 g
.35749 .01923 m
.33032 .03831 L
.31157 .04751 L
.30204 .0509 L
.27376 .05775 L
.24548 .05983 L
.21719 .05782 L
.18891 .05223 L
.17119 .04751 L
.16063 .04349 L
.13235 .03198 L
.10652 .01923 L
s
1 0 0 r
.35749 .98077 m
.33032 .96169 L
.31157 .95249 L
.30204 .9491 L
.27376 .94225 L
.24548 .94017 L
.21719 .94218 L
.18891 .94777 L
.17119 .95249 L
.16063 .95651 L
.13235 .96802 L
.10652 .98077 L
F
0 g
.35749 .98077 m
.33032 .96169 L
.31157 .95249 L
.30204 .9491 L
.27376 .94225 L
.24548 .94017 L
.21719 .94218 L
.18891 .94777 L
.17119 .95249 L
.16063 .95651 L
.13235 .96802 L
.10652 .98077 L
s
0 1 .879 r
.98037 .01923 m
.95249 .04705 L
.95203 .04751 L
.92421 .07523 L
.92365 .07579 L
.89593 .10338 L
.89525 .10407 L
.86765 .13149 L
.8668 .13235 L
.83937 .15953 L
.83829 .16063 L
.81109 .18748 L
.8097 .18891 L
.78281 .21529 L
.78098 .21719 L
.75452 .24286 L
.75205 .24548 L
.72624 .27004 L
.72281 .27376 L
.69796 .29651 L
.69303 .30204 L
.66968 .32167 L
.6623 .33032 L
.6414 .34431 L
.62276 .3586 L
.61312 .36298 L
.58484 .37516 L
.55656 .37525 L
.52936 .3586 L
.52828 .3534 L
.51757 .33032 L
.511 .30204 L
.50737 .27376 L
.50518 .24548 L
.50377 .21719 L
.50284 .18891 L
.50219 .16063 L
.50172 .13235 L
.50138 .10407 L
.50112 .07579 L
.50092 .04751 L
.50077 .01923 L
F
0 g
.98037 .01923 m
.95249 .04705 L
.95203 .04751 L
.92421 .07523 L
.92365 .07579 L
.89593 .10338 L
.89525 .10407 L
.86765 .13149 L
.8668 .13235 L
.83937 .15953 L
.83829 .16063 L
.81109 .18748 L
.8097 .18891 L
.78281 .21529 L
.78098 .21719 L
.75452 .24286 L
.75205 .24548 L
.72624 .27004 L
.72281 .27376 L
.69796 .29651 L
.69303 .30204 L
.66968 .32167 L
.6623 .33032 L
.6414 .34431 L
.62276 .3586 L
.61312 .36298 L
.58484 .37516 L
.55656 .37525 L
.52936 .3586 L
.52828 .3534 L
.51757 .33032 L
.511 .30204 L
.50737 .27376 L
.50518 .24548 L
.50377 .21719 L
.50284 .18891 L
.50219 .16063 L
.50172 .13235 L
.50138 .10407 L
.50112 .07579 L
.50092 .04751 L
.50077 .01923 L
s
0 .879 1 r
.98037 .98077 m
.95249 .95295 L
.95203 .95249 L
.92421 .92477 L
.92365 .92421 L
.89593 .89662 L
.89525 .89593 L
.86765 .86851 L
.8668 .86765 L
.83937 .84047 L
.83829 .83937 L
.81109 .81252 L
.8097 .81109 L
.78281 .78471 L
.78098 .78281 L
.75452 .75714 L
.75205 .75452 L
.72624 .72996 L
.72281 .72624 L
.69796 .70349 L
.69303 .69796 L
.66968 .67833 L
.6623 .66968 L
.6414 .65569 L
.62276 .6414 L
.61312 .63702 L
.58484 .62484 L
.55656 .62475 L
.52936 .6414 L
.52828 .6466 L
.51757 .66968 L
.511 .69796 L
.50737 .72624 L
.50518 .75452 L
.50377 .78281 L
.50284 .81109 L
.50219 .83937 L
.50172 .86765 L
.50138 .89593 L
.50112 .92421 L
.50092 .95249 L
.50077 .98077 L
F
0 g
.98037 .98077 m
.95249 .95295 L
.95203 .95249 L
.92421 .92477 L
.92365 .92421 L
.89593 .89662 L
.89525 .89593 L
.86765 .86851 L
.8668 .86765 L
.83937 .84047 L
.83829 .83937 L
.81109 .81252 L
.8097 .81109 L
.78281 .78471 L
.78098 .78281 L
.75452 .75714 L
.75205 .75452 L
.72624 .72996 L
.72281 .72624 L
.69796 .70349 L
.69303 .69796 L
.66968 .67833 L
.6623 .66968 L
.6414 .65569 L
.62276 .6414 L
.61312 .63702 L
.58484 .62484 L
.55656 .62475 L
.52936 .6414 L
.52828 .6466 L
.51757 .66968 L
.511 .69796 L
.50737 .72624 L
.50518 .75452 L
.50377 .78281 L
.50284 .81109 L
.50219 .83937 L
.50172 .86765 L
.50138 .89593 L
.50112 .92421 L
.50092 .95249 L
.50077 .98077 L
s
0 1 .537 r
.97434 .01923 m
.95249 .04037 L
.94497 .04751 L
.92421 .06706 L
.91502 .07579 L
.89593 .09343 L
.88451 .10407 L
.86765 .11922 L
.85315 .13235 L
.83937 .14423 L
.82043 .16063 L
.81109 .16819 L
.7853 .18891 L
.78281 .19074 L
.75452 .21115 L
.74623 .21719 L
.72624 .22876 L
.69796 .24293 L
.69171 .24548 L
.66968 .25221 L
.6414 .25572 L
.61312 .25185 L
.59455 .24548 L
.58484 .23784 L
.56357 .21719 L
.55656 .2071 L
.54644 .18891 L
.53536 .16063 L
.52828 .13493 L
.52768 .13235 L
.5221 .10407 L
.51795 .07579 L
.51478 .04751 L
.51231 .01923 L
F
0 g
.97434 .01923 m
.95249 .04037 L
.94497 .04751 L
.92421 .06706 L
.91502 .07579 L
.89593 .09343 L
.88451 .10407 L
.86765 .11922 L
.85315 .13235 L
.83937 .14423 L
.82043 .16063 L
.81109 .16819 L
.7853 .18891 L
.78281 .19074 L
.75452 .21115 L
.74623 .21719 L
.72624 .22876 L
.69796 .24293 L
.69171 .24548 L
.66968 .25221 L
.6414 .25572 L
.61312 .25185 L
.59455 .24548 L
.58484 .23784 L
.56357 .21719 L
.55656 .2071 L
.54644 .18891 L
.53536 .16063 L
.52828 .13493 L
.52768 .13235 L
.5221 .10407 L
.51795 .07579 L
.51478 .04751 L
.51231 .01923 L
s
0 .537 1 r
.97434 .98077 m
.95249 .95963 L
.94497 .95249 L
.92421 .93294 L
.91502 .92421 L
.89593 .90657 L
.88451 .89593 L
.86765 .88078 L
.85315 .86765 L
.83937 .85577 L
.82043 .83937 L
.81109 .83181 L
.7853 .81109 L
.78281 .80926 L
.75452 .78885 L
.74623 .78281 L
.72624 .77124 L
.69796 .75707 L
.69171 .75452 L
.66968 .74779 L
.6414 .74428 L
.61312 .74815 L
.59455 .75452 L
.58484 .76216 L
.56357 .78281 L
.55656 .7929 L
.54644 .81109 L
.53536 .83937 L
.52828 .86507 L
.52768 .86765 L
.5221 .89593 L
.51795 .92421 L
.51478 .95249 L
.51231 .98077 L
F
0 g
.97434 .98077 m
.95249 .95963 L
.94497 .95249 L
.92421 .93294 L
.91502 .92421 L
.89593 .90657 L
.88451 .89593 L
.86765 .88078 L
.85315 .86765 L
.83937 .85577 L
.82043 .83937 L
.81109 .83181 L
.7853 .81109 L
.78281 .80926 L
.75452 .78885 L
.74623 .78281 L
.72624 .77124 L
.69796 .75707 L
.69171 .75452 L
.66968 .74779 L
.6414 .74428 L
.61312 .74815 L
.59455 .75452 L
.58484 .76216 L
.56357 .78281 L
.55656 .7929 L
.54644 .81109 L
.53536 .83937 L
.52828 .86507 L
.52768 .86765 L
.5221 .89593 L
.51795 .92421 L
.51478 .95249 L
.51231 .98077 L
s
.061 1 0 r
.96058 .01923 m
.95249 .02653 L
.92794 .04751 L
.92421 .05062 L
.89593 .07386 L
.89357 .07579 L
.86765 .09579 L
.85666 .10407 L
.83937 .11611 L
.81464 .13235 L
.81109 .13445 L
.78281 .15019 L
.7608 .16063 L
.75452 .16292 L
.72624 .17188 L
.69796 .17652 L
.66968 .17595 L
.6414 .16904 L
.62295 .16063 L
.61312 .15389 L
.58956 .13235 L
.58484 .1266 L
.56961 .10407 L
.55656 .07752 L
.55584 .07579 L
.54567 .04751 L
.53792 .01923 L
F
0 g
.96058 .01923 m
.95249 .02653 L
.92794 .04751 L
.92421 .05062 L
.89593 .07386 L
.89357 .07579 L
.86765 .09579 L
.85666 .10407 L
.83937 .11611 L
.81464 .13235 L
.81109 .13445 L
.78281 .15019 L
.7608 .16063 L
.75452 .16292 L
.72624 .17188 L
.69796 .17652 L
.66968 .17595 L
.6414 .16904 L
.62295 .16063 L
.61312 .15389 L
.58956 .13235 L
.58484 .1266 L
.56961 .10407 L
.55656 .07752 L
.55584 .07579 L
.54567 .04751 L
.53792 .01923 L
s
.061 0 1 r
.96058 .98077 m
.95249 .97347 L
.92794 .95249 L
.92421 .94938 L
.89593 .92614 L
.89357 .92421 L
.86765 .90421 L
.85666 .89593 L
.83937 .88389 L
.81464 .86765 L
.81109 .86555 L
.78281 .84981 L
.7608 .83937 L
.75452 .83708 L
.72624 .82812 L
.69796 .82348 L
.66968 .82405 L
.6414 .83096 L
.62295 .83937 L
.61312 .84611 L
.58956 .86765 L
.58484 .8734 L
.56961 .89593 L
.55656 .92248 L
.55584 .92421 L
.54567 .95249 L
.53792 .98077 L
F
0 g
.96058 .98077 m
.95249 .97347 L
.92794 .95249 L
.92421 .94938 L
.89593 .92614 L
.89357 .92421 L
.86765 .90421 L
.85666 .89593 L
.83937 .88389 L
.81464 .86765 L
.81109 .86555 L
.78281 .84981 L
.7608 .83937 L
.75452 .83708 L
.72624 .82812 L
.69796 .82348 L
.66968 .82405 L
.6414 .83096 L
.62295 .83937 L
.61312 .84611 L
.58956 .86765 L
.58484 .8734 L
.56961 .89593 L
.55656 .92248 L
.55584 .92421 L
.54567 .95249 L
.53792 .98077 L
s
.915 1 0 r
.93642 .01923 m
.92421 .02824 L
.89634 .04751 L
.89593 .04778 L
.86765 .06558 L
.85 .07579 L
.83937 .08125 L
.81109 .09436 L
.78444 .10407 L
.78281 .10451 L
.75452 .11117 L
.72624 .1139 L
.69796 .11204 L
.66968 .10473 L
.66784 .10407 L
.6414 .09054 L
.62201 .07579 L
.61312 .06713 L
.59665 .04751 L
.58484 .02955 L
.57905 .01923 L
F
0 g
.93642 .01923 m
.92421 .02824 L
.89634 .04751 L
.89593 .04778 L
.86765 .06558 L
.85 .07579 L
.83937 .08125 L
.81109 .09436 L
.78444 .10407 L
.78281 .10451 L
.75452 .11117 L
.72624 .1139 L
.69796 .11204 L
.66968 .10473 L
.66784 .10407 L
.6414 .09054 L
.62201 .07579 L
.61312 .06713 L
.59665 .04751 L
.58484 .02955 L
.57905 .01923 L
s
.915 0 1 r
.93642 .98077 m
.92421 .97176 L
.89634 .95249 L
.89593 .95222 L
.86765 .93442 L
.85 .92421 L
.83937 .91875 L
.81109 .90564 L
.78444 .89593 L
.78281 .89549 L
.75452 .88883 L
.72624 .8861 L
.69796 .88796 L
.66968 .89527 L
.66784 .89593 L
.6414 .90946 L
.62201 .92421 L
.61312 .93287 L
.59665 .95249 L
.58484 .97045 L
.57905 .98077 L
F
0 g
.93642 .98077 m
.92421 .97176 L
.89634 .95249 L
.89593 .95222 L
.86765 .93442 L
.85 .92421 L
.83937 .91875 L
.81109 .90564 L
.78444 .89593 L
.78281 .89549 L
.75452 .88883 L
.72624 .8861 L
.69796 .88796 L
.66968 .89527 L
.66784 .89593 L
.6414 .90946 L
.62201 .92421 L
.61312 .93287 L
.59665 .95249 L
.58484 .97045 L
.57905 .98077 L
s
0 .879 1 r
.98077 .49923 m
.95249 .49908 L
.92421 .49888 L
.89593 .49862 L
.86765 .49828 L
.83937 .49781 L
.81109 .49716 L
.78281 .49623 L
.75452 .49482 L
.72624 .49263 L
.69796 .489 L
.66968 .48243 L
.6466 .47172 L
.6414 .47064 L
.62475 .44344 L
.62484 .41516 L
.63702 .38688 L
.6414 .37724 L
.65569 .3586 L
.66968 .3377 L
.67833 .33032 L
.69796 .30697 L
.70349 .30204 L
.72624 .27719 L
.72996 .27376 L
.75452 .24795 L
.75714 .24548 L
.78281 .21902 L
.78471 .21719 L
.81109 .1903 L
.81252 .18891 L
.83937 .16171 L
.84047 .16063 L
.86765 .1332 L
.86851 .13235 L
.89593 .10475 L
.89662 .10407 L
.92421 .07635 L
.92477 .07579 L
.95249 .04797 L
.95295 .04751 L
.98077 .01963 L
F
0 g
.98077 .49923 m
.95249 .49908 L
.92421 .49888 L
.89593 .49862 L
.86765 .49828 L
.83937 .49781 L
.81109 .49716 L
.78281 .49623 L
.75452 .49482 L
.72624 .49263 L
.69796 .489 L
.66968 .48243 L
.6466 .47172 L
.6414 .47064 L
.62475 .44344 L
.62484 .41516 L
.63702 .38688 L
.6414 .37724 L
.65569 .3586 L
.66968 .3377 L
.67833 .33032 L
.69796 .30697 L
.70349 .30204 L
.72624 .27719 L
.72996 .27376 L
.75452 .24795 L
.75714 .24548 L
.78281 .21902 L
.78471 .21719 L
.81109 .1903 L
.81252 .18891 L
.83937 .16171 L
.84047 .16063 L
.86765 .1332 L
.86851 .13235 L
.89593 .10475 L
.89662 .10407 L
.92421 .07635 L
.92477 .07579 L
.95249 .04797 L
.95295 .04751 L
.98077 .01963 L
s
0 1 .879 r
.98077 .98037 m
.95295 .95249 L
.95249 .95203 L
.92477 .92421 L
.92421 .92365 L
.89662 .89593 L
.89593 .89525 L
.86851 .86765 L
.86765 .8668 L
.84047 .83937 L
.83937 .83829 L
.81252 .81109 L
.81109 .8097 L
.78471 .78281 L
.78281 .78098 L
.75714 .75452 L
.75452 .75205 L
.72996 .72624 L
.72624 .72281 L
.70349 .69796 L
.69796 .69303 L
.67833 .66968 L
.66968 .6623 L
.65569 .6414 L
.6414 .62276 L
.63702 .61312 L
.62484 .58484 L
.62475 .55656 L
.6414 .52936 L
.6466 .52828 L
.66968 .51757 L
.69796 .511 L
.72624 .50737 L
.75452 .50518 L
.78281 .50377 L
.81109 .50284 L
.83937 .50219 L
.86765 .50172 L
.89593 .50138 L
.92421 .50112 L
.95249 .50092 L
.98077 .50077 L
F
0 g
.98077 .98037 m
.95295 .95249 L
.95249 .95203 L
.92477 .92421 L
.92421 .92365 L
.89662 .89593 L
.89593 .89525 L
.86851 .86765 L
.86765 .8668 L
.84047 .83937 L
.83937 .83829 L
.81252 .81109 L
.81109 .8097 L
.78471 .78281 L
.78281 .78098 L
.75714 .75452 L
.75452 .75205 L
.72996 .72624 L
.72624 .72281 L
.70349 .69796 L
.69796 .69303 L
.67833 .66968 L
.66968 .6623 L
.65569 .6414 L
.6414 .62276 L
.63702 .61312 L
.62484 .58484 L
.62475 .55656 L
.6414 .52936 L
.6466 .52828 L
.66968 .51757 L
.69796 .511 L
.72624 .50737 L
.75452 .50518 L
.78281 .50377 L
.81109 .50284 L
.83937 .50219 L
.86765 .50172 L
.89593 .50138 L
.92421 .50112 L
.95249 .50092 L
.98077 .50077 L
s
1 0 0 r
.89348 .01923 m
.86765 .03198 L
.83937 .04349 L
.82881 .04751 L
.81109 .05223 L
.78281 .05782 L
.75452 .05983 L
.72624 .05775 L
.69796 .0509 L
.68843 .04751 L
.66968 .03831 L
.64251 .01923 L
F
0 g
.89348 .01923 m
.86765 .03198 L
.83937 .04349 L
.82881 .04751 L
.81109 .05223 L
.78281 .05782 L
.75452 .05983 L
.72624 .05775 L
.69796 .0509 L
.68843 .04751 L
.66968 .03831 L
.64251 .01923 L
s
1 0 0 r
.89348 .98077 m
.86765 .96802 L
.83937 .95651 L
.82881 .95249 L
.81109 .94777 L
.78281 .94218 L
.75452 .94017 L
.72624 .94225 L
.69796 .9491 L
.68843 .95249 L
.66968 .96169 L
.64251 .98077 L
F
0 g
.89348 .98077 m
.86765 .96802 L
.83937 .95651 L
.82881 .95249 L
.81109 .94777 L
.78281 .94218 L
.75452 .94017 L
.72624 .94225 L
.69796 .9491 L
.68843 .95249 L
.66968 .96169 L
.64251 .98077 L
s
0 .537 1 r
.98077 .48769 m
.95249 .48522 L
.92421 .48205 L
.89593 .4779 L
.86765 .47232 L
.86507 .47172 L
.83937 .46464 L
.81109 .45356 L
.7929 .44344 L
.78281 .43643 L
.76216 .41516 L
.75452 .40545 L
.74815 .38688 L
.74428 .3586 L
.74779 .33032 L
.75452 .30829 L
.75707 .30204 L
.77124 .27376 L
.78281 .25377 L
.78885 .24548 L
.80926 .21719 L
.81109 .2147 L
.83181 .18891 L
.83937 .17957 L
.85577 .16063 L
.86765 .14685 L
.88078 .13235 L
.89593 .11549 L
.90657 .10407 L
.92421 .08498 L
.93294 .07579 L
.95249 .05503 L
.95963 .04751 L
.98077 .02566 L
F
0 g
.98077 .48769 m
.95249 .48522 L
.92421 .48205 L
.89593 .4779 L
.86765 .47232 L
.86507 .47172 L
.83937 .46464 L
.81109 .45356 L
.7929 .44344 L
.78281 .43643 L
.76216 .41516 L
.75452 .40545 L
.74815 .38688 L
.74428 .3586 L
.74779 .33032 L
.75452 .30829 L
.75707 .30204 L
.77124 .27376 L
.78281 .25377 L
.78885 .24548 L
.80926 .21719 L
.81109 .2147 L
.83181 .18891 L
.83937 .17957 L
.85577 .16063 L
.86765 .14685 L
.88078 .13235 L
.89593 .11549 L
.90657 .10407 L
.92421 .08498 L
.93294 .07579 L
.95249 .05503 L
.95963 .04751 L
.98077 .02566 L
s
0 1 .537 r
.98077 .97434 m
.95963 .95249 L
.95249 .94497 L
.93294 .92421 L
.92421 .91502 L
.90657 .89593 L
.89593 .88451 L
.88078 .86765 L
.86765 .85315 L
.85577 .83937 L
.83937 .82043 L
.83181 .81109 L
.81109 .7853 L
.80926 .78281 L
.78885 .75452 L
.78281 .74623 L
.77124 .72624 L
.75707 .69796 L
.75452 .69171 L
.74779 .66968 L
.74428 .6414 L
.74815 .61312 L
.75452 .59455 L
.76216 .58484 L
.78281 .56357 L
.7929 .55656 L
.81109 .54644 L
.83937 .53536 L
.86507 .52828 L
.86765 .52768 L
.89593 .5221 L
.92421 .51795 L
.95249 .51478 L
.98077 .51231 L
F
0 g
.98077 .97434 m
.95963 .95249 L
.95249 .94497 L
.93294 .92421 L
.92421 .91502 L
.90657 .89593 L
.89593 .88451 L
.88078 .86765 L
.86765 .85315 L
.85577 .83937 L
.83937 .82043 L
.83181 .81109 L
.81109 .7853 L
.80926 .78281 L
.78885 .75452 L
.78281 .74623 L
.77124 .72624 L
.75707 .69796 L
.75452 .69171 L
.74779 .66968 L
.74428 .6414 L
.74815 .61312 L
.75452 .59455 L
.76216 .58484 L
.78281 .56357 L
.7929 .55656 L
.81109 .54644 L
.83937 .53536 L
.86507 .52828 L
.86765 .52768 L
.89593 .5221 L
.92421 .51795 L
.95249 .51478 L
.98077 .51231 L
s
.061 1 0 r
.98077 .96058 m
.97347 .95249 L
.95249 .92794 L
.94938 .92421 L
.92614 .89593 L
.92421 .89357 L
.90421 .86765 L
.89593 .85666 L
.88389 .83937 L
.86765 .81464 L
.86555 .81109 L
.84981 .78281 L
.83937 .7608 L
.83708 .75452 L
.82812 .72624 L
.82348 .69796 L
.82405 .66968 L
.83096 .6414 L
.83937 .62295 L
.84611 .61312 L
.86765 .58956 L
.8734 .58484 L
.89593 .56961 L
.92248 .55656 L
.92421 .55584 L
.95249 .54567 L
.98077 .53792 L
F
0 g
.98077 .96058 m
.97347 .95249 L
.95249 .92794 L
.94938 .92421 L
.92614 .89593 L
.92421 .89357 L
.90421 .86765 L
.89593 .85666 L
.88389 .83937 L
.86765 .81464 L
.86555 .81109 L
.84981 .78281 L
.83937 .7608 L
.83708 .75452 L
.82812 .72624 L
.82348 .69796 L
.82405 .66968 L
.83096 .6414 L
.83937 .62295 L
.84611 .61312 L
.86765 .58956 L
.8734 .58484 L
.89593 .56961 L
.92248 .55656 L
.92421 .55584 L
.95249 .54567 L
.98077 .53792 L
s
.061 0 1 r
.98077 .46208 m
.95249 .45433 L
.92421 .44416 L
.92248 .44344 L
.89593 .43039 L
.8734 .41516 L
.86765 .41044 L
.84611 .38688 L
.83937 .37705 L
.83096 .3586 L
.82405 .33032 L
.82348 .30204 L
.82812 .27376 L
.83708 .24548 L
.83937 .2392 L
.84981 .21719 L
.86555 .18891 L
.86765 .18536 L
.88389 .16063 L
.89593 .14334 L
.90421 .13235 L
.92421 .10643 L
.92614 .10407 L
.94938 .07579 L
.95249 .07206 L
.97347 .04751 L
.98077 .03942 L
F
0 g
.98077 .46208 m
.95249 .45433 L
.92421 .44416 L
.92248 .44344 L
.89593 .43039 L
.8734 .41516 L
.86765 .41044 L
.84611 .38688 L
.83937 .37705 L
.83096 .3586 L
.82405 .33032 L
.82348 .30204 L
.82812 .27376 L
.83708 .24548 L
.83937 .2392 L
.84981 .21719 L
.86555 .18891 L
.86765 .18536 L
.88389 .16063 L
.89593 .14334 L
.90421 .13235 L
.92421 .10643 L
.92614 .10407 L
.94938 .07579 L
.95249 .07206 L
.97347 .04751 L
.98077 .03942 L
s
.915 0 1 r
.98077 .42095 m
.97045 .41516 L
.95249 .40335 L
.93287 .38688 L
.92421 .37799 L
.90946 .3586 L
.89593 .33216 L
.89527 .33032 L
.88796 .30204 L
.8861 .27376 L
.88883 .24548 L
.89549 .21719 L
.89593 .21556 L
.90564 .18891 L
.91875 .16063 L
.92421 .15 L
.93442 .13235 L
.95222 .10407 L
.95249 .10366 L
.97176 .07579 L
.98077 .06358 L
F
0 g
.98077 .42095 m
.97045 .41516 L
.95249 .40335 L
.93287 .38688 L
.92421 .37799 L
.90946 .3586 L
.89593 .33216 L
.89527 .33032 L
.88796 .30204 L
.8861 .27376 L
.88883 .24548 L
.89549 .21719 L
.89593 .21556 L
.90564 .18891 L
.91875 .16063 L
.92421 .15 L
.93442 .13235 L
.95222 .10407 L
.95249 .10366 L
.97176 .07579 L
.98077 .06358 L
s
.915 1 0 r
.98077 .93642 m
.97176 .92421 L
.95249 .89634 L
.95222 .89593 L
.93442 .86765 L
.92421 .85 L
.91875 .83937 L
.90564 .81109 L
.89593 .78444 L
.89549 .78281 L
.88883 .75452 L
.8861 .72624 L
.88796 .69796 L
.89527 .66968 L
.89593 .66784 L
.90946 .6414 L
.92421 .62201 L
.93287 .61312 L
.95249 .59665 L
.97045 .58484 L
.98077 .57905 L
F
0 g
.98077 .93642 m
.97176 .92421 L
.95249 .89634 L
.95222 .89593 L
.93442 .86765 L
.92421 .85 L
.91875 .83937 L
.90564 .81109 L
.89593 .78444 L
.89549 .78281 L
.88883 .75452 L
.8861 .72624 L
.88796 .69796 L
.89527 .66968 L
.89593 .66784 L
.90946 .6414 L
.92421 .62201 L
.93287 .61312 L
.95249 .59665 L
.97045 .58484 L
.98077 .57905 L
s
1 0 0 r
.98077 .35749 m
.96169 .33032 L
.95249 .31157 L
.9491 .30204 L
.94225 .27376 L
.94017 .24548 L
.94218 .21719 L
.94777 .18891 L
.95249 .17119 L
.95651 .16063 L
.96802 .13235 L
.98077 .10652 L
F
0 g
.98077 .35749 m
.96169 .33032 L
.95249 .31157 L
.9491 .30204 L
.94225 .27376 L
.94017 .24548 L
.94218 .21719 L
.94777 .18891 L
.95249 .17119 L
.95651 .16063 L
.96802 .13235 L
.98077 .10652 L
s
1 0 0 r
.98077 .89348 m
.96802 .86765 L
.95651 .83937 L
.95249 .82881 L
.94777 .81109 L
.94218 .78281 L
.94017 .75452 L
.94225 .72624 L
.9491 .69796 L
.95249 .68843 L
.96169 .66968 L
.98077 .64251 L
F
0 g
.98077 .89348 m
.96802 .86765 L
.95651 .83937 L
.95249 .82881 L
.94777 .81109 L
.94218 .78281 L
.94017 .75452 L
.94225 .72624 L
.9491 .69796 L
.95249 .68843 L
.96169 .66968 L
.98077 .64251 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{222, 222},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
  ImageRangeCache->{{{0, 221}, {221, 0}} -> {-2, -2, 0, 0}}],
 StyleBox["               ",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.192308 0.5 0.192308 [
[.11538 -0.0125 -6 -9 ]
[.11538 -0.0125 6 0 ]
[.30769 -0.0125 -6 -9 ]
[.30769 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69231 -0.0125 -3 -9 ]
[.69231 -0.0125 3 0 ]
[.88462 -0.0125 -3 -9 ]
[.88462 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .11538 -12 -4.5 ]
[-0.0125 .11538 0 4.5 ]
[-0.0125 .30769 -12 -4.5 ]
[-0.0125 .30769 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .69231 -6 -4.5 ]
[-0.0125 .69231 0 4.5 ]
[-0.0125 .88462 -6 -4.5 ]
[-0.0125 .88462 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11538 0 m
.11538 .00625 L
s
[(-2)] .11538 -0.0125 0 1 Mshowa
.30769 0 m
.30769 .00625 L
s
[(-1)] .30769 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69231 0 m
.69231 .00625 L
s
[(1)] .69231 -0.0125 0 1 Mshowa
.88462 0 m
.88462 .00625 L
s
[(2)] .88462 -0.0125 0 1 Mshowa
.125 Mabswid
.15385 0 m
.15385 .00375 L
s
.19231 0 m
.19231 .00375 L
s
.23077 0 m
.23077 .00375 L
s
.26923 0 m
.26923 .00375 L
s
.34615 0 m
.34615 .00375 L
s
.38462 0 m
.38462 .00375 L
s
.42308 0 m
.42308 .00375 L
s
.46154 0 m
.46154 .00375 L
s
.53846 0 m
.53846 .00375 L
s
.57692 0 m
.57692 .00375 L
s
.61538 0 m
.61538 .00375 L
s
.65385 0 m
.65385 .00375 L
s
.73077 0 m
.73077 .00375 L
s
.76923 0 m
.76923 .00375 L
s
.80769 0 m
.80769 .00375 L
s
.84615 0 m
.84615 .00375 L
s
.07692 0 m
.07692 .00375 L
s
.03846 0 m
.03846 .00375 L
s
.92308 0 m
.92308 .00375 L
s
.96154 0 m
.96154 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .11538 m
.00625 .11538 L
s
[(-2)] -0.0125 .11538 1 0 Mshowa
0 .30769 m
.00625 .30769 L
s
[(-1)] -0.0125 .30769 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .69231 m
.00625 .69231 L
s
[(1)] -0.0125 .69231 1 0 Mshowa
0 .88462 m
.00625 .88462 L
s
[(2)] -0.0125 .88462 1 0 Mshowa
.125 Mabswid
0 .15385 m
.00375 .15385 L
s
0 .19231 m
.00375 .19231 L
s
0 .23077 m
.00375 .23077 L
s
0 .26923 m
.00375 .26923 L
s
0 .34615 m
.00375 .34615 L
s
0 .38462 m
.00375 .38462 L
s
0 .42308 m
.00375 .42308 L
s
0 .46154 m
.00375 .46154 L
s
0 .53846 m
.00375 .53846 L
s
0 .57692 m
.00375 .57692 L
s
0 .61538 m
.00375 .61538 L
s
0 .65385 m
.00375 .65385 L
s
0 .73077 m
.00375 .73077 L
s
0 .76923 m
.00375 .76923 L
s
0 .80769 m
.00375 .80769 L
s
0 .84615 m
.00375 .84615 L
s
0 .07692 m
.00375 .07692 L
s
0 .03846 m
.00375 .03846 L
s
0 .92308 m
.00375 .92308 L
s
0 .96154 m
.00375 .96154 L
s
.25 Mabswid
0 0 m
0 1 L
s
.11538 .99375 m
.11538 1 L
s
.30769 .99375 m
.30769 1 L
s
.5 .99375 m
.5 1 L
s
.69231 .99375 m
.69231 1 L
s
.88462 .99375 m
.88462 1 L
s
.125 Mabswid
.15385 .99625 m
.15385 1 L
s
.19231 .99625 m
.19231 1 L
s
.23077 .99625 m
.23077 1 L
s
.26923 .99625 m
.26923 1 L
s
.34615 .99625 m
.34615 1 L
s
.38462 .99625 m
.38462 1 L
s
.42308 .99625 m
.42308 1 L
s
.46154 .99625 m
.46154 1 L
s
.53846 .99625 m
.53846 1 L
s
.57692 .99625 m
.57692 1 L
s
.61538 .99625 m
.61538 1 L
s
.65385 .99625 m
.65385 1 L
s
.73077 .99625 m
.73077 1 L
s
.76923 .99625 m
.76923 1 L
s
.80769 .99625 m
.80769 1 L
s
.84615 .99625 m
.84615 1 L
s
.07692 .99625 m
.07692 1 L
s
.03846 .99625 m
.03846 1 L
s
.92308 .99625 m
.92308 1 L
s
.96154 .99625 m
.96154 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .11538 m
1 .11538 L
s
.99375 .30769 m
1 .30769 L
s
.99375 .5 m
1 .5 L
s
.99375 .69231 m
1 .69231 L
s
.99375 .88462 m
1 .88462 L
s
.125 Mabswid
.99625 .15385 m
1 .15385 L
s
.99625 .19231 m
1 .19231 L
s
.99625 .23077 m
1 .23077 L
s
.99625 .26923 m
1 .26923 L
s
.99625 .34615 m
1 .34615 L
s
.99625 .38462 m
1 .38462 L
s
.99625 .42308 m
1 .42308 L
s
.99625 .46154 m
1 .46154 L
s
.99625 .53846 m
1 .53846 L
s
.99625 .57692 m
1 .57692 L
s
.99625 .61538 m
1 .61538 L
s
.99625 .65385 m
1 .65385 L
s
.99625 .73077 m
1 .73077 L
s
.99625 .76923 m
1 .76923 L
s
.99625 .80769 m
1 .80769 L
s
.99625 .84615 m
1 .84615 L
s
.99625 .07692 m
1 .07692 L
s
.99625 .03846 m
1 .03846 L
s
.99625 .92308 m
1 .92308 L
s
.99625 .96154 m
1 .96154 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.129 0 1 r
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.035 0 1 r
.01923 .6998 m
.02464 .69796 L
.04751 .68824 L
.07579 .67669 L
.09266 .66968 L
.10407 .6652 L
.13235 .6538 L
.16063 .64243 L
.16287 .6414 L
.18891 .63135 L
.21719 .6204 L
.23529 .61312 L
.24548 .60987 L
.27376 .60006 L
.30204 .59111 L
.32644 .58484 L
.33032 .58414 L
.3586 .58116 L
.38567 .58484 L
.38688 .5853 L
.4147 .61312 L
.41516 .61433 L
.41884 .6414 L
.41586 .66968 L
.41516 .67356 L
.40889 .69796 L
.39994 .72624 L
.39013 .75452 L
.38688 .76471 L
.3796 .78281 L
.36865 .81109 L
.3586 .83713 L
.35757 .83937 L
.3462 .86765 L
.3348 .89593 L
.33032 .90734 L
.32331 .92421 L
.31176 .95249 L
.30204 .97536 L
.3002 .98077 L
.01923 .98077 L
F
0 g
.01923 .6998 m
.02464 .69796 L
.04751 .68824 L
.07579 .67669 L
.09266 .66968 L
.10407 .6652 L
.13235 .6538 L
.16063 .64243 L
.16287 .6414 L
.18891 .63135 L
.21719 .6204 L
.23529 .61312 L
.24548 .60987 L
.27376 .60006 L
.30204 .59111 L
.32644 .58484 L
.33032 .58414 L
.3586 .58116 L
.38567 .58484 L
.38688 .5853 L
.4147 .61312 L
.41516 .61433 L
.41884 .6414 L
.41586 .66968 L
.41516 .67356 L
.40889 .69796 L
.39994 .72624 L
.39013 .75452 L
.38688 .76471 L
.3796 .78281 L
.36865 .81109 L
.3586 .83713 L
.35757 .83937 L
.3462 .86765 L
.3348 .89593 L
.33032 .90734 L
.32331 .92421 L
.31176 .95249 L
.30204 .97536 L
.3002 .98077 L
s
.035 0 1 r
.01923 .3002 m
.02464 .30204 L
.04751 .31176 L
.07579 .32331 L
.09266 .33032 L
.10407 .3348 L
.13235 .3462 L
.16063 .35757 L
.16287 .3586 L
.18891 .36865 L
.21719 .3796 L
.23529 .38688 L
.24548 .39013 L
.27376 .39994 L
.30204 .40889 L
.32644 .41516 L
.33032 .41586 L
.3586 .41884 L
.38567 .41516 L
.38688 .4147 L
.4147 .38688 L
.41516 .38567 L
.41884 .3586 L
.41586 .33032 L
.41516 .32644 L
.40889 .30204 L
.39994 .27376 L
.39013 .24548 L
.38688 .23529 L
.3796 .21719 L
.36865 .18891 L
.3586 .16287 L
.35757 .16063 L
.3462 .13235 L
.3348 .10407 L
.33032 .09266 L
.32331 .07579 L
.31176 .04751 L
.30204 .02464 L
.3002 .01923 L
.01923 .01923 L
F
0 g
.01923 .3002 m
.02464 .30204 L
.04751 .31176 L
.07579 .32331 L
.09266 .33032 L
.10407 .3348 L
.13235 .3462 L
.16063 .35757 L
.16287 .3586 L
.18891 .36865 L
.21719 .3796 L
.23529 .38688 L
.24548 .39013 L
.27376 .39994 L
.30204 .40889 L
.32644 .41516 L
.33032 .41586 L
.3586 .41884 L
.38567 .41516 L
.38688 .4147 L
.4147 .38688 L
.41516 .38567 L
.41884 .3586 L
.41586 .33032 L
.41516 .32644 L
.40889 .30204 L
.39994 .27376 L
.39013 .24548 L
.38688 .23529 L
.3796 .21719 L
.36865 .18891 L
.3586 .16287 L
.35757 .16063 L
.3462 .13235 L
.3348 .10407 L
.33032 .09266 L
.32331 .07579 L
.31176 .04751 L
.30204 .02464 L
.3002 .01923 L
s
.223 0 1 r
.01923 .69848 m
.02081 .69796 L
.04751 .68667 L
.07579 .67477 L
.08751 .66968 L
.10407 .66286 L
.13235 .65086 L
.15408 .6414 L
.16063 .63873 L
.18891 .62651 L
.21719 .61388 L
.21853 .61312 L
.24548 .60114 L
.27376 .58727 L
.27707 .58484 L
.30204 .57276 L
.32576 .55656 L
.33032 .55576 L
.35458 .52828 L
.3586 .52196 L
.36275 .5 L
.3586 .47804 L
.35458 .47172 L
.33032 .44424 L
.32576 .44344 L
.30204 .42724 L
.27707 .41516 L
.27376 .41273 L
.24548 .39886 L
.21853 .38688 L
.21719 .38612 L
.18891 .37349 L
.16063 .36127 L
.15408 .3586 L
.13235 .34914 L
.10407 .33714 L
.08751 .33032 L
.07579 .32523 L
.04751 .31333 L
.02081 .30204 L
.01923 .30152 L
F
0 g
.01923 .69848 m
.02081 .69796 L
.04751 .68667 L
.07579 .67477 L
.08751 .66968 L
.10407 .66286 L
.13235 .65086 L
.15408 .6414 L
.16063 .63873 L
.18891 .62651 L
.21719 .61388 L
.21853 .61312 L
.24548 .60114 L
.27376 .58727 L
.27707 .58484 L
.30204 .57276 L
.32576 .55656 L
.33032 .55576 L
.35458 .52828 L
.3586 .52196 L
.36275 .5 L
.3586 .47804 L
.35458 .47172 L
.33032 .44424 L
.32576 .44344 L
.30204 .42724 L
.27707 .41516 L
.27376 .41273 L
.24548 .39886 L
.21853 .38688 L
.21719 .38612 L
.18891 .37349 L
.16063 .36127 L
.15408 .3586 L
.13235 .34914 L
.10407 .33714 L
.08751 .33032 L
.07579 .32523 L
.04751 .31333 L
.02081 .30204 L
.01923 .30152 L
s
0 .23 1 r
.01923 .29057 m
.04751 .30032 L
.05233 .30204 L
.07579 .30951 L
.10407 .31801 L
.13235 .32559 L
.15149 .33032 L
.16063 .33186 L
.18891 .3363 L
.21719 .33823 L
.24548 .33655 L
.27171 .33032 L
.27376 .32941 L
.30204 .31288 L
.31288 .30204 L
.32941 .27376 L
.33032 .27171 L
.33655 .24548 L
.33823 .21719 L
.3363 .18891 L
.33186 .16063 L
.33032 .15149 L
.32559 .13235 L
.31801 .10407 L
.30951 .07579 L
.30204 .05233 L
.30032 .04751 L
.29057 .01923 L
.01923 .01923 L
F
0 g
.01923 .29057 m
.04751 .30032 L
.05233 .30204 L
.07579 .30951 L
.10407 .31801 L
.13235 .32559 L
.15149 .33032 L
.16063 .33186 L
.18891 .3363 L
.21719 .33823 L
.24548 .33655 L
.27171 .33032 L
.27376 .32941 L
.30204 .31288 L
.31288 .30204 L
.32941 .27376 L
.33032 .27171 L
.33655 .24548 L
.33823 .21719 L
.3363 .18891 L
.33186 .16063 L
.33032 .15149 L
.32559 .13235 L
.31801 .10407 L
.30951 .07579 L
.30204 .05233 L
.30032 .04751 L
.29057 .01923 L
s
0 .23 1 r
.01923 .70943 m
.04751 .69968 L
.05233 .69796 L
.07579 .69049 L
.10407 .68199 L
.13235 .67441 L
.15149 .66968 L
.16063 .66814 L
.18891 .6637 L
.21719 .66177 L
.24548 .66345 L
.27171 .66968 L
.27376 .67059 L
.30204 .68712 L
.31288 .69796 L
.32941 .72624 L
.33032 .72829 L
.33655 .75452 L
.33823 .78281 L
.3363 .81109 L
.33186 .83937 L
.33032 .84851 L
.32559 .86765 L
.31801 .89593 L
.30951 .92421 L
.30204 .94767 L
.30032 .95249 L
.29057 .98077 L
.01923 .98077 L
F
0 g
.01923 .70943 m
.04751 .69968 L
.05233 .69796 L
.07579 .69049 L
.10407 .68199 L
.13235 .67441 L
.15149 .66968 L
.16063 .66814 L
.18891 .6637 L
.21719 .66177 L
.24548 .66345 L
.27171 .66968 L
.27376 .67059 L
.30204 .68712 L
.31288 .69796 L
.32941 .72624 L
.33032 .72829 L
.33655 .75452 L
.33823 .78281 L
.3363 .81109 L
.33186 .83937 L
.33032 .84851 L
.32559 .86765 L
.31801 .89593 L
.30951 .92421 L
.30204 .94767 L
.30032 .95249 L
.29057 .98077 L
s
0 .695 1 r
.01923 .27065 m
.0459 .27376 L
.04751 .27688 L
.07579 .28179 L
.10407 .28502 L
.13235 .28604 L
.16063 .28416 L
.18891 .27831 L
.20231 .27376 L
.21719 .26673 L
.24548 .24573 L
.24573 .24548 L
.26673 .21719 L
.27376 .20231 L
.27831 .18891 L
.28416 .16063 L
.28604 .13235 L
.28502 .10407 L
.28179 .07579 L
.27688 .04751 L
.27376 .0459 L
.27065 .01923 L
.01923 .01923 L
F
0 g
.01923 .27065 m
.0459 .27376 L
.04751 .27688 L
.07579 .28179 L
.10407 .28502 L
.13235 .28604 L
.16063 .28416 L
.18891 .27831 L
.20231 .27376 L
.21719 .26673 L
.24548 .24573 L
.24573 .24548 L
.26673 .21719 L
.27376 .20231 L
.27831 .18891 L
.28416 .16063 L
.28604 .13235 L
.28502 .10407 L
.28179 .07579 L
.27688 .04751 L
.27376 .0459 L
.27065 .01923 L
s
0 .695 1 r
.01923 .72935 m
.0459 .72624 L
.04751 .72312 L
.07579 .71821 L
.10407 .71498 L
.13235 .71396 L
.16063 .71584 L
.18891 .72169 L
.20231 .72624 L
.21719 .73327 L
.24548 .75427 L
.24573 .75452 L
.26673 .78281 L
.27376 .79769 L
.27831 .81109 L
.28416 .83937 L
.28604 .86765 L
.28502 .89593 L
.28179 .92421 L
.27688 .95249 L
.27376 .9541 L
.27065 .98077 L
.01923 .98077 L
F
0 g
.01923 .72935 m
.0459 .72624 L
.04751 .72312 L
.07579 .71821 L
.10407 .71498 L
.13235 .71396 L
.16063 .71584 L
.18891 .72169 L
.20231 .72624 L
.21719 .73327 L
.24548 .75427 L
.24573 .75452 L
.26673 .78281 L
.27376 .79769 L
.27831 .81109 L
.28416 .83937 L
.28604 .86765 L
.28502 .89593 L
.28179 .92421 L
.27688 .95249 L
.27376 .9541 L
.27065 .98077 L
s
0 1 .642 r
.01923 .75759 m
.04751 .75582 L
.07579 .75623 L
.10407 .75942 L
.13235 .76625 L
.16063 .77808 L
.16891 .78281 L
.18891 .7975 L
.2025 .81109 L
.21719 .83109 L
.22192 .83937 L
.23375 .86765 L
.24058 .89593 L
.24377 .92421 L
.24418 .95249 L
.24241 .98077 L
.01923 .98077 L
F
0 g
.01923 .75759 m
.04751 .75582 L
.07579 .75623 L
.10407 .75942 L
.13235 .76625 L
.16063 .77808 L
.16891 .78281 L
.18891 .7975 L
.2025 .81109 L
.21719 .83109 L
.22192 .83937 L
.23375 .86765 L
.24058 .89593 L
.24377 .92421 L
.24418 .95249 L
.24241 .98077 L
s
0 1 .642 r
.01923 .24241 m
.04751 .24418 L
.07579 .24377 L
.10407 .24058 L
.13235 .23375 L
.16063 .22192 L
.16891 .21719 L
.18891 .2025 L
.2025 .18891 L
.21719 .16891 L
.22192 .16063 L
.23375 .13235 L
.24058 .10407 L
.24377 .07579 L
.24418 .04751 L
.24241 .01923 L
.01923 .01923 L
F
0 g
.01923 .24241 m
.04751 .24418 L
.07579 .24377 L
.10407 .24058 L
.13235 .23375 L
.16063 .22192 L
.16891 .21719 L
.18891 .2025 L
.2025 .18891 L
.21719 .16891 L
.22192 .16063 L
.23375 .13235 L
.24058 .10407 L
.24377 .07579 L
.24418 .04751 L
.24241 .01923 L
s
.488 0 1 r
.01923 .68841 m
.04751 .67444 L
.05667 .66968 L
.07579 .65983 L
.10407 .64413 L
.1086 .6414 L
.13235 .627 L
.15239 .61312 L
.16063 .60725 L
.18641 .58484 L
.18891 .58262 L
.20986 .55656 L
.21719 .54401 L
.22345 .52828 L
.22786 .5 L
.22345 .47172 L
.21719 .45599 L
.20986 .44344 L
.18891 .41738 L
.18641 .41516 L
.16063 .39275 L
.15239 .38688 L
.13235 .373 L
.1086 .3586 L
.10407 .35587 L
.07579 .34017 L
.05667 .33032 L
.04751 .32556 L
.01923 .31159 L
F
0 g
.01923 .68841 m
.04751 .67444 L
.05667 .66968 L
.07579 .65983 L
.10407 .64413 L
.1086 .6414 L
.13235 .627 L
.15239 .61312 L
.16063 .60725 L
.18641 .58484 L
.18891 .58262 L
.20986 .55656 L
.21719 .54401 L
.22345 .52828 L
.22786 .5 L
.22345 .47172 L
.21719 .45599 L
.20986 .44344 L
.18891 .41738 L
.18641 .41516 L
.16063 .39275 L
.15239 .38688 L
.13235 .373 L
.1086 .3586 L
.10407 .35587 L
.07579 .34017 L
.05667 .33032 L
.04751 .32556 L
.01923 .31159 L
s
.221 1 0 r
.01923 .20767 m
.04751 .2044 L
.07579 .19797 L
.10076 .18891 L
.10407 .1874 L
.13235 .17103 L
.1455 .16063 L
.16063 .1455 L
.17103 .13235 L
.1874 .10407 L
.18891 .10076 L
.19797 .07579 L
.2044 .04751 L
.20767 .01923 L
.01923 .01923 L
F
0 g
.01923 .20767 m
.04751 .2044 L
.07579 .19797 L
.10076 .18891 L
.10407 .1874 L
.13235 .17103 L
.1455 .16063 L
.16063 .1455 L
.17103 .13235 L
.1874 .10407 L
.18891 .10076 L
.19797 .07579 L
.2044 .04751 L
.20767 .01923 L
s
.221 1 0 r
.01923 .79233 m
.04751 .7956 L
.07579 .80203 L
.10076 .81109 L
.10407 .8126 L
.13235 .82897 L
.1455 .83937 L
.16063 .8545 L
.17103 .86765 L
.1874 .89593 L
.18891 .89924 L
.19797 .92421 L
.2044 .95249 L
.20767 .98077 L
.01923 .98077 L
F
0 g
.01923 .79233 m
.04751 .7956 L
.07579 .80203 L
.10076 .81109 L
.10407 .8126 L
.13235 .82897 L
.1455 .83937 L
.16063 .8545 L
.17103 .86765 L
.1874 .89593 L
.18891 .89924 L
.19797 .92421 L
.2044 .95249 L
.20767 .98077 L
s
1 .718 0 r
.01923 .16768 m
.0426 .16063 L
.04751 .15881 L
.07579 .14546 L
.09581 .13235 L
.10407 .12578 L
.12578 .10407 L
.13235 .09581 L
.14546 .07579 L
.15881 .04751 L
.16063 .0426 L
.16768 .01923 L
.01923 .01923 L
F
0 g
.01923 .16768 m
.0426 .16063 L
.04751 .15881 L
.07579 .14546 L
.09581 .13235 L
.10407 .12578 L
.12578 .10407 L
.13235 .09581 L
.14546 .07579 L
.15881 .04751 L
.16063 .0426 L
.16768 .01923 L
s
1 .718 0 r
.01923 .83232 m
.0426 .83937 L
.04751 .84119 L
.07579 .85454 L
.09581 .86765 L
.10407 .87422 L
.12578 .89593 L
.13235 .90419 L
.14546 .92421 L
.15881 .95249 L
.16063 .9574 L
.16768 .98077 L
.01923 .98077 L
F
0 g
.01923 .83232 m
.0426 .83937 L
.04751 .84119 L
.07579 .85454 L
.09581 .86765 L
.10407 .87422 L
.12578 .89593 L
.13235 .90419 L
.14546 .92421 L
.15881 .95249 L
.16063 .9574 L
.16768 .98077 L
s
.953 0 1 r
.01923 .66425 m
.04751 .64438 L
.05136 .6414 L
.07579 .62122 L
.08424 .61312 L
.10407 .59175 L
.10927 .58484 L
.12666 .55656 L
.13235 .54327 L
.13683 .52828 L
.14016 .5 L
.13683 .47172 L
.13235 .45673 L
.12666 .44344 L
.10927 .41516 L
.10407 .40825 L
.08424 .38688 L
.07579 .37878 L
.05136 .3586 L
.04751 .35562 L
.01923 .33575 L
F
0 g
.01923 .66425 m
.04751 .64438 L
.05136 .6414 L
.07579 .62122 L
.08424 .61312 L
.10407 .59175 L
.10927 .58484 L
.12666 .55656 L
.13235 .54327 L
.13683 .52828 L
.14016 .5 L
.13683 .47172 L
.13235 .45673 L
.12666 .44344 L
.10927 .41516 L
.10407 .40825 L
.08424 .38688 L
.07579 .37878 L
.05136 .3586 L
.04751 .35562 L
.01923 .33575 L
s
1 0 0 r
.01923 .12306 m
.04751 .10773 L
.053 .10407 L
.07579 .08578 L
.08578 .07579 L
.10407 .053 L
.10773 .04751 L
.12306 .01923 L
.01923 .01923 L
F
0 g
.01923 .12306 m
.04751 .10773 L
.053 .10407 L
.07579 .08578 L
.08578 .07579 L
.10407 .053 L
.10773 .04751 L
.12306 .01923 L
s
1 0 0 r
.01923 .87694 m
.04751 .89227 L
.053 .89593 L
.07579 .91422 L
.08578 .92421 L
.10407 .947 L
.10773 .95249 L
.12306 .98077 L
.01923 .98077 L
F
0 g
.01923 .87694 m
.04751 .89227 L
.053 .89593 L
.07579 .91422 L
.08578 .92421 L
.10407 .947 L
.10773 .95249 L
.12306 .98077 L
s
1 0 .384 r
.01923 .61842 m
.02387 .61312 L
.04437 .58484 L
.04751 .58 L
.05867 .55656 L
.06716 .52828 L
.06996 .5 L
.06716 .47172 L
.05867 .44344 L
.04751 .42 L
.04437 .41516 L
.02387 .38688 L
.01923 .38158 L
F
0 g
.01923 .61842 m
.02387 .61312 L
.04437 .58484 L
.04751 .58 L
.05867 .55656 L
.06716 .52828 L
.06996 .5 L
.06716 .47172 L
.05867 .44344 L
.04751 .42 L
.04437 .41516 L
.02387 .38688 L
.01923 .38158 L
s
.223 0 1 r
.69848 .01923 m
.69796 .02081 L
.68667 .04751 L
.67477 .07579 L
.66968 .08751 L
.66286 .10407 L
.65086 .13235 L
.6414 .15408 L
.63873 .16063 L
.62651 .18891 L
.61388 .21719 L
.61312 .21853 L
.60114 .24548 L
.58727 .27376 L
.58484 .27707 L
.57276 .30204 L
.55656 .32576 L
.55576 .33032 L
.52828 .35458 L
.52196 .3586 L
.5 .36275 L
.47804 .3586 L
.47172 .35458 L
.44424 .33032 L
.44344 .32576 L
.42724 .30204 L
.41516 .27707 L
.41273 .27376 L
.39886 .24548 L
.38688 .21853 L
.38612 .21719 L
.37349 .18891 L
.36127 .16063 L
.3586 .15408 L
.34914 .13235 L
.33714 .10407 L
.33032 .08751 L
.32523 .07579 L
.31333 .04751 L
.30204 .02081 L
.30152 .01923 L
F
0 g
.69848 .01923 m
.69796 .02081 L
.68667 .04751 L
.67477 .07579 L
.66968 .08751 L
.66286 .10407 L
.65086 .13235 L
.6414 .15408 L
.63873 .16063 L
.62651 .18891 L
.61388 .21719 L
.61312 .21853 L
.60114 .24548 L
.58727 .27376 L
.58484 .27707 L
.57276 .30204 L
.55656 .32576 L
.55576 .33032 L
.52828 .35458 L
.52196 .3586 L
.5 .36275 L
.47804 .3586 L
.47172 .35458 L
.44424 .33032 L
.44344 .32576 L
.42724 .30204 L
.41516 .27707 L
.41273 .27376 L
.39886 .24548 L
.38688 .21853 L
.38612 .21719 L
.37349 .18891 L
.36127 .16063 L
.3586 .15408 L
.34914 .13235 L
.33714 .10407 L
.33032 .08751 L
.32523 .07579 L
.31333 .04751 L
.30204 .02081 L
.30152 .01923 L
s
.223 0 1 r
.69848 .98077 m
.69796 .97919 L
.68667 .95249 L
.67477 .92421 L
.66968 .91249 L
.66286 .89593 L
.65086 .86765 L
.6414 .84592 L
.63873 .83937 L
.62651 .81109 L
.61388 .78281 L
.61312 .78147 L
.60114 .75452 L
.58727 .72624 L
.58484 .72293 L
.57276 .69796 L
.55656 .67424 L
.55576 .66968 L
.52828 .64542 L
.52196 .6414 L
.5 .63725 L
.47804 .6414 L
.47172 .64542 L
.44424 .66968 L
.44344 .67424 L
.42724 .69796 L
.41516 .72293 L
.41273 .72624 L
.39886 .75452 L
.38688 .78147 L
.38612 .78281 L
.37349 .81109 L
.36127 .83937 L
.3586 .84592 L
.34914 .86765 L
.33714 .89593 L
.33032 .91249 L
.32523 .92421 L
.31333 .95249 L
.30204 .97919 L
.30152 .98077 L
F
0 g
.69848 .98077 m
.69796 .97919 L
.68667 .95249 L
.67477 .92421 L
.66968 .91249 L
.66286 .89593 L
.65086 .86765 L
.6414 .84592 L
.63873 .83937 L
.62651 .81109 L
.61388 .78281 L
.61312 .78147 L
.60114 .75452 L
.58727 .72624 L
.58484 .72293 L
.57276 .69796 L
.55656 .67424 L
.55576 .66968 L
.52828 .64542 L
.52196 .6414 L
.5 .63725 L
.47804 .6414 L
.47172 .64542 L
.44424 .66968 L
.44344 .67424 L
.42724 .69796 L
.41516 .72293 L
.41273 .72624 L
.39886 .75452 L
.38688 .78147 L
.38612 .78281 L
.37349 .81109 L
.36127 .83937 L
.3586 .84592 L
.34914 .86765 L
.33714 .89593 L
.33032 .91249 L
.32523 .92421 L
.31333 .95249 L
.30204 .97919 L
.30152 .98077 L
s
.488 0 1 r
.68841 .01923 m
.67444 .04751 L
.66968 .05667 L
.65983 .07579 L
.64413 .10407 L
.6414 .1086 L
.627 .13235 L
.61312 .15239 L
.60725 .16063 L
.58484 .18641 L
.58262 .18891 L
.55656 .20986 L
.54401 .21719 L
.52828 .22345 L
.5 .22786 L
.47172 .22345 L
.45599 .21719 L
.44344 .20986 L
.41738 .18891 L
.41516 .18641 L
.39275 .16063 L
.38688 .15239 L
.373 .13235 L
.3586 .1086 L
.35587 .10407 L
.34017 .07579 L
.33032 .05667 L
.32556 .04751 L
.31159 .01923 L
F
0 g
.68841 .01923 m
.67444 .04751 L
.66968 .05667 L
.65983 .07579 L
.64413 .10407 L
.6414 .1086 L
.627 .13235 L
.61312 .15239 L
.60725 .16063 L
.58484 .18641 L
.58262 .18891 L
.55656 .20986 L
.54401 .21719 L
.52828 .22345 L
.5 .22786 L
.47172 .22345 L
.45599 .21719 L
.44344 .20986 L
.41738 .18891 L
.41516 .18641 L
.39275 .16063 L
.38688 .15239 L
.373 .13235 L
.3586 .1086 L
.35587 .10407 L
.34017 .07579 L
.33032 .05667 L
.32556 .04751 L
.31159 .01923 L
s
.488 0 1 r
.68841 .98077 m
.67444 .95249 L
.66968 .94333 L
.65983 .92421 L
.64413 .89593 L
.6414 .8914 L
.627 .86765 L
.61312 .84761 L
.60725 .83937 L
.58484 .81359 L
.58262 .81109 L
.55656 .79014 L
.54401 .78281 L
.52828 .77655 L
.5 .77214 L
.47172 .77655 L
.45599 .78281 L
.44344 .79014 L
.41738 .81109 L
.41516 .81359 L
.39275 .83937 L
.38688 .84761 L
.373 .86765 L
.3586 .8914 L
.35587 .89593 L
.34017 .92421 L
.33032 .94333 L
.32556 .95249 L
.31159 .98077 L
F
0 g
.68841 .98077 m
.67444 .95249 L
.66968 .94333 L
.65983 .92421 L
.64413 .89593 L
.6414 .8914 L
.627 .86765 L
.61312 .84761 L
.60725 .83937 L
.58484 .81359 L
.58262 .81109 L
.55656 .79014 L
.54401 .78281 L
.52828 .77655 L
.5 .77214 L
.47172 .77655 L
.45599 .78281 L
.44344 .79014 L
.41738 .81109 L
.41516 .81359 L
.39275 .83937 L
.38688 .84761 L
.373 .86765 L
.3586 .8914 L
.35587 .89593 L
.34017 .92421 L
.33032 .94333 L
.32556 .95249 L
.31159 .98077 L
s
.953 0 1 r
.66425 .01923 m
.64438 .04751 L
.6414 .05136 L
.62122 .07579 L
.61312 .08424 L
.59175 .10407 L
.58484 .10927 L
.55656 .12666 L
.54327 .13235 L
.52828 .13683 L
.5 .14016 L
.47172 .13683 L
.45673 .13235 L
.44344 .12666 L
.41516 .10927 L
.40825 .10407 L
.38688 .08424 L
.37878 .07579 L
.3586 .05136 L
.35562 .04751 L
.33575 .01923 L
F
0 g
.66425 .01923 m
.64438 .04751 L
.6414 .05136 L
.62122 .07579 L
.61312 .08424 L
.59175 .10407 L
.58484 .10927 L
.55656 .12666 L
.54327 .13235 L
.52828 .13683 L
.5 .14016 L
.47172 .13683 L
.45673 .13235 L
.44344 .12666 L
.41516 .10927 L
.40825 .10407 L
.38688 .08424 L
.37878 .07579 L
.3586 .05136 L
.35562 .04751 L
.33575 .01923 L
s
.953 0 1 r
.66425 .98077 m
.64438 .95249 L
.6414 .94864 L
.62122 .92421 L
.61312 .91576 L
.59175 .89593 L
.58484 .89073 L
.55656 .87334 L
.54327 .86765 L
.52828 .86317 L
.5 .85984 L
.47172 .86317 L
.45673 .86765 L
.44344 .87334 L
.41516 .89073 L
.40825 .89593 L
.38688 .91576 L
.37878 .92421 L
.3586 .94864 L
.35562 .95249 L
.33575 .98077 L
F
0 g
.66425 .98077 m
.64438 .95249 L
.6414 .94864 L
.62122 .92421 L
.61312 .91576 L
.59175 .89593 L
.58484 .89073 L
.55656 .87334 L
.54327 .86765 L
.52828 .86317 L
.5 .85984 L
.47172 .86317 L
.45673 .86765 L
.44344 .87334 L
.41516 .89073 L
.40825 .89593 L
.38688 .91576 L
.37878 .92421 L
.3586 .94864 L
.35562 .95249 L
.33575 .98077 L
s
1 0 .384 r
.61842 .01923 m
.61312 .02387 L
.58484 .04437 L
.58 .04751 L
.55656 .05867 L
.52828 .06716 L
.5 .06996 L
.47172 .06716 L
.44344 .05867 L
.42 .04751 L
.41516 .04437 L
.38688 .02387 L
.38158 .01923 L
F
0 g
.61842 .01923 m
.61312 .02387 L
.58484 .04437 L
.58 .04751 L
.55656 .05867 L
.52828 .06716 L
.5 .06996 L
.47172 .06716 L
.44344 .05867 L
.42 .04751 L
.41516 .04437 L
.38688 .02387 L
.38158 .01923 L
s
1 0 .384 r
.61842 .98077 m
.61312 .97613 L
.58484 .95563 L
.58 .95249 L
.55656 .94133 L
.52828 .93284 L
.5 .93004 L
.47172 .93284 L
.44344 .94133 L
.42 .95249 L
.41516 .95563 L
.38688 .97613 L
.38158 .98077 L
F
0 g
.61842 .98077 m
.61312 .97613 L
.58484 .95563 L
.58 .95249 L
.55656 .94133 L
.52828 .93284 L
.5 .93004 L
.47172 .93284 L
.44344 .94133 L
.42 .95249 L
.41516 .95563 L
.38688 .97613 L
.38158 .98077 L
s
.035 0 1 r
.98077 .3002 m
.97536 .30204 L
.95249 .31176 L
.92421 .32331 L
.90734 .33032 L
.89593 .3348 L
.86765 .3462 L
.83937 .35757 L
.83713 .3586 L
.81109 .36865 L
.78281 .3796 L
.76471 .38688 L
.75452 .39013 L
.72624 .39994 L
.69796 .40889 L
.67356 .41516 L
.66968 .41586 L
.6414 .41884 L
.61433 .41516 L
.61312 .4147 L
.5853 .38688 L
.58484 .38567 L
.58116 .3586 L
.58414 .33032 L
.58484 .32644 L
.59111 .30204 L
.60006 .27376 L
.60987 .24548 L
.61312 .23529 L
.6204 .21719 L
.63135 .18891 L
.6414 .16287 L
.64243 .16063 L
.6538 .13235 L
.6652 .10407 L
.66968 .09266 L
.67669 .07579 L
.68824 .04751 L
.69796 .02464 L
.6998 .01923 L
.98077 .01923 L
F
0 g
.98077 .3002 m
.97536 .30204 L
.95249 .31176 L
.92421 .32331 L
.90734 .33032 L
.89593 .3348 L
.86765 .3462 L
.83937 .35757 L
.83713 .3586 L
.81109 .36865 L
.78281 .3796 L
.76471 .38688 L
.75452 .39013 L
.72624 .39994 L
.69796 .40889 L
.67356 .41516 L
.66968 .41586 L
.6414 .41884 L
.61433 .41516 L
.61312 .4147 L
.5853 .38688 L
.58484 .38567 L
.58116 .3586 L
.58414 .33032 L
.58484 .32644 L
.59111 .30204 L
.60006 .27376 L
.60987 .24548 L
.61312 .23529 L
.6204 .21719 L
.63135 .18891 L
.6414 .16287 L
.64243 .16063 L
.6538 .13235 L
.6652 .10407 L
.66968 .09266 L
.67669 .07579 L
.68824 .04751 L
.69796 .02464 L
.6998 .01923 L
s
.035 0 1 r
.98077 .6998 m
.97536 .69796 L
.95249 .68824 L
.92421 .67669 L
.90734 .66968 L
.89593 .6652 L
.86765 .6538 L
.83937 .64243 L
.83713 .6414 L
.81109 .63135 L
.78281 .6204 L
.76471 .61312 L
.75452 .60987 L
.72624 .60006 L
.69796 .59111 L
.67356 .58484 L
.66968 .58414 L
.6414 .58116 L
.61433 .58484 L
.61312 .5853 L
.5853 .61312 L
.58484 .61433 L
.58116 .6414 L
.58414 .66968 L
.58484 .67356 L
.59111 .69796 L
.60006 .72624 L
.60987 .75452 L
.61312 .76471 L
.6204 .78281 L
.63135 .81109 L
.6414 .83713 L
.64243 .83937 L
.6538 .86765 L
.6652 .89593 L
.66968 .90734 L
.67669 .92421 L
.68824 .95249 L
.69796 .97536 L
.6998 .98077 L
.98077 .98077 L
F
0 g
.98077 .6998 m
.97536 .69796 L
.95249 .68824 L
.92421 .67669 L
.90734 .66968 L
.89593 .6652 L
.86765 .6538 L
.83937 .64243 L
.83713 .6414 L
.81109 .63135 L
.78281 .6204 L
.76471 .61312 L
.75452 .60987 L
.72624 .60006 L
.69796 .59111 L
.67356 .58484 L
.66968 .58414 L
.6414 .58116 L
.61433 .58484 L
.61312 .5853 L
.5853 .61312 L
.58484 .61433 L
.58116 .6414 L
.58414 .66968 L
.58484 .67356 L
.59111 .69796 L
.60006 .72624 L
.60987 .75452 L
.61312 .76471 L
.6204 .78281 L
.63135 .81109 L
.6414 .83713 L
.64243 .83937 L
.6538 .86765 L
.6652 .89593 L
.66968 .90734 L
.67669 .92421 L
.68824 .95249 L
.69796 .97536 L
.6998 .98077 L
s
.223 0 1 r
.98077 .69848 m
.97919 .69796 L
.95249 .68667 L
.92421 .67477 L
.91249 .66968 L
.89593 .66286 L
.86765 .65086 L
.84592 .6414 L
.83937 .63873 L
.81109 .62651 L
.78281 .61388 L
.78147 .61312 L
.75452 .60114 L
.72624 .58727 L
.72293 .58484 L
.69796 .57276 L
.67424 .55656 L
.66968 .55576 L
.64542 .52828 L
.6414 .52196 L
.63725 .5 L
.6414 .47804 L
.64542 .47172 L
.66968 .44424 L
.67424 .44344 L
.69796 .42724 L
.72293 .41516 L
.72624 .41273 L
.75452 .39886 L
.78147 .38688 L
.78281 .38612 L
.81109 .37349 L
.83937 .36127 L
.84592 .3586 L
.86765 .34914 L
.89593 .33714 L
.91249 .33032 L
.92421 .32523 L
.95249 .31333 L
.97919 .30204 L
.98077 .30152 L
F
0 g
.98077 .69848 m
.97919 .69796 L
.95249 .68667 L
.92421 .67477 L
.91249 .66968 L
.89593 .66286 L
.86765 .65086 L
.84592 .6414 L
.83937 .63873 L
.81109 .62651 L
.78281 .61388 L
.78147 .61312 L
.75452 .60114 L
.72624 .58727 L
.72293 .58484 L
.69796 .57276 L
.67424 .55656 L
.66968 .55576 L
.64542 .52828 L
.6414 .52196 L
.63725 .5 L
.6414 .47804 L
.64542 .47172 L
.66968 .44424 L
.67424 .44344 L
.69796 .42724 L
.72293 .41516 L
.72624 .41273 L
.75452 .39886 L
.78147 .38688 L
.78281 .38612 L
.81109 .37349 L
.83937 .36127 L
.84592 .3586 L
.86765 .34914 L
.89593 .33714 L
.91249 .33032 L
.92421 .32523 L
.95249 .31333 L
.97919 .30204 L
.98077 .30152 L
s
0 .23 1 r
.98077 .29057 m
.95249 .30032 L
.94767 .30204 L
.92421 .30951 L
.89593 .31801 L
.86765 .32559 L
.84851 .33032 L
.83937 .33186 L
.81109 .3363 L
.78281 .33823 L
.75452 .33655 L
.72829 .33032 L
.72624 .32941 L
.69796 .31288 L
.68712 .30204 L
.67059 .27376 L
.66968 .27171 L
.66345 .24548 L
.66177 .21719 L
.6637 .18891 L
.66814 .16063 L
.66968 .15149 L
.67441 .13235 L
.68199 .10407 L
.69049 .07579 L
.69796 .05233 L
.69968 .04751 L
.70943 .01923 L
.98077 .01923 L
F
0 g
.98077 .29057 m
.95249 .30032 L
.94767 .30204 L
.92421 .30951 L
.89593 .31801 L
.86765 .32559 L
.84851 .33032 L
.83937 .33186 L
.81109 .3363 L
.78281 .33823 L
.75452 .33655 L
.72829 .33032 L
.72624 .32941 L
.69796 .31288 L
.68712 .30204 L
.67059 .27376 L
.66968 .27171 L
.66345 .24548 L
.66177 .21719 L
.6637 .18891 L
.66814 .16063 L
.66968 .15149 L
.67441 .13235 L
.68199 .10407 L
.69049 .07579 L
.69796 .05233 L
.69968 .04751 L
.70943 .01923 L
s
0 .23 1 r
.98077 .70943 m
.95249 .69968 L
.94767 .69796 L
.92421 .69049 L
.89593 .68199 L
.86765 .67441 L
.84851 .66968 L
.83937 .66814 L
.81109 .6637 L
.78281 .66177 L
.75452 .66345 L
.72829 .66968 L
.72624 .67059 L
.69796 .68712 L
.68712 .69796 L
.67059 .72624 L
.66968 .72829 L
.66345 .75452 L
.66177 .78281 L
.6637 .81109 L
.66814 .83937 L
.66968 .84851 L
.67441 .86765 L
.68199 .89593 L
.69049 .92421 L
.69796 .94767 L
.69968 .95249 L
.70943 .98077 L
.98077 .98077 L
F
0 g
.98077 .70943 m
.95249 .69968 L
.94767 .69796 L
.92421 .69049 L
.89593 .68199 L
.86765 .67441 L
.84851 .66968 L
.83937 .66814 L
.81109 .6637 L
.78281 .66177 L
.75452 .66345 L
.72829 .66968 L
.72624 .67059 L
.69796 .68712 L
.68712 .69796 L
.67059 .72624 L
.66968 .72829 L
.66345 .75452 L
.66177 .78281 L
.6637 .81109 L
.66814 .83937 L
.66968 .84851 L
.67441 .86765 L
.68199 .89593 L
.69049 .92421 L
.69796 .94767 L
.69968 .95249 L
.70943 .98077 L
s
0 .695 1 r
.98077 .27065 m
.9541 .27376 L
.95249 .27688 L
.92421 .28179 L
.89593 .28502 L
.86765 .28604 L
.83937 .28416 L
.81109 .27831 L
.79769 .27376 L
.78281 .26673 L
.75452 .24573 L
.75427 .24548 L
.73327 .21719 L
.72624 .20231 L
.72169 .18891 L
.71584 .16063 L
.71396 .13235 L
.71498 .10407 L
.71821 .07579 L
.72312 .04751 L
.72624 .0459 L
.72935 .01923 L
.98077 .01923 L
F
0 g
.98077 .27065 m
.9541 .27376 L
.95249 .27688 L
.92421 .28179 L
.89593 .28502 L
.86765 .28604 L
.83937 .28416 L
.81109 .27831 L
.79769 .27376 L
.78281 .26673 L
.75452 .24573 L
.75427 .24548 L
.73327 .21719 L
.72624 .20231 L
.72169 .18891 L
.71584 .16063 L
.71396 .13235 L
.71498 .10407 L
.71821 .07579 L
.72312 .04751 L
.72624 .0459 L
.72935 .01923 L
s
0 .695 1 r
.98077 .72935 m
.9541 .72624 L
.95249 .72312 L
.92421 .71821 L
.89593 .71498 L
.86765 .71396 L
.83937 .71584 L
.81109 .72169 L
.79769 .72624 L
.78281 .73327 L
.75452 .75427 L
.75427 .75452 L
.73327 .78281 L
.72624 .79769 L
.72169 .81109 L
.71584 .83937 L
.71396 .86765 L
.71498 .89593 L
.71821 .92421 L
.72312 .95249 L
.72624 .9541 L
.72935 .98077 L
.98077 .98077 L
F
0 g
.98077 .72935 m
.9541 .72624 L
.95249 .72312 L
.92421 .71821 L
.89593 .71498 L
.86765 .71396 L
.83937 .71584 L
.81109 .72169 L
.79769 .72624 L
.78281 .73327 L
.75452 .75427 L
.75427 .75452 L
.73327 .78281 L
.72624 .79769 L
.72169 .81109 L
.71584 .83937 L
.71396 .86765 L
.71498 .89593 L
.71821 .92421 L
.72312 .95249 L
.72624 .9541 L
.72935 .98077 L
s
0 1 .642 r
.98077 .75759 m
.95249 .75582 L
.92421 .75623 L
.89593 .75942 L
.86765 .76625 L
.83937 .77808 L
.83109 .78281 L
.81109 .7975 L
.7975 .81109 L
.78281 .83109 L
.77808 .83937 L
.76625 .86765 L
.75942 .89593 L
.75623 .92421 L
.75582 .95249 L
.75759 .98077 L
.98077 .98077 L
F
0 g
.98077 .75759 m
.95249 .75582 L
.92421 .75623 L
.89593 .75942 L
.86765 .76625 L
.83937 .77808 L
.83109 .78281 L
.81109 .7975 L
.7975 .81109 L
.78281 .83109 L
.77808 .83937 L
.76625 .86765 L
.75942 .89593 L
.75623 .92421 L
.75582 .95249 L
.75759 .98077 L
s
0 1 .642 r
.98077 .24241 m
.95249 .24418 L
.92421 .24377 L
.89593 .24058 L
.86765 .23375 L
.83937 .22192 L
.83109 .21719 L
.81109 .2025 L
.7975 .18891 L
.78281 .16891 L
.77808 .16063 L
.76625 .13235 L
.75942 .10407 L
.75623 .07579 L
.75582 .04751 L
.75759 .01923 L
.98077 .01923 L
F
0 g
.98077 .24241 m
.95249 .24418 L
.92421 .24377 L
.89593 .24058 L
.86765 .23375 L
.83937 .22192 L
.83109 .21719 L
.81109 .2025 L
.7975 .18891 L
.78281 .16891 L
.77808 .16063 L
.76625 .13235 L
.75942 .10407 L
.75623 .07579 L
.75582 .04751 L
.75759 .01923 L
s
.488 0 1 r
.98077 .68841 m
.95249 .67444 L
.94333 .66968 L
.92421 .65983 L
.89593 .64413 L
.8914 .6414 L
.86765 .627 L
.84761 .61312 L
.83937 .60725 L
.81359 .58484 L
.81109 .58262 L
.79014 .55656 L
.78281 .54401 L
.77655 .52828 L
.77214 .5 L
.77655 .47172 L
.78281 .45599 L
.79014 .44344 L
.81109 .41738 L
.81359 .41516 L
.83937 .39275 L
.84761 .38688 L
.86765 .373 L
.8914 .3586 L
.89593 .35587 L
.92421 .34017 L
.94333 .33032 L
.95249 .32556 L
.98077 .31159 L
F
0 g
.98077 .68841 m
.95249 .67444 L
.94333 .66968 L
.92421 .65983 L
.89593 .64413 L
.8914 .6414 L
.86765 .627 L
.84761 .61312 L
.83937 .60725 L
.81359 .58484 L
.81109 .58262 L
.79014 .55656 L
.78281 .54401 L
.77655 .52828 L
.77214 .5 L
.77655 .47172 L
.78281 .45599 L
.79014 .44344 L
.81109 .41738 L
.81359 .41516 L
.83937 .39275 L
.84761 .38688 L
.86765 .373 L
.8914 .3586 L
.89593 .35587 L
.92421 .34017 L
.94333 .33032 L
.95249 .32556 L
.98077 .31159 L
s
.221 1 0 r
.98077 .20767 m
.95249 .2044 L
.92421 .19797 L
.89924 .18891 L
.89593 .1874 L
.86765 .17103 L
.8545 .16063 L
.83937 .1455 L
.82897 .13235 L
.8126 .10407 L
.81109 .10076 L
.80203 .07579 L
.7956 .04751 L
.79233 .01923 L
.98077 .01923 L
F
0 g
.98077 .20767 m
.95249 .2044 L
.92421 .19797 L
.89924 .18891 L
.89593 .1874 L
.86765 .17103 L
.8545 .16063 L
.83937 .1455 L
.82897 .13235 L
.8126 .10407 L
.81109 .10076 L
.80203 .07579 L
.7956 .04751 L
.79233 .01923 L
s
.221 1 0 r
.98077 .79233 m
.95249 .7956 L
.92421 .80203 L
.89924 .81109 L
.89593 .8126 L
.86765 .82897 L
.8545 .83937 L
.83937 .8545 L
.82897 .86765 L
.8126 .89593 L
.81109 .89924 L
.80203 .92421 L
.7956 .95249 L
.79233 .98077 L
.98077 .98077 L
F
0 g
.98077 .79233 m
.95249 .7956 L
.92421 .80203 L
.89924 .81109 L
.89593 .8126 L
.86765 .82897 L
.8545 .83937 L
.83937 .8545 L
.82897 .86765 L
.8126 .89593 L
.81109 .89924 L
.80203 .92421 L
.7956 .95249 L
.79233 .98077 L
s
1 .718 0 r
.98077 .16768 m
.9574 .16063 L
.95249 .15881 L
.92421 .14546 L
.90419 .13235 L
.89593 .12578 L
.87422 .10407 L
.86765 .09581 L
.85454 .07579 L
.84119 .04751 L
.83937 .0426 L
.83232 .01923 L
.98077 .01923 L
F
0 g
.98077 .16768 m
.9574 .16063 L
.95249 .15881 L
.92421 .14546 L
.90419 .13235 L
.89593 .12578 L
.87422 .10407 L
.86765 .09581 L
.85454 .07579 L
.84119 .04751 L
.83937 .0426 L
.83232 .01923 L
s
1 .718 0 r
.98077 .83232 m
.9574 .83937 L
.95249 .84119 L
.92421 .85454 L
.90419 .86765 L
.89593 .87422 L
.87422 .89593 L
.86765 .90419 L
.85454 .92421 L
.84119 .95249 L
.83937 .9574 L
.83232 .98077 L
.98077 .98077 L
F
0 g
.98077 .83232 m
.9574 .83937 L
.95249 .84119 L
.92421 .85454 L
.90419 .86765 L
.89593 .87422 L
.87422 .89593 L
.86765 .90419 L
.85454 .92421 L
.84119 .95249 L
.83937 .9574 L
.83232 .98077 L
s
.953 0 1 r
.98077 .66425 m
.95249 .64438 L
.94864 .6414 L
.92421 .62122 L
.91576 .61312 L
.89593 .59175 L
.89073 .58484 L
.87334 .55656 L
.86765 .54327 L
.86317 .52828 L
.85984 .5 L
.86317 .47172 L
.86765 .45673 L
.87334 .44344 L
.89073 .41516 L
.89593 .40825 L
.91576 .38688 L
.92421 .37878 L
.94864 .3586 L
.95249 .35562 L
.98077 .33575 L
F
0 g
.98077 .66425 m
.95249 .64438 L
.94864 .6414 L
.92421 .62122 L
.91576 .61312 L
.89593 .59175 L
.89073 .58484 L
.87334 .55656 L
.86765 .54327 L
.86317 .52828 L
.85984 .5 L
.86317 .47172 L
.86765 .45673 L
.87334 .44344 L
.89073 .41516 L
.89593 .40825 L
.91576 .38688 L
.92421 .37878 L
.94864 .3586 L
.95249 .35562 L
.98077 .33575 L
s
1 0 0 r
.98077 .12306 m
.95249 .10773 L
.947 .10407 L
.92421 .08578 L
.91422 .07579 L
.89593 .053 L
.89227 .04751 L
.87694 .01923 L
.98077 .01923 L
F
0 g
.98077 .12306 m
.95249 .10773 L
.947 .10407 L
.92421 .08578 L
.91422 .07579 L
.89593 .053 L
.89227 .04751 L
.87694 .01923 L
s
1 0 0 r
.98077 .87694 m
.95249 .89227 L
.947 .89593 L
.92421 .91422 L
.91422 .92421 L
.89593 .947 L
.89227 .95249 L
.87694 .98077 L
.98077 .98077 L
F
0 g
.98077 .87694 m
.95249 .89227 L
.947 .89593 L
.92421 .91422 L
.91422 .92421 L
.89593 .947 L
.89227 .95249 L
.87694 .98077 L
s
1 0 .384 r
.98077 .61842 m
.97613 .61312 L
.95563 .58484 L
.95249 .58 L
.94133 .55656 L
.93284 .52828 L
.93004 .5 L
.93284 .47172 L
.94133 .44344 L
.95249 .42 L
.95563 .41516 L
.97613 .38688 L
.98077 .38158 L
F
0 g
.98077 .61842 m
.97613 .61312 L
.95563 .58484 L
.95249 .58 L
.94133 .55656 L
.93284 .52828 L
.93004 .5 L
.93284 .47172 L
.94133 .44344 L
.95249 .42 L
.95563 .41516 L
.97613 .38688 L
.98077 .38158 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{222, 222},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
  ImageRangeCache->{{{0, 221}, {221, 0}} -> {-2, -2, 0, 0}}],
 StyleBox["     \n\tFigure 3.B",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Contour plot for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"u", 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["x", "3"], "-", 
     RowBox[{"3", " ", "x", " ", 
      SuperscriptBox["y", "2"]}]}], "=", "C"}]}]]],
 "     and     ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"v", 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"3", " ", 
      SuperscriptBox["x", "2"], " ", "y"}], "-", 
     SuperscriptBox["y", "3"]}], "=", "C"}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "\tIn Chapter 11 we will show that if  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    RowBox[{"u", 
     RowBox[{"(", 
      RowBox[{"x", ",", "y"}], ")"}]}], "+", 
    RowBox[{"i", " ", "v", 
     RowBox[{"(", 
      RowBox[{"x", ",", "y"}], ")"}]}]}]}]]],
 " is an analytic function.  Then the two families of level curves    ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"u", 
     RowBox[{"(", 
      RowBox[{"x", ",", "y"}], ")"}]}], "=", 
    RowBox[{"C", ":", " ", 
     RowBox[{
      StyleBox["C",
       FontSize->14], "  ", 
      StyleBox["is",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox[" ",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox["a",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox[" ",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox["real",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox[" ",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox["constant",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]]}]}]}], "}"}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"v", 
     RowBox[{"(", 
      RowBox[{"x", ",", "y"}], ")"}]}], "=", 
    RowBox[{
     StyleBox["C",
      FontSize->14], ":", " ", 
     RowBox[{
      StyleBox["C",
       FontSize->14], "  ", 
      StyleBox["is",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox[" ",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox["a",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox[" ",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox["real",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox[" ",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox["constant",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]]}]}]}], "}"}]]],
 ",  are orthogonal in the sense that if ",
 Cell[BoxData[
  RowBox[{"(", 
   RowBox[{
    SubscriptBox["x", "0"], ",", 
    SubscriptBox["y", "0"]}], ")"}]]],
 "is a point in common to the two curves  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"u", 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], "=", 
   StyleBox[
    SubscriptBox["C", "1"],
    FontSize->14]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"v", 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], "=", 
   StyleBox[
    SubscriptBox["C", "2"],
    FontSize->14]}]]],
 ",  and  if   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"f", "'"}], 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["x", "0"], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["y", "0"]}]}], ")"}]}], "\[NotEqual]", "0", " "}]]],
 ",  then these two curves intersect orthogonally.  The orthogonal grid shown \
in Figure 3.C.  "
}], "Text"],

Cell[TextData[{
 "\t\t\t",
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.190476 0.5 0.190476 [
[.11905 -0.0125 -6 -9 ]
[.11905 -0.0125 6 0 ]
[.30952 -0.0125 -6 -9 ]
[.30952 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69048 -0.0125 -3 -9 ]
[.69048 -0.0125 3 0 ]
[.88095 -0.0125 -3 -9 ]
[.88095 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .11905 -12 -4.5 ]
[-0.0125 .11905 0 4.5 ]
[-0.0125 .30952 -12 -4.5 ]
[-0.0125 .30952 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .69048 -6 -4.5 ]
[-0.0125 .69048 0 4.5 ]
[-0.0125 .88095 -6 -4.5 ]
[-0.0125 .88095 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 0 m
.11905 .00625 L
s
[(-2)] .11905 -0.0125 0 1 Mshowa
.30952 0 m
.30952 .00625 L
s
[(-1)] .30952 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69048 0 m
.69048 .00625 L
s
[(1)] .69048 -0.0125 0 1 Mshowa
.88095 0 m
.88095 .00625 L
s
[(2)] .88095 -0.0125 0 1 Mshowa
.125 Mabswid
.15714 0 m
.15714 .00375 L
s
.19524 0 m
.19524 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.27143 0 m
.27143 .00375 L
s
.34762 0 m
.34762 .00375 L
s
.38571 0 m
.38571 .00375 L
s
.42381 0 m
.42381 .00375 L
s
.4619 0 m
.4619 .00375 L
s
.5381 0 m
.5381 .00375 L
s
.57619 0 m
.57619 .00375 L
s
.61429 0 m
.61429 .00375 L
s
.65238 0 m
.65238 .00375 L
s
.72857 0 m
.72857 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.80476 0 m
.80476 .00375 L
s
.84286 0 m
.84286 .00375 L
s
.08095 0 m
.08095 .00375 L
s
.04286 0 m
.04286 .00375 L
s
.00476 0 m
.00476 .00375 L
s
.91905 0 m
.91905 .00375 L
s
.95714 0 m
.95714 .00375 L
s
.99524 0 m
.99524 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .11905 m
.00625 .11905 L
s
[(-2)] -0.0125 .11905 1 0 Mshowa
0 .30952 m
.00625 .30952 L
s
[(-1)] -0.0125 .30952 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .69048 m
.00625 .69048 L
s
[(1)] -0.0125 .69048 1 0 Mshowa
0 .88095 m
.00625 .88095 L
s
[(2)] -0.0125 .88095 1 0 Mshowa
.125 Mabswid
0 .15714 m
.00375 .15714 L
s
0 .19524 m
.00375 .19524 L
s
0 .23333 m
.00375 .23333 L
s
0 .27143 m
.00375 .27143 L
s
0 .34762 m
.00375 .34762 L
s
0 .38571 m
.00375 .38571 L
s
0 .42381 m
.00375 .42381 L
s
0 .4619 m
.00375 .4619 L
s
0 .5381 m
.00375 .5381 L
s
0 .57619 m
.00375 .57619 L
s
0 .61429 m
.00375 .61429 L
s
0 .65238 m
.00375 .65238 L
s
0 .72857 m
.00375 .72857 L
s
0 .76667 m
.00375 .76667 L
s
0 .80476 m
.00375 .80476 L
s
0 .84286 m
.00375 .84286 L
s
0 .08095 m
.00375 .08095 L
s
0 .04286 m
.00375 .04286 L
s
0 .00476 m
.00375 .00476 L
s
0 .91905 m
.00375 .91905 L
s
0 .95714 m
.00375 .95714 L
s
0 .99524 m
.00375 .99524 L
s
.25 Mabswid
0 0 m
0 1 L
s
.11905 .99375 m
.11905 1 L
s
.30952 .99375 m
.30952 1 L
s
.5 .99375 m
.5 1 L
s
.69048 .99375 m
.69048 1 L
s
.88095 .99375 m
.88095 1 L
s
.125 Mabswid
.15714 .99625 m
.15714 1 L
s
.19524 .99625 m
.19524 1 L
s
.23333 .99625 m
.23333 1 L
s
.27143 .99625 m
.27143 1 L
s
.34762 .99625 m
.34762 1 L
s
.38571 .99625 m
.38571 1 L
s
.42381 .99625 m
.42381 1 L
s
.4619 .99625 m
.4619 1 L
s
.5381 .99625 m
.5381 1 L
s
.57619 .99625 m
.57619 1 L
s
.61429 .99625 m
.61429 1 L
s
.65238 .99625 m
.65238 1 L
s
.72857 .99625 m
.72857 1 L
s
.76667 .99625 m
.76667 1 L
s
.80476 .99625 m
.80476 1 L
s
.84286 .99625 m
.84286 1 L
s
.08095 .99625 m
.08095 1 L
s
.04286 .99625 m
.04286 1 L
s
.00476 .99625 m
.00476 1 L
s
.91905 .99625 m
.91905 1 L
s
.95714 .99625 m
.95714 1 L
s
.99524 .99625 m
.99524 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .11905 m
1 .11905 L
s
.99375 .30952 m
1 .30952 L
s
.99375 .5 m
1 .5 L
s
.99375 .69048 m
1 .69048 L
s
.99375 .88095 m
1 .88095 L
s
.125 Mabswid
.99625 .15714 m
1 .15714 L
s
.99625 .19524 m
1 .19524 L
s
.99625 .23333 m
1 .23333 L
s
.99625 .27143 m
1 .27143 L
s
.99625 .34762 m
1 .34762 L
s
.99625 .38571 m
1 .38571 L
s
.99625 .42381 m
1 .42381 L
s
.99625 .4619 m
1 .4619 L
s
.99625 .5381 m
1 .5381 L
s
.99625 .57619 m
1 .57619 L
s
.99625 .61429 m
1 .61429 L
s
.99625 .65238 m
1 .65238 L
s
.99625 .72857 m
1 .72857 L
s
.99625 .76667 m
1 .76667 L
s
.99625 .80476 m
1 .80476 L
s
.99625 .84286 m
1 .84286 L
s
.99625 .08095 m
1 .08095 L
s
.99625 .04286 m
1 .04286 L
s
.99625 .00476 m
1 .00476 L
s
.99625 .91905 m
1 .91905 L
s
.99625 .95714 m
1 .95714 L
s
.99625 .99524 m
1 .99524 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.02381 .88974 m
.03644 .86415 L
.04784 .83613 L
.05182 .82568 L
.05649 .80812 L
.06203 .78011 L
.06402 .7521 L
.06196 .72409 L
.05518 .69608 L
.05182 .68664 L
.0427 .66807 L
.02381 .64116 L
s
.97619 .35884 m
.9573 .33193 L
.94818 .31336 L
.94482 .30392 L
.93804 .27591 L
.93598 .2479 L
.93797 .21989 L
.94351 .19188 L
.94818 .17432 L
.95216 .16387 L
.96356 .13585 L
.97619 .11026 L
s
.88974 .97619 m
.86415 .96356 L
.83613 .95216 L
.82568 .94818 L
.80812 .94351 L
.78011 .93797 L
.7521 .93598 L
.72409 .93804 L
.69608 .94482 L
.68664 .94818 L
.66807 .9573 L
.64116 .97619 L
s
.35884 .02381 m
.33193 .0427 L
.31336 .05182 L
.30392 .05518 L
.27591 .06196 L
.2479 .06402 L
.21989 .06203 L
.19188 .05649 L
.17432 .05182 L
.16387 .04784 L
.13585 .03644 L
.11026 .02381 L
s
.02381 .93226 m
.03273 .92017 L
.05182 .89257 L
.05209 .89216 L
.06972 .86415 L
.07983 .84667 L
.08524 .83613 L
.09822 .80812 L
.10784 .78173 L
.10828 .78011 L
.11488 .7521 L
.11758 .72409 L
.11573 .69608 L
.10849 .66807 L
.10784 .66624 L
.09444 .64006 L
.07983 .62085 L
.07125 .61204 L
.05182 .59573 L
.03403 .58403 L
.02381 .5783 L
s
.97619 .4217 m
.96597 .41597 L
.94818 .40427 L
.92875 .38796 L
.92017 .37915 L
.90556 .35994 L
.89216 .33376 L
.89151 .33193 L
.88427 .30392 L
.88242 .27591 L
.88512 .2479 L
.89172 .21989 L
.89216 .21827 L
.90178 .19188 L
.91476 .16387 L
.92017 .15333 L
.93028 .13585 L
.94791 .10784 L
.94818 .10743 L
.96727 .07983 L
.97619 .06774 L
s
.93226 .97619 m
.92017 .96727 L
.89257 .94818 L
.89216 .94791 L
.86415 .93028 L
.84667 .92017 L
.83613 .91476 L
.80812 .90178 L
.78173 .89216 L
.78011 .89172 L
.7521 .88512 L
.72409 .88242 L
.69608 .88427 L
.66807 .89151 L
.66624 .89216 L
.64006 .90556 L
.62085 .92017 L
.61204 .92875 L
.59573 .94818 L
.58403 .96597 L
.5783 .97619 L
s
.4217 .02381 m
.41597 .03403 L
.40427 .05182 L
.38796 .07125 L
.37915 .07983 L
.35994 .09444 L
.33376 .10784 L
.33193 .10849 L
.30392 .11573 L
.27591 .11758 L
.2479 .11488 L
.21989 .10828 L
.21827 .10784 L
.19188 .09822 L
.16387 .08524 L
.15333 .07983 L
.13585 .06972 L
.10784 .05209 L
.10743 .05182 L
.07983 .03273 L
.06774 .02381 L
s
.02381 .95619 m
.03104 .94818 L
.05182 .92387 L
.0549 .92017 L
.07792 .89216 L
.07983 .88982 L
.09964 .86415 L
.10784 .85326 L
.11976 .83613 L
.13585 .81165 L
.13793 .80812 L
.15352 .78011 L
.16387 .75832 L
.16613 .7521 L
.17501 .72409 L
.1796 .69608 L
.17903 .66807 L
.1722 .64006 L
.16387 .62178 L
.15718 .61204 L
.13585 .58871 L
.13016 .58403 L
.10784 .56895 L
.08155 .55602 L
.07983 .5553 L
.05182 .54523 L
.02381 .53756 L
s
.97619 .46244 m
.94818 .45477 L
.92017 .4447 L
.91845 .44398 L
.89216 .43105 L
.86984 .41597 L
.86415 .41129 L
.84282 .38796 L
.83613 .37822 L
.8278 .35994 L
.82097 .33193 L
.8204 .30392 L
.82499 .27591 L
.83387 .2479 L
.83613 .24168 L
.84648 .21989 L
.86207 .19188 L
.86415 .18835 L
.88024 .16387 L
.89216 .14674 L
.90036 .13585 L
.92017 .11018 L
.92208 .10784 L
.9451 .07983 L
.94818 .07613 L
.96896 .05182 L
.97619 .04381 L
s
.95619 .97619 m
.94818 .96896 L
.92387 .94818 L
.92017 .9451 L
.89216 .92208 L
.88982 .92017 L
.86415 .90036 L
.85326 .89216 L
.83613 .88024 L
.81165 .86415 L
.80812 .86207 L
.78011 .84648 L
.75832 .83613 L
.7521 .83387 L
.72409 .82499 L
.69608 .8204 L
.66807 .82097 L
.64006 .8278 L
.62178 .83613 L
.61204 .84282 L
.58871 .86415 L
.58403 .86984 L
.56895 .89216 L
.55602 .91845 L
.5553 .92017 L
.54523 .94818 L
.53756 .97619 L
s
.46244 .02381 m
.45477 .05182 L
.4447 .07983 L
.44398 .08155 L
.43105 .10784 L
.41597 .13016 L
.41129 .13585 L
.38796 .15718 L
.37822 .16387 L
.35994 .1722 L
.33193 .17903 L
.30392 .1796 L
.27591 .17501 L
.2479 .16613 L
.24168 .16387 L
.21989 .15352 L
.19188 .13793 L
.18835 .13585 L
.16387 .11976 L
.14674 .10784 L
.13585 .09964 L
.11018 .07983 L
.10784 .07792 L
.07983 .0549 L
.07613 .05182 L
.05182 .03104 L
.04381 .02381 L
s
.02381 .96982 m
.04475 .94818 L
.05182 .94073 L
.07118 .92017 L
.07983 .91107 L
.0973 .89216 L
.10784 .88085 L
.12285 .86415 L
.13585 .84979 L
.14762 .83613 L
.16387 .81738 L
.17135 .80812 L
.19188 .78258 L
.19368 .78011 L
.2139 .7521 L
.21989 .74389 L
.23134 .72409 L
.24538 .69608 L
.2479 .68989 L
.25457 .66807 L
.25805 .64006 L
.25422 .61204 L
.2479 .59365 L
.24034 .58403 L
.21989 .56297 L
.20989 .55602 L
.19188 .54599 L
.16387 .53502 L
.1384 .52801 L
.13585 .52742 L
.10784 .52189 L
.07983 .51778 L
.05182 .51464 L
.02381 .5122 L
s
.97619 .4878 m
.94818 .48536 L
.92017 .48222 L
.89216 .47811 L
.86415 .47258 L
.8616 .47199 L
.83613 .46498 L
.80812 .45401 L
.79011 .44398 L
.78011 .43703 L
.75966 .41597 L
.7521 .40635 L
.74578 .38796 L
.74195 .35994 L
.74543 .33193 L
.7521 .31011 L
.75462 .30392 L
.76866 .27591 L
.78011 .25611 L
.7861 .2479 L
.80632 .21989 L
.80812 .21742 L
.82865 .19188 L
.83613 .18262 L
.85238 .16387 L
.86415 .15021 L
.87715 .13585 L
.89216 .11915 L
.9027 .10784 L
.92017 .08893 L
.92882 .07983 L
.94818 .05927 L
.95525 .05182 L
.97619 .03018 L
s
.96982 .97619 m
.94818 .95525 L
.94073 .94818 L
.92017 .92882 L
.91107 .92017 L
.89216 .9027 L
.88085 .89216 L
.86415 .87715 L
.84979 .86415 L
.83613 .85238 L
.81738 .83613 L
.80812 .82865 L
.78258 .80812 L
.78011 .80632 L
.7521 .7861 L
.74389 .78011 L
.72409 .76866 L
.69608 .75462 L
.68989 .7521 L
.66807 .74543 L
.64006 .74195 L
.61204 .74578 L
.59365 .7521 L
.58403 .75966 L
.56297 .78011 L
.55602 .79011 L
.54599 .80812 L
.53502 .83613 L
.52801 .8616 L
.52742 .86415 L
.52189 .89216 L
.51778 .92017 L
.51464 .94818 L
.5122 .97619 L
s
.4878 .02381 m
.48536 .05182 L
.48222 .07983 L
.47811 .10784 L
.47258 .13585 L
.47199 .1384 L
.46498 .16387 L
.45401 .19188 L
.44398 .20989 L
.43703 .21989 L
.41597 .24034 L
.40635 .2479 L
.38796 .25422 L
.35994 .25805 L
.33193 .25457 L
.31011 .2479 L
.30392 .24538 L
.27591 .23134 L
.25611 .21989 L
.2479 .2139 L
.21989 .19368 L
.21742 .19188 L
.19188 .17135 L
.18262 .16387 L
.16387 .14762 L
.15021 .13585 L
.13585 .12285 L
.11915 .10784 L
.10784 .0973 L
.08893 .07983 L
.07983 .07118 L
.05927 .05182 L
.05182 .04475 L
.03018 .02381 L
s
.02381 .97579 m
.05137 .94818 L
.05182 .94773 L
.07928 .92017 L
.07983 .91962 L
.10716 .89216 L
.10784 .89148 L
.135 .86415 L
.13585 .86331 L
.16278 .83613 L
.16387 .83507 L
.19046 .80812 L
.19188 .80675 L
.218 .78011 L
.21989 .7783 L
.24531 .7521 L
.2479 .74965 L
.27223 .72409 L
.27591 .72068 L
.29845 .69608 L
.30392 .69119 L
.32337 .66807 L
.33193 .66075 L
.34579 .64006 L
.35994 .62159 L
.36429 .61204 L
.37635 .58403 L
.37644 .55602 L
.35994 .52908 L
.35479 .52801 L
.33193 .5174 L
.30392 .51089 L
.27591 .5073 L
.2479 .50513 L
.21989 .50374 L
.19188 .50281 L
.16387 .50216 L
.13585 .5017 L
.10784 .50136 L
.07983 .50111 L
.05182 .50091 L
.02381 .50076 L
s
.97619 .49924 m
.94818 .49909 L
.92017 .49889 L
.89216 .49864 L
.86415 .4983 L
.83613 .49784 L
.80812 .49719 L
.78011 .49626 L
.7521 .49487 L
.72409 .4927 L
.69608 .48911 L
.66807 .4826 L
.64521 .47199 L
.64006 .47092 L
.62356 .44398 L
.62365 .41597 L
.63571 .38796 L
.64006 .37841 L
.65421 .35994 L
.66807 .33925 L
.67663 .33193 L
.69608 .30881 L
.70155 .30392 L
.72409 .27932 L
.72777 .27591 L
.7521 .25035 L
.75469 .2479 L
.78011 .2217 L
.782 .21989 L
.80812 .19325 L
.80954 .19188 L
.83613 .16493 L
.83722 .16387 L
.86415 .13669 L
.865 .13585 L
.89216 .10852 L
.89284 .10784 L
.92017 .08038 L
.92072 .07983 L
.94818 .05227 L
.94863 .05182 L
.97619 .02421 L
s
.97579 .97619 m
.94818 .94863 L
.94773 .94818 L
.92017 .92072 L
.91962 .92017 L
.89216 .89284 L
.89148 .89216 L
.86415 .865 L
.86331 .86415 L
.83613 .83722 L
.83507 .83613 L
.80812 .80954 L
.80675 .80812 L
.78011 .782 L
.7783 .78011 L
.7521 .75469 L
.74965 .7521 L
.72409 .72777 L
.72068 .72409 L
.69608 .70155 L
.69119 .69608 L
.66807 .67663 L
.66075 .66807 L
.64006 .65421 L
.62159 .64006 L
.61204 .63571 L
.58403 .62365 L
.55602 .62356 L
.52908 .64006 L
.52801 .64521 L
.5174 .66807 L
.51089 .69608 L
.5073 .72409 L
.50513 .7521 L
.50374 .78011 L
.50281 .80812 L
.50216 .83613 L
.5017 .86415 L
.50136 .89216 L
.50111 .92017 L
.50091 .94818 L
.50076 .97619 L
s
.49924 .02381 m
.49909 .05182 L
.49889 .07983 L
.49864 .10784 L
.4983 .13585 L
.49784 .16387 L
.49719 .19188 L
.49626 .21989 L
.49487 .2479 L
.4927 .27591 L
.48911 .30392 L
.4826 .33193 L
.47199 .35479 L
.47092 .35994 L
.44398 .37644 L
.41597 .37635 L
.38796 .36429 L
.37841 .35994 L
.35994 .34579 L
.33925 .33193 L
.33193 .32337 L
.30881 .30392 L
.30392 .29845 L
.27932 .27591 L
.27591 .27223 L
.25035 .2479 L
.2479 .24531 L
.2217 .21989 L
.21989 .218 L
.19325 .19188 L
.19188 .19046 L
.16493 .16387 L
.16387 .16278 L
.13669 .13585 L
.13585 .135 L
.10852 .10784 L
.10784 .10716 L
.08038 .07983 L
.07983 .07928 L
.05227 .05182 L
.05182 .05137 L
.02421 .02381 L
s
.02381 .49924 m
.05182 .49909 L
.07983 .49889 L
.10784 .49864 L
.13585 .4983 L
.16387 .49784 L
.19188 .49719 L
.21989 .49626 L
.2479 .49487 L
.27591 .4927 L
.30392 .48911 L
.33193 .4826 L
.35479 .47199 L
.35994 .47092 L
.37644 .44398 L
.37635 .41597 L
.36429 .38796 L
.35994 .37841 L
.34579 .35994 L
.33193 .33925 L
.32337 .33193 L
.30392 .30881 L
.29845 .30392 L
.27591 .27932 L
.27223 .27591 L
.2479 .25035 L
.24531 .2479 L
.21989 .2217 L
.218 .21989 L
.19188 .19325 L
.19046 .19188 L
.16387 .16493 L
.16278 .16387 L
.13585 .13669 L
.135 .13585 L
.10784 .10852 L
.10716 .10784 L
.07983 .08038 L
.07928 .07983 L
.05182 .05227 L
.05137 .05182 L
.02381 .02421 L
s
.97619 .97579 m
.94863 .94818 L
.94818 .94773 L
.92072 .92017 L
.92017 .91962 L
.89284 .89216 L
.89216 .89148 L
.865 .86415 L
.86415 .86331 L
.83722 .83613 L
.83613 .83507 L
.80954 .80812 L
.80812 .80675 L
.782 .78011 L
.78011 .7783 L
.75469 .7521 L
.7521 .74965 L
.72777 .72409 L
.72409 .72068 L
.70155 .69608 L
.69608 .69119 L
.67663 .66807 L
.66807 .66075 L
.65421 .64006 L
.64006 .62159 L
.63571 .61204 L
.62365 .58403 L
.62356 .55602 L
.64006 .52908 L
.64521 .52801 L
.66807 .5174 L
.69608 .51089 L
.72409 .5073 L
.7521 .50513 L
.78011 .50374 L
.80812 .50281 L
.83613 .50216 L
.86415 .5017 L
.89216 .50136 L
.92017 .50111 L
.94818 .50091 L
.97619 .50076 L
s
.49924 .97619 m
.49909 .94818 L
.49889 .92017 L
.49864 .89216 L
.4983 .86415 L
.49784 .83613 L
.49719 .80812 L
.49626 .78011 L
.49487 .7521 L
.4927 .72409 L
.48911 .69608 L
.4826 .66807 L
.47199 .64521 L
.47092 .64006 L
.44398 .62356 L
.41597 .62365 L
.38796 .63571 L
.37841 .64006 L
.35994 .65421 L
.33925 .66807 L
.33193 .67663 L
.30881 .69608 L
.30392 .70155 L
.27932 .72409 L
.27591 .72777 L
.25035 .7521 L
.2479 .75469 L
.2217 .78011 L
.21989 .782 L
.19325 .80812 L
.19188 .80954 L
.16493 .83613 L
.16387 .83722 L
.13669 .86415 L
.13585 .865 L
.10852 .89216 L
.10784 .89284 L
.08038 .92017 L
.07983 .92072 L
.05227 .94818 L
.05182 .94863 L
.02421 .97619 L
s
.97579 .02381 m
.94818 .05137 L
.94773 .05182 L
.92017 .07928 L
.91962 .07983 L
.89216 .10716 L
.89148 .10784 L
.86415 .135 L
.86331 .13585 L
.83613 .16278 L
.83507 .16387 L
.80812 .19046 L
.80675 .19188 L
.78011 .218 L
.7783 .21989 L
.7521 .24531 L
.74965 .2479 L
.72409 .27223 L
.72068 .27591 L
.69608 .29845 L
.69119 .30392 L
.66807 .32337 L
.66075 .33193 L
.64006 .34579 L
.62159 .35994 L
.61204 .36429 L
.58403 .37635 L
.55602 .37644 L
.52908 .35994 L
.52801 .35479 L
.5174 .33193 L
.51089 .30392 L
.5073 .27591 L
.50513 .2479 L
.50374 .21989 L
.50281 .19188 L
.50216 .16387 L
.5017 .13585 L
.50136 .10784 L
.50111 .07983 L
.50091 .05182 L
.50076 .02381 L
s
.02381 .4878 m
.05182 .48536 L
.07983 .48222 L
.10784 .47811 L
.13585 .47258 L
.1384 .47199 L
.16387 .46498 L
.19188 .45401 L
.20989 .44398 L
.21989 .43703 L
.24034 .41597 L
.2479 .40635 L
.25422 .38796 L
.25805 .35994 L
.25457 .33193 L
.2479 .31011 L
.24538 .30392 L
.23134 .27591 L
.21989 .25611 L
.2139 .2479 L
.19368 .21989 L
.19188 .21742 L
.17135 .19188 L
.16387 .18262 L
.14762 .16387 L
.13585 .15021 L
.12285 .13585 L
.10784 .11915 L
.0973 .10784 L
.07983 .08893 L
.07118 .07983 L
.05182 .05927 L
.04475 .05182 L
.02381 .03018 L
s
.97619 .96982 m
.95525 .94818 L
.94818 .94073 L
.92882 .92017 L
.92017 .91107 L
.9027 .89216 L
.89216 .88085 L
.87715 .86415 L
.86415 .84979 L
.85238 .83613 L
.83613 .81738 L
.82865 .80812 L
.80812 .78258 L
.80632 .78011 L
.7861 .7521 L
.78011 .74389 L
.76866 .72409 L
.75462 .69608 L
.7521 .68989 L
.74543 .66807 L
.74195 .64006 L
.74578 .61204 L
.7521 .59365 L
.75966 .58403 L
.78011 .56297 L
.79011 .55602 L
.80812 .54599 L
.83613 .53502 L
.8616 .52801 L
.86415 .52742 L
.89216 .52189 L
.92017 .51778 L
.94818 .51464 L
.97619 .5122 L
s
.4878 .97619 m
.48536 .94818 L
.48222 .92017 L
.47811 .89216 L
.47258 .86415 L
.47199 .8616 L
.46498 .83613 L
.45401 .80812 L
.44398 .79011 L
.43703 .78011 L
.41597 .75966 L
.40635 .7521 L
.38796 .74578 L
.35994 .74195 L
.33193 .74543 L
.31011 .7521 L
.30392 .75462 L
.27591 .76866 L
.25611 .78011 L
.2479 .7861 L
.21989 .80632 L
.21742 .80812 L
.19188 .82865 L
.18262 .83613 L
.16387 .85238 L
.15021 .86415 L
.13585 .87715 L
.11915 .89216 L
.10784 .9027 L
.08893 .92017 L
.07983 .92882 L
.05927 .94818 L
.05182 .95525 L
.03018 .97619 L
s
.96982 .02381 m
.94818 .04475 L
.94073 .05182 L
.92017 .07118 L
.91107 .07983 L
.89216 .0973 L
.88085 .10784 L
.86415 .12285 L
.84979 .13585 L
.83613 .14762 L
.81738 .16387 L
.80812 .17135 L
.78258 .19188 L
.78011 .19368 L
.7521 .2139 L
.74389 .21989 L
.72409 .23134 L
.69608 .24538 L
.68989 .2479 L
.66807 .25457 L
.64006 .25805 L
.61204 .25422 L
.59365 .2479 L
.58403 .24034 L
.56297 .21989 L
.55602 .20989 L
.54599 .19188 L
.53502 .16387 L
.52801 .1384 L
.52742 .13585 L
.52189 .10784 L
.51778 .07983 L
.51464 .05182 L
.5122 .02381 L
s
.02381 .46244 m
.05182 .45477 L
.07983 .4447 L
.08155 .44398 L
.10784 .43105 L
.13016 .41597 L
.13585 .41129 L
.15718 .38796 L
.16387 .37822 L
.1722 .35994 L
.17903 .33193 L
.1796 .30392 L
.17501 .27591 L
.16613 .2479 L
.16387 .24168 L
.15352 .21989 L
.13793 .19188 L
.13585 .18835 L
.11976 .16387 L
.10784 .14674 L
.09964 .13585 L
.07983 .11018 L
.07792 .10784 L
.0549 .07983 L
.05182 .07613 L
.03104 .05182 L
.02381 .04381 L
s
.97619 .95619 m
.96896 .94818 L
.94818 .92387 L
.9451 .92017 L
.92208 .89216 L
.92017 .88982 L
.90036 .86415 L
.89216 .85326 L
.88024 .83613 L
.86415 .81165 L
.86207 .80812 L
.84648 .78011 L
.83613 .75832 L
.83387 .7521 L
.82499 .72409 L
.8204 .69608 L
.82097 .66807 L
.8278 .64006 L
.83613 .62178 L
.84282 .61204 L
.86415 .58871 L
.86984 .58403 L
.89216 .56895 L
.91845 .55602 L
.92017 .5553 L
.94818 .54523 L
.97619 .53756 L
s
.46244 .97619 m
.45477 .94818 L
.4447 .92017 L
.44398 .91845 L
.43105 .89216 L
.41597 .86984 L
.41129 .86415 L
.38796 .84282 L
.37822 .83613 L
.35994 .8278 L
.33193 .82097 L
.30392 .8204 L
.27591 .82499 L
.2479 .83387 L
.24168 .83613 L
.21989 .84648 L
.19188 .86207 L
.18835 .86415 L
.16387 .88024 L
.14674 .89216 L
.13585 .90036 L
.11018 .92017 L
.10784 .92208 L
.07983 .9451 L
.07613 .94818 L
.05182 .96896 L
.04381 .97619 L
s
.95619 .02381 m
.94818 .03104 L
.92387 .05182 L
.92017 .0549 L
.89216 .07792 L
.88982 .07983 L
.86415 .09964 L
.85326 .10784 L
.83613 .11976 L
.81165 .13585 L
.80812 .13793 L
.78011 .15352 L
.75832 .16387 L
.7521 .16613 L
.72409 .17501 L
.69608 .1796 L
.66807 .17903 L
.64006 .1722 L
.62178 .16387 L
.61204 .15718 L
.58871 .13585 L
.58403 .13016 L
.56895 .10784 L
.55602 .08155 L
.5553 .07983 L
.54523 .05182 L
.53756 .02381 L
s
.02381 .4217 m
.03403 .41597 L
.05182 .40427 L
.07125 .38796 L
.07983 .37915 L
.09444 .35994 L
.10784 .33376 L
.10849 .33193 L
.11573 .30392 L
.11758 .27591 L
.11488 .2479 L
.10828 .21989 L
.10784 .21827 L
.09822 .19188 L
.08524 .16387 L
.07983 .15333 L
.06972 .13585 L
.05209 .10784 L
.05182 .10743 L
.03273 .07983 L
.02381 .06774 L
s
.97619 .93226 m
.96727 .92017 L
.94818 .89257 L
.94791 .89216 L
.93028 .86415 L
.92017 .84667 L
.91476 .83613 L
.90178 .80812 L
.89216 .78173 L
.89172 .78011 L
.88512 .7521 L
.88242 .72409 L
.88427 .69608 L
.89151 .66807 L
.89216 .66624 L
.90556 .64006 L
.92017 .62085 L
.92875 .61204 L
.94818 .59573 L
.96597 .58403 L
.97619 .5783 L
s
.4217 .97619 m
.41597 .96597 L
.40427 .94818 L
.38796 .92875 L
.37915 .92017 L
.35994 .90556 L
.33376 .89216 L
.33193 .89151 L
.30392 .88427 L
.27591 .88242 L
.2479 .88512 L
.21989 .89172 L
.21827 .89216 L
.19188 .90178 L
.16387 .91476 L
.15333 .92017 L
.13585 .93028 L
.10784 .94791 L
.10743 .94818 L
.07983 .96727 L
.06774 .97619 L
s
.93226 .02381 m
.92017 .03273 L
.89257 .05182 L
.89216 .05209 L
.86415 .06972 L
.84667 .07983 L
.83613 .08524 L
.80812 .09822 L
.78173 .10784 L
.78011 .10828 L
.7521 .11488 L
.72409 .11758 L
.69608 .11573 L
.66807 .10849 L
.66624 .10784 L
.64006 .09444 L
.62085 .07983 L
.61204 .07125 L
.59573 .05182 L
.58403 .03403 L
.5783 .02381 L
s
.02381 .35884 m
.0427 .33193 L
.05182 .31336 L
.05518 .30392 L
.06196 .27591 L
.06402 .2479 L
.06203 .21989 L
.05649 .19188 L
.05182 .17432 L
.04784 .16387 L
.03644 .13585 L
.02381 .11026 L
s
.97619 .88974 m
.96356 .86415 L
.95216 .83613 L
.94818 .82568 L
.94351 .80812 L
.93797 .78011 L
.93598 .7521 L
.93804 .72409 L
.94482 .69608 L
.94818 .68664 L
.9573 .66807 L
.97619 .64116 L
s
.35884 .97619 m
.33193 .9573 L
.31336 .94818 L
.30392 .94482 L
.27591 .93804 L
.2479 .93598 L
.21989 .93797 L
.19188 .94351 L
.17432 .94818 L
.16387 .95216 L
.13585 .96356 L
.11026 .97619 L
s
.88974 .02381 m
.86415 .03644 L
.83613 .04784 L
.82568 .05182 L
.80812 .05649 L
.78011 .06203 L
.7521 .06402 L
.72409 .06196 L
.69608 .05518 L
.68664 .05182 L
.66807 .0427 L
.64116 .02381 L
s
.02381 .6173 m
.0284 .61204 L
.04871 .58403 L
.05182 .57924 L
.06288 .55602 L
.07128 .52801 L
.07406 .5 L
.07128 .47199 L
.06288 .44398 L
.05182 .42076 L
.04871 .41597 L
.0284 .38796 L
.02381 .3827 L
s
.97619 .6173 m
.9716 .61204 L
.95129 .58403 L
.94818 .57924 L
.93712 .55602 L
.92872 .52801 L
.92594 .5 L
.92872 .47199 L
.93712 .44398 L
.94818 .42076 L
.95129 .41597 L
.9716 .38796 L
.97619 .3827 L
s
.6173 .97619 m
.61204 .9716 L
.58403 .95129 L
.57924 .94818 L
.55602 .93712 L
.52801 .92872 L
.5 .92594 L
.47199 .92872 L
.44398 .93712 L
.42076 .94818 L
.41597 .95129 L
.38796 .9716 L
.3827 .97619 L
s
.6173 .02381 m
.61204 .0284 L
.58403 .04871 L
.57924 .05182 L
.55602 .06288 L
.52801 .07128 L
.5 .07406 L
.47199 .07128 L
.44398 .06288 L
.42076 .05182 L
.41597 .04871 L
.38796 .0284 L
.3827 .02381 L
s
.02381 .66269 m
.05182 .643 L
.05563 .64006 L
.07983 .62007 L
.0882 .61204 L
.10784 .59088 L
.11299 .58403 L
.13022 .55602 L
.13585 .54286 L
.14029 .52801 L
.14359 .5 L
.14029 .47199 L
.13585 .45714 L
.13022 .44398 L
.11299 .41597 L
.10784 .40912 L
.0882 .38796 L
.07983 .37993 L
.05563 .35994 L
.05182 .357 L
.02381 .33731 L
s
.97619 .66269 m
.94818 .643 L
.94437 .64006 L
.92017 .62007 L
.9118 .61204 L
.89216 .59088 L
.88701 .58403 L
.86978 .55602 L
.86415 .54286 L
.85971 .52801 L
.85641 .5 L
.85971 .47199 L
.86415 .45714 L
.86978 .44398 L
.88701 .41597 L
.89216 .40912 L
.9118 .38796 L
.92017 .37993 L
.94437 .35994 L
.94818 .357 L
.97619 .33731 L
s
.66269 .97619 m
.643 .94818 L
.64006 .94437 L
.62007 .92017 L
.61204 .9118 L
.59088 .89216 L
.58403 .88701 L
.55602 .86978 L
.54286 .86415 L
.52801 .85971 L
.5 .85641 L
.47199 .85971 L
.45714 .86415 L
.44398 .86978 L
.41597 .88701 L
.40912 .89216 L
.38796 .9118 L
.37993 .92017 L
.35994 .94437 L
.357 .94818 L
.33731 .97619 L
s
.66269 .02381 m
.643 .05182 L
.64006 .05563 L
.62007 .07983 L
.61204 .0882 L
.59088 .10784 L
.58403 .11299 L
.55602 .13022 L
.54286 .13585 L
.52801 .14029 L
.5 .14359 L
.47199 .14029 L
.45714 .13585 L
.44398 .13022 L
.41597 .11299 L
.40912 .10784 L
.38796 .0882 L
.37993 .07983 L
.35994 .05563 L
.357 .05182 L
.33731 .02381 L
s
.02381 .68661 m
.05182 .67278 L
.0609 .66807 L
.07983 .65831 L
.10784 .64276 L
.11232 .64006 L
.13585 .62579 L
.1557 .61204 L
.16387 .60623 L
.1894 .58403 L
.19188 .58183 L
.21262 .55602 L
.21989 .54359 L
.22609 .52801 L
.23045 .5 L
.22609 .47199 L
.21989 .45641 L
.21262 .44398 L
.19188 .41817 L
.1894 .41597 L
.16387 .39377 L
.1557 .38796 L
.13585 .37421 L
.11232 .35994 L
.10784 .35724 L
.07983 .34169 L
.0609 .33193 L
.05182 .32722 L
.02381 .31339 L
s
.97619 .68661 m
.94818 .67278 L
.9391 .66807 L
.92017 .65831 L
.89216 .64276 L
.88768 .64006 L
.86415 .62579 L
.8443 .61204 L
.83613 .60623 L
.8106 .58403 L
.80812 .58183 L
.78738 .55602 L
.78011 .54359 L
.77391 .52801 L
.76955 .5 L
.77391 .47199 L
.78011 .45641 L
.78738 .44398 L
.80812 .41817 L
.8106 .41597 L
.83613 .39377 L
.8443 .38796 L
.86415 .37421 L
.88768 .35994 L
.89216 .35724 L
.92017 .34169 L
.9391 .33193 L
.94818 .32722 L
.97619 .31339 L
s
.68661 .97619 m
.67278 .94818 L
.66807 .9391 L
.65831 .92017 L
.64276 .89216 L
.64006 .88768 L
.62579 .86415 L
.61204 .8443 L
.60623 .83613 L
.58403 .8106 L
.58183 .80812 L
.55602 .78738 L
.54359 .78011 L
.52801 .77391 L
.5 .76955 L
.47199 .77391 L
.45641 .78011 L
.44398 .78738 L
.41817 .80812 L
.41597 .8106 L
.39377 .83613 L
.38796 .8443 L
.37421 .86415 L
.35994 .88768 L
.35724 .89216 L
.34169 .92017 L
.33193 .9391 L
.32722 .94818 L
.31339 .97619 L
s
.68661 .02381 m
.67278 .05182 L
.66807 .0609 L
.65831 .07983 L
.64276 .10784 L
.64006 .11232 L
.62579 .13585 L
.61204 .1557 L
.60623 .16387 L
.58403 .1894 L
.58183 .19188 L
.55602 .21262 L
.54359 .21989 L
.52801 .22609 L
.5 .23045 L
.47199 .22609 L
.45641 .21989 L
.44398 .21262 L
.41817 .19188 L
.41597 .1894 L
.39377 .16387 L
.38796 .1557 L
.37421 .13585 L
.35994 .11232 L
.35724 .10784 L
.34169 .07983 L
.33193 .0609 L
.32722 .05182 L
.31339 .02381 L
s
.02381 .69659 m
.02538 .69608 L
.05182 .68489 L
.07983 .67311 L
.09144 .66807 L
.10784 .66131 L
.13585 .64942 L
.15738 .64006 L
.16387 .63741 L
.19188 .62531 L
.21989 .6128 L
.22121 .61204 L
.2479 .60018 L
.27591 .58644 L
.27919 .58403 L
.30392 .57206 L
.32742 .55602 L
.33193 .55523 L
.35596 .52801 L
.35994 .52175 L
.36406 .5 L
.35994 .47825 L
.35596 .47199 L
.33193 .44477 L
.32742 .44398 L
.30392 .42794 L
.27919 .41597 L
.27591 .41356 L
.2479 .39982 L
.22121 .38796 L
.21989 .3872 L
.19188 .37469 L
.16387 .36259 L
.15738 .35994 L
.13585 .35058 L
.10784 .33869 L
.09144 .33193 L
.07983 .32689 L
.05182 .31511 L
.02538 .30392 L
.02381 .30341 L
s
.97619 .69659 m
.97462 .69608 L
.94818 .68489 L
.92017 .67311 L
.90856 .66807 L
.89216 .66131 L
.86415 .64942 L
.84262 .64006 L
.83613 .63741 L
.80812 .62531 L
.78011 .6128 L
.77879 .61204 L
.7521 .60018 L
.72409 .58644 L
.72081 .58403 L
.69608 .57206 L
.67258 .55602 L
.66807 .55523 L
.64404 .52801 L
.64006 .52175 L
.63594 .5 L
.64006 .47825 L
.64404 .47199 L
.66807 .44477 L
.67258 .44398 L
.69608 .42794 L
.72081 .41597 L
.72409 .41356 L
.7521 .39982 L
.77879 .38796 L
.78011 .3872 L
.80812 .37469 L
.83613 .36259 L
.84262 .35994 L
.86415 .35058 L
.89216 .33869 L
.90856 .33193 L
.92017 .32689 L
.94818 .31511 L
.97462 .30392 L
.97619 .30341 L
s
.69659 .97619 m
.69608 .97462 L
.68489 .94818 L
.67311 .92017 L
.66807 .90856 L
.66131 .89216 L
.64942 .86415 L
.64006 .84262 L
.63741 .83613 L
.62531 .80812 L
.6128 .78011 L
.61204 .77879 L
.60018 .7521 L
.58644 .72409 L
.58403 .72081 L
.57206 .69608 L
.55602 .67258 L
.55523 .66807 L
.52801 .64404 L
.52175 .64006 L
.5 .63594 L
.47825 .64006 L
.47199 .64404 L
.44477 .66807 L
.44398 .67258 L
.42794 .69608 L
.41597 .72081 L
.41356 .72409 L
.39982 .7521 L
.38796 .77879 L
.3872 .78011 L
.37469 .80812 L
.36259 .83613 L
.35994 .84262 L
.35058 .86415 L
.33869 .89216 L
.33193 .90856 L
.32689 .92017 L
.31511 .94818 L
.30392 .97462 L
.30341 .97619 L
s
.69659 .02381 m
.69608 .02538 L
.68489 .05182 L
.67311 .07983 L
.66807 .09144 L
.66131 .10784 L
.64942 .13585 L
.64006 .15738 L
.63741 .16387 L
.62531 .19188 L
.6128 .21989 L
.61204 .22121 L
.60018 .2479 L
.58644 .27591 L
.58403 .27919 L
.57206 .30392 L
.55602 .32742 L
.55523 .33193 L
.52801 .35596 L
.52175 .35994 L
.5 .36406 L
.47825 .35994 L
.47199 .35596 L
.44477 .33193 L
.44398 .32742 L
.42794 .30392 L
.41597 .27919 L
.41356 .27591 L
.39982 .2479 L
.38796 .22121 L
.3872 .21989 L
.37469 .19188 L
.36259 .16387 L
.35994 .15738 L
.35058 .13585 L
.33869 .10784 L
.33193 .09144 L
.32689 .07983 L
.31511 .05182 L
.30392 .02538 L
.30341 .02381 L
s
.97619 .6979 m
.97083 .69608 L
.94818 .68645 L
.92017 .67501 L
.90346 .66807 L
.89216 .66363 L
.86415 .65233 L
.83613 .64108 L
.83392 .64006 L
.80812 .6301 L
.78011 .61925 L
.76219 .61204 L
.7521 .60882 L
.72409 .59911 L
.69608 .59024 L
.67191 .58403 L
.66807 .58333 L
.64006 .58039 L
.61324 .58403 L
.61204 .58449 L
.58449 .61204 L
.58403 .61324 L
.58039 .64006 L
.58333 .66807 L
.58403 .67191 L
.59024 .69608 L
.59911 .72409 L
.60882 .7521 L
.61204 .76219 L
.61925 .78011 L
.6301 .80812 L
.64006 .83392 L
.64108 .83613 L
.65233 .86415 L
.66363 .89216 L
.66807 .90346 L
.67501 .92017 L
.68645 .94818 L
.69608 .97083 L
.6979 .97619 L
s
.02381 .6979 m
.02917 .69608 L
.05182 .68645 L
.07983 .67501 L
.09654 .66807 L
.10784 .66363 L
.13585 .65233 L
.16387 .64108 L
.16608 .64006 L
.19188 .6301 L
.21989 .61925 L
.23781 .61204 L
.2479 .60882 L
.27591 .59911 L
.30392 .59024 L
.32809 .58403 L
.33193 .58333 L
.35994 .58039 L
.38676 .58403 L
.38796 .58449 L
.41551 .61204 L
.41597 .61324 L
.41961 .64006 L
.41667 .66807 L
.41597 .67191 L
.40976 .69608 L
.40089 .72409 L
.39118 .7521 L
.38796 .76219 L
.38075 .78011 L
.3699 .80812 L
.35994 .83392 L
.35892 .83613 L
.34767 .86415 L
.33637 .89216 L
.33193 .90346 L
.32499 .92017 L
.31355 .94818 L
.30392 .97083 L
.3021 .97619 L
s
.97619 .3021 m
.97083 .30392 L
.94818 .31355 L
.92017 .32499 L
.90346 .33193 L
.89216 .33637 L
.86415 .34767 L
.83613 .35892 L
.83392 .35994 L
.80812 .3699 L
.78011 .38075 L
.76219 .38796 L
.7521 .39118 L
.72409 .40089 L
.69608 .40976 L
.67191 .41597 L
.66807 .41667 L
.64006 .41961 L
.61324 .41597 L
.61204 .41551 L
.58449 .38796 L
.58403 .38676 L
.58039 .35994 L
.58333 .33193 L
.58403 .32809 L
.59024 .30392 L
.59911 .27591 L
.60882 .2479 L
.61204 .23781 L
.61925 .21989 L
.6301 .19188 L
.64006 .16608 L
.64108 .16387 L
.65233 .13585 L
.66363 .10784 L
.66807 .09654 L
.67501 .07983 L
.68645 .05182 L
.69608 .02917 L
.6979 .02381 L
s
.02381 .3021 m
.02917 .30392 L
.05182 .31355 L
.07983 .32499 L
.09654 .33193 L
.10784 .33637 L
.13585 .34767 L
.16387 .35892 L
.16608 .35994 L
.19188 .3699 L
.21989 .38075 L
.23781 .38796 L
.2479 .39118 L
.27591 .40089 L
.30392 .40976 L
.32809 .41597 L
.33193 .41667 L
.35994 .41961 L
.38676 .41597 L
.38796 .41551 L
.41551 .38796 L
.41597 .38676 L
.41961 .35994 L
.41667 .33193 L
.41597 .32809 L
.40976 .30392 L
.40089 .27591 L
.39118 .2479 L
.38796 .23781 L
.38075 .21989 L
.3699 .19188 L
.35994 .16608 L
.35892 .16387 L
.34767 .13585 L
.33637 .10784 L
.33193 .09654 L
.32499 .07983 L
.31355 .05182 L
.30392 .02917 L
.3021 .02381 L
s
.97619 .70744 m
.94818 .69778 L
.9434 .69608 L
.92017 .68868 L
.89216 .68025 L
.86415 .67275 L
.84519 .66807 L
.83613 .66654 L
.80812 .66214 L
.78011 .66023 L
.7521 .66189 L
.72612 .66807 L
.72409 .66897 L
.69608 .68533 L
.68533 .69608 L
.66897 .72409 L
.66807 .72612 L
.66189 .7521 L
.66023 .78011 L
.66214 .80812 L
.66654 .83613 L
.66807 .84519 L
.67275 .86415 L
.68025 .89216 L
.68868 .92017 L
.69608 .9434 L
.69778 .94818 L
.70744 .97619 L
s
.02381 .70744 m
.05182 .69778 L
.0566 .69608 L
.07983 .68868 L
.10784 .68025 L
.13585 .67275 L
.15481 .66807 L
.16387 .66654 L
.19188 .66214 L
.21989 .66023 L
.2479 .66189 L
.27388 .66807 L
.27591 .66897 L
.30392 .68533 L
.31467 .69608 L
.33103 .72409 L
.33193 .72612 L
.33811 .7521 L
.33977 .78011 L
.33786 .80812 L
.33346 .83613 L
.33193 .84519 L
.32725 .86415 L
.31975 .89216 L
.31132 .92017 L
.30392 .9434 L
.30222 .94818 L
.29256 .97619 L
s
.97619 .29256 m
.94818 .30222 L
.9434 .30392 L
.92017 .31132 L
.89216 .31975 L
.86415 .32725 L
.84519 .33193 L
.83613 .33346 L
.80812 .33786 L
.78011 .33977 L
.7521 .33811 L
.72612 .33193 L
.72409 .33103 L
.69608 .31467 L
.68533 .30392 L
.66897 .27591 L
.66807 .27388 L
.66189 .2479 L
.66023 .21989 L
.66214 .19188 L
.66654 .16387 L
.66807 .15481 L
.67275 .13585 L
.68025 .10784 L
.68868 .07983 L
.69608 .0566 L
.69778 .05182 L
.70744 .02381 L
s
.02381 .29256 m
.05182 .30222 L
.0566 .30392 L
.07983 .31132 L
.10784 .31975 L
.13585 .32725 L
.15481 .33193 L
.16387 .33346 L
.19188 .33786 L
.21989 .33977 L
.2479 .33811 L
.27388 .33193 L
.27591 .33103 L
.30392 .31467 L
.31467 .30392 L
.33103 .27591 L
.33193 .27388 L
.33811 .2479 L
.33977 .21989 L
.33786 .19188 L
.33346 .16387 L
.33193 .15481 L
.32725 .13585 L
.31975 .10784 L
.31132 .07983 L
.30392 .0566 L
.30222 .05182 L
.29256 .02381 L
s
.97619 .72717 m
.94977 .72409 L
.94818 .721 L
.92017 .71613 L
.89216 .71294 L
.86415 .71192 L
.83613 .71379 L
.80812 .71958 L
.79485 .72409 L
.78011 .73105 L
.7521 .75185 L
.75185 .7521 L
.73105 .78011 L
.72409 .79485 L
.71958 .80812 L
.71379 .83613 L
.71192 .86415 L
.71294 .89216 L
.71613 .92017 L
.721 .94818 L
.72409 .94977 L
.72717 .97619 L
s
.02381 .72717 m
.05023 .72409 L
.05182 .721 L
.07983 .71613 L
.10784 .71294 L
.13585 .71192 L
.16387 .71379 L
.19188 .71958 L
.20515 .72409 L
.21989 .73105 L
.2479 .75185 L
.24815 .7521 L
.26895 .78011 L
.27591 .79485 L
.28042 .80812 L
.28621 .83613 L
.28808 .86415 L
.28706 .89216 L
.28387 .92017 L
.279 .94818 L
.27591 .94977 L
.27283 .97619 L
s
.97619 .27283 m
.94977 .27591 L
.94818 .279 L
.92017 .28387 L
.89216 .28706 L
.86415 .28808 L
.83613 .28621 L
.80812 .28042 L
.79485 .27591 L
.78011 .26895 L
.7521 .24815 L
.75185 .2479 L
.73105 .21989 L
.72409 .20515 L
.71958 .19188 L
.71379 .16387 L
.71192 .13585 L
.71294 .10784 L
.71613 .07983 L
.721 .05182 L
.72409 .05023 L
.72717 .02381 L
s
.02381 .27283 m
.05023 .27591 L
.05182 .279 L
.07983 .28387 L
.10784 .28706 L
.13585 .28808 L
.16387 .28621 L
.19188 .28042 L
.20515 .27591 L
.21989 .26895 L
.2479 .24815 L
.24815 .2479 L
.26895 .21989 L
.27591 .20515 L
.28042 .19188 L
.28621 .16387 L
.28808 .13585 L
.28706 .10784 L
.28387 .07983 L
.279 .05182 L
.27591 .05023 L
.27283 .02381 L
s
.97619 .75514 m
.94818 .75338 L
.92017 .75379 L
.89216 .75695 L
.86415 .76371 L
.83613 .77544 L
.82793 .78011 L
.80812 .79467 L
.79467 .80812 L
.78011 .82793 L
.77544 .83613 L
.76371 .86415 L
.75695 .89216 L
.75379 .92017 L
.75338 .94818 L
.75514 .97619 L
s
.02381 .75514 m
.05182 .75338 L
.07983 .75379 L
.10784 .75695 L
.13585 .76371 L
.16387 .77544 L
.17207 .78011 L
.19188 .79467 L
.20533 .80812 L
.21989 .82793 L
.22456 .83613 L
.23629 .86415 L
.24305 .89216 L
.24621 .92017 L
.24662 .94818 L
.24486 .97619 L
s
.97619 .24486 m
.94818 .24662 L
.92017 .24621 L
.89216 .24305 L
.86415 .23629 L
.83613 .22456 L
.82793 .21989 L
.80812 .20533 L
.79467 .19188 L
.78011 .17207 L
.77544 .16387 L
.76371 .13585 L
.75695 .10784 L
.75379 .07983 L
.75338 .05182 L
.75514 .02381 L
s
.02381 .24486 m
.05182 .24662 L
.07983 .24621 L
.10784 .24305 L
.13585 .23629 L
.16387 .22456 L
.17207 .21989 L
.19188 .20533 L
.20533 .19188 L
.21989 .17207 L
.22456 .16387 L
.23629 .13585 L
.24305 .10784 L
.24621 .07983 L
.24662 .05182 L
.24486 .02381 L
s
.97619 .78955 m
.94818 .79279 L
.92017 .79915 L
.89544 .80812 L
.89216 .80962 L
.86415 .82584 L
.85113 .83613 L
.83613 .85113 L
.82584 .86415 L
.80962 .89216 L
.80812 .89544 L
.79915 .92017 L
.79279 .94818 L
.78955 .97619 L
s
.02381 .78955 m
.05182 .79279 L
.07983 .79915 L
.10456 .80812 L
.10784 .80962 L
.13585 .82584 L
.14887 .83613 L
.16387 .85113 L
.17416 .86415 L
.19038 .89216 L
.19188 .89544 L
.20085 .92017 L
.20721 .94818 L
.21045 .97619 L
s
.97619 .21045 m
.94818 .20721 L
.92017 .20085 L
.89544 .19188 L
.89216 .19038 L
.86415 .17416 L
.85113 .16387 L
.83613 .14887 L
.82584 .13585 L
.80962 .10784 L
.80812 .10456 L
.79915 .07983 L
.79279 .05182 L
.78955 .02381 L
s
.02381 .21045 m
.05182 .20721 L
.07983 .20085 L
.10456 .19188 L
.10784 .19038 L
.13585 .17416 L
.14887 .16387 L
.16387 .14887 L
.17416 .13585 L
.19038 .10784 L
.19188 .10456 L
.20085 .07983 L
.20721 .05182 L
.21045 .02381 L
s
.97619 .82915 m
.95305 .83613 L
.94818 .83794 L
.92017 .85116 L
.90034 .86415 L
.89216 .87066 L
.87066 .89216 L
.86415 .90034 L
.85116 .92017 L
.83794 .94818 L
.83613 .95305 L
.82915 .97619 L
s
.02381 .82915 m
.04695 .83613 L
.05182 .83794 L
.07983 .85116 L
.09966 .86415 L
.10784 .87066 L
.12934 .89216 L
.13585 .90034 L
.14884 .92017 L
.16206 .94818 L
.16387 .95305 L
.17085 .97619 L
s
.97619 .17085 m
.95305 .16387 L
.94818 .16206 L
.92017 .14884 L
.90034 .13585 L
.89216 .12934 L
.87066 .10784 L
.86415 .09966 L
.85116 .07983 L
.83794 .05182 L
.83613 .04695 L
.82915 .02381 L
s
.02381 .17085 m
.04695 .16387 L
.05182 .16206 L
.07983 .14884 L
.09966 .13585 L
.10784 .12934 L
.12934 .10784 L
.13585 .09966 L
.14884 .07983 L
.16206 .05182 L
.16387 .04695 L
.17085 .02381 L
s
.97619 .87335 m
.94818 .88853 L
.94274 .89216 L
.92017 .91028 L
.91028 .92017 L
.89216 .94274 L
.88853 .94818 L
.87335 .97619 L
s
.02381 .87335 m
.05182 .88853 L
.05726 .89216 L
.07983 .91028 L
.08972 .92017 L
.10784 .94274 L
.11147 .94818 L
.12665 .97619 L
s
.97619 .12665 m
.94818 .11147 L
.94274 .10784 L
.92017 .08972 L
.91028 .07983 L
.89216 .05726 L
.88853 .05182 L
.87335 .02381 L
s
.02381 .12665 m
.05182 .11147 L
.05726 .10784 L
.07983 .08972 L
.08972 .07983 L
.10784 .05726 L
.11147 .05182 L
.12665 .02381 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-2, -2, 0, 0}}],
 "     ",
 StyleBox["\n\t\tFigure 3.C",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  The orthogonal grid formed by ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["x", "3"], "-", 
    RowBox[{"3", " ", "x", " ", 
     SuperscriptBox["y", "2"]}]}], "=", "C"}]]],
 " and ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"3", " ", 
     SuperscriptBox["x", "2"], " ", "y"}], "-", 
    SuperscriptBox["y", "3"]}], "=", "C"}]]],
 ". "
}], "Text"],

Cell[TextData[{
 StyleBox["Extra Example 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Show that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"u", 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], "=", " ", 
   RowBox[{"x", "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["x", "3"]}], "-", 
    RowBox[{"6", " ", "x", " ", "y"}], "-", 
    RowBox[{"4", " ", 
     SuperscriptBox["x", "3"], " ", "y"}], "+", 
    RowBox[{"6", " ", "x", " ", 
     SuperscriptBox["y", "2"]}], "+", 
    RowBox[{"4", " ", "x", " ", 
     SuperscriptBox["y", "3"]}]}]}]]],
 "  is a harmonic function and find the harmonic conjugate  ",
 Cell[BoxData[
  RowBox[{"v", 
   RowBox[{"(", 
    RowBox[{"x", ",", "y"}], ")"}]}]]],
 "."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Extra Solution 1.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell["Enter the function u[x,y], do a step by step construction.", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"u", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", " ", 
     RowBox[{"x", "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["x", "3"]}], "-", 
      RowBox[{"6", " ", "x", " ", "y"}], "-", 
      RowBox[{"4", " ", 
       SuperscriptBox["x", "3"], " ", "y"}], "+", 
      RowBox[{"6", " ", "x", " ", 
       SuperscriptBox["y", "2"]}], "+", 
      RowBox[{"4", " ", "x", " ", 
       SuperscriptBox["y", "3"]}]}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", "c", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"c", "[", "x_", "]"}], "=", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", " ", 
          RowBox[{
           SubscriptBox["\[PartialD]", "y"], " ", 
           RowBox[{"u", "[", 
            RowBox[{"x", ",", "y"}], "]"}]}]}], " ", "-", " ", 
         RowBox[{
          SubscriptBox["\[PartialD]", "x"], "  ", 
          RowBox[{"(", 
           RowBox[{"\[Integral]", 
            RowBox[{
             RowBox[{
              SubscriptBox["\[PartialD]", "x"], " ", 
              RowBox[{"u", "[", 
               RowBox[{"x", ",", "y"}], "]"}]}], 
             RowBox[{"\[DifferentialD]", "y"}]}]}], ")"}]}]}], ")"}], 
       RowBox[{"\[DifferentialD]", "x"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{
     RowBox[{"v", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", " ", 
     RowBox[{
      RowBox[{"\[Integral]", 
       RowBox[{
        RowBox[{
         SubscriptBox["\[PartialD]", "x"], 
         RowBox[{"u", "[", 
          RowBox[{"x", ",", "y"}], "]"}]}], 
        RowBox[{"\[DifferentialD]", "y"}]}]}], " ", "+", " ", 
      RowBox[{"c", "[", "x", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< u[x,y] = \>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(u\), \(x\)]\)[x,y] = \>\"", ",", 
      RowBox[{
       SubscriptBox["\[PartialD]", "x"], 
       RowBox[{"u", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(u\), \(y\)]\)[x,y] = \>\"", ",", 
      RowBox[{
       SubscriptBox["\[PartialD]", "y"], 
       RowBox[{"u", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Construct the function c[x]\>\"", "]"}], ";"}],
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<c[x] = \[Integral](- \!\(\*SubscriptBox[\(\[PartialD]\), \
\(y\)]\)u[x,y] - \!\(\*SubscriptBox[\(\[PartialD]\), \(x\)]\)(\[Integral]\!\(\
\*SubscriptBox[\(\[PartialD]\), \(x\)]\) u[x,y]\[DifferentialD]y))\
\[DifferentialD]x\>\"", " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<c[x] = \[Integral](- \!\(\*SubscriptBox[\(\[PartialD]\), \
\(y\)]\)(\>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}], ",", 
      "\"\<) - \!\(\*SubscriptBox[\(\[PartialD]\), \
\(x\)]\)(\[Integral]\!\(\*SubscriptBox[\(\[PartialD]\), \(x\)]\)(\>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}], ",", 
      "\"\<)\[DifferentialD]y))\[DifferentialD]x\>\""}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<c[x] = \[Integral](- (\>\"", ",", 
      RowBox[{
       SubscriptBox["\[PartialD]", "y"], 
       RowBox[{"u", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}], ",", 
      "\"\<) - \!\(\*SubscriptBox[\(\[PartialD]\), \(x\)]\)(\>\"", ",", 
      RowBox[{"\[Integral]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[PartialD]", "x"], 
          RowBox[{"u", "[", 
           RowBox[{"x", ",", "y"}], "]"}]}], ")"}], 
        RowBox[{"\[DifferentialD]", "y"}]}]}], ",", 
      "\"\<))\[DifferentialD]x\>\""}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<c[x] = \[Integral](\>\"", ",", 
      RowBox[{"-", " ", 
       RowBox[{
        SubscriptBox["\[PartialD]", "y"], 
        RowBox[{"u", "[", 
         RowBox[{"x", ",", "y"}], "]"}]}]}], ",", "\"\< - (\>\"", ",", 
      RowBox[{
       SubscriptBox["\[PartialD]", "x"], 
       RowBox[{"(", 
        RowBox[{"\[Integral]", 
         RowBox[{
          RowBox[{
           SubscriptBox["\[PartialD]", "x"], 
           RowBox[{"(", 
            RowBox[{"u", "[", 
             RowBox[{"x", ",", "y"}], "]"}], ")"}]}], 
          RowBox[{"\[DifferentialD]", "y"}]}]}], ")"}]}], " ", ",", 
      "\"\<))\[DifferentialD]x\>\""}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<c[x] = \[Integral](\>\"", ",", 
      RowBox[{
       RowBox[{"-", " ", 
        RowBox[{
         SubscriptBox["\[PartialD]", "y"], 
         RowBox[{"u", "[", 
          RowBox[{"x", ",", "y"}], "]"}]}]}], " ", "-", " ", 
       RowBox[{
        SubscriptBox["\[PartialD]", "x"], 
        RowBox[{"(", 
         RowBox[{"\[Integral]", 
          RowBox[{
           RowBox[{
            SubscriptBox["\[PartialD]", "x"], " ", 
            RowBox[{"u", "[", 
             RowBox[{"x", ",", "y"}], "]"}]}], 
           RowBox[{"\[DifferentialD]", "y"}]}]}], ")"}]}]}], ",", 
      "\"\<)\[DifferentialD]x\>\""}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<c[x] = \>\"", ",", 
      RowBox[{"\[Integral]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", " ", 
           RowBox[{
            SubscriptBox["\[PartialD]", "y"], 
            RowBox[{"u", "[", 
             RowBox[{"x", ",", "y"}], "]"}]}]}], " ", "-", " ", 
          RowBox[{
           SubscriptBox["\[PartialD]", "x"], 
           RowBox[{"(", 
            RowBox[{"\[Integral]", 
             RowBox[{
              RowBox[{
               SubscriptBox["\[PartialD]", "x"], " ", 
               RowBox[{"u", "[", 
                RowBox[{"x", ",", "y"}], "]"}]}], 
              RowBox[{"\[DifferentialD]", "y"}]}]}], ")"}]}]}], ")"}], 
        RowBox[{"\[DifferentialD]", "x"}]}]}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Now construct v[x,y]\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<v[x,y] = \[Integral]\!\(\*SubscriptBox[\(\[PartialD]\), \
\(y\)]\)v[x,y]\[DifferentialD]y + c[x]\>\"", " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<v[x,y] = \[Integral]\!\(\*SubscriptBox[\(\[PartialD]\), \
\(x\)]\)u[x,y]\[DifferentialD]y + c[x]\>\"", " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<v[x,y] = \[Integral]\!\(\*SubscriptBox[\(\[PartialD]\), \(x\)]\)(\>\
\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}], ",", "\"\<)\[DifferentialD]y + (\>\"", 
      ",", 
      RowBox[{"c", "[", "x", "]"}], ",", "\"\<)\>\""}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<v[x,y] = \[Integral](\>\"", ",", 
      RowBox[{
       SubscriptBox["\[PartialD]", "x"], 
       RowBox[{"u", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}], ",", 
      "\"\<)\[DifferentialD]y + (\>\"", ",", 
      RowBox[{"c", "[", "x", "]"}], ",", "\"\<)\>\""}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<v[x,y] = (\>\"", ",", 
      RowBox[{"\[Integral]", 
       RowBox[{
        RowBox[{
         SubscriptBox["\[PartialD]", "x"], 
         RowBox[{"u", "[", 
          RowBox[{"x", ",", "y"}], "]"}]}], 
        RowBox[{"\[DifferentialD]", "y"}]}]}], ",", "\"\<) + (\>\"", ",", 
      RowBox[{"c", "[", "x", "]"}], ",", "\"\<)\>\"", ",", "\"\<+ C\>\""}], 
     " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<v[x,y] = \>\"", ",", 
      RowBox[{
       RowBox[{"\[Integral]", 
        RowBox[{
         RowBox[{
          SubscriptBox["\[PartialD]", "x"], 
          RowBox[{"u", "[", 
           RowBox[{"x", ",", "y"}], "]"}]}], 
         RowBox[{"\[DifferentialD]", "y"}]}]}], " ", "+", " ", 
       RowBox[{"c", "[", "x", "]"}]}], ",", "\"\<+ C\>\""}], " ", "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<v[x,y] = \>\"", ",", 
      RowBox[{"Expand", "[", 
       RowBox[{
        RowBox[{"\[Integral]", 
         RowBox[{
          RowBox[{
           SubscriptBox["\[PartialD]", "x"], 
           RowBox[{"u", "[", 
            RowBox[{"x", ",", "y"}], "]"}]}], 
          RowBox[{"\[DifferentialD]", "y"}]}]}], " ", "+", " ", 
        RowBox[{"c", "[", "x", "]"}]}], "]"}], ",", "\"\<+ C\>\""}], " ", 
     "]"}], ";"}], "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{
  3.399020634640625*^9, {3.39902105321875*^9, 3.399021056796875*^9}}],

Cell[TextData[{
 "We are done!\n\n",
 StyleBox["Aside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  We can also construct v[x,y] by the following alternative method."
}], "Text"],

Cell["\<\
Enter the function u[x,y], and determine if it is a harmonic function.  If \
so, proceed with the construction of the harmonic conjugate v[x,y].\
\>", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "F", ",", "u", ",", "v", ",", "x", ",", "y"}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"u", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", " ", 
     RowBox[{"x", "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["x", "3"]}], "-", 
      RowBox[{"6", " ", "x", " ", "y"}], "-", 
      RowBox[{"4", " ", 
       SuperscriptBox["x", "3"], " ", "y"}], "+", 
      RowBox[{"6", " ", "x", " ", 
       SuperscriptBox["y", "2"]}], "+", 
      RowBox[{"4", " ", "x", " ", 
       SuperscriptBox["y", "3"]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"v", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", " ", 
     RowBox[{"con", "[", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<u(x,y) = \>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<Constructing the harmonic conjugate we get\>\"", "]"}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<v(x,y) = \>\"", ",", 
      RowBox[{"v", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<v(x,y) = \>\"", ",", 
      RowBox[{"Expand", "[", 
       RowBox[{"v", "[", 
        RowBox[{"x", ",", "y"}], "]"}], "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399020640375*^9}],

Cell["\<\
Form the analytic function  f[z] = u[x,y]+ i v[x,y]  and verify that the \
Cauchy-Riemann equations hold.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Ux", " ", "=", " ", 
     RowBox[{
      SubscriptBox["\[PartialD]", "x"], " ", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Uy", " ", "=", " ", 
     RowBox[{
      SubscriptBox["\[PartialD]", "y"], " ", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Vx", " ", "=", " ", 
     RowBox[{
      SubscriptBox["\[PartialD]", "x"], " ", 
      RowBox[{"v", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Vy", " ", "=", " ", 
     RowBox[{
      SubscriptBox["\[PartialD]", "y"], " ", 
      RowBox[{"v", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}]}], ";"}], " ", "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], "=", 
     RowBox[{
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}], " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"v", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<   f[z] = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<   f[z] = u[x,y] + \[ImaginaryI] v[x,y]\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< u[x,y] = \>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< v[x,y] = \>\"", ",", 
      RowBox[{"v", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(u\), \(x\)]\)[x,y] = \>\"", ",", "Ux"}], "]"}],
     ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(u\), \(y\)]\)[x,y] = \>\"", ",", "Uy"}], "]"}],
     ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(v\), \(x\)]\)[x,y] = \>\"", ",", "Vx"}], "]"}],
     ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(v\), \(y\)]\)[x,y] = \>\"", ",", "Vy"}], "]"}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Is \!\(\*SubscriptBox[\(u\), \(x\)]\)[x,y] =  \
\!\(\*SubscriptBox[\(v\), \(y\)]\)[x,y] ?      \>\"", ",", 
      RowBox[{"Ux", "\[Equal]", "Vy"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Is \!\(\*SubscriptBox[\(u\), \(y\)]\)[x,y] = \
-\!\(\*SubscriptBox[\(v\), \(x\)]\)[x,y] ?      \>\"", ",", 
      RowBox[{"Uy", "\[Equal]", 
       RowBox[{"-", "Vx"}]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39902064534375*^9}],

Cell[TextData[{
 "Therefore  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"v", "[", 
    RowBox[{"x", ",", "y"}], "]"}], "=", 
   RowBox[{
    RowBox[{"3", " ", 
     SuperscriptBox["x", "2"]}], "+", 
    SuperscriptBox["x", "4"], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"6", " ", 
        SuperscriptBox["x", "2"]}]}], ")"}], " ", "y"}], "-", 
    RowBox[{"3", " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["x", "2"]}]}], ")"}], " ", 
     SuperscriptBox["y", "2"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["y", "3"]}], "+", 
    SuperscriptBox["y", "4"]}]}]]],
 " is the harmonic conjugate of  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"u", "[", 
    RowBox[{"x", ",", "y"}], "]"}], "=", 
   RowBox[{"x", "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["x", "3"]}], "-", 
    RowBox[{"6", " ", "x", " ", "y"}], "-", 
    RowBox[{"4", " ", 
     SuperscriptBox["x", "3"], " ", "y"}], "+", 
    RowBox[{"6", " ", "x", " ", 
     SuperscriptBox["y", "2"]}], "+", 
    RowBox[{"4", " ", "x", " ", 
     SuperscriptBox["y", "3"]}]}]}]]],
 ".  \n",
 StyleBox["\nAside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  We can use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to get the standard form of an analytic function.  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "z_", "]"}], "=", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{
       RowBox[{"f", "[", 
        RowBox[{"x", ",", "y"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"x", "\[Rule]", 
          FractionBox[
           RowBox[{"z", "+", 
            RowBox[{"Conjugate", "[", "z", "]"}]}], "2"]}], ",", 
         RowBox[{"y", "\[Rule]", 
          FractionBox[
           RowBox[{"z", "-", 
            RowBox[{"Conjugate", "[", "z", "]"}]}], 
           RowBox[{"2", "\[ImaginaryI]"}]]}]}], "}"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "z_", "]"}], "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"F", "[", "z", "]"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"W", "=", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{
       RowBox[{"f", "[", 
        RowBox[{"x", ",", "y"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"x", "\[Rule]", 
          FractionBox[
           RowBox[{"z", "+", 
            OverscriptBox[
             RowBox[{"z", " "}], "_"]}], "2"]}], ",", 
         RowBox[{"y", "\[Rule]", 
          FractionBox[
           RowBox[{"z", "-", 
            OverscriptBox[
             RowBox[{"z", " "}], "_"]}], 
           RowBox[{"2", "\[ImaginaryI]"}]]}]}], "}"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<f[z] = u[x,y] + \[ImaginaryI] v[x,y]\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", "W"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"F", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399020649671875*^9}]
}, Closed]],

Cell[TextData[{
 StyleBox["Fluid Flow",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "\n\n\tHarmonic functions are solutions to many physical problems.  \
Applications include two-dimensional models of heat flow, electrostatics, and \
fluid flow.  We now give an example of the latter.\n\t\n\tWe assume that an \
incompressible and frictionless fluid flows over the complex plane and that \
all cross sections in planes parallel to the complex plane are the same.  \
Situations such as this occur when fluid is flowing in a deep channel. The \
velocity vector at the point ",
 Cell[BoxData[
  RowBox[{"(", 
   RowBox[{"x", ",", "y"}], ")"}]]],
 " is \n\n",
 StyleBox["(3-29)\t",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    StyleBox["V",
     FontWeight->"Bold"], 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"p", 
     RowBox[{"(", 
      RowBox[{"x", ",", "y"}], ")"}]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", "q", 
     RowBox[{"(", 
      RowBox[{"x", ",", "y"}], ")"}]}]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "\tThe assumption that the flow is irrotational and has no sources or sinks \
implies that both the curl and divergence vanish, that is, ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["q", "x"], "-", 
    SubscriptBox["p", "y"]}], "=", "0"}]]],
 " and ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["p", "x"], "+", 
    SubscriptBox["q", "y"]}], "=", "0"}]]],
 ".  Hence ",
 StyleBox["p",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["q",
  FontFamily->"Courier New"],
 " obey the partial differential equations \n\n",
 StyleBox["(3-30)\t",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["p", "x"], 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"-", " ", 
     SubscriptBox["q", "y"]}], 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}]}]]],
 ",   and \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["p", "y"], 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], " ", "=", " ", 
   RowBox[{
    SubscriptBox["q", "x"], 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "Equations ",
 StyleBox["(3-30)",
  FontColor->RGBColor[0, 0, 1]],
 " are similar to the Cauchy-Riemann equations and permit us to define a \
special complex function:\n\n",
 StyleBox["(3-31)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"u", 
      RowBox[{"(", 
       RowBox[{"x", ",", "y"}], ")"}]}], "+", 
     RowBox[{"\[ImaginaryI]", " ", "v", 
      RowBox[{"(", 
       RowBox[{"x", ",", "y"}], ")"}]}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{"p", 
      RowBox[{"(", 
       RowBox[{"x", ",", "y"}], ")"}]}], "-", 
     RowBox[{"\[ImaginaryI]", " ", "q", 
      RowBox[{"(", 
       RowBox[{"x", ",", "y"}], ")"}]}]}]}]}]]],
 ".  \n\nHere we have  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["u", "x"], "=", 
    SubscriptBox["p", "x"]}], ",", " ", 
   RowBox[{
    SubscriptBox["u", "y"], "=", 
    SubscriptBox["p", "y"]}], ",", " ", 
   RowBox[{
    SubscriptBox["v", "x"], "=", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SubscriptBox["q", "x"]}], "  ", 
      StyleBox["and",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "  ", 
      SubscriptBox["v", "y"]}], "=", 
     RowBox[{"-", 
      SubscriptBox["q", "y"]}]}]}]}]]],
 ".  We can use Equations ",
 StyleBox["(3-30)",
  FontColor->RGBColor[0, 0, 1]],
 " to verify that the Cauchy-Riemann equations are satisfied for ",
 StyleBox["f",
  FontFamily->"Courier New"],
 ":  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["u", "x"], 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["p", "x"], 
     RowBox[{"(", 
      RowBox[{"x", ",", "y"}], ")"}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"-", " ", 
       SubscriptBox["q", "y"]}], 
      RowBox[{"(", 
       RowBox[{"x", ",", "y"}], ")"}]}], " ", "=", " ", 
     RowBox[{
      SubscriptBox["v", "y"], 
      RowBox[{"(", 
       RowBox[{"x", ",", "y"}], ")"}]}]}]}]}]]],
 ",   and    \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["u", "y"], 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["p", "y"], 
     RowBox[{"(", 
      RowBox[{"x", ",", "y"}], ")"}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      SubscriptBox["q", "x"], 
      RowBox[{"(", 
       RowBox[{"x", ",", "y"}], ")"}]}], " ", "=", " ", 
     RowBox[{
      RowBox[{"-", " ", 
       SubscriptBox["v", "x"]}], 
      RowBox[{"(", 
       RowBox[{"x", ",", "y"}], ")"}]}]}]}]}]]],
 ".  \n\nAssuming the functions ",
 StyleBox["p",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["q",
  FontFamily->"Courier New"],
 " have continuous partials, Theorem 3.4 guarantees that function ",
 StyleBox["f",
  FontFamily->"Courier New"],
 " defined in Equation ",
 StyleBox["(3-31)",
  FontColor->RGBColor[0, 0, 1]],
 " is analytic, and that the fluid flow of Equation ",
 StyleBox["(3-29)",
  FontColor->RGBColor[0, 0, 1]],
 " is the conjugate of an analytic function, that is,\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    StyleBox["V",
     FontWeight->"Bold"], 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], " ", "=", " ", 
   OverscriptBox[
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "_"]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "\n\tIn Chapter 6 we will prove that every analytic function ",
 StyleBox["f",
  FontFamily->"Courier New"],
 " has an analytic antiderivative ",
 StyleBox["F",
  FontFamily->"Courier New"],
 ";  assuming this to be the case, we can write  \n\n",
 StyleBox["(3-32)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"F", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"\[Phi]", 
     RowBox[{"(", 
      RowBox[{"x", ",", "y"}], ")"}]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", "\[Psi]", 
     RowBox[{"(", 
      RowBox[{"x", ",", "y"}], ")"}]}]}]}]]],
 ",  \n\nwhere ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"F", "'"}], 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}]}]]],
 ".  \n\n\tTheorem 3.8 tells us that ",
 Cell[BoxData[
  RowBox[{"\[Phi]", 
   RowBox[{"(", 
    RowBox[{"x", ",", "y"}], ")"}]}]]],
 " is a harmonic function.  If we use the vector interpretation of a complex \
number we see that the gradient of ",
 Cell[BoxData["\[Phi]"]],
 " can be written as \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"grad", " ", "\[Phi]", 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], " ", "=", "  ", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Phi]", "x"], 
     RowBox[{"(", 
      RowBox[{"x", ",", "y"}], ")"}]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["\[Phi]", "y"], 
     RowBox[{"(", 
      RowBox[{"x", ",", "y"}], ")"}]}]}]}]]],
 "."
}], "Text"],

Cell[TextData[{
 "\n\tThe Cauchy-Riemann equations applied to ",
 Cell[BoxData[
  RowBox[{"F", 
   RowBox[{"(", "z", ")"}]}]]],
 " give  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["\[Phi]", "y"], 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], "=", 
   RowBox[{
    RowBox[{"-", " ", 
     SubscriptBox["\[Psi]", "x"]}], 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}]}]]],
 ";   making this substitution in the last equation yields  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"grad", " ", "\[Phi]", 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], " ", "=", "  ", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["\[Phi]", "x"], 
      RowBox[{"(", 
       RowBox[{"x", ",", "y"}], ")"}]}], "-", 
     RowBox[{"\[ImaginaryI]", " ", 
      SubscriptBox["\[Psi]", "x"], 
      RowBox[{"(", 
       RowBox[{"x", ",", "y"}], ")"}]}]}], " ", "=", " ", 
    OverscriptBox[
     RowBox[{
      RowBox[{
       SubscriptBox["\[Phi]", "x"], 
       RowBox[{"(", 
        RowBox[{"x", ",", "y"}], ")"}]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Psi]", "x"], 
       RowBox[{"(", 
        RowBox[{"x", ",", "y"}], ")"}]}]}], "_"]}]}]]],
 ".  \n\nEquation ",
 StyleBox["(3-14)",
  FontColor->RGBColor[0, 0, 1]],
 " says that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["\[Phi]", "x"], 
     RowBox[{"(", 
      RowBox[{"x", ",", "y"}], ")"}]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["\[Psi]", "x"], 
     RowBox[{"(", 
      RowBox[{"x", ",", "y"}], ")"}]}]}], "=", 
   RowBox[{
    RowBox[{"F", "'"}], 
    RowBox[{"(", "z", ")"}]}]}]]],
 ",  which by the preceeding equation and Equation ",
 StyleBox["(3-32)",
  FontColor->RGBColor[0, 0, 1]],
 " imply that  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"grad", " ", "\[Phi]", 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], " ", "=", " ", 
   RowBox[{
    OverscriptBox[
     RowBox[{
      RowBox[{"F", "'"}], 
      RowBox[{"(", "z", ")"}]}], "_"], " ", "=", " ", 
    OverscriptBox[
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], "_"]}]}]]],
 ".  \n\nFinally, from Equation ",
 StyleBox["(3-29)",
  FontColor->RGBColor[0, 0, 1]],
 ",  ",
 Cell[BoxData[
  RowBox[{"\[Phi]", 
   RowBox[{"(", 
    RowBox[{"x", ",", "y"}], ")"}]}]]],
 " is the scalar potential function for the a fluid flow, so \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    StyleBox["V",
     FontWeight->"Bold"], 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], "=", 
   RowBox[{"grad", " ", "\[Phi]", 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}]}]]],
 "."
}], "Text"],

Cell[TextData[{
 "\tThe curves given by ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"x", ",", "y"}], ")"}], ":", "  ", 
     RowBox[{"\[Phi]", 
      RowBox[{"(", 
       RowBox[{"x", ",", "y"}], ")"}]}]}], "=", "constant"}], "}"}]]],
 " are call",
 "ed equipotentials.  ",
 "The curves ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"x", ",", "y"}], ")"}], ":", " ", 
     RowBox[{"\[Psi]", 
      RowBox[{"(", 
       RowBox[{"x", ",", "y"}], ")"}]}]}], "=", "constant"}], "}"}]]],
 " are ca",
 "lled streamlines and de",
 "scribe the path of fluid flow.  In Chapter 11 we will see that the family \
of equipotentials is orthogonal to the family of streamlines."
}], "Text"],

Cell[TextData[{
 StyleBox["Example 3.14.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  ",
 "Show that the harmonic function",
 " ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Phi]", 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], " ", "=", " ", 
   RowBox[{
    SuperscriptBox["x", "2"], "-", 
    SuperscriptBox["y", "2"]}]}]]],
 "  is the scalar potential function for the fluid flow  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    StyleBox["V",
     FontWeight->"Bold"], 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"2", " ", "x"}], "-", 
    RowBox[{"2", " ", "\[ImaginaryI]", " ", "y"}]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "Solution.  We can write the fluid flow expression as\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    StyleBox["V",
     FontWeight->"Bold"], 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"2", " ", "x"}], "-", 
     RowBox[{"2", " ", "\[ImaginaryI]", " ", "y"}]}], " ", "=", " ", 
    RowBox[{"2", "z"}]}]}]]],
 ".   \n\nAn antiderivative of  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{"2", "z"}]}]]],
 "  is  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"F", 
    RowBox[{"(", "z", ")"}]}], "=", 
   SuperscriptBox["z", "2"]}]]],
 ",  and the real part of ",
 Cell[BoxData[
  RowBox[{"F", 
   RowBox[{"(", "z", ")"}]}]]],
 " is the desired harmonic function:  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Phi]", 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"Re", "[", 
     RowBox[{"F", 
      RowBox[{"(", "z", ")"}]}], "]"}], " ", "=", " ", 
    RowBox[{
     RowBox[{"Re", "[", 
      RowBox[{
       SuperscriptBox["x", "2"], "-", 
       SuperscriptBox["y", "2"], "+", 
       RowBox[{"2", " ", "\[ImaginaryI]", " ", "x", " ", "y"}]}], "]"}], " ", 
     "=", " ", 
     RowBox[{
      SuperscriptBox["x", "2"], "-", 
      SuperscriptBox["y", "2"]}]}]}]}]]],
 ".  \n\nNote that the hyperbolas  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Phi]", 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox["x", "2"], "-", 
     SuperscriptBox["y", "2"]}], " ", "=", " ", "C"}]}]]],
 "  are the equipotential curves and that the hyperbolas  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Psi]", 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"2", "x", " ", "y"}], " ", "=", " ", "C"}]}]]],
 "  are the streamline curves; these curves are orthogonal, as shown in \
Figure 3.6."
}], "Text"],

Cell[TextData[{
 "\t\t\t",
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8  scalefont  setfont
% Scaling calculations
0.0131579 0.131579 0.0131579 0.131579 [
[.14474 .00066 -4.21875 -10.9375 ]
[.14474 .00066 4.21875 0 ]
[.27632 .00066 -4.21875 -10.9375 ]
[.27632 .00066 4.21875 0 ]
[.40789 .00066 -4.21875 -10.9375 ]
[.40789 .00066 4.21875 0 ]
[.53947 .00066 -4.21875 -10.9375 ]
[.53947 .00066 4.21875 0 ]
[.67105 .00066 -4.21875 -10.9375 ]
[.67105 .00066 4.21875 0 ]
[.80263 .00066 -4.21875 -10.9375 ]
[.80263 .00066 4.21875 0 ]
[.93421 .00066 -4.21875 -10.9375 ]
[.93421 .00066 4.21875 0 ]
[.00066 .14474 -8.4375 -5.46875 ]
[.00066 .14474 0 5.46875 ]
[.00066 .27632 -8.4375 -5.46875 ]
[.00066 .27632 0 5.46875 ]
[.00066 .40789 -8.4375 -5.46875 ]
[.00066 .40789 0 5.46875 ]
[.00066 .53947 -8.4375 -5.46875 ]
[.00066 .53947 0 5.46875 ]
[.00066 .67105 -8.4375 -5.46875 ]
[.00066 .67105 0 5.46875 ]
[.00066 .80263 -8.4375 -5.46875 ]
[.00066 .80263 0 5.46875 ]
[.00066 .93421 -8.4375 -5.46875 ]
[.00066 .93421 0 5.46875 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.14474 .01316 m
.14474 .01941 L
s
gsave
.14474 .00066 -65.2188 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.27632 .01316 m
.27632 .01941 L
s
gsave
.27632 .00066 -65.2188 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.40789 .01316 m
.40789 .01941 L
s
gsave
.40789 .00066 -65.2188 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.53947 .01316 m
.53947 .01941 L
s
gsave
.53947 .00066 -65.2188 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.67105 .01316 m
.67105 .01941 L
s
gsave
.67105 .00066 -65.2188 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.80263 .01316 m
.80263 .01941 L
s
gsave
.80263 .00066 -65.2188 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.93421 .01316 m
.93421 .01941 L
s
gsave
.93421 .00066 -65.2188 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
1.000 setlinewidth
grestore
0 .01316 m
1 .01316 L
s
.01316 .14474 m
.01941 .14474 L
s
gsave
.00066 .14474 -69.4375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.01316 .27632 m
.01941 .27632 L
s
gsave
.00066 .27632 -69.4375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.01316 .40789 m
.01941 .40789 L
s
gsave
.00066 .40789 -69.4375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.01316 .53947 m
.01941 .53947 L
s
gsave
.00066 .53947 -69.4375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.01316 .67105 m
.01941 .67105 L
s
gsave
.00066 .67105 -69.4375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.01316 .80263 m
.01941 .80263 L
s
gsave
.00066 .80263 -69.4375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.01316 .93421 m
.01941 .93421 L
s
gsave
.00066 .93421 -69.4375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
1.000 setlinewidth
grestore
.01316 0 m
.01316 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.03195 .93421 m
.03408 .84058 L
.03636 .75943 L
.04046 .64732 L
.04534 .5512 L
.04977 .486 L
.0544 .43292 L
.05943 .38732 L
.06856 .32567 L
.07863 .27759 L
.08931 .2405 L
.09843 .21619 L
.10847 .1948 L
.12686 .16542 L
.14664 .14286 L
.16666 .12594 L
.1857 .1135 L
.22188 .09611 L
.24052 .08931 L
.26038 .08319 L
.29978 .07356 L
.33774 .0665 L
.37426 .0611 L
.4131 .05645 L
.45051 .05274 L
.48649 .04974 L
.52478 .047 L
.56164 .04472 L
.60083 .04262 L
.63858 .04084 L
.67489 .03932 L
.71352 .03788 L
.75072 .03663 L
.78649 .03555 L
.82457 .03449 L
.86123 .03357 L
.9002 .03268 L
.93421 .03195 L
s
.08835 .93421 m
.09632 .84591 L
.10505 .76678 L
.12266 .64558 L
.14203 .55051 L
.16008 .4845 L
.19471 .39459 L
.21364 .35859 L
.23152 .33029 L
.26564 .28744 L
.30194 .25297 L
.33689 .22708 L
.37049 .20696 L
.40627 .18932 L
.44071 .17513 L
.47732 .16236 L
.51259 .15182 L
.54651 .143 L
.58261 .13477 L
.61736 .12777 L
.6543 .12117 L
.68988 .11549 L
.72412 .11056 L
.76054 .10582 L
.79561 .10166 L
.82933 .09801 L
.86524 .09443 L
.89979 .09126 L
.93421 .08835 L
s
.18233 .93421 m
.21283 .79351 L
.2461 .68208 L
.27734 .60297 L
.30738 .54274 L
.33936 .49082 L
.37015 .44963 L
.40287 .41299 L
.43439 .38307 L
.46472 .35822 L
.49698 .33521 L
.52805 .31578 L
.55792 .29919 L
.58972 .28341 L
.62033 .26978 L
.65288 .25673 L
.68423 .24535 L
.71438 .23537 L
.74647 .22564 L
.77736 .21705 L
.81019 .20866 L
.84182 .20119 L
.87225 .19453 L
.90462 .18795 L
.93421 .18233 L
s
.31391 .93421 m
.33907 .8631 L
.36652 .79709 L
.39229 .74379 L
.41708 .69896 L
.44346 .65691 L
.46886 .62103 L
.49585 .58704 L
.52186 .5577 L
.54688 .53217 L
.5735 .50752 L
.59913 .48589 L
.62377 .46682 L
.65001 .44812 L
.67526 .43153 L
.70211 .41523 L
.72797 .40068 L
.75285 .38765 L
.77932 .37471 L
.80481 .36307 L
.83189 .3515 L
.85799 .34104 L
.8831 .33158 L
.9098 .3221 L
.93421 .31391 L
s
.48308 .93421 m
.50138 .89969 L
.52134 .86487 L
.54009 .83457 L
.55811 .8074 L
.5773 .78038 L
.59577 .75606 L
.6154 .73184 L
.63432 .70996 L
.65251 .69013 L
.67187 .67023 L
.69051 .65215 L
.70843 .63568 L
.72752 .61905 L
.74588 .60386 L
.76541 .58853 L
.78422 .57449 L
.80231 .56163 L
.82156 .54856 L
.8401 .53656 L
.8598 .52439 L
.87878 .51318 L
.89704 .50285 L
.91646 .49232 L
.93421 .48308 L
s
.68985 .93421 m
.69976 .92091 L
.71057 .90684 L
.72073 .89402 L
.73049 .88203 L
.74089 .86962 L
.75089 .858 L
.76152 .846 L
.77177 .83475 L
.78163 .82421 L
.79211 .81329 L
.80221 .80306 L
.81192 .79346 L
.82225 .78349 L
.8322 .77413 L
.84278 .76443 L
.85297 .75531 L
.86277 .74675 L
.87319 .73786 L
.88323 .7295 L
.8939 .72082 L
.90418 .71265 L
.91407 .70497 L
.9246 .69699 L
.93421 .68985 L
s
0 0 1 r
[ .025 .025 ] 0 setdash
.01316 .01316 m
.05052 .05052 L
.09127 .09127 L
.12954 .12954 L
.16635 .16635 L
.20552 .20552 L
.24323 .24323 L
.28331 .28331 L
.32193 .32193 L
.35908 .35908 L
.3986 .3986 L
.43666 .43666 L
.47325 .47325 L
.51221 .51221 L
.54971 .54971 L
.58958 .58958 L
.62798 .62798 L
.66492 .66492 L
.70423 .70423 L
.74207 .74207 L
.78228 .78228 L
.82103 .82103 L
.85831 .85831 L
.89797 .89797 L
.93421 .93421 L
s
.01316 .14474 m
.01428 .14474 L
.01531 .14475 L
.01649 .14478 L
.01761 .14481 L
.01959 .14489 L
.02175 .14502 L
.02412 .14519 L
.02664 .14543 L
.03116 .14596 L
.04019 .14749 L
.05014 .14983 L
.06017 .15288 L
.07096 .15687 L
.09047 .16577 L
.12993 .18908 L
.16794 .21631 L
.2045 .24537 L
.2434 .27835 L
.28086 .31144 L
.32066 .34763 L
.35901 .38319 L
.39591 .41789 L
.43516 .45519 L
.47295 .49141 L
.5093 .52645 L
.54799 .56394 L
.58524 .60017 L
.62483 .63882 L
.66297 .67615 L
.69965 .71215 L
.73869 .75052 L
.77627 .78754 L
.81241 .82317 L
.85089 .86116 L
.88792 .89776 L
.92476 .93421 L
s
.01316 .27632 m
.01425 .27632 L
.01524 .27632 L
.01638 .27634 L
.01746 .27635 L
.01939 .27639 L
.02148 .27645 L
.02378 .27653 L
.02621 .27664 L
.03059 .27689 L
.0351 .27723 L
.03933 .27761 L
.04896 .27874 L
.05879 .28024 L
.06778 .28192 L
.08802 .28676 L
.12482 .29902 L
.16021 .31462 L
.19788 .33468 L
.23415 .3568 L
.27269 .38276 L
.30982 .40972 L
.34555 .43711 L
.38355 .46752 L
.42015 .49781 L
.45534 .52772 L
.4928 .56025 L
.52886 .59213 L
.5672 .62652 L
.60412 .66007 L
.63965 .69267 L
.67744 .72767 L
.71384 .76162 L
.74882 .79447 L
.78608 .82965 L
.82194 .86367 L
.86007 .90001 L
.89582 .93421 L
s
.01316 .40789 m
.01419 .4079 L
.01512 .4079 L
.0162 .40791 L
.01722 .40792 L
.01903 .40794 L
.021 .40797 L
.02317 .40802 L
.02547 .40809 L
.02959 .40824 L
.03385 .40844 L
.03784 .40867 L
.04692 .40934 L
.05618 .41023 L
.06465 .41124 L
.08373 .41415 L
.10032 .4174 L
.11843 .42169 L
.15395 .43225 L
.18814 .44494 L
.22447 .4609 L
.25948 .47845 L
.29317 .49712 L
.32899 .5187 L
.3635 .54094 L
.39668 .56353 L
.432 .5887 L
.466 .61389 L
.50214 .64158 L
.53695 .66904 L
.57045 .69608 L
.60608 .72546 L
.64039 .75426 L
.67338 .78238 L
.70851 .81274 L
.74231 .8423 L
.77826 .87409 L
.81288 .905 L
.84534 .93421 L
s
.01316 .53947 m
.01409 .53947 L
.01494 .53948 L
.01592 .53948 L
.01685 .53949 L
.01849 .5395 L
.02028 .53952 L
.02225 .53955 L
.02434 .53959 L
.02808 .53969 L
.03195 .53981 L
.03557 .53995 L
.04382 .54037 L
.05223 .54092 L
.05993 .54155 L
.07726 .54336 L
.09233 .5454 L
.10878 .54809 L
.14104 .55479 L
.17209 .56295 L
.20509 .57338 L
.23689 .58505 L
.26749 .5977 L
.30003 .61258 L
.33137 .62819 L
.36151 .64431 L
.39359 .66257 L
.42447 .68113 L
.4573 .70183 L
.48892 .72263 L
.51934 .74338 L
.55171 .76618 L
.58287 .78877 L
.61283 .81104 L
.64474 .83529 L
.67544 .85911 L
.70809 .88491 L
.73954 .91018 L
.76902 .93421 L
s
.01316 .67105 m
.01395 .67105 L
.01468 .67105 L
.01551 .67106 L
.0163 .67106 L
.01771 .67107 L
.01923 .67108 L
.02091 .6711 L
.02269 .67112 L
.02589 .67118 L
.02918 .67125 L
.03227 .67133 L
.03931 .67157 L
.04648 .6719 L
.05305 .67226 L
.06783 .67332 L
.08068 .67451 L
.0947 .67609 L
.12221 .68003 L
.1487 .68487 L
.17684 .69111 L
.20396 .69816 L
.23005 .70588 L
.2578 .71507 L
.28453 .72482 L
.31023 .73501 L
.33759 .7467 L
.36393 .75872 L
.39192 .77229 L
.41889 .7861 L
.44483 .80003 L
.47243 .8155 L
.49901 .83101 L
.52456 .84644 L
.55177 .86341 L
.57796 .88024 L
.6058 .89863 L
.63262 .9168 L
.65776 .93421 L
s
.01316 .80263 m
.01374 .80263 L
.01428 .80263 L
.01489 .80263 L
.01547 .80263 L
.01651 .80264 L
.01763 .80264 L
.01887 .80265 L
.02018 .80266 L
.02253 .80269 L
.02495 .80272 L
.02723 .80276 L
.0324 .80287 L
.03768 .80301 L
.04252 .80318 L
.05339 .80366 L
.06285 .80419 L
.07317 .80491 L
.09342 .8067 L
.11291 .80891 L
.13363 .81177 L
.15358 .81502 L
.17279 .81861 L
.19321 .8229 L
.21288 .8275 L
.2318 .83235 L
.25193 .83795 L
.27132 .84377 L
.29192 .8504 L
.31177 .85722 L
.33086 .86416 L
.35118 .87195 L
.37074 .87984 L
.38954 .88776 L
.40957 .89657 L
.42884 .90538 L
.44933 .91511 L
.46907 .92482 L
.48757 .93421 L
s
.14474 .01325 m
.14571 .0292 L
.1466 .03537 L
.14859 .04523 L
.15218 .05803 L
.16033 .07908 L
.17676 .11039 L
.21169 .16183 L
.24479 .20379 L
.27663 .24143 L
.31051 .27981 L
.34313 .31576 L
.37449 .34968 L
.40789 .38531 L
.44003 .41924 L
.4742 .45503 L
.50712 .48927 L
.53878 .52204 L
.57247 .55677 L
.60491 .59009 L
.63938 .6254 L
.67259 .65933 L
.70455 .69191 L
.73854 .7265 L
.77127 .75976 L
.80275 .79171 L
.83626 .82567 L
.86851 .85833 L
.90279 .89301 L
.93421 .92476 L
s
.27632 .01328 m
.27713 .03385 L
.27787 .04177 L
.27953 .05439 L
.28252 .07062 L
.28931 .09686 L
.303 .13464 L
.33211 .19338 L
.35969 .23862 L
.38623 .2776 L
.41446 .31613 L
.44164 .35131 L
.46778 .38387 L
.49561 .41752 L
.52239 .44913 L
.55087 .48207 L
.5783 .51329 L
.60468 .54292 L
.63276 .5741 L
.65979 .60382 L
.68852 .63514 L
.71619 .66508 L
.74282 .69372 L
.77115 .724 L
.79843 .75302 L
.82466 .7808 L
.85258 .81027 L
.87946 .83852 L
.90803 .86846 L
.93421 .89582 L
s
.40789 .01329 m
.40854 .03581 L
.40914 .04448 L
.41046 .05826 L
.41286 .07593 L
.41829 .10434 L
.42925 .14473 L
.45253 .20611 L
.4746 .25213 L
.49583 .29092 L
.51841 .32854 L
.54016 .36232 L
.56107 .39314 L
.58333 .42459 L
.60476 .45381 L
.62754 .48395 L
.64948 .51225 L
.67059 .53889 L
.69305 .56673 L
.71468 .59308 L
.73766 .62068 L
.7598 .64692 L
.7811 .67188 L
.80376 .69817 L
.82558 .72324 L
.84657 .74716 L
.86891 .77243 L
.89041 .79658 L
.91327 .82209 L
.93421 .84534 L
s
.53947 .01329 m
.53996 .03581 L
.5404 .04447 L
.5414 .05823 L
.54319 .07585 L
.54727 .10408 L
.55149 .12628 L
.55549 .14397 L
.57295 .20384 L
.58887 .24648 L
.60581 .28561 L
.62212 .31947 L
.6378 .34957 L
.6545 .37964 L
.67057 .40709 L
.68766 .43499 L
.70411 .46083 L
.71994 .4849 L
.73679 .50978 L
.75301 .53313 L
.77024 .55737 L
.78685 .58025 L
.80283 .60186 L
.81982 .62447 L
.83619 .64591 L
.85193 .66625 L
.86868 .68763 L
.88481 .70797 L
.90195 .72936 L
.91847 .74976 L
.93421 .76902 L
s
.67105 .01328 m
.67138 .03383 L
.67167 .04174 L
.67234 .05428 L
.67353 .07034 L
.67625 .09601 L
.67907 .11615 L
.68173 .13216 L
.69337 .18597 L
.70399 .22391 L
.71528 .2584 L
.72615 .28799 L
.7366 .31407 L
.74774 .33993 L
.75845 .36335 L
.76984 .38698 L
.78081 .40872 L
.79137 .42883 L
.8026 .44949 L
.81341 .46876 L
.8249 .48866 L
.83597 .50732 L
.84662 .52486 L
.85795 .54311 L
.86886 .56034 L
.87936 .57661 L
.89053 .59363 L
.90128 .60976 L
.91271 .62664 L
.92372 .64267 L
.93421 .65776 L
s
.80263 .01325 m
.80279 .02917 L
.80294 .03529 L
.80327 .045 L
.80387 .05743 L
.80457 .06851 L
.80523 .07726 L
.80797 .10512 L
.81076 .12674 L
.81379 .14636 L
.81944 .17692 L
.82487 .20187 L
.8301 .22322 L
.83567 .24392 L
.84102 .26234 L
.84672 .28066 L
.8522 .29729 L
.85748 .31251 L
.8631 .328 L
.8685 .34232 L
.87425 .35697 L
.87978 .37061 L
.88511 .38333 L
.89077 .39649 L
.89623 .40882 L
.90148 .42039 L
.90706 .43244 L
.91244 .44378 L
.91815 .45559 L
.92366 .46674 L
.92895 .47728 L
.93421 .48757 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {0, 0, 0, 0}}],
 "  ",
 StyleBox["\nFigure 3.6",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Blue equipotential curves ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["x", "2"], "-", 
    SuperscriptBox["y", "2"]}], "=", "C"}]]],
 ", and red streamline curves ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"2", "x", " ", "y"}], "=", " ", "C"}]]],
 ", for ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"F", 
    RowBox[{"(", "z", ")"}]}], "=", 
   SuperscriptBox["z", "2"]}]]],
 ". "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Explore ",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 StyleBox["Solution 3.14.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "Enter the complex potential  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"F", "[", "z", "]"}], "=", 
   SuperscriptBox["z", "2"]}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"F", ",", "\[Phi]", ",", "\[CurlyPhi]", ",", "z"}], "]"}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "z_", "]"}], " ", "=", " ", 
     SuperscriptBox["z", "2"]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Phi]", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"Re", "[", 
       RowBox[{"F", "[", 
        RowBox[{"x", "+", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], "]"}]}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"\[CurlyPhi]", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"Im", "[", 
       RowBox[{"F", "[", 
        RowBox[{"x", "+", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], "]"}]}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The complex potential is\>\"", "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  F(z) = \>\"", ",", 
      RowBox[{"F", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< F'(z) = \>\"", ",", 
      RowBox[{"Expand", "[", 
       RowBox[{
        RowBox[{"F", "'"}], "[", 
        RowBox[{"x", "+", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The vector field is\>\"", "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<V(x,y) = \!\(\*OverscriptBox[\(F' \((z)\)\), \(_\)]\) = \>\"", ",", 
      "\n", "       ", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"Conjugate", "[", 
        RowBox[{
         RowBox[{"F", "'"}], "[", 
         RowBox[{"x", "+", 
          RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], "]"}]}], "]"}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The equipotential curves are\>\"", "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Phi](x,y) = \>\"", ",", 
      RowBox[{"\[Phi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The streamline curves are\>\"", "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[CurlyPhi](x,y) = \>\"", ",", 
      RowBox[{"\[CurlyPhi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399020531546875*^9}],

Cell[TextData[{
 "\nUse ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to make a contour plot of the velocity potential and streamline curves"
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"g1", "=", 
    RowBox[{"ContourPlot", "[", 
     RowBox[{
      RowBox[{"\[Phi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", 
        RowBox[{"-", "8"}], ",", "8"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"y", ",", "0", ",", "8"}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{"Contours", " ", "\[Rule]", " ", "10"}], ",", 
      RowBox[{"PlotPoints", "\[Rule]", "25"}], ",", 
      RowBox[{"AspectRatio", "\[Rule]", 
       FractionBox["1", "2"]}], ",", "\[IndentingNewLine]", 
      RowBox[{"ContourShading", "\[Rule]", "False"}], ",", 
      RowBox[{"AxesLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}]}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<The curves  \[Phi](x,y) = \>\"", ",", 
      RowBox[{"\[Phi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}], ",", "\"\< = C\>\""}], " ", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{"g2", "=", 
    RowBox[{"ContourPlot", "[", 
     RowBox[{
      RowBox[{"\[CurlyPhi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", 
        RowBox[{"-", "8"}], ",", "8"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"y", ",", "0", ",", "8"}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{"Contours", " ", "\[Rule]", " ", "10"}], ",", 
      RowBox[{"PlotPoints", "\[Rule]", "25"}], ",", 
      RowBox[{"AspectRatio", "\[Rule]", 
       FractionBox["1", "2"]}], ",", "\[IndentingNewLine]", 
      RowBox[{"ContourShading", "\[Rule]", "False"}], ",", 
      RowBox[{"AxesLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}]}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<The curves  \[CurlyPhi](x,y) = \>\"", ",", 
      RowBox[{"\[CurlyPhi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}], ",", "\"\< = C\>\""}], " ", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"g1", ",", "g2"}], "]"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<The equipotential  curves  \[Phi](x,y) = \>\"", ",", 
      RowBox[{"\[Phi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}], ",", "\"\< = C\>\""}], " ", "]"}], 
    ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<and the streamline curves  \[CurlyPhi](x,y) = \>\"", ",", 
      RowBox[{"\[CurlyPhi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}], ",", "\"\< = C\>\""}], " ", "]"}], 
    ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399020540203125*^9, 3.399020544890625*^9}, {
  3.399020587078125*^9, 3.39902058890625*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"\[Phi]", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "8"}], ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "0", ",", "8"}], "}"}], ",", 
     RowBox[{"Contours", " ", "\[Rule]", " ", "10"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "25"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["1", "2"]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The equipotential curves are\>\"", "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Phi](x,y) = \>\"", ",", 
      RowBox[{"\[Phi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}], ",", "\"\< = C\>\""}], " ", "]"}], 
    ";"}], "  ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3990205974375*^9, 3.39902059878125*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"\[CurlyPhi]", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "8"}], ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "0", ",", "8"}], "}"}], ",", 
     RowBox[{"Contours", " ", "\[Rule]", " ", "10"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "25"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["1", "2"]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The streamline curves are\>\"", "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[CurlyPhi](x,y) = \>\"", ",", 
      RowBox[{"\[CurlyPhi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}], ",", "\"\< = C\>\""}], " ", "]"}], 
    ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39902060703125*^9, 3.39902060728125*^9}}]
}, Closed]],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Analytic Functions",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/AnalyticFunBib.html"], None}],
 
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Cauchy-Riemann Equations",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/CauchyRiemannBib.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Harmonic Functions",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/HarmonicFunBib.html"], None}],
 
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/complex.html"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2008 John H. Mathews, Russell W. \
Howell",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/"], None}],
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[0, 1, 0]]], "Text",
 CellChangeTimes->{{3.399020522515625*^9, 3.399020522609375*^9}}]
},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{1004, 632},
WindowMargins->{{1, Automatic}, {Automatic, 0}},
ShowSelection->True,
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "CHAPTER 1"->{
  Cell[568, 21, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"],
  Cell[102758, 3725, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"],
  Cell[212861, 7110, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"CHAPTER 1", 471288, 19470}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"],
Cell[905, 32, 119, 2, 29, "Text"],
Cell[1027, 36, 2137, 71, 123, "Text"],
Cell[3167, 109, 2089, 66, 110, "Text"],
Cell[5259, 177, 78698, 2910, 188, "Text"],
Cell[CellGroupData[{
Cell[83982, 3091, 99, 2, 29, "Text"],
Cell[84084, 3095, 3471, 87, 292, "Input"],
Cell[87558, 3184, 446, 12, 92, "Input"],
Cell[88007, 3198, 424, 12, 92, "Input"],
Cell[88434, 3212, 406, 11, 92, "Input"],
Cell[88843, 3225, 407, 11, 92, "Input"],
Cell[89253, 3238, 605, 19, 106, "Input"]
}, Closed]],
Cell[89873, 3260, 208, 4, 26, "Text"],
Cell[90084, 3266, 1992, 72, 47, "Text",
 Evaluatable->False],
Cell[92079, 3340, 10332, 369, 511, "Text"],
Cell[CellGroupData[{
Cell[102436, 3713, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[102580, 3719, 175, 4, 29, "Text",
 Evaluatable->False],
Cell[102758, 3725, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"]
}, Closed]],
Cell[103107, 3737, 2658, 97, 62, "Text"],
Cell[105768, 3836, 4469, 160, 272, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[110262, 4000, 233, 9, 29, "Text",
 Evaluatable->False],
Cell[110498, 4011, 112, 3, 29, "Text"],
Cell[110613, 4016, 3699, 109, 472, "Input"],
Cell[114315, 4127, 1477, 55, 83, "Text",
 Evaluatable->False],
Cell[115795, 4184, 1953, 56, 232, "Input"]
}, Closed]],
Cell[117763, 4243, 128, 3, 26, "Text"],
Cell[117894, 4248, 1990, 68, 140, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[119909, 4320, 233, 9, 29, "Text",
 Evaluatable->False],
Cell[120145, 4331, 112, 3, 29, "Text"],
Cell[120260, 4336, 3822, 113, 472, "Input"],
Cell[124085, 4451, 1945, 70, 86, "Text",
 Evaluatable->False],
Cell[126033, 4523, 1949, 56, 232, "Input"]
}, Closed]],
Cell[127997, 4582, 5426, 199, 86, "Text"],
Cell[133426, 4783, 63826, 1781, 250, "Text"],
Cell[197255, 6566, 3050, 100, 191, "Text"],
Cell[200308, 6668, 976, 37, 47, "Text",
 Evaluatable->False],
Cell[201287, 6707, 8581, 295, 326, "Text"],
Cell[209871, 7004, 2648, 90, 110, "Text"],
Cell[CellGroupData[{
Cell[212544, 7098, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[212688, 7104, 170, 4, 29, "Text",
 Evaluatable->False],
Cell[212861, 7110, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"]
}, Closed]],
Cell[213210, 7122, 285, 5, 44, "Text"],
Cell[213498, 7129, 352, 13, 34, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[213875, 7146, 341, 11, 29, "Text",
 Evaluatable->False],
Cell[214219, 7159, 3092, 82, 332, "Input",
 InitializationCell->True]
}, Closed]],
Cell[217326, 7244, 571, 23, 26, "Text",
 Evaluatable->False],
Cell[217900, 7269, 3544, 125, 206, "Text"],
Cell[221447, 7396, 2356, 85, 223, "Text"],
Cell[CellGroupData[{
Cell[223828, 7485, 233, 9, 29, "Text",
 Evaluatable->False],
Cell[224064, 7496, 74, 0, 29, "Text"],
Cell[224141, 7498, 8949, 250, 668, "Input"],
Cell[233093, 7750, 1275, 35, 132, "Input"],
Cell[234371, 7787, 1275, 35, 132, "Input"],
Cell[235649, 7824, 2075, 57, 152, "Input"],
Cell[237727, 7883, 194, 6, 65, "Text"],
Cell[237924, 7891, 168, 3, 29, "Text"],
Cell[238095, 7896, 1563, 45, 232, "Input"],
Cell[239661, 7943, 129, 3, 29, "Text"],
Cell[239793, 7948, 3313, 99, 412, "Input"],
Cell[243109, 8049, 884, 34, 76, "Text"],
Cell[243996, 8085, 2363, 73, 266, "Input"]
}, Closed]],
Cell[246374, 8161, 4057, 138, 26, "Text"],
Cell[250434, 8301, 93507, 5611, 257, "Text"],
Cell[343944, 13914, 5273, 185, 65, "Text"],
Cell[349220, 14101, 52237, 2825, 323, "Text"],
Cell[401460, 16928, 788, 28, 29, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[402273, 16960, 160, 4, 29, "Text",
 Evaluatable->False],
Cell[402436, 16966, 74, 0, 29, "Text"],
Cell[402513, 16968, 9659, 268, 701, "Input"],
Cell[412175, 17238, 194, 6, 65, "Text"],
Cell[412372, 17246, 168, 3, 29, "Text"],
Cell[412543, 17251, 1898, 55, 232, "Input"],
Cell[414444, 17308, 129, 3, 29, "Text"],
Cell[414576, 17313, 3312, 99, 412, "Input"],
Cell[417891, 17414, 1351, 47, 68, "Text"],
Cell[419245, 17463, 2363, 73, 266, "Input"]
}, Closed]],
Cell[421623, 17539, 1106, 33, 170, "Text"],
Cell[422732, 17574, 1178, 47, 125, "Text"],
Cell[423913, 17623, 3580, 131, 269, "Text"],
Cell[427496, 17756, 1519, 54, 193, "Text"],
Cell[429018, 17812, 2665, 98, 229, "Text"],
Cell[431686, 17912, 769, 27, 47, "Text"],
Cell[432458, 17941, 736, 29, 29, "Text",
 Evaluatable->False],
Cell[433197, 17972, 1993, 70, 194, "Text"],
Cell[435193, 18044, 25298, 1106, 323, "Text"],
Cell[CellGroupData[{
Cell[460516, 19154, 233, 9, 29, "Text",
 Evaluatable->False],
Cell[460752, 19165, 166, 7, 29, "Text"],
Cell[460921, 19174, 3024, 89, 397, "Input"],
Cell[463948, 19265, 162, 5, 47, "Text"],
Cell[464113, 19272, 2765, 66, 328, "Input"],
Cell[466881, 19340, 1156, 30, 153, "Input"],
Cell[468040, 19372, 1167, 30, 153, "Input"]
}, Closed]],
Cell[469222, 19405, 281, 7, 26, "Text"],
Cell[469506, 19414, 275, 7, 29, "Text"],
Cell[469784, 19423, 285, 7, 29, "Text"],
Cell[470072, 19432, 275, 7, 29, "Text"],
Cell[470350, 19441, 249, 5, 29, "Text"],
Cell[470602, 19448, 320, 7, 29, "Text"]
}
]
*)

(* End of internal cache information *)
