(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    167522,       5552]
NotebookOptionsPosition[    158580,       5270]
NotebookOutlinePosition[    159828,       5318]
CellTagsIndexPosition[    159754,       5313]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["Chapter 4  Sequences, Julia and Mandelbrot Sets, and \
Power Series",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
 StyleBox["Overview",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "\n\n\tIn 1980 ",
 StyleBox[ButtonBox["Benoit Mandelbrot",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/\
Mandelbrot.html"], None}],
  FontVariations->{"Underline"->True}],
 " led a team of mathematicians in producing some stunning computer graphics \
from very simple rules for manipulating complex numbers.  This event marked \
the beginning of a new branch of mathematics, known as fractal geometry, that \
has some amazing applications.  Many of the tools needed to appreciate \
Mandelbrot's work are contained in this chapter.  We look at extensions to \
the complex domain of sequences and series, ideas that are familiar to \
students who have completed a standard calculus course."
}], "Text"],

Cell[TextData[StyleBox["4.1  Sequences and Series",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
 "\tIn formal terms, a complex sequence is a function whose domain is the \
positive integers and whose range is a subset of the complex numbers.  The \
following are examples of sequences:  \n\n",
 Cell[BoxData[GridBox[{
    {
     RowBox[{
      StyleBox[
       RowBox[{"(", 
        RowBox[{"4", "-", "1"}], ")"}],
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->RGBColor[0, 0, 0.996109]], "                    "}], 
     RowBox[{
      RowBox[{"f", 
       RowBox[{"(", "n", ")"}]}], " ", "=", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"2", "-", 
         FractionBox["1", "n"]}], ")"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"5", "+", 
          FractionBox["1", "n"]}], ")"}], "\[ImaginaryI]"}]}]}], 
     RowBox[{" ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"n", "=", "1"}], 
         StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontVariations->{"StrikeThrough"->False,
          "Underline"->False},
          FontColor->GrayLevel[0]], "2", 
         StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontVariations->{"StrikeThrough"->False,
          "Underline"->False},
          FontColor->GrayLevel[0]], "3", 
         StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontVariations->{"StrikeThrough"->False,
          "Underline"->False},
          FontColor->GrayLevel[0]], "..."}], ")"}], 
       StyleBox[";",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]]}]}]},
    {
     RowBox[{
      StyleBox[
       RowBox[{"(", 
        RowBox[{"4", "-", "2"}], ")"}],
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->RGBColor[0, 0, 0.996109]], "                    "}], 
     RowBox[{
      RowBox[{"g", 
       RowBox[{"(", "n", ")"}]}], " ", "=", " ", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", 
         FractionBox[
          RowBox[{"\[Pi]", " ", "n"}], "4"]}]], "                        ", 
       StyleBox[
        FractionBox["1", "1"],
        FontColor->GrayLevel[1]]}]}], 
     RowBox[{" ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"n", "=", "1"}], 
         StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontVariations->{"StrikeThrough"->False,
          "Underline"->False},
          FontColor->GrayLevel[0]], "2", 
         StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontVariations->{"StrikeThrough"->False,
          "Underline"->False},
          FontColor->GrayLevel[0]], "3", 
         StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontVariations->{"StrikeThrough"->False,
          "Underline"->False},
          FontColor->GrayLevel[0]], "..."}], ")"}], 
       StyleBox[";",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]]}]}]},
    {
     RowBox[{
      StyleBox[
       RowBox[{"(", 
        RowBox[{"4", "-", "3"}], ")"}],
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->RGBColor[0, 0, 0.996109]], "                    "}], 
     RowBox[{
      RowBox[{"h", 
       RowBox[{"(", "k", ")"}]}], " ", "=", " ", 
      RowBox[{"5", "+", 
       RowBox[{"3", "\[ImaginaryI]"}], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          FractionBox["1", 
           RowBox[{"1", "+", "\[ImaginaryI]"}]], ")"}], "k"], "    ", 
        StyleBox[
         FractionBox["1", "1"],
         FontColor->GrayLevel[1]]}]}]}], 
     RowBox[{" ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"k", "=", "1"}], 
         StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontVariations->{"StrikeThrough"->False,
          "Underline"->False},
          FontColor->GrayLevel[0]], "2", 
         StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontVariations->{"StrikeThrough"->False,
          "Underline"->False},
          FontColor->GrayLevel[0]], "3", 
         StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontVariations->{"StrikeThrough"->False,
          "Underline"->False},
          FontColor->GrayLevel[0]], "..."}], ")"}], 
       StyleBox[";",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]]}]}]},
    {
     RowBox[{
      StyleBox[
       RowBox[{"(", 
        RowBox[{"4", "-", "4"}], ")"}],
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->RGBColor[0, 0, 0.996109]], "                    "}], 
     RowBox[{
      RowBox[{"r", 
       RowBox[{"(", "n", ")"}]}], " ", "=", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         FractionBox["1", "4"], "+", 
         FractionBox["\[ImaginaryI]", "2"]}], ")"}], "n"], 
      "                    "}], 
     RowBox[{" ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"n", "=", "1"}], 
         StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontVariations->{"StrikeThrough"->False,
          "Underline"->False},
          FontColor->GrayLevel[0]], "2", 
         StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontVariations->{"StrikeThrough"->False,
          "Underline"->False},
          FontColor->GrayLevel[0]], "3", 
         StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontVariations->{"StrikeThrough"->False,
          "Underline"->False},
          FontColor->GrayLevel[0]], "..."}], ")"}], 
       StyleBox[".",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]]}]}]}
   }]]],
 "  "
}], "Text",
 CellChangeTimes->{3.39902116090625*^9}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "n"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["f", "n_"], " ", "=", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2", "-", 
        FractionBox["1", "n"]}], ")"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"5", "+", 
         FractionBox["1", "n"]}], ")"}], "\[ImaginaryI]"}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(f\), \(n\)]\) = f(n) = \>\"", " ", ",", 
      SubscriptBox["f", "n"]}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"TableForm", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          SubscriptBox["\"\<f\>\"", "n"], ",", "\"\<=\>\"", ",", 
          SubscriptBox["f", "n"], ",", "\"\<=\>\"", ",", 
          RowBox[{"PaddedForm", "[", 
           RowBox[{
            RowBox[{"N", "[", 
             SubscriptBox["f", "n"], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"12", ",", "12"}], "}"}]}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"n", ",", "1", ",", "20"}], "}"}]}], "]"}], "]"}], "]"}], 
    ";"}], "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.400259600859375*^9, 3.40025963309375*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"g", ",", "n"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["g", "n_"], " ", "=", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", 
       FractionBox[
        RowBox[{"\[Pi]", " ", "n"}], "4"]}]]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(g\), \(n\)]\) = g(n) = \>\"", " ", ",", 
      SubscriptBox["g", "n"]}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"TableForm", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          SubscriptBox["\"\<g\>\"", "n"], ",", "\"\<=\>\"", ",", 
          SubscriptBox["g", "n"], ",", "\"\<=\>\"", ",", 
          RowBox[{"PaddedForm", "[", 
           RowBox[{
            RowBox[{"N", "[", 
             SubscriptBox["g", "n"], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"12", ",", "12"}], "}"}]}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"n", ",", "1", ",", "16"}], "}"}]}], "]"}], "]"}], "]"}], 
    ";"}], "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.4002596200625*^9, 3.400259628828125*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"h", ",", "k"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["h", "k_"], " ", "=", " ", 
     RowBox[{"5", "+", 
      RowBox[{"3", "\[ImaginaryI]"}], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        FractionBox["1", 
         RowBox[{"1", "+", "\[ImaginaryI]"}]], ")"}], "k"]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(h\), \(k\)]\) = h(k) = 5+3\[ImaginaryI] + \
(\!\(\*FractionBox[\(1\), \(1 + \[ImaginaryI]\)]\)\!\(\*SuperscriptBox[\()\), \
\(k\)]\) = \>\"", " ", ",", 
      SubscriptBox["h", "k"]}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"TableForm", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          SubscriptBox["\"\<h\>\"", "k"], ",", "\"\<=\>\"", ",", 
          SubscriptBox["h", "k"], ",", "\"\<=\>\"", ",", 
          RowBox[{"PaddedForm", "[", 
           RowBox[{
            RowBox[{"N", "[", 
             SubscriptBox["h", "k"], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"12", ",", "12"}], "}"}]}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", "1", ",", "14"}], "}"}]}], "]"}], "]"}], "]"}], 
    ";"}], "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.400259641*^9, 3.40025964896875*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"r", ",", "n"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["r", "n_"], " ", "=", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        FractionBox["1", "4"], "+", 
        FractionBox["\[ImaginaryI]", "2"]}], ")"}], "n"]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(r\), \(n\)]\) = r(n) = \>\"", " ", ",", 
      SubscriptBox["r", "n"]}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"TableForm", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          SubscriptBox["\"\<r\>\"", "n"], ",", "\"\<=\>\"", ",", 
          SubscriptBox["r", "n"], ",", "\"\<=\>\"", ",", 
          RowBox[{"PaddedForm", "[", 
           RowBox[{
            RowBox[{"N", "[", 
             SubscriptBox["r", "n"], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"12", ",", "12"}], "}"}]}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"n", ",", "1", ",", "16"}], "}"}]}], "]"}], "]"}], "]"}], 
    ";"}], "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.40025965853125*^9, 3.40025966478125*^9}}]
}, Closed]],

Cell[TextData[{
 "\tFor convenience, at times we use the term sequence rather than complex \
sequence.  If we want a function ",
 StyleBox["s",
  FontFamily->"Courier New"],
 " to represent an arbitrary sequence, we can specify it by writing  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"s", 
     RowBox[{"(", "1", ")"}]}], "=", 
    SubscriptBox["z", "1"]}], ",", 
   RowBox[{
    RowBox[{"s", 
     RowBox[{"(", "2", ")"}]}], "=", 
    SubscriptBox["z", "2"]}], ",", 
   RowBox[{
    RowBox[{"s", 
     RowBox[{"(", "3", ")"}]}], "=", 
    SubscriptBox["z", "3"]}]}]]],
 ",  and so on.  The values   ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], ",", 
   SubscriptBox["z", "2"], ",", 
   SubscriptBox["z", "3"], ",", "..."}]]],
 ",  are called the terms of a sequence, and mathematicians, being generally \
lazy when it comes to such things, often refer to ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], ",", 
   SubscriptBox["z", "2"], ",", 
   SubscriptBox["z", "3"], ",", 
   RowBox[{"etc", "."}]}]]],
 " as the sequence itself, even though they are really speaking of the range \
of the sequence when they do so.  You will usually see a sequence written as  \
",
 Cell[BoxData[
  SubsuperscriptBox[
   RowBox[{"{", 
    SubscriptBox["z", "n"], "}"}], 
   RowBox[{"n", "=", "1"}], "\[Infinity]"]]],
 ", ",
 Cell[BoxData[
  SubsuperscriptBox[
   RowBox[{"{", 
    SubscriptBox["z", "n"], "}"}], "1", "\[Infinity]"]]],
 ", or when the indices are understood, as ",
 Cell[BoxData[
  RowBox[{"{", 
   SubscriptBox["z", "n"], "}"}]]],
 ".  Mathematicians are also not so fussy about starting a sequence at  ",
 Cell[BoxData[
  SubscriptBox["z", "1"]]],
 ", so that  ",
 Cell[BoxData[
  SubsuperscriptBox[
   RowBox[{"{", 
    SubscriptBox["z", "n"], "}"}], 
   RowBox[{"n", "=", 
    RowBox[{"-", "1"}]}], "\[Infinity]"]]],
 ", ",
 Cell[BoxData[
  SubsuperscriptBox[
   RowBox[{"{", 
    SubscriptBox["z", "n"], "}"}], 
   RowBox[{"n", "=", "0"}], "\[Infinity]"]]],
 ", etc., would also be acceptable notation, provided all terms were defined. \
 For example, the sequence ",
 StyleBox["r",
  FontFamily->"Courier New"],
 " given by Equation ",
 StyleBox["(4-4)",
  FontColor->RGBColor[0, 0, 1]],
 " could be written in a variety of ways:  \n\n\t",
 Cell[BoxData[
  SubsuperscriptBox[
   RowBox[{"{", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       FractionBox["1", "4"], "+", 
       FractionBox["\[ImaginaryI]", "2"]}], ")"}], "n"], " ", "}"}], 
   RowBox[{"n", "=", "1"}], "\[Infinity]"]]],
 ",  ",
 Cell[BoxData[
  SubsuperscriptBox[
   RowBox[{"{", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       FractionBox["1", "4"], "+", 
       FractionBox["\[ImaginaryI]", "2"]}], ")"}], "n"], " ", "}"}], "1", 
   "\[Infinity]"]]],
 ",  ",
 Cell[BoxData[
  SubsuperscriptBox[
   RowBox[{"{", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       FractionBox["1", "4"], "+", 
       FractionBox["\[ImaginaryI]", "2"]}], ")"}], "n"], " ", "}"}], 
   RowBox[{"n", "=", "1"}], "\[Infinity]"]]],
 ",  ",
 Cell[BoxData[
  SubsuperscriptBox[
   RowBox[{"{", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       FractionBox["1", "4"], "+", 
       FractionBox["\[ImaginaryI]", "2"]}], ")"}], 
     RowBox[{"n", "+", "2"}]], " ", "}"}], 
   RowBox[{"n", "=", 
    RowBox[{"-", "2"}]}], "\[Infinity]"]]],
 ", ",
 Cell[BoxData[
  SubsuperscriptBox[
   RowBox[{"{", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       FractionBox["1", "4"], "+", 
       FractionBox["\[ImaginaryI]", "2"]}], ")"}], "k"], " ", "}"}], 
   RowBox[{"k", "=", "1"}], "\[Infinity]"]]],
 ", ..."
}], "Text"],

Cell[TextData[{
 "\tThe sequences ",
 StyleBox["f",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["g",
  FontFamily->"Courier New"],
 " given by Equations ",
 StyleBox["(4-1)",
  FontColor->RGBColor[0, 0, 1]],
 " and ",
 StyleBox["(4-2)",
  FontColor->RGBColor[0, 0, 1]],
 " behave differently as ",
 StyleBox["n",
  FontFamily->"Courier New"],
 " gets larger.  The terms in Equation ",
 StyleBox["(4-1)",
  FontColor->RGBColor[0, 0, 1]],
 " approach  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"2", "+", 
    RowBox[{"5", "\[ImaginaryI]"}]}], " ", "=", 
   RowBox[{"(", 
    RowBox[{"2", ",", "5"}], ")"}]}]]],
 ",  but those in Equation  ",
 StyleBox["(4-2)",
  FontColor->RGBColor[0, 0, 1]],
 "  do not approach any particular number, as they oscillate around the eight \
eighth roots of unity on the unit circle.  Informally, the sequence  ",
 Cell[BoxData[
  SubsuperscriptBox[
   RowBox[{"{", 
    SubscriptBox["z", "n"], "}"}], "1", "\[Infinity]"]]],
 "  has  ",
 Cell[BoxData["\[Zeta]"]],
 "  as its limit as  n  approaches infinity, provided the terms  ",
 Cell[BoxData[
  SubscriptBox["z", "n"]]],
 "  can be made as close as we want to  ",
 Cell[BoxData["\[Zeta]"]],
 "  by making  n  large enough.  When this happens, we write \n\n ",
 StyleBox["(4-5)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    UnderscriptBox["lim", 
     RowBox[{"n", "\[Rule]", "\[Infinity]"}]], " ", 
    SubscriptBox["z", "n"]}], "=", 
   RowBox[{
    RowBox[{"\[Zeta]", "      ", 
     StyleBox["or",
      FontFamily->"Times New Roman"], "     ", 
     SubscriptBox["z", "n"]}], "\[Rule]", 
    RowBox[{
     RowBox[{"\[Zeta]", "   ", 
      StyleBox["as",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "   ", "n"}], " ", "\[Rule]", 
     "\[Infinity]"}]}]}]]],
 ". \n\nIf  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    UnderscriptBox["lim", 
     RowBox[{"n", "\[Rule]", "\[Infinity]"}]], " ", 
    SubscriptBox["z", "n"]}], "=", "\[Zeta]"}]]],
 ",  we say that the sequence  ",
 Cell[BoxData[
  SubsuperscriptBox[
   RowBox[{"{", 
    SubscriptBox["z", "n"], "}"}], "1", "\[Infinity]"]]],
 "  converges to  ",
 Cell[BoxData["\[Zeta]"]],
 ".  \n\n\tWe need a rigorous definition for Statement ",
 StyleBox["(4-5)",
  FontColor->RGBColor[0, 0, 1]],
 ", however, if we are to do honest mathematics."
}], "Text"],

Cell[TextData[{
 StyleBox["Definition 4.1 (",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Limit of a Sequence",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/ConvergentSequence.html"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 StyleBox[").",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    UnderscriptBox["lim", 
     RowBox[{"n", "\[Rule]", "\[Infinity]"}]], " ", 
    SubscriptBox["z", "n"]}], "=", "\[Zeta]"}]]],
 "  means that for any real number  ",
 Cell[BoxData[
  RowBox[{"\[Epsilon]", ">", "0"}]]],
 "  there corresponds a positive integer  ",
 Cell[BoxData[
  SubscriptBox["N", "\[Epsilon]"]]],
 "  (which depends on  ",
 Cell[BoxData["\[Epsilon]"]],
 ")  such that  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "n"], "\[Element]", 
   RowBox[{
    SubscriptBox["D", "\[Epsilon]"], 
    RowBox[{"(", "\[Zeta]", ")"}]}]}]]],
 "  whenever  ",
 Cell[BoxData[
  RowBox[{"n", ">", 
   SubscriptBox["N", "\[Epsilon]"]}]]],
 ".   That is  ",
 Cell[BoxData[
  RowBox[{"|", 
   RowBox[{"\[Zeta]", "-", 
    SubscriptBox["z", "n"]}], "|", 
   RowBox[{"<", "\[Element]"}]}]]],
 "  whenever  ",
 Cell[BoxData[
  RowBox[{"n", ">", 
   SubscriptBox["N", "\[Epsilon]"]}]]],
 ".  Figure 4.1 illustrates a convergent sequence."
}], "Text"],

Cell[TextData[{
 StyleBox["\t\t\t\t",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .75 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-017 0.025 -2.08167e-017 0.025 [
[ 0 0 0 0 ]
[ 1 .75 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .75 L
0 .75 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-15. 3.75 moveto 0 0 lineto
-15. -3.75 lineto fill
-15. 3.75 moveto 0 0 lineto
-15. -3.75 lineto
-15. 3.75 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
0 0 1 r
.02 w
.375 .375 Mdot
1 0 0 r
.34338 .39661 Mdot
.33224 .42243 Mdot
.31531 .44712 Mdot
.29668 .46878 Mdot
.28691 .49398 Mdot
.30014 .53232 Mdot
.35144 .5837 Mdot
.4492 .63047 Mdot
.57972 .6446 Mdot
.70073 .60721 Mdot
.76331 .52455 Mdot
.74997 .42572 Mdot
.6897 .34206 Mdot
.63436 .28558 Mdot
.62947 .2462 Mdot
.71204 .21172 Mdot
.91502 .19207 Mdot
0 0 1 r
.5 Mabswid
[ ] 0 setdash
newpath
.375 .375 .3625 0 365.73 arc
s
0 g
gsave
.9175 .15 -69.4063 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
70.188 14.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
75.813 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.7275 .175 -69.4063 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
70.188 14.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
75.813 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.6275 .2075 -69.4063 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
70.188 14.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
75.813 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.585 .6125 -69.4063 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
70.188 14.625 moveto
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.813 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.44 .6 -74.5313 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
70.188 14.625 moveto
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.313 14.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
80.438 14.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
86.063 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.71 .65 -66.5938 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.725 .625 -65.6875 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(N) show
68.375 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.7425 .61 -65.6875 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\316) show
68.375 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.35 .225 -66.5938 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\316) show
70.188 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.4 .4 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
70.188 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 1 r
.375 .375 m
.375 .0125 L
s
% Start of user PostScript
15. 15. 15. 0.5 MAarrowhead1
% End of user PostScript
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 216},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\
eJztW1lzVEUYvckkJJHNhIQtYBbAxJBYQUHAsITJPtkhZBcISYCImBAiAuKC
S7mVpWWVZemDPugbZbk/WeqDD1ZZ5bv/Zsztr3N6ZnJuT98kYgpNwcyt853v
fN1f951ebt/OsblLk1fG5qbGx0pbZsdmLk2NXyttnp6dhyIZnpdR6nneX6We
fx2fv9Qf8fl/8TL/w0fSX4/7XwW+510BRvyvXB/IVUDE0w7qf47/meNDXwq9
3//K9oGN/lUEVwr7XEi9AApBKgT2qZC6/a9MH9gGkrn6WEgxeBXDtAOOHwmp
BaYS0Hfi6gMhNcGrHKZyOL4npCiA3SDtgeO7QqoHUAFSBbC3hXQMQCVSWAns
TSEdJRk39CrQ3xB6HYC9IFUTiVeFfhj0GtBrgGnSQQCP+ld5uFLYK0I6AKAW
pFpgLwlpPylJIKYcb4vj44R0gGBPEOymSOyD5iFCMnXU9FpCYo6HCXZdJEyO
6gjpSYI9J47VcGStb5pY0/cSEnNk2KxIVBHTMUfsqkiYnnuCkI7DqukVhMQc
GfasSDxMTFFH7IpI7CGmBkfsmXASjQS7LBK7HelNBHtaJHY50psJNiUSZWii
VkJqgVXTSwmJOTLsokiUEFObI3ZBJB4ippgjNikSO4mp3RGbEIkdxNThiGH4
8grDiXVay+gB07LFjhIMa0AZI8EBthPHLkdMbpisJFl7tG1EpdsRayCyllBb
iUSPI8Yqpm8kb7PIbyFuvY5YPc/b9nDKJwmGqZtXg8aXnOtyp5cIlE1Js3Ra
r4jQTzliOdYOGlt+gFz3DqqjFRKVPkcsl8hmpmD+X/vyQ+U5hEqo1SYicdoR
W8Nz2BNOuZ9g2Wj+/dJtcdd6BY4SDDsqsriTvHxCGnDEjqSKPUhIgwTDyOtt
WEnZeuQsizT3uqBQibl1DXXC/eZhVZSmSfjpMKYhgkWJLKvieuKrancqXDz5
ic9J/YlPulGTMqU+PYklv5G02sPLy+TGJYRUg4NSzw4KrnpMEdHOTNBmqe0l
ZcwhvBFU0WibRmH98qSj8ijB0slmByXDIrY20JS+jE8F1o/K9lkbzCL2ADGd
IZhaQ6huw0bPkGKNktEAsd5VIcYmNz1LzRmbgGmxPGI6S7BzBOteMQm2n8fo
q16C3UtjjljXikmsIabzBGtGD2Fri5BiTei7TKzzfhEzOWNLPy3GfgXHHQOE
lGBYxz2XmCBY+4pJZDnS/5dYbRL9uFvY1CYWTkwtw9R9zOYg942YU84ixDTp
iP0XJCYkifPQhXCO49KU81DIiPfeccl1/DMcfdr/VLN7tha0OI6gJ5uFpwcr
295hOxaWAMO47/IXcmErI7sDhyDByjjyL4oNI3v5yxebJhIhMzWDFLPtB4vj
ACqilkhqD4k1Pttms4w3/Uj2ZpSM9R8VudVFZybV6ikP/dj+n/A2qbmaxptN
o/5IU1tXH8tMrRcFvB7OsQd5mSNWy/RyBRyvEatlmt+DOrKIFsffw9FjiHMr
nGMbanZzqY43iNWy4GxdqmMb6siKqh3ZQvs3glnW5SHpZtXGUm/ZyDA7Mqw+
y3VkWzkN1tRb9oAaram3OP5KMMvGVUj6LwSzbCX+vHz6WiRCTi/QefRPQY4q
9Q3BjmZbjf3MLJJge9CmiRf96sf1M49ECbZFHrVKrE/NgF1i0cgVXxiM6dOH
KNRZbIvjjwTTT1XYM5wfwtG/J9hAMP07gslTI/p87dtw9G8IJtMm+ijw62A6
eyD5FcFkNkcfwt4l2MiS6GyPux3dgc1JR4MdY+iAbCaqHdlGuBnWzGEPM408
QjzkEQTdCDdDnWoYNTvVi42FP/ZcSz2RORgulBkcC1MU/b9MKYjHJ8fsSKHs
+tNdzUGIpRY+qEIsKDvbeFZU2O6n3A+LHgsq5awwcdlhzHMix473DBKJDQQr
CWpg9mOVi8bSvzns5BKLvA5RyknqA0OpLpgHX72eYqewTvM0V1mbnI0AJi47
6ZGuBNkIamtyNv7lJceNJNSXnYJ7nRSO/YiacZ+dJtEB2Ek9FoANGQUorV7M
JTgkNloJ8b3DE8XCFKZQ9Z+ePJcSj1HUvAwtwxq8yKpcRjzMDgs7+2zW8wk3
lP+t1yTlC/a40TEHoLem8WaHSQehw05Gb2GKCTVkJ1wHkbtduGLzWH1Ilp2z
vU3uo5QkqSbR81h2YPgFSLBVlQyC2UmdZ6F6WpQdZL4FUbY4NMOGEdVHByqD
xCJBYmwg1iV7BA1+B1fF/G7Q4dlJ8hcJVpyaWXNi/Tahy3w94Tz8DVzpo/Ks
T7E9AU3fR0yzBHte6I8h3AyuZDlKB7zLKZWho/FUUHf0ZMag/C/i6mUxHZK2
nAfOJzdO4psbZ3D1mpjYwf0hkPSbH+xoPtuV0/TjKEkflN4SUxRAN0jviKkR
QAwk/V5My0KfiJs3ZN4XUwe4dSB9KKYucE3W9Hs95g2halx9IibzhpF5Uecz
MampsHqPRc3f1VtLX4hJpXyTD+j3mlRC0rwM5WX8DciMjC0=\
\>"],
  ImageRangeCache->{{{0, 287}, {215, 0}} -> {0, 0, 0, 0}}],
 StyleBox["\n\t\t\tFigure 4.1",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "   A sequence ",
 Cell[BoxData[
  SubsuperscriptBox[
   RowBox[{"{", 
    SubscriptBox["z", "n"], "}"}], "1", "\[Infinity]"]]],
 " that converges to ",
 Cell[BoxData["\[Zeta]"]],
 ".   (If  ",
 Cell[BoxData[
  RowBox[{"n", ">", 
   SubscriptBox["N", "\[Epsilon]"]}]]],
 " then ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "n"], "\[Element]", 
   RowBox[{
    SubscriptBox["D", "\[Epsilon]"], 
    RowBox[{"(", "\[Zeta]", ")"}]}]}]]],
 ".)"
}], "Text"],

Cell[TextData[{
 StyleBox["Remark 4.1.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 " The reason we use the notation ",
 Cell[BoxData[
  SubscriptBox["N", "\[Epsilon]"]]],
 " is to emphasize the fact that this number depends on our choice of ",
 Cell[BoxData["\[Epsilon]"]],
 ".  Sometimes it will be convenient to drop the subscript."
}], "Text"],

Cell["\<\
\tIn form, Definition 4.1 is exactly the same as the corresponding definition \
for limits of real sequences.  In fact, a simple criterion casts the \
convergence of complex sequences in terms of the convergence of real \
sequences.\
\>", "Text"],

Cell[TextData[{
 StyleBox["Theorem 4.1.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Let  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "n"], "=", 
   RowBox[{
    SubscriptBox["x", "n"], "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["y", "n"]}]}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{"\[Zeta]", "=", 
   RowBox[{"u", "+", 
    RowBox[{"\[ImaginaryI]", " ", "v"}]}]}]]],
 ".  Then \n\n ",
 StyleBox["(4-6)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    UnderscriptBox["lim", 
     RowBox[{"n", "\[Rule]", "\[Infinity]"}]], " ", 
    SubscriptBox["z", "n"]}], "=", "\[Zeta]"}]]],
 ",   iff  \n\n ",
 StyleBox["(4-7)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    UnderscriptBox["lim", 
     RowBox[{"n", "\[Rule]", "\[Infinity]"}]], " ", 
    SubscriptBox["x", "n"]}], "=", 
   RowBox[{
    RowBox[{"u", "    ", 
     StyleBox["and",
      FontFamily->"Times New Roman"], "    ", 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"n", "\[Rule]", "\[Infinity]"}]], " ", 
      SubscriptBox["y", "n"]}]}], "=", "v"}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 4.1 is in the book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 4.1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Find the limit of the sequence  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"{", 
    SubscriptBox["z", "n"], "}"}], "=", 
   RowBox[{"{", 
    FractionBox[
     RowBox[{
      SqrtBox["n"], " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", 
       RowBox[{"(", " ", 
        RowBox[{"n", "+", "1"}], ")"}]}]}], "n"], "}"}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "Solution.  We write  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "n"], " ", "=", " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["x", "n"], "+", 
     RowBox[{"\[ImaginaryI]", " ", 
      SubscriptBox["y", "n"]}]}], " ", "=", " ", 
    RowBox[{
     FractionBox[
      RowBox[{"1", " "}], 
      SqrtBox["n"]], " ", "+", " ", 
     RowBox[{"\[ImaginaryI]", 
      FractionBox[
       RowBox[{"n", "+", "1"}], "n"]}]}]}]}]]],
 ".  Using results concerning sequences of real numbers, we find that  \n\n\t\
",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    UnderscriptBox["lim", 
     RowBox[{"n", "\[Rule]", "\[Infinity]"}]], " ", 
    SubscriptBox["x", "n"]}], "=", 
   RowBox[{
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"n", "\[Rule]", "\[Infinity]"}]], " ", 
     FractionBox[
      RowBox[{"1", " "}], 
      SqrtBox["n"]]}], "=", "0"}]}]]],
 "    and    ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    UnderscriptBox["lim", 
     RowBox[{"n", "\[Rule]", "\[Infinity]"}]], " ", 
    SubscriptBox["y", "n"]}], "=", 
   RowBox[{
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"n", "\[Rule]", "\[Infinity]"}]], " ", 
     FractionBox[
      RowBox[{"n", "+", "1"}], "n"]}], "=", "1"}]}]]],
 ".  \n\nTherefore  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    UnderscriptBox["lim", 
     RowBox[{"n", "\[Rule]", "\[Infinity]"}]], " ", 
    SubscriptBox["z", "n"]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"n", "\[Rule]", "\[Infinity]"}]], " ", 
     FractionBox[
      RowBox[{
       SqrtBox["n"], " ", "+", " ", 
       RowBox[{"\[ImaginaryI]", 
        RowBox[{"(", " ", 
         RowBox[{"n", "+", "1"}], ")"}]}]}], "n"]}], " ", "=", " ", 
    RowBox[{
     RowBox[{"0", "+", "\[ImaginaryI]"}], " ", "=", " ", 
     "\[ImaginaryI]"}]}]}]]],
 ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 4.1.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell["Enter the formula for the terms of the sequence.", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", 
     RowBox[{"x", ",", "y", ",", "z"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"limX", ",", "limY", ",", "limZ", ",", "n"}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["x", "n_"], " ", "=", " ", 
     FractionBox[
      SqrtBox["n"], "n"]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["y", "n_"], " ", "=", " ", 
     FractionBox[
      RowBox[{"n", "+", "1"}], "n"]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "n_"], " ", "=", " ", 
     RowBox[{
      SubscriptBox["x", "n"], " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["y", "n"]}]}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"table", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       SubscriptBox["z", "n"], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "1", ",", "9"}], "}"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"table", "=", 
     RowBox[{"Append", "[", 
      RowBox[{"table", ",", "\"\<...\>\""}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"limX", " ", "=", " ", 
     RowBox[{"Limit", "[", 
      RowBox[{
       SubscriptBox["x", "n"], ",", " ", 
       RowBox[{"n", "\[Rule]", "\[Infinity]"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"limY", " ", "=", " ", 
     RowBox[{"Limit", "[", 
      RowBox[{
       SubscriptBox["y", "n"], ",", " ", 
       RowBox[{"n", "\[Rule]", "\[Infinity]"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"limZ", " ", "=", " ", 
     RowBox[{"Limit", "[", 
      RowBox[{
       SubscriptBox["z", "n"], ",", " ", 
       RowBox[{"n", "\[Rule]", "\[Infinity]"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(n\)]\) = \>\"", ",", 
      SubscriptBox["z", "n"]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(x\), \(n\)]\) = \>\"", ",", 
      SubscriptBox["x", "n"]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(y\), \(n\)]\) = \>\"", ",", 
      SubscriptBox["y", "n"]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(lim\), \(n \[Rule] \[Infinity]\)]\) \
\!\(\*SubscriptBox[\(x\), \(n\)]\) = \>\"", ",", 
      "\"\<\!\(\*UnderscriptBox[\(lim\), \(n \[Rule] \[Infinity]\)]\) \>\"", 
      ",", 
      SubscriptBox["x", "n"], ",", "\"\< = \>\"", ",", "limX"}], "]"}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(lim\), \(n \[Rule] \[Infinity]\)]\) \
\!\(\*SubscriptBox[\(y\), \(n\)]\) = \>\"", ",", 
      "\"\<\!\(\*UnderscriptBox[\(lim\), \(n \[Rule] \[Infinity]\)]\) \>\"", 
      ",", 
      SubscriptBox["y", "n"], ",", "\"\< = \>\"", ",", "limY"}], "]"}], ";"}],
    " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(z\), \(n\)]\)} = \>\"", ",", "table"}], "]"}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<{\!\(\*SubscriptBox[\(z\), \(n\)]\)} = \>\"", ",", 
      RowBox[{"N", "[", "table", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The limit of the sequence is\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(lim\), \(n \[Rule] \[Infinity]\)]\) \
\!\(\*SubscriptBox[\(z\), \(n\)]\) = \>\"", ",", 
      "\"\<\!\(\*UnderscriptBox[\(lim\), \(n \[Rule] \[Infinity]\)]\) (\>\"", 
      ",", 
      SubscriptBox["z", "n"], ",", "\"\<)\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(lim\), \(n \[Rule] \[Infinity]\)]\) \
\!\(\*SubscriptBox[\(z\), \(n\)]\) = \>\"", ",", "limX", ",", 
      "\"\< + \[ImaginaryI] (\>\"", ",", "limY", ",", "\"\<)\>\""}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(lim\), \(n \[Rule] \[Infinity]\)]\) \
\!\(\*SubscriptBox[\(z\), \(n\)]\) = \>\"", ",", "limZ"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399021214765625*^9}],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to compute some of the terms in the sequence."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(z\), \(n\)]\) = z(n) = \>\"", " ", ",", 
      SubscriptBox["z", "n"]}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"TableForm", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          SubscriptBox["\"\<z\>\"", "n"], ",", "\"\<=\>\"", ",", 
          SubscriptBox["z", "n"], ",", "\"\<=\>\"", ",", 
          RowBox[{"PaddedForm", "[", 
           RowBox[{
            RowBox[{"N", "[", 
             SubscriptBox["z", "n"], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"12", ",", "12"}], "}"}]}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"n", ",", "1", ",", "20"}], "}"}]}], "]"}], "]"}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39902122159375*^9, 3.39902122265625*^9}}],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to compute more of the terms in the sequence."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(z\), SuperscriptBox[\(2\), \(n\)]]\) = \
z(\!\(\*SuperscriptBox[\(2\), \(n\)]\)) = \>\"", " ", ",", 
      SubscriptBox["z", 
       SuperscriptBox["2", "n"]]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"TableForm", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          SubscriptBox["\"\<z\>\"", 
           SuperscriptBox["2", "n"]], ",", "\"\<=\>\"", ",", 
          SubscriptBox["z", 
           SuperscriptBox["2", "n"]], ",", "\"\<=\>\"", ",", 
          RowBox[{"PaddedForm", "[", 
           RowBox[{
            RowBox[{"N", "[", 
             SubscriptBox["z", 
              SuperscriptBox["2", "n"]], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"12", ",", "12"}], "}"}]}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"n", ",", "1", ",", "20"}], "}"}]}], "]"}], "]"}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39902122640625*^9, 3.399021227875*^9}}],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to plot some of the terms in the sequence."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"set", " ", "=", "  ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"N", "[", 
          SubscriptBox["x", "n"], "]"}], ",", 
         RowBox[{"N", "[", 
          SubscriptBox["y", "n"], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "1", ",", "50"}], "}"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dot", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"PointSize", "[", "0.025", "]"}], ",", "Red", ",", 
        RowBox[{"Point", "[", 
         RowBox[{"{", 
          RowBox[{"0", ",", "1"}], "}"}], "]"}]}], "}"}], "]"}]}], ";"}], " ",
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gr", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"set", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"PointSize", "[", "0.015", "]"}], ",", "Blue"}], "}"}]}], 
       ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0.0", ",", "1.0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.0", ",", "2.0"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "1", ",", 
            FractionBox["1", "2"]}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "2", ",", 
            FractionBox["1", "2"]}], "]"}]}], "}"}]}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"gr", ",", "dot", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.05"}], ",", "1.05"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "2.05"}], "}"}]}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(lim\), \(n \[Rule] \[Infinity]\)]\) \
\!\(\*SubscriptBox[\(z\), \(n\)]\) = \!\(\*UnderscriptBox[\(lim\), \(n \
\[Rule] \[Infinity]\)]\) (\>\"", ",", 
      SubscriptBox["z", "n"], ",", "\"\<) = \>\"", ",", "limX", ",", 
      "\"\< + \[ImaginaryI] (\>\"", ",", "limY", ",", "\"\<) = \>\"", ",", 
      "limZ"}], "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399021231515625*^9, 3.39902128625*^9}, {
  3.399193062875*^9, 3.399193099328125*^9}, {3.399201005515625*^9, 
  3.399201006359375*^9}, {3.399798004374752*^9, 3.3997980046716275`*^9}, {
  3.400259493875*^9, 3.400259500734375*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "We see that the limit of the sequence  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"{", 
    SubscriptBox["z", "n"], "}"}], "=", 
   RowBox[{
    RowBox[{"{", 
     FractionBox[
      RowBox[{
       SqrtBox["n"], " ", "+", " ", 
       RowBox[{"\[ImaginaryI]", 
        RowBox[{"(", " ", 
         RowBox[{"n", "+", "1"}], ")"}]}]}], "n"], "}"}], "   ", "is", "   ", 
    "\[ImaginaryI]"}]}]]],
 ".  However, the real part is converging slowly to 0  and the imaginary part \
is converging a little faster to  ",
 Cell[BoxData["\[ImaginaryI]"]],
 ".  "
}], "Text"]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 4.2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Show that the sequence  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"{", 
    SubscriptBox["z", "n"], "}"}], "=", 
   RowBox[{"{", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}], "n"], "}"}]}]]],
 "  diverges.  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "Solution.  We have  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    SubscriptBox["z", "n"], "  ", "=", " ", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}], "n"], " ", "=", " ", 
     RowBox[{
      SubscriptBox["x", "n"], " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["y", "n"]}]}]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{
   SubscriptBox["z", "n"], "   ", "=", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       SqrtBox["2"], ")"}], "n"], "  ", "cos", 
     FractionBox[
      RowBox[{"n", " ", "\[Pi]"}], "4"]}], " ", "+", " ", 
    RowBox[{"\[ImaginaryI]", "  ", 
     SuperscriptBox[
      RowBox[{"(", 
       SqrtBox["2"], ")"}], "n"], " ", "sin", 
     FractionBox[
      RowBox[{"n", " ", "\[Pi]"}], "4"]}]}]}]}]],
 "  \n\nThe real sequences  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["x", "n"], " ", "=", " ", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      SqrtBox["2"], ")"}], "n"], "  ", "cos", 
    FractionBox[
     RowBox[{"n", " ", "\[Pi]"}], "4"]}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{
    SubscriptBox["y", "n"], " ", "=", " ", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       SqrtBox["2"], ")"}], "n"], " ", "sin", 
     FractionBox[
      RowBox[{"n", " ", "\[Pi]"}], "4"]}]}]}]]],
 "  both exhibit divergent oscillations, so we conclude that  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "n"], " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}], "n"]}]]],
 "  diverges."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Explore ",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 StyleBox["Solution 4.2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell["\<\
Enter the formula for the terms of the sequence, and determine if the \
sequence converges or diverges.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", 
     RowBox[{"x", ",", "y", ",", "z"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"limX", ",", "limY", ",", "limZ", ",", "n"}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "n_"], "=", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", " ", "+", " ", "\[ImaginaryI]"}], ")"}], "n"]}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"table", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       SubscriptBox["z", "n"], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "1", ",", "10"}], "}"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"table", "=", 
     RowBox[{"Append", "[", 
      RowBox[{"table", ",", "\"\<...\>\""}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"lim", " ", "=", " ", 
     RowBox[{"Limit", "[", 
      RowBox[{
       SubscriptBox["z", "n"], ",", " ", 
       RowBox[{"n", "\[Rule]", "\[Infinity]"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<{\!\(\*SubscriptBox[\(z\), \(n\)]\)} = {\>\"", ",", 
      SubscriptBox["z", "n"], ",", "\"\<}\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<{\!\(\*SubscriptBox[\(z\), \(n\)]\)} = {\>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       SubscriptBox["z", "n"], "]"}], ",", "\"\<}\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(z\), \(n\)]\)} = \>\"", ",", "table"}], "]"}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(lim\), \(n \[Rule] \[Infinity]\)]\) \
\!\(\*SubscriptBox[\(z\), \(n\)]\) = \>\"", ",", 
      "\"\<\!\(\*UnderscriptBox[\(lim\), \(n \[Rule] \[Infinity]\)]\) \>\"", 
      ",", 
      SubscriptBox["z", "n"], ",", "\"\< = \>\"", ",", "lim"}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.3990212999375*^9}],

Cell["Investigate the limit in more detail.", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["x", "n_"], "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"Re", "[", 
       SubscriptBox["z", "n"], "]"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["y", "n_"], "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"Im", "[", 
       SubscriptBox["z", "n"], "]"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"limX", " ", "=", " ", 
     RowBox[{"Limit", "[", 
      RowBox[{
       SubscriptBox["x", "n"], ",", " ", 
       RowBox[{"n", "\[Rule]", "\[Infinity]"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"limY", " ", "=", " ", 
     RowBox[{"Limit", "[", 
      RowBox[{
       SubscriptBox["y", "n"], ",", " ", 
       RowBox[{"n", "\[Rule]", "\[Infinity]"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"limZ", " ", "=", " ", 
     RowBox[{"limX", " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", "limY"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(lim\), \(n \[Rule] \[Infinity]\)]\) \
\!\(\*SubscriptBox[\(x\), \(n\)]\) = \>\"", ",", 
      "\"\<\!\(\*UnderscriptBox[\(lim\), \(n \[Rule] \[Infinity]\)]\) \>\"", 
      ",", 
      SubscriptBox["x", "n"], ",", "\"\< = \>\"", ",", "limX"}], "]"}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(lim\), \(n \[Rule] \[Infinity]\)]\) \
\!\(\*SubscriptBox[\(y\), \(n\)]\) = \>\"", ",", 
      "\"\<\!\(\*UnderscriptBox[\(lim\), \(n \[Rule] \[Infinity]\)]\) \>\"", 
      ",", 
      SubscriptBox["y", "n"], ",", "\"\< = \>\"", ",", "limY"}], "]"}], ";"}],
    " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(lim\), \(n \[Rule] \[Infinity]\)]\) \
\!\(\*SubscriptBox[\(z\), \(n\)]\) = \>\"", ",", 
      "\"\<\!\(\*UnderscriptBox[\(lim\), \(n \[Rule] \[Infinity]\)]\) \>\"", 
      ",", 
      SubscriptBox["z", "n"], ",", "\"\< = \>\"", ",", "limX", ",", 
      "\"\< + \[ImaginaryI] (\>\"", ",", "limY", ",", "\"\<)\>\""}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(lim\), \(n \[Rule] \[Infinity]\)]\) \
\!\(\*SubscriptBox[\(z\), \(n\)]\) = \>\"", ",", 
      "\"\<\!\(\*UnderscriptBox[\(lim\), \(n \[Rule] \[Infinity]\)]\) \>\"", 
      ",", 
      SubscriptBox["z", "n"], ",", "\"\< = \>\"", ",", "limZ"}], "]"}], ";"}],
    " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.3990213044375*^9}],

Cell[TextData[{
 "Therefore, the limit of the sequence does ",
 StyleBox["not",
  FontColor->RGBColor[1, 0, 1]],
 " exist, and exhibits \"divergent oscillations.\""
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"ListPlot", "[", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        SubscriptBox["x", "n"], ",", 
        RowBox[{"{", 
         RowBox[{"n", ",", "1", ",", "14"}], "}"}]}], "]"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"Red", ",", 
         RowBox[{"PointSize", "[", "0.025", "]"}]}], "}"}]}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "14"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "65"}], ",", "25"}], "}"}]}], "}"}]}]}], "]"}], ";"}],
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(lim\), \(n \[Rule] \[Infinity]\)]\) \
\!\(\*SubscriptBox[\(x\), \(n\)]\) = \>\"", ",", 
      "\"\<\!\(\*UnderscriptBox[\(lim\), \(n \[Rule] \[Infinity]\)]\) \>\"", 
      ",", 
      SubscriptBox["x", "n"], ",", "\"\< = \>\"", ",", "limX"}], "]"}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<   {\!\(\*SubscriptBox[\(x\), \(n\)]\)}  diverges\>\"",
      "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ListPlot", "[", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        SubscriptBox["y", "n"], ",", 
        RowBox[{"{", 
         RowBox[{"n", ",", "1", ",", "14"}], "}"}]}], "]"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"Blue", ",", 
         RowBox[{"PointSize", "[", "0.025", "]"}]}], "}"}]}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "14"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "130"}], ",", "35"}], "}"}]}], "}"}]}]}], "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(lim\), \(n \[Rule] \[Infinity]\)]\) \
\!\(\*SubscriptBox[\(y\), \(n\)]\) = \>\"", ",", 
      "\"\<\!\(\*UnderscriptBox[\(lim\), \(n \[Rule] \[Infinity]\)]\) \>\"", 
      ",", 
      SubscriptBox["y", "n"], ",", "\"\< = \>\"", ",", "limY"}], "]"}], ";"}],
    " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<   {\!\(\*SubscriptBox[\(y\), \(n\)]\)}  diverges\>\"",
      "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399021308640625*^9, 3.399021309796875*^9}, {
  3.3997980102966275`*^9, 3.399798010624752*^9}}],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to compute some of the terms in the sequence."
}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{
   "\"\< \!\(\*SubscriptBox[\(z\), \(n\)]\) = z(n) = \>\"", " ", ",", 
    SubscriptBox["z", "n"]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"TableForm", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        SubscriptBox["\"\< z\>\"", "n"], ",", "\"\<=\>\"", ",", 
        SubscriptBox["z", "n"], ",", "\"\<=\>\"", ",", 
        RowBox[{"PaddedForm", "[", 
         RowBox[{
          RowBox[{"N", "[", 
           SubscriptBox["z", "n"], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"12", ",", "12"}], "}"}]}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"n", ",", "1", ",", "40"}], "}"}]}], "]"}], "]"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
   "Print", "[", "\"\<{\!\(\*SubscriptBox[\(z\), \(n\)]\)}  diverges\>\"", 
    "]"}], ";"}], " "}]}], "Input"],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to plot some of the terms in the sequence."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"set", " ", "=", "  ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"N", "[", 
          SubscriptBox["x", "n"], "]"}], ",", 
         RowBox[{"N", "[", 
          SubscriptBox["y", "n"], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "1", ",", "7"}], "}"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"set", ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"PointSize", "[", "0.02", "]"}], ",", "Red"}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "4.3"}], ",", "8.3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "9.0"}], ",", "2.5"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "4"}], ",", "8", ",", "2"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "8"}], ",", "2", ",", "2"}], "]"}]}], "}"}]}]}], "]"}],
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< \!\(\*SubscriptBox[\(z\), \(n\)]\)  = z(n) = \>\"", " ", ",", 
      SubscriptBox["z", "n"]}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(z\), \(n\)]\)} = \>\"", ",", "table"}], "]"}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(lim\), \(n \[Rule] \[Infinity]\)]\) \>\"", 
      ",", 
      SubscriptBox["z", "n"], ",", "\"\< = \>\"", ",", "limX", ",", 
      "\"\< + \[ImaginaryI] \>\"", ",", "limY"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<{\!\(\*SubscriptBox[\(z\), \(n\)]\)}  diverges\>\"", 
     "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39902131321875*^9, 3.39902131709375*^9}, {
  3.3991931321875*^9, 3.399193158515625*^9}, {3.399201023390625*^9, 
  3.39920104878125*^9}, {3.399798015718502*^9, 3.3997980159216275`*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "We see that the sequence  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"{", 
    SubscriptBox["z", "n"], "}"}], "=", 
   RowBox[{"{", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}], "n"], "}"}]}]]],
 "  is divergent.  "
}], "Text"]
}, Closed]],

Cell[TextData[{
 StyleBox["Definition 4.2 (Bounded Sequence).",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  A complex sequence ",
 Cell[BoxData[
  RowBox[{"{", 
   SubscriptBox["z", "n"], "}"}]]],
 " is bounded provided that there exists a positive real number ",
 StyleBox["R",
  FontFamily->"Courier New"],
 " and an integer ",
 StyleBox["N",
  FontFamily->"Courier New"],
 " such that  ",
 Cell[BoxData[
  RowBox[{"|", 
   SubscriptBox["z", "n"], "|", 
   RowBox[{"<", " ", "R"}]}]]],
 "  for all  ",
 Cell[BoxData[
  RowBox[{"n", ">", "N"}]]],
 ".  In other words, for ",
 Cell[BoxData[
  RowBox[{"n", ">", "N"}]]],
 ", the sequence ",
 Cell[BoxData[
  RowBox[{"{", 
   SubscriptBox["z", "n"], "}"}]]],
 " is contained in the disk  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["D", "R"], 
   RowBox[{"(", "0", ")"}]}]]],
 ".  "
}], "Text"],

Cell["\<\
\tBounded sequences play an important role in some newer developments in \
complex analysis that are discussed in Section 4.2.  A theorem from real \
analysis stipulates that convergent sequences are bounded.  The same result \
holds for complex sequences.\
\>", "Text"],

Cell[TextData[{
 StyleBox["Theorem 4.2.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  If ",
 Cell[BoxData[
  RowBox[{"{", 
   SubscriptBox["z", "n"], "}"}]]],
 " is a convergent sequence, then ",
 Cell[BoxData[
  RowBox[{"{", 
   SubscriptBox["z", "n"], "}"}]]],
 " is bounded.  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 4.2 is left as an exercise in the \
book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"]
}, Closed]],

Cell["\<\
\tAs with real numbers, we also have the following definition.  \
\>", "Text"],

Cell[TextData[{
 StyleBox["Definition 4.3 (",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Cauchy Sequence",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/CauchySequence.html"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 StyleBox[").",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  The sequence ",
 Cell[BoxData[
  RowBox[{"{", 
   SubscriptBox["z", "n"], "}"}]]],
 " is said to be a ",
 StyleBox[ButtonBox["Cauchy sequence",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/CauchySequence.html"], None}],
  FontVariations->{"Underline"->True}],
 " if for every  ",
 Cell[BoxData[
  RowBox[{"\[Epsilon]", ">", "0"}]]],
 "  there exists a positive integer  ",
 Cell[BoxData[
  SubscriptBox["N", "\[Epsilon]"]]],
 ",  such that if  ",
 Cell[BoxData[
  RowBox[{"n", ",", 
   RowBox[{"m", " ", ">", 
    SubscriptBox["N", "\[Epsilon]"]}]}]]],
 ",  then  ",
 Cell[BoxData[
  RowBox[{"|", 
   RowBox[{
    SubscriptBox["z", "n"], "-", 
    SubscriptBox["z", "m"]}], "|", 
   RowBox[{"<", "\[Element]"}]}]]],
 ",  or, equivalently,  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["z", "n"], "-", 
    SubscriptBox["z", "m"]}], " ", "\[Element]", " ", 
   RowBox[{
    SubscriptBox["D", "\[Epsilon]"], 
    RowBox[{"(", "0", ")"}]}]}]]],
 ".  "
}], "Text"],

Cell["\tThe following should now come as no surprise.", "Text"],

Cell[TextData[{
 StyleBox["Theorem 4.3,  (Cauchy Sequences Converge).",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  If  ",
 Cell[BoxData[
  RowBox[{"{", 
   SubscriptBox["z", "n"], "}"}]]],
 "  is a Cauchy sequence, then ",
 Cell[BoxData[
  RowBox[{"{", 
   SubscriptBox["z", "n"], "}"}]]],
 "  converges."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 4.3 is in the book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
 "\tOne of the most important notions in analysis (real or complex) is a \
theory that allows us to add up infinitely many terms.  To make sense of such \
an idea we begin with a sequence ",
 Cell[BoxData[
  RowBox[{"{", 
   SubscriptBox["z", "n"], "}"}]]],
 ", and form a new sequence ",
 Cell[BoxData[
  RowBox[{"{", 
   SubscriptBox["S", "n"], "}"}]]],
 ", called the sequence of partial sums, as follows. \n\n\t\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    SubscriptBox["S", "1"], " ", "=", " ", 
    SubscriptBox["z", "1"]}], 
   StyleBox[" ",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["S", "2"], " ", "=", " ", 
    RowBox[{
     SubscriptBox["z", "1"], "+", 
     SubscriptBox["z", "2"]}]}], 
   StyleBox[" ",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["S", "3"], " ", "=", " ", 
    RowBox[{
     SubscriptBox["z", "1"], "+", 
     SubscriptBox["z", "2"], "+", 
     SubscriptBox["z", "3"]}]}], 
   StyleBox[" ",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "\[IndentingNewLine]", "      ", 
   "\[VerticalEllipsis]"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    SubscriptBox["S", "n"], " ", "=", " ", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        SubscriptBox["z", "1"], "+", 
        SubscriptBox["z", "2"], "+"}], "..."}], "+", 
      SubscriptBox["z", "n"]}], " ", "=", " ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"k", "=", "1"}], "\[Infinity]"], 
      SubscriptBox["z", "k"]}]}]}], 
   StyleBox[" ",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "\[IndentingNewLine]", "      ", 
   "\[VerticalEllipsis]"}]}]],
 "   "
}], "Text"],

Cell[TextData[{
 StyleBox["Definition 4.4 (",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Infinite Series",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/Series.html"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 StyleBox[").",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  The formal expression ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"k", "=", "1"}], "\[Infinity]"], 
    SubscriptBox["z", "k"]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       SubscriptBox["z", "1"], "+", 
       SubscriptBox["z", "2"], "+"}], "..."}], "+", 
     SubscriptBox["z", "n"], "+"}], "..."}]}]]],
 "  is called an infinite series, and  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   SubscriptBox["z", "2"], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "...", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   SubscriptBox["z", "n"], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "..."}]]],
 ",  are called the terms of the series.  "
}], "Text"],

Cell[TextData[{
 "\tIf there is a complex number ",
 StyleBox["S",
  FontFamily->"Courier New"],
 " for which \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"S", " ", "=", " ", 
   RowBox[{
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"n", "\[Rule]", "\[Infinity]"}]], " ", 
     SubscriptBox["S", "n"]}], " ", "=", " ", 
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"n", "\[Rule]", "\[Infinity]"}]], 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"k", "=", "1"}], "n"], 
      SubscriptBox["z", "k"]}]}]}]}]]],
 ",  \n\t\t\t\nwe will say that the infinite series ",
 Cell[BoxData[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"k", "=", "1"}], "\[Infinity]"], 
   SubscriptBox["z", "k"]}]]],
 " converges to ",
 StyleBox["S",
  FontFamily->"Courier New"],
 ", and that ",
 StyleBox["S",
  FontFamily->"Courier New"],
 " is the sum of the infinite series.  When this occurs, we write \n\n\t\t\t\
",
 Cell[BoxData[
  RowBox[{"S", "=", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"k", "=", "1"}], "\[Infinity]"], 
    SubscriptBox["z", "k"]}]}]]],
 ".  \n\n\tThe series  ",
 Cell[BoxData[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"k", "=", "1"}], "\[Infinity]"], 
   SubscriptBox["z", "k"]}]]],
 "  is said to be absolutely convergent provided that the (real) series of \
magnitudes  ",
 Cell[BoxData[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"k", "=", "1"}], "\[Infinity]"], 
   RowBox[{"|", 
    SubscriptBox["z", "k"], "|"}]}]]],
 "  converges.  \n\n\tIf a series does not converge, we say that it diverges. \
"
}], "Text"],

Cell[TextData[{
 StyleBox["Remark 4.2.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  The first finitely many terms of a series do not affect its convergence \
or divergence and, in this respect, the beginning index of a series is \
irrelevant.  Thus, we will without comment conclude that if a series  ",
 Cell[BoxData[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"k", "=", 
     RowBox[{"N", "+", "1"}]}], "\[Infinity]"], 
   SubscriptBox["z", "k"]}]]],
 "  converges, then so does  ",
 Cell[BoxData[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"k", "=", "1"}], "\[Infinity]"], 
   SubscriptBox["z", "k"]}]]],
 ",  where  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   SubscriptBox["z", "2"], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "...", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   SubscriptBox["z", "N"]}]]],
 "  i",
 "s any fin",
 "ite collection of terms.  A similar remark holds for determining divergence \
of a series."
}], "Text"],

Cell["\<\
\tAs you might expect, many of the results concerning real series carry over \
to complex series.  We now give several of the more standard theorems for \
complex series, along with examples of how they are used.\
\>", "Text"],

Cell[TextData[{
 StyleBox["Theorem 4.4.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Let  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "n"], "=", 
   RowBox[{
    SubscriptBox["x", "n"], "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["y", "n"]}]}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{"S", "=", 
   RowBox[{"U", "+", 
    RowBox[{"\[ImaginaryI]", " ", "V"}]}]}]]],
 ".  Then  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"S", " ", "=", " ", 
   RowBox[{
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", "1"}], "\[Infinity]"], 
     SubscriptBox["z", "n"]}], " ", "=", " ", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", "1"}], "\[Infinity]"], 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["x", "n"], "+", 
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["y", "n"]}]}], ")"}]}]}]}]]],
 "     (converges) \n\nif and only if both  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"U", " ", "=", " ", 
   RowBox[{
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", "1"}], "\[Infinity]"], 
     RowBox[{
      SubscriptBox["x", "n"], "   ", 
      StyleBox["and",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "    ", "V"}]}], " ", "=", " ", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", "1"}], "\[Infinity]"], 
     SubscriptBox["y", "n"]}]}]}]]],
 "     (converge).  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 4.4 is in the book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
 StyleBox["Theorem 4.5.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  If  ",
 Cell[BoxData[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"n", "=", "1"}], "\[Infinity]"], 
   SubscriptBox["z", "n"]}]]],
 "  is a convergent complex series, then  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    UnderscriptBox["lim", 
     RowBox[{"n", "\[Rule]", "\[Infinity]"}]], " ", 
    SubscriptBox["z", "n"]}], "=", "0"}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 4.5 is left as an exercise in the \
book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 4.3.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Show that the series  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", "1"}], "\[Infinity]"], 
    FractionBox[
     RowBox[{"1", " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", "n", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], "n"]}]}], 
     SuperscriptBox["n", "2"]]}], " ", "=", " ", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", "1"}], "\[Infinity]"], 
    RowBox[{"[", 
     RowBox[{
      FractionBox["1", 
       SuperscriptBox["n", "2"]], "+", 
      RowBox[{"\[ImaginaryI]", 
       FractionBox[
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"-", "1"}], ")"}], "n"], "n"]}]}], "]"}]}]}]]],
 "  ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    FormBox["",
     TraditionalForm],
    FontSize->14], TraditionalForm]]],
 "is convergent."
}], "Text"],

Cell[TextData[{
 "Solution.  Recall that the real series  ",
 Cell[BoxData[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"n", "=", "1"}], "\[Infinity]"], 
   FractionBox["1", 
    SuperscriptBox["n", "2"]]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"n", "=", "1"}], "\[Infinity]"], 
   FractionBox[
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}], "n"], "n"]}]]],
 "  are convergent.  Hence, Theorem 4.4 implies that the given complex series \
is convergent.  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Explore ",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 StyleBox["Solution 4.3.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell["\<\
Enter the formula for the series, and determine if the series converges or \
diverges.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"k", ",", "n", ",", "sumX", ",", "sumY", ",", "sumZ"}], "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"sumX", " ", "=", 
     StyleBox[
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"n", "=", "1"}], "\[Infinity]"], 
       FractionBox["1", 
        SuperscriptBox["n", "2"]]}],
      FontSize->14]}], 
    StyleBox[";",
     FontSize->14]}], 
   StyleBox[" ",
    FontSize->14], "\n", 
   RowBox[{
    RowBox[{"sumY", " ", "=", " ", 
     StyleBox[
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"n", "=", "1"}], "\[Infinity]"], 
       FractionBox[
        RowBox[{"n", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"-", "1"}], ")"}], "n"]}], 
        SuperscriptBox["n", "2"]]}],
      FontSize->14]}], 
    StyleBox[";",
     FontSize->14]}], 
   StyleBox[" ",
    FontSize->14], "\n", 
   RowBox[{
    RowBox[{"sumZ", " ", "=", " ", 
     RowBox[{"sumX", " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", "sumY"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The real and imaginary parts are\>\"", "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<         \!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 1\), \(\
\[Infinity]\)]\)\!\(\*FractionBox[\(1\), SuperscriptBox[\(n\), \(2\)]]\) = \>\
\"", 
      StyleBox[",",
       FontSize->14], "sumX"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<    \!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 1\), \
\(\[Infinity]\)]\)\!\(\*FractionBox[\(n \*SuperscriptBox[\((\(-1\))\), \(n\)]\
\), SuperscriptBox[\(n\), \(2\)]]\) = \>\"", 
      StyleBox[",",
       FontSize->14], "sumY"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The complex series is\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 1\), \
\(\[Infinity]\)]\)\!\(\*FractionBox[\(1 + \[ImaginaryI]\\\ n \
\*SuperscriptBox[\((\(-1\))\), \(n\)]\), SuperscriptBox[\(n\), \(2\)]]\) = \>\
\"", ",", "sumZ"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 1\), \
\(\[Infinity]\)]\)\!\(\*FractionBox[\(1 + \[ImaginaryI]\\\ n \
\*SuperscriptBox[\((\(-1\))\), \(n\)]\), SuperscriptBox[\(n\), \(2\)]]\) = \>\
\"", ",", 
      RowBox[{"N", "[", "sumZ", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399021375796875*^9, 3.39902137840625*^9}}],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to construct some of the partial sums of the infinite series."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["X", "n_"], " ", "=", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"k", "=", "1"}], "n"], 
      FractionBox["1", 
       SuperscriptBox["k", "2"]]}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["Y", "n_"], " ", "=", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"k", "=", "1"}], "n"], 
      FractionBox[
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], "k"], "k"]}]}], 
    StyleBox[";",
     FontSize->14]}], 
   StyleBox[" ",
    FontSize->14], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["S", "n_"], " ", "=", " ", 
     RowBox[{
      StyleBox[
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"k", "=", "1"}], "n"], 
        FractionBox["1", 
         SuperscriptBox["k", "2"]]}],
       FontSize->14], 
      StyleBox[" ",
       FontSize->14], 
      StyleBox["+",
       FontSize->14], 
      StyleBox[" ",
       FontSize->14], 
      RowBox[{"\[ImaginaryI]", "  ", 
       StyleBox[
        RowBox[{
         UnderoverscriptBox["\[Sum]", 
          RowBox[{"k", "=", "1"}], "n"], 
         FractionBox[
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], "k"], "k"]}],
        FontSize->14]}]}]}], 
    StyleBox[";",
     FontSize->14]}], 
   StyleBox[" ",
    FontSize->14], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"table", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"FullSimplify", "[", 
        SubscriptBox["S", "n"], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "1", ",", "10"}], "}"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"table", "=", 
     RowBox[{"Append", "[", 
      RowBox[{"table", ",", "\"\<...\>\""}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\< \!\(\*SubscriptBox[\(S\), \(n\)]\)  = (\!\(\*UnderoverscriptBox[\(\
\[Sum]\), \(k = 1\), \(n\)]\)\!\(\*FractionBox[\(1\), SuperscriptBox[\(k\), \
\(2\)]]\)) + \[ImaginaryI](\!\(\*UnderoverscriptBox[\(\[Sum]\), \(k = 1\), \
\(n\)]\)\!\(\*FractionBox[SuperscriptBox[\((\(-1\))\), \(k\)], \(k\)]\))\>\"",
      "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(S\), \(n\)]\)} = \>\"", ",", "table"}], "]"}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<{\!\(\*SubscriptBox[\(S\), \(n\)]\)} = \>\"", ",", 
      RowBox[{"N", "[", "table", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(S\), \(n\)]\) = (\!\(\*UnderoverscriptBox[\(\
\[Sum]\), \(k = 1\), \(n\)]\)\!\(\*FractionBox[\(1\), SuperscriptBox[\(k\), \
\(2\)]]\)) + \[ImaginaryI](\!\(\*UnderoverscriptBox[\(\[Sum]\), \(k = 1\), \
\(n\)]\)\!\(\*FractionBox[SuperscriptBox[\((\(-1\))\), \(k\)], \(k\)]\)) = \>\
\"", ",", 
      SubscriptBox["S", "n"]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The sum of the infinite series is\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<S = \!\(\*UnderoverscriptBox[\(\[Sum]\), \(k = 1\), \
\(\[Infinity]\)]\)\!\(\*FractionBox[\(1\), \(\(SuperscriptBox[k, 2]\)\(\\\ \)\
\)]\)+ \[ImaginaryI]\!\(\*UnderoverscriptBox[\(\[Sum]\), \(k = 1\), \(\
\[Infinity]\)]\)\!\(\*FractionBox[SuperscriptBox[\((\(-1\))\), \(k\)], \(k\)]\
\) = \>\"", ",", "sumZ"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3990213823125*^9, 3.399021384*^9}}],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to compute some of the partial sums of the infinite series."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(S\), \(n\)]\) = S(n) = \>\"", " ", ",", 
      SubscriptBox["S", "n"]}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"TableForm", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          SubscriptBox["\"\<S\>\"", "n"], ",", "\"\<=\>\"", ",", 
          RowBox[{"Simplify", "[", 
           SubscriptBox["S", "n"], "]"}], ",", "\"\<=\>\"", ",", 
          RowBox[{"PaddedForm", "[", 
           RowBox[{
            RowBox[{"N", "[", 
             SubscriptBox["S", "n"], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"12", ",", "12"}], "}"}]}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"n", ",", "1", ",", "20"}], "}"}]}], "]"}], "]"}], "]"}], 
    ";"}], "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39902138815625*^9, 3.399021389046875*^9}}],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to plot some of the partial sums of the infinite series."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"set", " ", "=", "  ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         SubscriptBox["X", "n"], ",", 
         SubscriptBox["Y", "n"]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "1", ",", "30"}], "}"}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dot", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"PointSize", "[", "0.025", "]"}], ",", "Red", ",", 
        RowBox[{"Point", "[", 
         RowBox[{"{", 
          RowBox[{"sumX", ",", "sumY"}], "}"}], "]"}]}], "}"}], "]"}]}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"graph", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"set", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"PointSize", "[", "0.015", "]"}], ",", "Blue"}], "}"}]}], 
       ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0.9", ",", "1.7"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.05"}], ",", 
            RowBox[{"-", "0.4"}]}], "}"}]}], "}"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0.8", ",", "2", ",", "0.2"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "1"}], ",", 
            RowBox[{"-", "0.6"}], ",", "0.2"}], "]"}]}], "}"}]}]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"graph", ",", "dot", ",", 
     RowBox[{"AxesOrigin", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0.9", ",", 
        RowBox[{"-", "0.4"}]}], "}"}]}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(S\), \(n\)]\) = S(n) = \>\"", " ", ",", 
      SubscriptBox["S", "n"]}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(lim\), \(n \[Rule] \[Infinity]\)]\) \
\!\(\*SubscriptBox[\(S\), \(n\)]\) = \>\"", ",", "sumZ"}], "]"}], ";"}], "  ",
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(lim\), \(n \[Rule] \[Infinity]\)]\) \
\!\(\*SubscriptBox[\(S\), \(n\)]\) = \>\"", ",", 
      RowBox[{"N", "[", "sumZ", "]"}]}], "]"}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<S = \!\(\*UnderoverscriptBox[\(\[Sum]\), \(k = 1\), \
\(\[Infinity]\)]\)\!\(\*FractionBox[\(1 + \[ImaginaryI]\\\ k \
\*SuperscriptBox[\((\(-1\))\), \(k\)]\), SuperscriptBox[\(k\), \(2\)]]\) = \>\
\"", ",", "sumZ"}], " ", "]"}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<S = \!\(\*UnderoverscriptBox[\(\[Sum]\), \(k = 1\), \
\(\[Infinity]\)]\)\!\(\*FractionBox[\(1 + \[ImaginaryI]\\\ k \
\*SuperscriptBox[\((\(-1\))\), \(k\)]\), SuperscriptBox[\(k\), \(2\)]]\) = \>\
\"", ",", 
      RowBox[{"N", "[", "sumZ", "]"}]}], " ", "]"}], ";"}], "  ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39902139271875*^9, 3.399021397671875*^9}, {
  3.399193183375*^9, 3.399193197640625*^9}, {3.399201077546875*^9, 
  3.39920107803125*^9}, {3.3997980219841275`*^9, 3.3997980222028775`*^9}, {
  3.4002595101875*^9, 3.400259515015625*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "Therefore, we see that the infinite series converges, indeed  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", "1"}], "\[Infinity]"], 
    FractionBox[
     RowBox[{"1", " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", "n", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], "n"]}]}], 
     SuperscriptBox["n", "2"]]}], "=", 
   RowBox[{
    FractionBox[
     SuperscriptBox["\[Pi]", "2"], "6"], "-", 
    RowBox[{"\[ImaginaryI]", " ", 
     RowBox[{"Log", "[", "2", "]"}]}]}]}]]],
 ".  "
}], "Text"]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 4.4.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Show that the series  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", "1"}], "\[Infinity]"], 
    FractionBox[
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], "n"], "+", "\[ImaginaryI]"}], "n"]}], " ", 
   "=", " ", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", "1"}], "\[Infinity]"], 
    RowBox[{"[", 
     RowBox[{
      FractionBox[
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], "n"], "n"], "+", 
      RowBox[{"\[ImaginaryI]", 
       FractionBox["1", "n"]}]}], "]"}]}]}]]],
 "  is divergent."
}], "Text"],

Cell[TextData[{
 "Solution.  We know that the real series  ",
 Cell[BoxData[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"n", "=", "1"}], "\[Infinity]"], 
   FractionBox["1", "n"]}]]],
 "  is divergent.  Hence, Theorem 4.4 implies that the given complex series \
is divergent."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Explore ",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 StyleBox["Solution 4.4.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell["\<\
Enter the formula for the series, and determine if the series converges or \
diverges.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"n", ",", "sumN", ",", "sumX", ",", "sumY", ",", "sumZ"}], "]"}],
     ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"sumX", " ", "=", " ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "1"}], "\[Infinity]"], 
      FractionBox[
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], "n"], "n"]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 1\), \
\(\[Infinity]\)]\)\!\(\*FractionBox[SuperscriptBox[\((\(-1\))\), \(n\)], \
\(n\)]\) = \>\"", ",", "sumX"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The real part converges.\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"sumY", " ", "=", " ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "1"}], "\[Infinity]"], 
      FractionBox["1", "n"]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 1\), \
\(\[Infinity]\)]\)\!\(\*FractionBox[\(1\), \(n\)]\) = \>\"", ",", "sumY"}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The imaginary part diverges.\>\"", "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"sumZ", " ", "=", " ", 
     RowBox[{"sumX", " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", "sumY"}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 1\), \
\(\[Infinity]\)]\)\!\(\*FractionBox[\(\*SuperscriptBox[\((\(-1\))\), \(n\)] + \
\[ImaginaryI]\), \(n\)]\) = \>\"", ",", "sumZ"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The series diverges.\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.3990214163125*^9}],

Cell[TextData[{
 StyleBox["Remark 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]],
 "  Since the answer returned for the imaginary part was  ",
 Cell[BoxData[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"n", "=", "1"}], "\[Infinity]"], 
   FractionBox["1", "n"]}]]],
 ",  this means that a sum was not found.\nIt is known that the partial sums \
of the harmonic series grow slowly without bound.  \nFor example, adding 10,  \
100,  1000  and  10000 terms yields:"
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 1\), \
\(m\)]\)\!\(\*FractionBox[\(1\), \(n\)]\) = \>\"", ",", 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"n", "=", "1"}], "m"], 
       FractionBox["1", "n"]}]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"i", "=", "1"}], ",", 
      RowBox[{"i", "\[LessEqual]", "5"}], ",", 
      RowBox[{"i", "++"}], ",", "\n", "  ", 
      RowBox[{"Print", "[", 
       RowBox[{
        OverscriptBox["\"\<\!\(\*UnderscriptBox[\(\[Sum]\), \(n = 1\)]\)\>\"",
          
         SuperscriptBox["10", "i"]], ",", 
        "\"\<\!\(\*FractionBox[\(1\), \(n\)]\) = \>\"", ",", 
        RowBox[{"N", "[", 
         RowBox[{"HarmonicNumber", "[", 
          SuperscriptBox["10", "i"], "]"}], "]"}]}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399021424375*^9}],

Cell[TextData[{
 "Therefore, the series slowly diverges to ",
 Cell[BoxData["\[Infinity]"]],
 ".  "
}], "Text"],

Cell[TextData[{
 StyleBox["Remark 2.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]],
 "  The integral test could also be used."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"lim", "=", 
     RowBox[{"Limit", "[", 
      RowBox[{
       RowBox[{
        SubsuperscriptBox["\[Integral]", "1", "b"], 
        RowBox[{
         FractionBox["1", "x"], 
         RowBox[{"\[DifferentialD]", "x"}]}]}], ",", 
       RowBox[{"b", "\[Rule]", "\[Infinity]"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(1\), \
\(\[Infinity]\)]\)\!\(\*FractionBox[\(1\), \(x\)]\)\[DifferentialD]x = \>\"", 
      ",", 
      UnderscriptBox["\"\<lim\>\"", 
       RowBox[{"b", "\[Rule]", "\[Infinity]"}]], ",", 
      "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(1\), \
\(b\)]\)\!\(\*FractionBox[\(1\), \(x\)]\)\[DifferentialD]x = \>\"", ",", 
      UnderscriptBox["\"\<lim\>\"", 
       RowBox[{"b", "\[Rule]", "\[Infinity]"}]], ",", "\"\< \>\"", ",", " ", 
      RowBox[{
       SubsuperscriptBox["\[Integral]", "1", "b"], 
       RowBox[{
        FractionBox["1", "x"], 
        RowBox[{"\[DifferentialD]", "x"}]}]}], " ", ",", "\"\< = \>\"", ",", 
      "lim"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The integral diverges, therefore\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<the series  \!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 1\), \(\
\[Infinity]\)]\)\!\(\*FractionBox[\(1\), \(n\)]\)  diverges to  \
\[Infinity].\>\"", "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39902143334375*^9, 3.399021435*^9}}],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to construct some of the partial sums of the infinite series."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["X", "n_"], " ", "=", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"k", "=", "1"}], "n"], 
      FractionBox[
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], "k"], "k"]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["Y", "n_"], " ", "=", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"k", "=", "1"}], "n"], 
      FractionBox["1", "k"]}]}], 
    StyleBox[";",
     FontSize->14]}], 
   StyleBox[" ",
    FontSize->14], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["S", "n_"], " ", "=", " ", 
     RowBox[{
      StyleBox[
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"k", "=", "1"}], "n"], 
        FractionBox[
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"-", "1"}], ")"}], "k"], "k"]}],
       FontSize->14], 
      StyleBox[" ",
       FontSize->14], 
      StyleBox["+",
       FontSize->14], 
      StyleBox[" ",
       FontSize->14], 
      RowBox[{"\[ImaginaryI]", "  ", 
       StyleBox[
        RowBox[{
         UnderoverscriptBox["\[Sum]", 
          RowBox[{"k", "=", "1"}], "n"], 
         FractionBox["1", "k"]}],
        FontSize->14]}]}]}], 
    StyleBox[";",
     FontSize->14]}], 
   StyleBox[" ",
    FontSize->14], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"table", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"FullSimplify", "[", 
        SubscriptBox["S", "n"], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "1", ",", "10"}], "}"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"table", "=", 
     RowBox[{"Append", "[", 
      RowBox[{"table", ",", "\"\<...\>\""}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(S\), \(n\)]\)} = \>\"", ",", "table"}], "]"}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<{\!\(\*SubscriptBox[\(S\), \(n\)]\)} = \>\"", ",", 
      RowBox[{"N", "[", "table", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< \!\(\*SubscriptBox[\(S\), \(n\)]\)  = \!\(\*UnderoverscriptBox[\(\
\[Sum]\), \(k = 1\), \(n\)]\)\!\(\*FractionBox[SuperscriptBox[\((\(-1\))\), \
\(k\)], \(k\)]\) + \[ImaginaryI]\!\(\*UnderoverscriptBox[\(\[Sum]\), \(k = \
1\), \(n\)]\)\!\(\*FractionBox[\(1\), \(k\)]\) = \>\"", ",", 
      SubscriptBox["S", "n"]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< \!\(\*UnderoverscriptBox[\(\[Sum]\), \(k = 1\), \(\[Infinity]\)]\)\
\!\(\*FractionBox[SuperscriptBox[\((\(-1\))\), \(k\)], \(k\)]\) + \
\[ImaginaryI]\!\(\*UnderoverscriptBox[\(\[Sum]\), \(k = 1\), \(\[Infinity]\)]\
\)\!\(\*FractionBox[\(1\), \(k\)]\) = \>\"", ",", 
      SubscriptBox["S", "\[Infinity]"]}], "]"}], ";"}], " "}]}]], "Input",
 CellChangeTimes->{3.399021441515625*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(S\), SuperscriptBox[\(2\), \(n\)]]\) = \
S(\!\(\*SuperscriptBox[\(2\), \(n\)]\)) = \>\"", " ", ",", 
      SubscriptBox["S", 
       SuperscriptBox["2", "n"]]}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"TableForm", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          SubscriptBox["\"\<S\>\"", 
           SuperscriptBox["2", "n"]], ",", "\"\<=\>\"", ",", 
          RowBox[{"PaddedForm", "[", 
           RowBox[{
            RowBox[{"N", "[", 
             SubscriptBox["S", 
              SuperscriptBox["2", "n"]], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"12", ",", "12"}], "}"}]}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"n", ",", "1", ",", "17"}], "}"}]}], "]"}], "]"}], "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The series diverges.\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399021444125*^9, 3.399021448671875*^9}}]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 4.5.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Show that the series ",
 Cell[BoxData[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"n", "=", "1"}], "\[Infinity]"], 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}], "n"]}]]],
 " is divergent.  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "Solution.  Here we set  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "n"], "  ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}], "n"]}]]],
 "  and observe that  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    UnderscriptBox["lim", 
     RowBox[{"n", "\[Rule]", "\[Infinity]"}]], " ", 
    RowBox[{"|", 
     SubscriptBox["z", "n"], "|"}]}], "=", 
   RowBox[{
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"n", "\[Rule]", "\[Infinity]"}]], " ", 
     RowBox[{"|", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}], "n"], "|"}]}], "=", 
    RowBox[{
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"n", "\[Rule]", "\[Infinity]"}]], "  ", 
      SuperscriptBox[
       RowBox[{"(", 
        SqrtBox["2"], ")"}], "n"]}], "=", " ", "\[Infinity]"}]}]}]]],
 ".  \n\nThus ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    UnderscriptBox["lim", 
     RowBox[{"n", "\[Rule]", "\[Infinity]"}]], " ", 
    SubscriptBox["z", "n"]}], " ", "\[NotEqual]", " ", "0"}]]],
 ", and Theorem 4.5 implies that the series is not convergent;  hence it is \
divergent. "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Explore ",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 StyleBox["Solution 4.5.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "Enter the formula ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "n"], "=", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}], "n"]}]]],
 " for the terms of the sequence, and look at the modulus."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", 
     RowBox[{"x", ",", "y", ",", "z"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"limX", ",", "limY", ",", "limZ", ",", "n"}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "n_"], "=", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", " ", "+", " ", "\[ImaginaryI]"}], ")"}], "n"]}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["m", "n_"], "=", 
     RowBox[{"Abs", "[", 
      SubscriptBox["z", "n"], "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["M", "n_"], "=", 
     RowBox[{"ComplexExpand", "[", 
      SubscriptBox["m", "n"], "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"lim", " ", "=", " ", 
     RowBox[{"Limit", "[", 
      RowBox[{
       SubscriptBox["m", "n"], ",", " ", 
       RowBox[{"n", "\[Rule]", "\[Infinity]"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(lim\), \(n \[Rule] \[Infinity]\)]\) |\>\"", 
      ",", 
      SubscriptBox["z", "n"], ",", 
      "\"\<| = \!\(\*UnderscriptBox[\(lim\), \(n \[Rule] \[Infinity]\)]\) \
\>\"", ",", 
      SubscriptBox["m", "n"]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(lim\), \(n \[Rule] \[Infinity]\)]\) |\>\"", 
      ",", 
      SubscriptBox["z", "n"], ",", 
      "\"\<| = \!\(\*UnderscriptBox[\(lim\), \(n \[Rule] \[Infinity]\)]\) \
\>\"", ",", 
      SubscriptBox["M", "n"]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(lim\), \(n \[Rule] \[Infinity]\)]\) |\>\"", 
      ",", 
      SubscriptBox["z", "n"], ",", "\"\<| = \>\"", ",", "lim"}], "]"}], ";"}],
    " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399021458703125*^9}],

Cell[TextData[{
 "Hence ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    UnderscriptBox["lim", 
     RowBox[{"n", " ", "\[Rule]", " ", "\[Infinity]"}]], " ", 
    SubscriptBox["z", "n"]}], "\[NotEqual]", "0"}]]],
 ", and the series is divergent."
}], "Text"],

Cell[TextData[{
 StyleBox["Aside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " will indicate that there is a problem with convergence. "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"sum", "=", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "1"}], "\[Infinity]"], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}], "n"]}]}], ";"}], "   ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 1\), \
\(\[Infinity]\)]\)(1+\[ImaginaryI]\!\(\*SuperscriptBox[\()\), \(n\)]\) = \
\>\"", ",", "sum"}], "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399021464234375*^9, 3.399021465234375*^9}}],

Cell[TextData[{
 "Which is comforting to see that ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " knows the answer too! "
}], "Text"],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to construct some of the partial sums of the infinite series."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["S", "n_"], " ", "=", " ", 
     StyleBox[
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"k", "=", "1"}], "n"], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}], "k"]}],
      FontSize->14]}], 
    StyleBox[";",
     FontSize->14]}], 
   StyleBox[" ",
    FontSize->14], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["X", "n_"], " ", "=", 
     RowBox[{"ComplexExpand", "[", " ", 
      RowBox[{"Re", "[", 
       SubscriptBox["S", "n"], "]"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["Y", "n_"], " ", "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"Im", "[", 
       SubscriptBox["S", "n"], "]"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"table", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"FullSimplify", "[", 
        SubscriptBox["S", "n"], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "1", ",", "10"}], "}"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"table", "=", 
     RowBox[{"Append", "[", 
      RowBox[{"table", ",", "\"\<...\>\""}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(S\), \(n\)]\)} = \>\"", ",", "table"}], "]"}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<{\!\(\*SubscriptBox[\(S\), \(n\)]\)} = \>\"", ",", 
      RowBox[{"N", "[", "table", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< \!\(\*SubscriptBox[\(S\), \(n\)]\)  =  \!\(\*
StyleBox[UnderoverscriptBox[\"\[Sum]\", 
RowBox[{\"k\", \"=\", \"1\"}], \"n\"],
FontSize->14]\)\!\(\*
StyleBox[\"(\",
FontSize->14]\)\!\(\*
StyleBox[\"1\",
FontSize->14]\)\!\(\*
StyleBox[\"+\",
FontSize->14]\)\!\(\*
StyleBox[\"\[ImaginaryI]\",
FontSize->14]\)\!\(\*
StyleBox[SuperscriptBox[\")\", \"n\"],
FontSize->14]\) = \>\"", ",", 
      SubscriptBox["S", "n"]}], " ", "]"}], ";"}], " ", "\[IndentingNewLine]",
    
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< \!\(\*SubscriptBox[\(X\), \(n\)]\)  =  \
Re[\!\(\*SubscriptBox[\(S\), \(n\)]\)]  =  \>\"", ",", 
      SubscriptBox["X", "n"]}], " ", "]"}], ";"}], " ", "\[IndentingNewLine]",
    
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< \!\(\*SubscriptBox[\(Y\), \(n\)]\)  =  \
Im[\!\(\*SubscriptBox[\(S\), \(n\)]\)]  =  \>\"", ",", 
      SubscriptBox["Y", "n"]}], " ", "]"}], ";"}], " ", "\[IndentingNewLine]",
    
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Xlim", "=", 
     RowBox[{"Limit", "[", 
      RowBox[{
       SubscriptBox["X", "n"], ",", 
       RowBox[{"n", "\[Rule]", "\[Infinity]"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Ylim", "=", 
     RowBox[{"Limit", "[", 
      RowBox[{
       SubscriptBox["Y", "n"], ",", 
       RowBox[{"n", "\[Rule]", "\[Infinity]"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      UnderscriptBox["\"\<lim\>\"", 
       RowBox[{"n", "\[Rule]", "\[Infinity]"}]], ",", "\"\<(\>\"", ",", 
      SubscriptBox["X", "n"], ",", "\"\<) = \>\"", ",", "Xlim"}], "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      UnderscriptBox["\"\<lim\>\"", 
       RowBox[{"n", "\[Rule]", "\[Infinity]"}]], ",", "\"\<(\>\"", ",", 
      SubscriptBox["Y", "n"], ",", "\"\<) = \>\"", ",", "Ylim"}], "]"}], 
    ";"}], "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399021470046875*^9, 3.39902147665625*^9}}],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to compute more of the partial sums of the infinite series."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< \!\(\*SubscriptBox[\(S\), \(n\)]\) = S(n) = \>\"", " ", ",", 
      SubscriptBox["S", "n"]}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"TableForm", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          SubscriptBox["\"\<S\>\"", "n"], ",", "\"\<=\>\"", ",", 
          RowBox[{"Simplify", "[", 
           SubscriptBox["S", "n"], "]"}], ",", "\"\<=\>\"", ",", 
          RowBox[{"PaddedForm", "[", 
           RowBox[{
            RowBox[{"N", "[", 
             SubscriptBox["S", "n"], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"20", ",", "12"}], "}"}]}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"n", ",", "1", ",", "40"}], "}"}]}], "]"}], "]"}], "]"}], 
    ";"}], "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399021485375*^9, 3.39902148659375*^9}}],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to plot some of the partial sums of the infinite series."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"set", " ", "=", "  ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"N", "[", 
          SubscriptBox["X", "n"], "]"}], ",", 
         RowBox[{"N", "[", 
          SubscriptBox["Y", "n"], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "1", ",", "13"}], "}"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"set", ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"PointSize", "[", "0.02", "]"}], ",", "Red"}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "135"}], ",", "50"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "20"}], ",", "66"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "120"}], ",", "60", ",", "20"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "20"}], ",", "60", ",", "20"}], "]"}]}], "}"}]}]}], 
    "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<{\!\(\*SubscriptBox[\(S\), \(n\)]\)} = \>\"", ",", "set"}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(lim\), \(n \[Rule] \[Infinity]\)]\) \>\"", 
      ",", 
      SubscriptBox["S", "n"], ",", "\"\< = \>\"", ",", "Xlim", ",", 
      "\"\< + \[ImaginaryI] \>\"", ",", "Ylim"}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399021491453125*^9, 3.3990214951875*^9}, {
   3.399193230171875*^9, 3.39919323178125*^9}, 3.3992011516875*^9, {
   3.399798027406002*^9, 3.3997980276091275`*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "We see that the  series  ",
 Cell[BoxData[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"n", "=", "1"}], "\[Infinity]"], 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}], "n"]}]]],
 " is divergent.   "
}], "Text"]
}, Closed]],

Cell[TextData[{
 StyleBox["Theorem 4.6.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Let  ",
 Cell[BoxData[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"n", "=", "1"}], "\[Infinity]"], 
   RowBox[{
    SubscriptBox["z", "n"], "  ", "and", "  ", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", "1"}], "\[Infinity]"], 
     SubscriptBox["w", "n"]}]}]}]]],
 "  be convergent series, and let  c  be a complex number.  Then  \n\n\t\t\t\
",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", "1"}], "\[Infinity]"], 
    RowBox[{"c", " ", 
     SubscriptBox["z", "n"]}]}], "=", 
   RowBox[{"c", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", "1"}], "\[Infinity]"], 
     SubscriptBox["z", "n"]}]}]}]]],
 "  \n\t\tand  \n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", "1"}], "\[Infinity]"], 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["z", "n"], "+", 
      SubscriptBox["w", "n"]}], ")"}]}], "=", 
   RowBox[{
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", "1"}], "\[Infinity]"], 
     SubscriptBox["z", "n"]}], "+", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", "1"}], "\[Infinity]"], 
     SubscriptBox["w", "n"]}]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 4.6 is left as an exercise in the \
book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
 StyleBox["Definition 4.5 (",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Cauchy Product of Series",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/CauchyProduct.html"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 StyleBox[").",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Let  ",
 Cell[BoxData[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"n", "=", "1"}], "\[Infinity]"], 
   SubscriptBox["a", "n"]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"n", "=", "1"}], "\[Infinity]"], 
   SubscriptBox["b", "n"]}]]],
 "  be convergent series, where ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["a", "n"], "  ", "and", "  ", 
   SubscriptBox["b", "n"]}]]],
 "  are complex numbers.  The ",
 StyleBox[ButtonBox["Cauchy product",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/CauchyProduct.html"], None}],
  FontVariations->{"Underline"->True}],
 " of the two series is defined to be the series  ",
 Cell[BoxData[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"n", "=", "1"}], "\[Infinity]"], 
   SubscriptBox["c", "n"]}]]],
 ",  where  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["c", "n"], "=", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"k", "=", "1"}], "n"], 
    RowBox[{
     SubscriptBox["a", "k"], 
     SubscriptBox["b", 
      RowBox[{"n", "-", "k"}]]}]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 StyleBox["Theorem 4.7.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  If the Cauchy product converges, then  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", "1"}], "\[Infinity]"], 
    SubscriptBox["c", "n"]}], "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "1"}], "\[Infinity]"], 
      SubscriptBox["a", "n"]}], ")"}], 
    RowBox[{"(", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "1"}], "\[Infinity]"], 
      SubscriptBox["b", "n"]}], ")"}]}]}]]],
 ",  \n\t\twhere  \n\t\t\t",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["c", "n"], "=", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"k", "=", "1"}], "n"], 
    RowBox[{
     SubscriptBox["a", "k"], 
     SubscriptBox["b", 
      RowBox[{"n", "-", "k"}]]}]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "The proof can be found in a number of texts, for example, ",
 StyleBox[ButtonBox["Infinite Sequences and Series",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www.amazon.com/exec/obidos/tg/detail/-/0486601536/qid=\
1130330440/sr=2-1/ref=pd_bbs_b_2_1/002-9738967-2168054?v=glance&s=books"], 
    None}],
  FontVariations->{"Underline"->True}],
 ", by ",
 StyleBox[ButtonBox["Konrad Knopp",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Knopp.\
html"], None}],
  FontVariations->{"Underline"->True}],
 " (translated by Frederick Bagemihl;  New York: Dover, 1956)."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Theorem 4.8  (",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Comparison Test",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/ComparisonTest.html"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 StyleBox[").",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Let  ",
 Cell[BoxData[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"n", "=", "1"}], "\[Infinity]"], 
   SubscriptBox["M", "n"]}]]],
 "  be a convergent series of real nonnegative terms.  If  ",
 Cell[BoxData[
  RowBox[{"{", 
   SubscriptBox["z", "n"], "}"}]]],
 "  is a sequence of complex numbers and  ",
 Cell[BoxData[
  RowBox[{"|", 
   SubscriptBox["z", "n"], "|", 
   RowBox[{"\[LessEqual]", " ", 
    SubscriptBox["M", "n"]}]}]]],
 "  holds for all  n, then  ",
 Cell[BoxData[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"n", "=", "1"}], "\[Infinity]"], 
   SubscriptBox["z", "n"]}]]],
 "  converges."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 4.8 is in the book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
 StyleBox["Corollary 4.1. ",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 " If  ",
 Cell[BoxData[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"n", "=", "1"}], "\[Infinity]"], 
   RowBox[{"|", 
    SubscriptBox["z", "n"], "|"}]}]]],
 ", then  ",
 Cell[BoxData[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"n", "=", "1"}], "\[Infinity]"], 
   SubscriptBox["z", "n"]}]]],
 "  converges.  In other words, absolute convergence implies convergence for \
complex series as well as for real series."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Corollary 4.1 is left as an exercise in the \
book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 4.6.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Show that the series  ",
 Cell[BoxData[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"n", "=", "1"}], "\[Infinity]"], 
   FractionBox[
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"3", " ", "+", " ", 
       RowBox[{"4", "\[ImaginaryI]"}]}], ")"}], "n"], 
    RowBox[{
     SuperscriptBox["5", "n"], " ", 
     SuperscriptBox["n", "2"]}]]}]]],
 "  is convergent."
}], "Text"],

Cell[TextData[{
 "Solution.  We calculate  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", 
    SubscriptBox["z", "n"], "|"}], "  ", "=", " ", 
   RowBox[{
    RowBox[{"|", 
     FractionBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"3", " ", "+", " ", 
         RowBox[{"4", "\[ImaginaryI]"}]}], ")"}], "n"], 
      RowBox[{
       SuperscriptBox["5", "n"], " ", 
       SuperscriptBox["n", "2"]}]], "|"}], " ", "=", " ", 
    RowBox[{
     FractionBox["1", 
      SuperscriptBox["n", "2"]], " ", "=", " ", 
     SubscriptBox["M", "n"]}]}]}]]],
 ".    Using the comparison test and the fact that  ",
 Cell[BoxData[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"n", "=", "1"}], "\[Infinity]"], 
   FractionBox["1", 
    SuperscriptBox["n", "2"]]}]]],
 "  converges, we determine that  ",
 Cell[BoxData[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"n", "=", "1"}], "\[Infinity]"], 
   RowBox[{"|", 
    FractionBox[
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"3", " ", "+", " ", 
        RowBox[{"4", "\[ImaginaryI]"}]}], ")"}], "n"], 
     RowBox[{
      SuperscriptBox["5", "n"], " ", 
      SuperscriptBox["n", "2"]}]], "|"}]}]]],
 "  converges and hence, by Corollary 4.1, so does ",
 Cell[BoxData[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"n", "=", "1"}], "\[Infinity]"], 
   FractionBox[
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"3", " ", "+", " ", 
       RowBox[{"4", "\[ImaginaryI]"}]}], ")"}], "n"], 
    RowBox[{
     SuperscriptBox["5", "n"], " ", 
     SuperscriptBox["n", "2"]}]]}]]],
 ". "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Explore ",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 StyleBox["Solution 4.6.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell["\<\
Enter the formula for the series, and determine if the series converges or \
diverges.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", 
     RowBox[{"x", ",", "y", ",", "z"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "absZn", ",", "n", ",", "sum", ",", "sumX", ",", "sumY", ",", "sumZ"}], 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "n_"], " ", "=", " ", 
     FractionBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"3", "+", 
         RowBox[{"4", "\[ImaginaryI]"}]}], ")"}], "n"], 
      RowBox[{
       SuperscriptBox["5", "n"], " ", 
       SuperscriptBox["n", "2"]}]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["x", "n_"], " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"Re", "[", 
       SubscriptBox["z", "n"], "]"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["y", "n_"], " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"Im", "[", 
       SubscriptBox["z", "n"], "]"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"sumX", " ", "=", " ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "1"}], "\[Infinity]"], 
      SubscriptBox["x", "n"]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"sumY", " ", "=", " ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "1"}], "\[Infinity]"], 
      SubscriptBox["y", "n"]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"sumZ", " ", "=", " ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "1"}], "\[Infinity]"], 
      SubscriptBox["z", "n"]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  \!\(\*SubscriptBox[\(z\), \(n\)]\) = \>\"", ",", 
      SubscriptBox["z", "n"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  \!\(\*SubscriptBox[\(z\), \(n\)]\) = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       SubscriptBox["z", "n"], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  \!\(\*SubscriptBox[\(x\), \(n\)]\) = \>\"", ",", 
      SubscriptBox["x", "n"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  \!\(\*SubscriptBox[\(y\), \(n\)]\) = \>\"", ",", 
      SubscriptBox["y", "n"]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 1\), \
\(\[Infinity]\)]\)\!\(\*SubscriptBox[\(x\), \(n\)]\) = \>\"", ",", "sumX"}], 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<     = \>\"", ",", 
      RowBox[{"FullSimplify", "[", "sumX", "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<     = \>\"", ",", 
      RowBox[{"Chop", "[", 
       RowBox[{"N", "[", "sumX", "]"}], "]"}]}], " ", "]"}], ";"}], " ", "\n",
    
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 1\), \
\(\[Infinity]\)]\)\!\(\*SubscriptBox[\(y\), \(n\)]\) = \>\"", ",", "sumY"}], 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<     = \>\"", ",", 
      RowBox[{"FullSimplify", "[", "sumY", "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<     = \>\"", ",", 
      RowBox[{"Chop", "[", 
       RowBox[{"N", "[", "sumY", "]"}], "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\\n\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 1\), \
\(\[Infinity]\)]\)\!\(\*FractionBox[SuperscriptBox[\((3 + 4  \
\[ImaginaryI])\), \(n\)], \(\*SuperscriptBox[\(5\), \
\(n\)]*\*SuperscriptBox[\(n\), \(2\)]\)]\) = \>\"", ",", "sumZ"}], " ", "]"}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 1\), \
\(\[Infinity]\)]\)\!\(\*FractionBox[SuperscriptBox[\((3 + 4  \
\[ImaginaryI])\), \(n\)], \(\*SuperscriptBox[\(5\), \
\(n\)]*\*SuperscriptBox[\(n\), \(2\)]\)]\) = \>\"", ",", 
      RowBox[{"N", "[", "sumZ", "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39902151721875*^9}],

Cell[TextData[{
 "Hence we see that the series converges and that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", "1"}], "\[Infinity]"], 
    FractionBox[
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"3", " ", "+", " ", 
        RowBox[{"4", "\[ImaginaryI]"}]}], ")"}], "n"], 
     RowBox[{
      SuperscriptBox["5", "n"], " ", 
      SuperscriptBox["n", "2"]}]]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"PolyLog", "[", 
     RowBox[{"2", ",", 
      RowBox[{
       FractionBox["3", "5"], "+", 
       FractionBox[
        RowBox[{"4", " ", "\[ImaginaryI]"}], "5"]}]}], "]"}], " ", "=", " ", 
    RowBox[{"0.403311", "\[InvisibleSpace]", "+", 
     RowBox[{"1.00841", "\[ImaginaryI]"}]}]}]}]]],
 ".  \nOr we could use Corollary 4.1 and show that the series converges \
absolutely.  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"absZn", " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"Abs", "[", 
       SubscriptBox["z", "n"], "]"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"sum", "  ", "=", "  ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "1"}], "\[Infinity]"], 
      FractionBox["1", 
       SuperscriptBox["n", "2"]]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<|\>\"", ",", 
      SubscriptBox["z", "n"], ",", "\"\<| = \>\"", ",", "absZn"}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 1\), \(\[Infinity]\)]\)|\
\!\(\*FractionBox[SuperscriptBox[\((3 + 4  \[ImaginaryI])\), \(n\)], \
\(\*SuperscriptBox[\(5\), \(n\)]*\*SuperscriptBox[\(n\), \(2\)]\)]\)| = \>\"",
       ",", "sum"}], "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399021524546875*^9}],

Cell[TextData[{
 "The series of absolute values converges, therefore the series converges.\n\n\
Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to construct some of the partial sums of the infinite series."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["S", "n_"], " ", "=", " ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"k", "=", "1"}], "n"], 
      FractionBox[
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"3", "+", 
          RowBox[{"4", "\[ImaginaryI]"}]}], ")"}], "k"], 
       RowBox[{
        SuperscriptBox["5", "k"], " ", 
        SuperscriptBox["k", "2"]}]]}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"table", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"FullSimplify", "[", 
        SubscriptBox["S", "n"], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "1", ",", "10"}], "}"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"table", "=", 
     RowBox[{"Append", "[", 
      RowBox[{"table", ",", "\"\<...\>\""}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\< \!\(\*SubscriptBox[\(S\), \(n\)]\)  =  \!\(\*UnderoverscriptBox[\(\
\[Sum]\), \(k = 1\), \(n\)]\)\!\(\*FractionBox[SuperscriptBox[\((3 + 4  \
\[ImaginaryI])\), \(k\)], \(\*SuperscriptBox[\(5\), \
\(k\)]*\*SuperscriptBox[\(k\), \(2\)]\)]\)\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(S\), \(n\)]\)} = \>\"", ",", "table"}], "]"}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<{\!\(\*SubscriptBox[\(S\), \(n\)]\)} = \>\"", ",", 
      RowBox[{"N", "[", "table", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(S\), \(n\)]\) = \!\(\*UnderoverscriptBox[\(\
\[Sum]\), \(k = 1\), \(n\)]\)\!\(\*FractionBox[SuperscriptBox[\((3 + 4  \
\[ImaginaryI])\), \(k\)], \(\*SuperscriptBox[\(5\), \
\(k\)]*\*SuperscriptBox[\(k\), \(2\)]\)]\) = \>\"", ",", 
      SubscriptBox["S", "n"]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39902152946875*^9}],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to construct some of the partial sums of the infinite series."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(S\), \(n\)]\) = S(n) = \>\"", " ", ",", 
      SubscriptBox["S", "n"]}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"TableForm", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          SubscriptBox["\"\<S\>\"", "n"], ",", "\"\<=\>\"", ",", 
          RowBox[{"Simplify", "[", 
           SubscriptBox["S", "n"], "]"}], ",", "\"\<=\>\"", ",", 
          RowBox[{"PaddedForm", "[", 
           RowBox[{
            RowBox[{"N", "[", 
             SubscriptBox["S", "n"], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"12", ",", "12"}], "}"}]}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"n", ",", "1", ",", "20"}], "}"}]}], "]"}], "]"}], "]"}], 
    ";"}], "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399021535625*^9, 3.399021536703125*^9}}],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to compute more of the partial sums of the infinite series."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(S\), SuperscriptBox[\(2\), \(n\)]]\) = \
S(\!\(\*SuperscriptBox[\(2\), \(n\)]\)) = \>\"", " ", ",", 
      SubscriptBox["S", 
       SuperscriptBox["2", "n"]]}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"TableForm", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          SubscriptBox["\"\<S\>\"", 
           SuperscriptBox["2", "n"]], ",", "\"\<=\>\"", ",", 
          RowBox[{"PaddedForm", "[", 
           RowBox[{
            RowBox[{"N", "[", 
             SubscriptBox["S", 
              SuperscriptBox["2", "n"]], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"12", ",", "12"}], "}"}]}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"n", ",", "1", ",", "10"}], "}"}]}], "]"}], "]"}], "]"}], 
    ";"}], "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399021540359375*^9, 3.39902154140625*^9}}],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to plot some of the partial sums of the infinite series."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"set", " ", "=", "  ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          SubscriptBox["S", "n"], "]"}], ",", 
         RowBox[{"Im", "[", 
          SubscriptBox["S", "n"], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "1", ",", "17"}], "}"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dot", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"PointSize", "[", "0.025", "]"}], ",", "Red", ",", 
         RowBox[{"Point", "[", 
          RowBox[{"{", 
           RowBox[{"sumX", ",", "sumY"}], "}"}], "]"}]}], "  ", "}"}], "}"}], 
      "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"graph", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"set", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"PointSize", "[", "0.02", "]"}], ",", "Blue"}], "}"}]}]}], 
      "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"graph", ",", "dot", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0.35", ",", "0.55"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0.95", ",", "1.1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "1", ",", "0.05"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0.6", ",", "1.1", ",", "0.05"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesOrigin", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0.35", ",", "0.95"}], "}"}]}]}], "]"}], "\[IndentingNewLine]",
    
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<{\!\(\*SubscriptBox[\(S\), \(n\)]\)} = \>\"", ",", 
      RowBox[{"N", "[", "table", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 1\), \
\(\[Infinity]\)]\)\!\(\*FractionBox[SuperscriptBox[\((3 + 4  \
\[ImaginaryI])\), \(n\)], \(\*SuperscriptBox[\(5\), \
\(n\)]*\*SuperscriptBox[\(n\), \(2\)]\)]\) = \>\"", ",", "sumZ", ",", 
      "\"\< = \>\"", ",", 
      RowBox[{"N", "[", "sumZ", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39902154453125*^9, 3.399021548921875*^9}, {
   3.3991932605*^9, 3.399193276015625*^9}, 3.399201206109375*^9, {
   3.399798032624752*^9, 3.399798032812252*^9}, {3.400259523546875*^9, 
   3.40025953121875*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "Therefore, we see that the series converges, and we have  ",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", "1"}], "\[Infinity]"], 
     FractionBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"3", " ", "+", " ", 
         RowBox[{"4", "\[ImaginaryI]"}]}], ")"}], "n"], 
      RowBox[{
       SuperscriptBox["5", "n"], " ", 
       SuperscriptBox["n", "2"]}]]}], "=", 
    RowBox[{
     RowBox[{"PolyLog", "[", 
      RowBox[{"2", ",", 
       RowBox[{
        FractionBox["3", "5"], "+", 
        FractionBox[
         RowBox[{"4", " ", "\[ImaginaryI]"}], "5"]}]}], "]"}], " ", "=", " ", 
     
     RowBox[{"0.403311", "\[InvisibleSpace]", "+", 
      RowBox[{"1.00841", "\[ImaginaryI]", " "}]}]}]}]}]]],
 ".  "
}], "Text"]
}, Closed]],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Geometric Series",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/GeometricSeriesBib.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Convergence of Series",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/SeriesConvergenceBib.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Power Series",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/PowerSeriesBib.html"], None}],
 
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/complex.html"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2008 John H. Mathews, Russell W. \
Howell",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/"], None}],
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[0, 1, 0]]], "Text",
 CellChangeTimes->{{3.399021148515625*^9, 3.399021148625*^9}}]
},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{988, 632},
WindowMargins->{{12, Automatic}, {Automatic, 2}},
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "CHAPTER 1"->{
  Cell[568, 21, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"],
  Cell[44301, 1560, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"],
  Cell[74694, 2524, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"],
  Cell[77320, 2626, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"],
  Cell[88233, 3008, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"],
  Cell[89461, 3057, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"],
  Cell[131903, 4412, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"],
  Cell[137071, 4602, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"],
  Cell[138386, 4652, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"CHAPTER 1", 158921, 5282}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"],
Cell[905, 32, 155, 3, 29, "Text"],
Cell[1063, 37, 860, 18, 101, "Text"],
Cell[1926, 57, 113, 2, 29, "Text"],
Cell[2042, 61, 7882, 248, 173, "Text"],
Cell[CellGroupData[{
Cell[9949, 313, 99, 2, 29, "Text"],
Cell[10051, 317, 1430, 41, 146, "Input"],
Cell[11484, 360, 1336, 37, 139, "Input"],
Cell[12823, 399, 1504, 41, 161, "Input"],
Cell[14330, 442, 1350, 38, 149, "Input"]
}, Closed]],
Cell[15695, 483, 3675, 127, 142, "Text"],
Cell[19373, 612, 2515, 86, 173, "Text"],
Cell[21891, 700, 1388, 50, 47, "Text"],
Cell[23282, 752, 18840, 723, 251, "Text"],
Cell[42125, 1477, 360, 10, 29, "Text"],
Cell[42488, 1489, 256, 5, 47, "Text"],
Cell[42747, 1496, 1212, 48, 101, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[43984, 1548, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[44128, 1554, 170, 4, 29, "Text",
 Evaluatable->False],
Cell[44301, 1560, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"]
}, Closed]],
Cell[44650, 1572, 487, 19, 41, "Text",
 Evaluatable->False],
Cell[45140, 1593, 1839, 66, 142, "Text"],
Cell[CellGroupData[{
Cell[47004, 1663, 156, 4, 29, "Text",
 Evaluatable->False],
Cell[47163, 1669, 64, 0, 29, "Text"],
Cell[47230, 1671, 4947, 134, 638, "Input"],
Cell[52180, 1807, 135, 5, 29, "Text"],
Cell[52318, 1814, 983, 26, 92, "Input"],
Cell[53304, 1842, 135, 5, 29, "Text"],
Cell[53442, 1849, 1181, 32, 92, "Input"],
Cell[54626, 1883, 132, 5, 29, "Text"],
Cell[54761, 1890, 2926, 80, 203, "Input"],
Cell[57690, 1972, 578, 19, 44, "Text"]
}, Closed]],
Cell[58283, 1994, 409, 16, 26, "Text",
 Evaluatable->False],
Cell[58695, 2012, 1679, 59, 155, "Text"],
Cell[CellGroupData[{
Cell[60399, 2075, 232, 9, 29, "Text",
 Evaluatable->False],
Cell[60634, 2086, 127, 3, 29, "Text"],
Cell[60764, 2091, 2299, 65, 282, "Input"],
Cell[63066, 2158, 53, 0, 29, "Text"],
Cell[63122, 2160, 2722, 71, 292, "Input"],
Cell[65847, 2233, 176, 5, 29, "Text"],
Cell[66026, 2240, 2597, 72, 192, "Input"],
Cell[68626, 2314, 135, 5, 29, "Text"],
Cell[68764, 2321, 959, 28, 72, "Input"],
Cell[69726, 2351, 132, 5, 29, "Text"],
Cell[69861, 2358, 2668, 74, 222, "Input"],
Cell[72532, 2434, 286, 11, 29, "Text"]
}, Closed]],
Cell[72833, 2448, 858, 35, 44, "Text"],
Cell[73694, 2485, 280, 5, 47, "Text"],
Cell[73977, 2492, 353, 15, 29, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[74355, 2511, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[74499, 2517, 192, 5, 29, "Text",
 Evaluatable->False],
Cell[74694, 2524, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"]
}, Closed]],
Cell[75043, 2536, 88, 2, 26, "Text"],
Cell[75134, 2540, 1396, 51, 47, "Text"],
Cell[76533, 2593, 63, 0, 29, "Text"],
Cell[76599, 2595, 379, 15, 29, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[77003, 2614, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[77147, 2620, 170, 4, 29, "Text",
 Evaluatable->False],
Cell[77320, 2626, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"]
}, Closed]],
Cell[77669, 2638, 3285, 109, 214, "Text"],
Cell[80957, 2749, 1867, 66, 47, "Text"],
Cell[82827, 2817, 1610, 55, 209, "Text"],
Cell[84440, 2874, 1572, 53, 67, "Text"],
Cell[86015, 2929, 236, 4, 47, "Text"],
Cell[86254, 2935, 1637, 57, 137, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[87916, 2996, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[88060, 3002, 170, 4, 29, "Text",
 Evaluatable->False],
Cell[88233, 3008, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"]
}, Closed]],
Cell[88582, 3020, 515, 20, 26, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[89122, 3044, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[89266, 3050, 192, 5, 29, "Text",
 Evaluatable->False],
Cell[89461, 3057, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"]
}, Closed]],
Cell[89810, 3069, 987, 37, 36, "Text"],
Cell[90800, 3108, 552, 19, 39, "Text"],
Cell[CellGroupData[{
Cell[91377, 3131, 232, 9, 29, "Text",
 Evaluatable->False],
Cell[91612, 3142, 110, 3, 29, "Text"],
Cell[91725, 3147, 2799, 81, 426, "Input"],
Cell[94527, 3230, 151, 5, 29, "Text"],
Cell[94681, 3237, 4053, 116, 484, "Input"],
Cell[98737, 3355, 149, 5, 29, "Text"],
Cell[98889, 3362, 1023, 27, 92, "Input"],
Cell[99915, 3391, 146, 5, 29, "Text"],
Cell[100064, 3398, 3848, 103, 361, "Input"],
Cell[103915, 3503, 601, 20, 40, "Text"]
}, Closed]],
Cell[104531, 3526, 764, 28, 35, "Text"],
Cell[105298, 3556, 301, 9, 35, "Text"],
Cell[CellGroupData[{
Cell[105624, 3569, 232, 9, 29, "Text",
 Evaluatable->False],
Cell[105859, 3580, 110, 3, 29, "Text"],
Cell[105972, 3585, 2205, 60, 410, "Input"],
Cell[108180, 3647, 498, 13, 71, "Text"],
Cell[108681, 3662, 1122, 30, 193, "Input"],
Cell[109806, 3694, 111, 4, 29, "Text"],
Cell[109920, 3700, 148, 5, 29, "Text"],
Cell[110071, 3707, 1649, 41, 186, "Input"],
Cell[111723, 3750, 151, 5, 29, "Text"],
Cell[111877, 3757, 3385, 102, 396, "Input"],
Cell[115265, 3861, 1189, 32, 112, "Input"]
}, Closed]],
Cell[116469, 3896, 403, 15, 26, "Text",
 Evaluatable->False],
Cell[116875, 3913, 1194, 40, 108, "Text"],
Cell[CellGroupData[{
Cell[118094, 3957, 232, 9, 29, "Text",
 Evaluatable->False],
Cell[118329, 3968, 265, 9, 29, "Text"],
Cell[118597, 3979, 2089, 60, 262, "Input"],
Cell[120689, 4041, 254, 9, 29, "Text"],
Cell[120946, 4052, 219, 8, 29, "Text"],
Cell[121168, 4062, 671, 18, 139, "Input"],
Cell[121842, 4082, 140, 5, 29, "Text"],
Cell[121985, 4089, 151, 5, 29, "Text"],
Cell[122139, 4096, 4051, 124, 472, "Input"],
Cell[126193, 4222, 149, 5, 29, "Text"],
Cell[126345, 4229, 1021, 27, 92, "Input"],
Cell[127369, 4258, 146, 5, 29, "Text"],
Cell[127518, 4265, 2303, 64, 182, "Input"],
Cell[129824, 4331, 279, 10, 29, "Text"]
}, Closed]],
Cell[130118, 4344, 1421, 51, 98, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[131564, 4399, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[131708, 4405, 192, 5, 29, "Text",
 Evaluatable->False],
Cell[131903, 4412, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"]
}, Closed]],
Cell[132252, 4424, 1519, 54, 44, "Text"],
Cell[133774, 4480, 981, 36, 101, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[134780, 4520, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[134924, 4526, 715, 19, 29, "Text",
 Evaluatable->False]
}, Closed]],
Cell[135654, 4548, 1075, 38, 44, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[136754, 4590, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[136898, 4596, 170, 4, 29, "Text",
 Evaluatable->False],
Cell[137071, 4602, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"]
}, Closed]],
Cell[137420, 4614, 600, 21, 26, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[138045, 4639, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[138189, 4645, 194, 5, 29, "Text",
 Evaluatable->False],
Cell[138386, 4652, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"]
}, Closed]],
Cell[138735, 4664, 495, 18, 38, "Text"],
Cell[139233, 4684, 1593, 55, 72, "Text"],
Cell[CellGroupData[{
Cell[140851, 4743, 232, 9, 29, "Text",
 Evaluatable->False],
Cell[141086, 4754, 110, 3, 29, "Text"],
Cell[141199, 4759, 4736, 131, 716, "Input"],
Cell[145938, 4892, 860, 26, 59, "Text"],
Cell[146801, 4920, 1127, 29, 200, "Input"],
Cell[147931, 4951, 229, 6, 65, "Text"],
Cell[148163, 4959, 2288, 63, 307, "Input"],
Cell[150454, 5024, 151, 5, 29, "Text"],
Cell[150608, 5031, 1021, 27, 92, "Input"],
Cell[151632, 5060, 149, 5, 29, "Text"],
Cell[151784, 5067, 1079, 29, 92, "Input"],
Cell[152866, 5098, 146, 5, 29, "Text"],
Cell[153015, 5105, 3020, 81, 236, "Input"],
Cell[156038, 5188, 827, 27, 41, "Text"]
}, Closed]],
Cell[156880, 5218, 281, 7, 26, "Text"],
Cell[157164, 5227, 279, 7, 29, "Text"],
Cell[157446, 5236, 286, 7, 29, "Text"],
Cell[157735, 5245, 269, 7, 29, "Text"],
Cell[158007, 5254, 249, 5, 29, "Text"],
Cell[158259, 5261, 317, 7, 29, "Text"]
}
]
*)

(* End of internal cache information *)
