(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    466098,       9626]
NotebookOptionsPosition[    459831,       9431]
NotebookOutlinePosition[    460538,       9461]
CellTagsIndexPosition[    460464,       9456]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["4.2  Julia and Mandelbrot Sets",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
 "\tAn impetus for studying complex analysis is the comparison of properties \
of real numbers and functions with their complex counterparts.  In this \
section we take a look at Newton's method for finding solutions to the \
equation ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "x", ")"}]}], "=", "0"}]]],
 ".  Then, by examining the more general topic of iteration, we will plunge \
into a breathtaking world of color and imagination. The mathematics \
surrounding this topic has generated a great deal of popular attention in the \
past few years."
}], "Text",
 CellChangeTimes->{3.399026152515625*^9}],

Cell[TextData[{
 "\tRecall from calculus that ",
 StyleBox[ButtonBox["Newton's method",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/NewtonsMethod.html"], None}],
  FontVariations->{"Underline"->True}],
 " method proceeds by starting with a function ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", "x", ")"}]}]]],
 " and an initial \"guess\"  ",
 Cell[BoxData[
  SubscriptBox["x", "0"]]],
 "  as a solution to ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "x", ")"}]}], "=", "0"}]]],
 ".  We then generate a new guess  ",
 Cell[BoxData[
  SubscriptBox["x", "1"]]],
 "  by the computation  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["x", "1"], "=", 
   RowBox[{
    SubscriptBox["x", "0"], "-", 
    FractionBox[
     RowBox[{"f", 
      RowBox[{"(", 
       SubscriptBox["x", "0"], ")"}]}], 
     RowBox[{
      RowBox[{"f", "'"}], 
      RowBox[{"(", 
       SubscriptBox["x", "0"], ")"}]}]]}]}]]],
 ".  Using  ",
 Cell[BoxData[
  SubscriptBox["x", "1"]]],
 " in place of  ",
 Cell[BoxData[
  SubscriptBox["x", "0"]]],
 ",  this process is repeated, giving us  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["x", "2"], "=", 
   RowBox[{
    SubscriptBox["x", "1"], "-", 
    FractionBox[
     RowBox[{"f", 
      RowBox[{"(", 
       SubscriptBox["x", "1"], ")"}]}], 
     RowBox[{
      RowBox[{"f", "'"}], 
      RowBox[{"(", 
       SubscriptBox["x", "1"], ")"}]}]]}]}]]],
 ".  Thus we obtain a sequence of points  ",
 Cell[BoxData[
  RowBox[{"{", 
   SubscriptBox["x", "k"], "}"}]]],
 ", where  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["x", 
    RowBox[{"k", "+", "1"}]], "=", 
   RowBox[{
    SubscriptBox["x", "k"], "-", 
    FractionBox[
     RowBox[{"f", 
      RowBox[{"(", 
       SubscriptBox["x", "k"], ")"}]}], 
     RowBox[{
      RowBox[{"f", "'"}], 
      RowBox[{"(", 
       SubscriptBox["x", "k"], ")"}]}]]}]}]]],
 ".  The points  ",
 Cell[BoxData[
  SubsuperscriptBox[
   RowBox[{"{", 
    SubscriptBox["x", "k"], "}"}], 
   RowBox[{"k", "=", "0"}], "\[Infinity]"]]],
 "  are called the iterates of  ",
 Cell[BoxData[
  SubscriptBox["x", "0"]]],
 ".  For functions defined on the real numbers, this method gives remarkably \
good results so that the sequence  ",
 Cell[BoxData[
  RowBox[{"{", 
   SubscriptBox["x", "k"], "}"}]]],
 "  often converges to a solution of  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "x", ")"}]}], "=", "0"}]]],
 "  rather quickly.  In the late 1800's the british mathematician ",
 StyleBox[ButtonBox["Arthur Cayley",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Cayley.\
html"], None}],
  FontVariations->{"Underline"->True}],
 " investigated the question as to whether Newton's method can be applied to \
complex functions.  He wrote a paper giving an analysis for how this method \
works for quadratic polynomials and indicated his intention to publish a \
subsequent paper for cubic polynomials.  Unfortunately, Cayley died before \
producing this paper. As you will see, the extension of ",
 StyleBox[ButtonBox["Newton's",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Newton.\
html"], None}],
  FontVariations->{"Underline"->True}],
 " method to the complex domain and the more general question of iteration \
are quite complicated."
}], "Text",
 CellChangeTimes->{{3.39902616765625*^9, 3.399026173640625*^9}}],

Cell[TextData[{
 StyleBox["Example 4.7.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Trace out the next five iterates of Newton's method given an initial \
guess of  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "0"], "=", 
   RowBox[{
    FractionBox["1", "4"], "+", 
    FractionBox["\[ImaginaryI]", "4"]}]}]]],
 "  as a solution to the equation  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", "0"}]]],
 ",  where  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    SuperscriptBox["z", "2"], "+", "1"}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "Solution.  For any guess z for a solution, Newton's method gives as the \
next guess the number ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"z", "-", 
    FractionBox[
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], 
     RowBox[{
      RowBox[{"f", "'"}], 
      RowBox[{"(", "z", ")"}]}]]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"z", "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["z", "2"], "+", "1"}], 
      RowBox[{"2", "z"}]]}], " ", "=", " ", 
    FractionBox[
     RowBox[{
      SuperscriptBox["z", "2"], "-", "1"}], 
     RowBox[{"2", "z"}]]}]}]]],
 ".  Table 4.1 gives the required iterates.  "
}], "Text"],

Cell[TextData[{
 "\tFigure 4.2 shows the relative positions of these points on the z plane.  \
Note that the points ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "4"], " ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], " ", 
   SubscriptBox["z", "5"]}]]],
 " are so close together that they appear to coincide, and that the value for \
",
 Cell[BoxData[
  SubscriptBox["z", "5"]]],
 " agrees to six decimal places with the actual solution ",
 Cell[BoxData[
  RowBox[{"z", "=", "\[ImaginaryI]"}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "\t\t",
 Cell[BoxData[
  RowBox[{
   TagBox[GridBox[{
      {"k", 
       RowBox[{"                                     ", 
        SubscriptBox["z", "k"]}], 
       RowBox[{"                              ", 
        RowBox[{"f", 
         RowBox[{"(", 
          SubscriptBox["z", "k"], ")"}]}]}]},
      {"0", 
       RowBox[{"   ", 
        RowBox[{"0.2500000000", "             \[InvisibleSpace]", "+", " ", 
         RowBox[{"0.2500000000", " ", "\[ImaginaryI]"}]}]}], 
       RowBox[{
        RowBox[{"1.0", "\[InvisibleSpace]", "000000000"}], "             ", 
        "+", " ", 
        RowBox[{"0.1250000000", " ", "\[ImaginaryI]"}]}]},
      {"1", 
       RowBox[{
        RowBox[{"-", "0.8750000000"}], "             ", "+", " ", 
        RowBox[{"1.1250000000", " ", "\[ImaginaryI]"}]}], 
       RowBox[{
        RowBox[{"0.5", "\[InvisibleSpace]", "000000000"}], "             ", 
        "-", " ", 
        RowBox[{"1.9687500000", " ", "\[ImaginaryI]"}]}]},
      {"2", 
       RowBox[{
        RowBox[{"-", "0.2221153846"}], "             ", "+", " ", 
        RowBox[{"0.8394230769", " ", "\[ImaginaryI]"}]}], 
       RowBox[{"0.3447041420", "             ", "-", " ", 
        RowBox[{"0.3728975591", " ", "\[ImaginaryI]"}]}]},
      {"3", 
       RowBox[{"   ", 
        RowBox[{"0.0362402512", "\[InvisibleSpace]             ", "+", " ", 
         RowBox[{"0.9763829875", " ", "\[ImaginaryI]"}]}]}], 
       RowBox[{"0.0479896174", "\[InvisibleSpace]             ", "+", " ", 
        RowBox[{"0.0707687295", " ", "\[ImaginaryI]"}]}]},
      {"4", 
       RowBox[{
        RowBox[{"-", "0.0008610408"}], "             ", "+", " ", 
        RowBox[{"0.9995811063", " ", "\[ImaginaryI]"}]}], 
       RowBox[{"0.0008383531", "\[InvisibleSpace]             ", "-", " ", 
        RowBox[{"0.0017213603", " ", "\[ImaginaryI]"}]}]},
      {"5", 
       RowBox[{"   ", 
        RowBox[{
         RowBox[{"3.6059156651", "\[Times]", 
          SuperscriptBox["10", 
           RowBox[{"-", "7"}]]}], " ", "+", " ", 
         RowBox[{"0.9999997166", " ", "\[ImaginaryI]"}]}]}], 
       RowBox[{
        RowBox[{"5.6677795053", "\[Times]", 
         SuperscriptBox["10", 
          RowBox[{"-", "7"}]]}], " ", "+", " ", 
        RowBox[{"7.2118292865", "\[Times]", 
         SuperscriptBox["10", 
          RowBox[{"-", "7"}]], " ", "\[ImaginaryI]"}]}]},
      {"6", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "1.0218768555"}], "\[Times]", 
         SuperscriptBox["10", 
          RowBox[{"-", "13"}]]}], "+", " ", 
        RowBox[{"0.9999999999", " ", "\[ImaginaryI]"}]}], 
       RowBox[{
        RowBox[{"4.9717068413", "\[Times]", 
         SuperscriptBox["10", 
          RowBox[{"-", "14"}]]}], "-", " ", 
        RowBox[{"2.0437537111", "\[Times]", 
         SuperscriptBox["10", 
          RowBox[{"-", "13"}]], " ", "\[ImaginaryI]"}]}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Function[BoxForm`e$, 
     TableForm[
     BoxForm`e$, 
      TableHeadings -> {None, {"k", "\!\(z\_k\)", "f[\!\(z\_k\)]"}}]]], 
   " "}]], "Input",
  FontWeight->"Plain"],
 "  ",
 StyleBox["\n\n\t\tTable 4.1",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  The iterates of ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "0"], "=", 
   RowBox[{
    FractionBox["1", "4"], "+", 
    FractionBox["\[ImaginaryI]", "4"]}]}]]],
 " for Newton's method applied to ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    SuperscriptBox["z", "2"], "+", "1"}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "\t\t\t",
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .85714 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.769231 0.854701 3.03306e-017 0.745342 [
[.12821 -0.0125 -15 -9 ]
[.12821 -0.0125 15 0 ]
[.34188 -0.0125 -12 -9 ]
[.34188 -0.0125 12 0 ]
[.55556 -0.0125 -15 -9 ]
[.55556 -0.0125 15 0 ]
[.98291 -0.0125 -12 -9 ]
[.98291 -0.0125 12 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 10 6.28125 ]
[.75673 .14907 -18 -4.5 ]
[.75673 .14907 0 4.5 ]
[.75673 .29814 -18 -4.5 ]
[.75673 .29814 0 4.5 ]
[.75673 .4472 -18 -4.5 ]
[.75673 .4472 0 4.5 ]
[.75673 .59627 -18 -4.5 ]
[.75673 .59627 0 4.5 ]
[.75673 .74534 -6 -4.5 ]
[.75673 .74534 0 4.5 ]
[.76923 .88214 -5 0 ]
[.76923 .88214 5 12.5625 ]
[ 0 0 0 0 ]
[ 1 .85714 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12821 0 m
.12821 .00625 L
s
[(-0.75)] .12821 -0.0125 0 1 Mshowa
.34188 0 m
.34188 .00625 L
s
[(-0.5)] .34188 -0.0125 0 1 Mshowa
.55556 0 m
.55556 .00625 L
s
[(-0.25)] .55556 -0.0125 0 1 Mshowa
.98291 0 m
.98291 .00625 L
s
[(0.25)] .98291 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.76923 .14907 m
.77548 .14907 L
s
[(0.2)] .75673 .14907 1 0 Mshowa
.76923 .29814 m
.77548 .29814 L
s
[(0.4)] .75673 .29814 1 0 Mshowa
.76923 .4472 m
.77548 .4472 L
s
[(0.6)] .75673 .4472 1 0 Mshowa
.76923 .59627 m
.77548 .59627 L
s
[(0.8)] .75673 .59627 1 0 Mshowa
.76923 .74534 m
.77548 .74534 L
s
[(1)] .75673 .74534 1 0 Mshowa
.76923 0 m
.76923 .85714 L
s
gsave
.76923 .88214 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .85714 L
0 .85714 L
closepath
clip
newpath
1 0 0 r
.02 w
.98291 .18634 Mdot
.02137 .83851 Mdot
.57939 .62566 Mdot
.80021 .72774 Mdot
.76849 .74503 Mdot
.76923 .74534 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 246.813},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\
eJztWUtPwkAQXtg2sRDQxOhJTBG8GD2o/0EPamKEeCfEBA5Gg/wZ/SE+rmri
4wd58YDdB9sHs9sFailkG8OO830znZkO0y09a/U7V9etfrfdco97rdtOt33n
Ht30PBXOIZRzEUI/LiLywBP5x8D7G1TJB0I1suSJ2hKSTSGMGJmyUV6gdcDC
l7YBHSaSJSSqa2ry1lmYW3SxQiF5R4EKdkjNIRZxJAsXdrMEq2sqdtgxhqkX
U3tY08g/7MjSz7sIUKsw1QGoUJ+cT2e+ygw2RCfkVZGH1cOWqcQZO4K6GUeF
Cux/FRqTGKk7WtKKGHAp8QCVWtnJWidTdrKWB97J/sBxRPEpnbJ9tCB09bDO
HxpYXAMpyk8anHhKuSR88ByGx3KAVI5kR44VJtEYfmWXgTvZAaADQHc4Bc+J
SeQbsGkYyEAG+m/oiSzSrQ90++aGj3TR2k1A91a1F2heRaas1Ba64UG3AJ08
RtSKgviV9Ge/IvNZX/8DVs4B33fApH3yaRNSJQ2SVkwZqZ+BFg2CRqHNOhLB
u0j1CIEeaKDnQI1BZIsINAbg+KNLcwrHePHrVwxXcvaX1kAGWkhIun2j7PE3
XonNDpUj3Rk2YQ7SzaPWvg3H5JuRC28gA80vBI0t9U/+8zG2nFRzSOWJ84Gl
7kl7ctI9WejT3W4aJK2YMtLqBpoTyBJNdSonYdGeJ2mQRmJ6ZVaIvyOiUJNB
79wiaD88RSN5CvBcG4zmjSxZ/w3MQIlBZdEAL3JSSbTScxokrZgSrwT9R+f1
3oTyp/hmXTLFFxBLMzbMqBU5moEzjO5EOPrBqkqO8Mu8CfNHuT8TRoyg\
\>"],
  ImageRangeCache->{{{0, 287}, {245.813, 0}} -> {0, 0, 0, 0}}],
 StyleBox["   \n\t\tFigure 4.2",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  The iterates of ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "0"], "=", 
   RowBox[{
    FractionBox["1", "4"], "+", 
    FractionBox["\[ImaginaryI]", "4"]}]}]]],
 " for Newton's method applied to ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    SuperscriptBox["z", "2"], "+", "1"}]}]]],
 ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 4.7.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "Enter the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], "=", 
   RowBox[{
    SuperscriptBox["z", "2"], "+", "1"}]}]]],
 "  and find the next five iterates."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", 
     RowBox[{"z", ",", "Z"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "i", ",", "k", ",", "K", ",", "list", ",", "set"}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{
      SuperscriptBox["z", "2"], " ", "+", " ", "1"}]}], " ", ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"K", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"i", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "0", ",", "5"}], "}"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Z", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", "6", "}"}]}], "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{
     SubscriptBox["Z", 
      RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], "=", 
     RowBox[{"N", "[", 
      RowBox[{
       FractionBox["1", "4"], "+", 
       FractionBox["\[ImaginaryI]", "4"]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"g", "[", "z_", "]"}], "=", 
     RowBox[{"z", "-", 
      FractionBox[
       RowBox[{"f", "[", "z", "]"}], 
       RowBox[{
        RowBox[{"f", "'"}], "[", "z", "]"}]]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The formula for iteration is\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(z\), \(k + 1\)]\) = \!\(\*SubscriptBox[\(z\), \
\(k\)]\) - \!\(\*FractionBox[\(f[\*SubscriptBox[\(z\), \(k\)]]\), \
\(\(f'\)[\*SubscriptBox[\(z\), \(k\)]]\)]\) = \>\"", ",", 
      RowBox[{"g", "[", "\"\<\!\(\*SubscriptBox[\(z\), \(k\)]\)\>\"", "]"}]}],
      "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399026374109375*^9}],

Cell[TextData[{
 "Now compute the next five iterates  ",
 Cell[BoxData[
  SubscriptBox["z", "k"]]],
 "  and the corresponding values of  ",
 Cell[BoxData[
  RowBox[{"f", "[", 
   SubscriptBox["z", "k"], "]"}]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"k", "=", "0"}], ",", 
      RowBox[{"k", "\[LessEqual]", "4"}], ",", 
      RowBox[{"k", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        SubscriptBox["Z", 
         RowBox[{"\[LeftDoubleBracket]", 
          RowBox[{"k", "+", "2"}], "\[RightDoubleBracket]"}]], "=", 
        RowBox[{"g", "[", 
         SubscriptBox["Z", 
          RowBox[{"\[LeftDoubleBracket]", 
           RowBox[{"k", "+", "1"}], "\[RightDoubleBracket]"}]], "]"}]}], 
       ";"}]}], "  ", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"TableForm", "[", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{"K", ",", "Z", ",", 
          RowBox[{"f", "[", "Z", "]"}]}], "}"}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"TableHeadings", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"None", ",", 
          RowBox[{"{", 
           RowBox[{
           "\"\<k\>\"", ",", "\"\<\!\(\*SubscriptBox[\(z\), \(k\)]\)\>\"", 
            ",", "\"\<f[\!\(\*SubscriptBox[\(z\), \(k\)]\)]\>\""}], "}"}]}], 
         "}"}]}]}], "]"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39902637865625*^9}],

Cell[TextData[{
 "Plot the iterates  ",
 Cell[BoxData[
  SubscriptBox["z", "k"]]],
 "  and observe that they are converging to  ",
 Cell[BoxData[
  RowBox[{"z", "=", "\[ImaginaryI]"}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"set", " ", "=", "  ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{"Z", ",", 
       RowBox[{"xx_Real", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"xx", ",", "0"}], "}"}]}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"list", " ", "=", "  ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{"set", ",", 
       RowBox[{
        RowBox[{"Complex", "[", 
         RowBox[{"xx_", ",", "yy_"}], "]"}], "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"xx", ",", "yy"}], "}"}]}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"list", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.9"}], ",", "0.5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0.0", ",", "1.2"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"PointSize", "[", "0.02", "]"}], ",", "Red"}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["1.2", "1.4"]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", "0.2"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "1.2", ",", "0.2"}], "]"}]}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"TableForm", "[", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{"K", ",", "Z"}], "}"}], "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"TableHeadings", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"None", ",", 
          RowBox[{"{", 
           RowBox[{
           "\"\<k\>\"", ",", "\"\<\!\(\*SubscriptBox[\(z\), \(k\)]\)\>\""}], 
           "}"}]}], "}"}]}]}], "]"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399026383453125*^9, 3.3990263859375*^9}, {
  3.399201481734375*^9, 3.39920149109375*^9}, {3.400260143765625*^9, 
  3.40026014571875*^9}}],

Cell[TextData[{
 "Notice that the points  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "4"], "  ", "and", "  ", 
   SubscriptBox["z", "5"]}]]],
 "  are co close together that they appear to coincide and that the value for \
 ",
 Cell[BoxData[
  RowBox[{" ", 
   SubscriptBox["z", "5"]}]]],
 "  agrees to six decimal places with the actual solution  ",
 Cell[BoxData[
  RowBox[{"z", "=", "\[ImaginaryI]"}]]],
 ".  "
}], "Text"]
}, Closed]],

Cell["\<\
\tThe complex version of Newton's method also appears to work quite well.  \
Recall, however, that with functions defined on the reals, not every initial \
guess produces a sequence that converges to a solution.  Example 4.8 shows \
that the same is true in the complex case. \
\>", "Text"],

Cell[TextData[{
 StyleBox["Example 4.8.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Show that Newton's method fails for the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    SuperscriptBox["z", "2"], "+", "1"}]}]]],
 "  if the initial guess is a real number."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "Solution.  From Example 4.7 we know that, for any guess ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " as a solution of ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["z", "2"], "+", "1"}], "=", "0"}]]],
 ", the next guess at a solution is  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"N", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    RowBox[{"z", "-", 
     FractionBox[
      RowBox[{"f", 
       RowBox[{"(", "z", ")"}]}], 
      RowBox[{
       RowBox[{"f", "'"}], 
       RowBox[{"(", "z", ")"}]}]]}], " ", "=", " ", 
    FractionBox[
     RowBox[{
      SuperscriptBox["z", "2"], "-", "1"}], 
     RowBox[{"2", "z"}]]}]}]]],
 ".  We let ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 " be any real number and ",
 Cell[BoxData[
  RowBox[{"{", 
   SubscriptBox["z", "k"], "}"}]]],
 " be the sequence of iterations produced by the initial seed ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 ".  If for any k,  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "k"], "=", "0"}]]],
 ",  the procedure terminates, as ",
 Cell[BoxData[
  SubscriptBox["z", 
   RowBox[{"k", "+", "1"}]]]],
 " will be undefined.  If all the terms of the sequence ",
 Cell[BoxData[
  RowBox[{"{", 
   SubscriptBox["z", "k"], "}"}]]],
 " are defined, an easy induction argument shows that all the terms of the \
sequence are real.  Because the solutions of ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["z", "2"], "+", "1"}], "=", "0"}]]],
 " are ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{"\[PlusMinus]", "\[ImaginaryI]"}]}]]],
 ", the sequence ",
 Cell[BoxData[
  RowBox[{"{", 
   SubscriptBox["z", "k"], "}"}]]],
 " cannot possibly converge to either solution.  In the exercises we ask you \
to explore in detail what happens when ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 " is in the upper or lower half-plane."
}], "Text"],

Cell[TextData[{
 StyleBox["Extra Example 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Investigate Newton's method for finding the roots of  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    SuperscriptBox["z", "3"], "+", "1"}]}]]],
 ".\nGiven the initial seed  ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 "  determine if the sequence  ",
 Cell[BoxData[
  RowBox[{"{", 
   SubscriptBox["z", "k"], "}"}]]],
 "  converges to one of the roots  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"z", "=", 
    RowBox[{"-", "1"}]}], ",", 
   RowBox[{
    FractionBox["1", "2"], "+", 
    FractionBox[
     RowBox[{"\[ImaginaryI]", " ", 
      SqrtBox["3"]}], "2"]}], ",", 
   RowBox[{
    FractionBox["1", "2"], "-", 
    FractionBox[
     RowBox[{"\[ImaginaryI]", " ", 
      SqrtBox["3"]}], "2"]}]}]]],
 "."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Extra Solution 1.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "Enter the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], "=", 
   RowBox[{
    SuperscriptBox["z", "3"], "+", "1"}]}]]],
 "  and find its roots."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", 
     RowBox[{"z", ",", "Z"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", "f", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", 
     RowBox[{
      SuperscriptBox["z", "3"], "+", "1"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"solset", "=", 
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"f", "[", "z", "]"}], "\[Equal]", "0"}], ",", "z"}], "]"}]}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "1"], "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{
       SubscriptBox["solset", 
        RowBox[{"\[LeftDoubleBracket]", 
         RowBox[{"1", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]], ",", 
       RowBox[{"TargetFunctions", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Im", ",", "Re"}], "}"}]}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "2"], "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{
       SubscriptBox["solset", 
        RowBox[{"\[LeftDoubleBracket]", 
         RowBox[{"2", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]], ",", 
       RowBox[{"TargetFunctions", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Im", ",", "Re"}], "}"}]}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "3"], "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{
       SubscriptBox["solset", 
        RowBox[{"\[LeftDoubleBracket]", 
         RowBox[{"3", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]], ",", 
       RowBox[{"TargetFunctions", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Im", ",", "Re"}], "}"}]}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The roots are\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["Z", "1"]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(2\)]\) = \>\"", ",", 
      SubscriptBox["Z", "2"]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(3\)]\) = \>\"", ",", 
      SubscriptBox["Z", "3"]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399026403*^9}],

Cell[TextData[{
 "We color each point ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 "  in the rectangle  ",
 Cell[BoxData[
  RowBox[{"R", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"z", "=", 
      RowBox[{"x", "+", 
       RowBox[{"\[ImaginaryI]y", ":", 
        RowBox[{
         RowBox[{"-", "2"}], "\[LessEqual]", "x", "\[LessEqual]", "2"}]}]}]}],
      ",", 
     RowBox[{
      RowBox[{"-", "2"}], "\[LessEqual]", "x", "\[LessEqual]", "2"}]}], 
    "}"}]}]]],
 " in the following fashion.  Color the point yellow, blue, or red, if the \
sequence of iterations produced by the seed  ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 "  converges to ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"-", "1"}], ",", 
   RowBox[{
    FractionBox["1", "2"], "+", 
    FractionBox[
     RowBox[{"\[ImaginaryI]", " ", 
      SqrtBox["3"]}], "2"]}], ",", 
   RowBox[{
    FractionBox["1", "2"], "-", 
    FractionBox[
     RowBox[{"\[ImaginaryI]", " ", 
      SqrtBox["3"]}], "2"]}]}]]],
 ", respectively.  The iteration formula is "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"g", "[", "z_", "]"}], "=", 
     RowBox[{"Together", "[", 
      RowBox[{"z", "-", 
       FractionBox[
        RowBox[{"f", "[", "z", "]"}], 
        RowBox[{
         RowBox[{"f", "'"}], "[", "z", "]"}]]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<g[z] = \>\"", ",", 
      RowBox[{"g", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39902640775*^9}],

Cell[TextData[{
 "The formulas for  f[z] and  g[z]  and approximations to the roots ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"z", "=", 
    RowBox[{"-", "1"}]}], ",", 
   RowBox[{
    FractionBox["1", "2"], "+", 
    FractionBox[
     RowBox[{"\[ImaginaryI]", " ", 
      SqrtBox["3"]}], "2"]}], ",", 
   RowBox[{
    RowBox[{"and", " ", 
     FractionBox["1", "2"]}], "-", 
    FractionBox[
     RowBox[{"\[ImaginaryI]", " ", 
      SqrtBox["3"]}], "2"]}]}]]],
 " are used in the function  newton[x,y]  to make the density plot."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"newton", "=", "\n", 
     RowBox[{"Compile", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"x", ",", "y"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Module", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"z", ",", 
           RowBox[{"ct", "=", "0"}]}], "}"}], ",", 
         RowBox[{
          RowBox[{"z", "=", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "y"}]}]}], ";", " ", 
          "\[IndentingNewLine]", 
          RowBox[{"While", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"Abs", "[", 
               RowBox[{"Evaluate", "[", 
                RowBox[{
                 SuperscriptBox["z", "3"], "+", "1"}], "]"}], "]"}], ">", 
              "0.001"}], " ", "&&", " ", 
             RowBox[{"ct", "\[LessEqual]", "50"}]}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"z", "=", 
              FractionBox[
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"2", " ", 
                 SuperscriptBox["z", "3"]}]}], 
               RowBox[{"3", " ", 
                SuperscriptBox["z", "2"]}]]}], ";", " ", 
             RowBox[{"++", "ct"}]}]}], "]"}], ";", " ", "\[IndentingNewLine]",
           
          RowBox[{"Which", "[", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{
             RowBox[{"Abs", "[", 
              RowBox[{"z", "-", 
               RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}]}], "]"}], "<", "0.1"}], ",", "0.15",
             ",", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"Abs", "[", 
              RowBox[{"z", "-", 
               RowBox[{"(", 
                RowBox[{"0.5", "\[InvisibleSpace]", "+", 
                 RowBox[{"0.866", " ", "\[ImaginaryI]"}]}], ")"}]}], "]"}], 
             "<", "0.1"}], ",", "0.5", ",", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"Abs", "[", 
              RowBox[{"z", "-", 
               RowBox[{"(", 
                RowBox[{"0.5", "\[InvisibleSpace]", "-", 
                 RowBox[{"0.866", " ", "\[ImaginaryI]"}]}], ")"}]}], "]"}], 
             "<", "0.1"}], ",", "0.9"}], "]"}]}]}], "]"}]}], " ", "]"}]}], 
    ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399026412125*^9}],

Cell[TextData[{
 "Make a plot showing the initial seeds  ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 ",  and the nature of the sequence ",
 Cell[BoxData[
  RowBox[{"{", 
   SubscriptBox["z", "k"], "}"}]]],
 "  that is produced by it."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"DensityPlot", "[", 
    RowBox[{
     RowBox[{"newton", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "2"}], ",", "2."}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotPoints", "\[Rule]", "100"}], ",", 
     RowBox[{"Mesh", "\[Rule]", "False"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
     RowBox[{"ColorFunction", "\[Rule]", "\"\<BlueGreenYellow\>\""}]}], "]"}],
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Blue points converge to  -1.\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<Green points converge to  \!\(\*FractionBox[\(1\), \
\(2\)]\)+\!\(\*FractionBox[\(\[ImaginaryI] \*SqrtBox[\(3\)]\), \(2\)]\).\>\"",
      "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<Yellow  points converge to  \!\(\*FractionBox[\(1\), \
\(2\)]\)-\!\(\*FractionBox[\(\[ImaginaryI] \*SqrtBox[\(3\)]\), \(2\)]\).\>\"",
      "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399026418234375*^9, 3.399026421234375*^9}, {
  3.399026577546875*^9, 3.39902661059375*^9}}],

Cell[TextData[{
 StyleBox["Remark.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 "  The color scheme for the above graph might be different from the text or \
those produced with ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " 5. "
}], "Text",
 CellChangeTimes->{{3.399026620546875*^9, 3.399026654875*^9}}],

Cell[TextData[{
 StyleBox["Notice.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 "  ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " does not produce graphs with the color scheme indicated in the book!"
}], "Text"]
}, Closed]],

Cell[TextData[{
 "\tThe case for cubic polynomials is more complicated than that for \
quadratics.  Fortunately, we can get an idea of what's going on by doing some \
experimentation with computer graphics.  We begin with the cubic polynomial \
",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    SuperscriptBox["z", "3"], "+", "1"}]}]]],
 ".  (Recall that the roots of this polynomial are at ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"z", "=", 
    RowBox[{"-", "1"}]}], ",", " ", 
   RowBox[{
    FractionBox["1", "2"], "+", 
    RowBox[{
     FractionBox[
      RowBox[{" ", 
       SqrtBox["3"]}], "2"], "\[ImaginaryI]"}]}], ",", " ", 
   RowBox[{
    FractionBox["1", "2"], "-", 
    RowBox[{
     FractionBox[
      RowBox[{" ", 
       SqrtBox["3"]}], "2"], "\[ImaginaryI]"}]}]}]]],
 ".)  We associate a color with each root (blue, red, and green, \
respectively).  We form a rectangular region ",
 Cell[BoxData["R"]],
 ", which contains the three roots of ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", "z", ")"}]}]]],
 ", and partition this region into equal rectangles ",
 Cell[BoxData[
  SubscriptBox["R", 
   RowBox[{"i", " ", "j"}]]]],
 ".  We then choose a point ",
 Cell[BoxData[
  SubscriptBox["z", 
   RowBox[{"i", " ", "j"}]]]],
 " at the center of each rectangle and for each of these points we apply the \
following algorithm."
}], "Text"],

Cell[TextData[{
 StyleBox["1.",
  FontColor->RGBColor[0, 0, 1]],
 "  With  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"N", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"z", "-", 
     FractionBox[
      RowBox[{"f", 
       RowBox[{"(", "z", ")"}]}], 
      RowBox[{
       RowBox[{"f", "'"}], 
       RowBox[{"(", "z", ")"}]}]]}], " ", "=", " ", 
    RowBox[{
     RowBox[{"z", "-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["z", "3"], "+", "1"}], 
       RowBox[{"3", " ", 
        SuperscriptBox["z", "2"]}]]}], " ", "=", " ", 
     FractionBox[
      RowBox[{
       RowBox[{"2", " ", 
        SuperscriptBox["z", "3"]}], "-", "1"}], 
      RowBox[{"3", " ", 
       SuperscriptBox["z", "2"]}]]}]}]}]]],
 ",  compute  ",
 Cell[BoxData[
  RowBox[{"N", 
   RowBox[{"(", 
    SubscriptBox["z", 
     RowBox[{"i", " ", "j"}]], ")"}]}]]],
 ".  Continue computing successive iterates of this initial point until we \
either are within a certain preassigned tolerance (say, ) of one of the roots \
of   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", "0"}]]],
 ",  or until the number of iterations has exceeded a preassigned maximum."
}], "Text"],

Cell[TextData[{
 StyleBox["2.",
  FontColor->RGBColor[0, 0, 1]],
 "  If Step 1 leaves us within  of one of the roots of ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", "z", ")"}]}]]],
 ", we color the entire rectangle ",
 Cell[BoxData[
  SubscriptBox["R", 
   RowBox[{"i", " ", "j"}]]]],
 " with the color associated with that root.  \nOtherwise, we assume that the \
initial point ",
 Cell[BoxData[
  SubscriptBox["z", 
   RowBox[{"i", " ", "j"}]]]],
 " does not converge to any root, and we color the entire rectangle yellow."
}], "Text"],

Cell[TextData[{
 "\tNote that this algorithm doesn't prove anything.  In Step 2, there is no \
a priori reason to justify the assumption mentioned, nor is there any \
necessity for an initial point ",
 Cell[BoxData[
  SubscriptBox["z", 
   RowBox[{"i", " ", "j"}]]]],
 " to have its sequence of iterates converging to one of the roots of ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", "0"}]]],
 ", just because a particular iteration is within  of that root.  Finally, \
the fact that one point in a rectangle behaves in a certain way does not \
imply that all the points in that rectangle behave in a like manner.  \
Nevertheless, we can use this algorithm as a basis for mathematical \
explorations.  Indeed, computer experiments such as the one described have \
contributed to a lot of exciting mathematics during the past 20 years.  The \
color plates located on the inside front and back covers of this book \
illustrate the results of applying our algorithm to various functions.  Color \
plate 1shows the results for the cubic polynomial ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    SuperscriptBox["z", "3"], "+", "1"}]}]]],
 ".  The points in the blue, red, and green regions are those \"initial \
guesses\" that will converge to the roots ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"z", "=", 
    RowBox[{"-", "1"}]}], ",", " ", 
   RowBox[{
    FractionBox["1", "2"], "+", 
    RowBox[{
     FractionBox[
      RowBox[{" ", 
       SqrtBox["3"]}], "2"], "\[ImaginaryI]"}]}], ",", " ", 
   RowBox[{
    FractionBox["1", "2"], "-", 
    RowBox[{
     FractionBox[
      RowBox[{" ", 
       SqrtBox["3"]}], "2"], "\[ImaginaryI]"}]}]}]]],
 " -1, respectively.  (The roots themselves are located in the middle of the \
three largest colored regions.)  The complexity of this picture becomes \
apparent when you observe that, wherever two colors appear to meet, the third \
color emerges between them.  But then, a closer inspection of the area where \
this third color meets one of the other colors reveals again a different \
color between them.  This process continues with an infinite complexity."
}], "Text"],

Cell[TextData[{
 "\t\t",
 Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
  ImageSize->{350, 233},
  ImageMargins->0],
 "  \n\n\t\t",
 StyleBox[ButtonBox["Color Plate 1.",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/n2003/juliamandelbrotset/\
JuliaMandelbrotPlates/Links/JuliaMandelbrotPlates_lnk_1.html"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 "  ",
 StyleBox[ButtonBox["Newton's method applied to",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/n2003/juliamandelbrotset/\
JuliaMandelbrotPlates/Links/JuliaMandelbrotPlates_lnk_1.html"], None}],
  FontVariations->{"Underline"->True}],
 "  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    SuperscriptBox["z", "3"], "+", "1"}]}]],
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[". ",
  FontColor->RGBColor[0, 0, 1]]
}], "Text",
 CellChangeTimes->{{3.39965005884375*^9, 3.399650062078125*^9}, 
   3.3996501218125*^9, 3.399650171828125*^9, {3.399650272890625*^9, 
   3.39965030653125*^9}}],

Cell[TextData[{
 "\tThere appear to be no yellow regions with any area in Color plate 1, \
indicating that at least most initial guesses ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 " at a solution to ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["z", "3"], "+", "1"}], "=", "0"}]]],
 " will produce a sequence ",
 Cell[BoxData[
  RowBox[{"{", 
   SubscriptBox["z", "k"], "}"}]]],
 " that converges to one of the three roots.  Color plate 2 demonstrates that \
this outcome does not always occur.  It shows the results of applying the \
preceding algorithm to the polynomial ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    SuperscriptBox["z", "3"], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "0.26"}], "+", 
       RowBox[{"0.02", "\[ImaginaryI]"}]}], ")"}], "z"}], "+", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "0.74"}], "+", 
      RowBox[{"0.02", "\[ImaginaryI]"}]}], ")"}]}]}]]],
 ".  The yellow area shown is often referred to as the rabbit.  It consists \
of a main body and two ears.  Upon closer inspection (color plate 3) you can \
see that each of the ears consists of a main body and two ears.  Color plate \
2 is an example of a fractal image.  Mathematicians use the term fractal to \
indicate an object that have this kind of recursive structure."
}], "Text"],

Cell[TextData[{
 "\t\t",
 Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
  ImageSize->{350, 233},
  ImageMargins->0],
 "  \n\n\t\t",
 StyleBox[ButtonBox["Color Plate 2.",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/n2003/juliamandelbrotset/\
JuliaMandelbrotPlates/Links/JuliaMandelbrotPlates_lnk_2.html"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 "  ",
 StyleBox[ButtonBox["The rabbit fractal of",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/n2003/juliamandelbrotset/\
JuliaMandelbrotPlates/Links/JuliaMandelbrotPlates_lnk_2.html"], None}],
  FontVariations->{"Underline"->True}],
 "  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    SuperscriptBox["z", "3"], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "0.26"}], "+", 
       RowBox[{"0.02", "\[ImaginaryI]"}]}], ")"}], "z"}], "-", "0.74", "+", 
    RowBox[{"0.02", "\[ImaginaryI]"}]}]}]],
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[".  ",
  FontColor->RGBColor[0, 0, 1]]
}], "Text",
 CellChangeTimes->{{3.39965005884375*^9, 3.399650062078125*^9}, 
   3.399650116921875*^9, 3.399650183078125*^9, {3.399650270875*^9, 
   3.39965027115625*^9}, {3.39965031190625*^9, 3.399650317640625*^9}}],

Cell[TextData[{
 "\t\t",
 Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
  ImageSize->{350, 233},
  ImageMargins->0],
 "  \n\n\t\t",
 StyleBox[ButtonBox["Color Plate 3.",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/n2003/juliamandelbrotset/\
JuliaMandelbrotPlates/Links/JuliaMandelbrotPlates_lnk_3.html"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 "  ",
 StyleBox[ButtonBox["A zoom of the rabbit fractal of",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/n2003/juliamandelbrotset/\
JuliaMandelbrotPlates/Links/JuliaMandelbrotPlates_lnk_3.html"], None}],
  FontVariations->{"Underline"->True}],
 "  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    SuperscriptBox["z", "3"], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "0.26"}], "+", 
       RowBox[{"0.02", "\[ImaginaryI]"}]}], ")"}], "z"}], "-", "0.74", "+", 
    RowBox[{"0.02", "\[ImaginaryI]"}]}]}]],
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[".  ",
  FontColor->RGBColor[0, 0, 1]]
}], "Text",
 CellChangeTimes->{{3.39965005884375*^9, 3.399650062078125*^9}, 
   3.39965011215625*^9, 3.399650193171875*^9, {3.399650269234375*^9, 
   3.399650269625*^9}, {3.39965032634375*^9, 3.399650329671875*^9}}],

Cell[TextData[{
 "\tIn 1918 the French mathematicians ",
 StyleBox[ButtonBox["Gaston Julia",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Julia.\
html"], None}],
  FontVariations->{"Underline"->True}],
 " and ",
 StyleBox[ButtonBox["Pierre Fatou",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Fatou.\
html"], None}],
  FontVariations->{"Underline"->True}],
 " noticed the fractal phenomenon when exploring iterations of functions not \
necessarily connected with Newton's method.  Beginning with a function  f(z)  \
and a point  ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 ",  they computed the iterates  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], "=", 
   RowBox[{"f", 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}]}]]],
 ", ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "2"], "=", 
   RowBox[{"f", 
    RowBox[{"(", 
     SubscriptBox["z", "1"], ")"}]}]}]]],
 ", ... , ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", 
    RowBox[{"k", "+", "1"}]], "=", 
   RowBox[{"f", 
    RowBox[{"(", 
     SubscriptBox["z", "k"], ")"}]}]}]]],
 ", and investigated properties of the sequences  ",
 Cell[BoxData[
  RowBox[{"{", 
   SubscriptBox["z", "k"], "}"}]]],
 ".  Their findings did not receive a great deal of attention, in part \
because computer graphics were not available at this time.  With the recent \
proliferation of computers, it is not surprising that these investigations \
were revived in the 1980's.  Detailed studies of Newton's method and the more \
general topic of iteration were undertaken by a host of mathematicians \
including Curry, Douady, Garnett, Hubbard, ",
 StyleBox[ButtonBox["Mandelbrot",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/\
Mandelbrot.html"], None}],
  FontVariations->{"Underline"->True}],
 ", ",
 StyleBox[ButtonBox["Milnor",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Milnor.\
html"], None}],
  FontVariations->{"Underline"->True}],
 " and Sullivan.  We now turn our attention to some of their results by \
focusing on the iterates produced by quadratics of the form   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["f", "c"], 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    SuperscriptBox["z", "2"], "+", "c"}]}]]],
 ".  You will be surprised at the startling pictures that graphical iterates \
of such a simple functions produce."
}], "Text"],

Cell[TextData[{
 StyleBox["Example 4.9.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  For  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["f", "c"], 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    SuperscriptBox["z", "2"], "+", "c"}]}]]],
 ",  analyze all possible iterations when ",
 Cell[BoxData[
  RowBox[{"c", "=", "0"}]]],
 ", that is, for the function ",
 Cell[BoxData[
  SubscriptBox["f", "0"]]],
 " defined by  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["f", "0"], 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    SuperscriptBox["z", "2"], "+", "0"}]}]]],
 "."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "Solution.  We leave as an exercise the claim that, if  ",
 Cell[BoxData[
  RowBox[{"|", 
   SubscriptBox["z", "0"], "|", 
   RowBox[{"<", " ", "1"}]}]]],
 ",  the sequence will converge to ",
 StyleBox["0",
  FontFamily->"Courier New"],
 ";  if  ",
 Cell[BoxData[
  RowBox[{"|", 
   SubscriptBox["z", "0"], "|", 
   RowBox[{">", " ", "1"}]}]]],
 ",  the sequence will be unbounded;  and if  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", 
    SubscriptBox["z", "0"], "|"}], "=", " ", "1"}]]],
 ",  the sequence will either oscillate around the unit circle or converge to \
",
 StyleBox["1",
  FontFamily->"Courier New"],
 "."
}], "Text"],

Cell[TextData[{
 "\tFor the function ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["f", "c"], 
   RowBox[{"(", "z", ")"}]}]]],
 " defined by  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["f", "c"], 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    SuperscriptBox["z", "2"], "+", "c"}]}]]],
 ",  and an initial seed  ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 ",  the set of iterates given by  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], "=", 
   RowBox[{
    SubscriptBox["f", "c"], 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}]}]]],
 ", ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "2"], "=", 
   RowBox[{
    SubscriptBox["f", "c"], 
    RowBox[{"(", 
     SubscriptBox["z", "1"], ")"}]}]}]]],
 ", etc., are also called the ",
 StyleBox["orbits",
  FontColor->RGBColor[0, 0, 1]],
 " of  ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 "  generated by  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["f", "c"], 
   RowBox[{"(", "z", ")"}]}]]],
 ".  We let  ",
 Cell[BoxData[
  SubscriptBox["K", "c"]]],
 "  denote the set of points with bounded orbits for  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["f", "c"], 
   RowBox[{"(", "z", ")"}]}]]],
 ".  Example 4.9 shows that  ",
 Cell[BoxData[
  SubscriptBox["K", "0"]]],
 "  is the closed unit disk ",
 Cell[BoxData[
  RowBox[{
   OverscriptBox[
    SubscriptBox["D", "1"], "_"], 
   RowBox[{"(", "0", ")"}]}]]],
 ".  The boundary of  ",
 Cell[BoxData[
  SubscriptBox["K", "c"]]],
 "  is known as the ",
 StyleBox[ButtonBox["Julia set",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/JuliaSet.html"], None}],
  FontVariations->{"Underline"->True}],
 " for the function  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["f", "c"], 
   RowBox[{"(", "z", ")"}]}]]],
 ".  Thus the Julia set for  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["f", "0"], 
   RowBox[{"(", "z", ")"}]}]]],
 "  is the unit circle  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["C", "1"], 
   RowBox[{"(", "0", ")"}]}]]],
 ".  It turns out that  ",
 Cell[BoxData[
  SubscriptBox["K", "c"]]],
 "  is a nice simple set only when  ",
 Cell[BoxData[
  RowBox[{"c", "=", 
   RowBox[{
    RowBox[{"0", "  ", "or", "  ", "c"}], "=", 
    RowBox[{"-", "2"}]}]}]]],
 ".  Otherwise,   ",
 Cell[BoxData[
  SubscriptBox["K", "c"]]],
 "  is fractal.  Color plate 4 shows ",
 Cell[BoxData[
  SubscriptBox["K", 
   RowBox[{"-", "1.25"}]]]],
 ".  The variation in colors indicate the length of time it takes for points \
to become \"sufficiently unbounded\" according to the following algorithm, \
which uses the same notation as our algorithm for iterations via Newton's \
method."
}], "Text"],

Cell[TextData[{
 "\t\t",
 Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
  ImageSize->{350, 233},
  ImageMargins->0],
 "  \n\n\t\t",
 StyleBox[ButtonBox["Color Plate 4.",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/n2003/juliamandelbrotset/\
JuliaMandelbrotPlates/Links/JuliaMandelbrotPlates_lnk_4.html"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 "  ",
 StyleBox[ButtonBox["The Julia set for",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/n2003/juliamandelbrotset/\
JuliaMandelbrotPlates/Links/JuliaMandelbrotPlates_lnk_4.html"], None}],
  FontVariations->{"Underline"->True}],
 "  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["f", "c"], 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    RowBox[{
     SubscriptBox["f", 
      RowBox[{"-", "1.25"}]], 
     RowBox[{"(", "z", ")"}]}], "=", 
    RowBox[{
     SuperscriptBox["z", "2"], "-", "1.25"}]}]}]],
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[". ",
  FontColor->RGBColor[0, 0, 1]]
}], "Text",
 CellChangeTimes->{{3.39965005884375*^9, 3.399650062078125*^9}, 
   3.399650106484375*^9, 3.399650210203125*^9, {3.3996502668125*^9, 
   3.39965026728125*^9}, {3.399650339265625*^9, 3.39965034209375*^9}}],

Cell[TextData[{
 StyleBox["Extra Example 2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 " Plot the Julia set for ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["f", "c"], 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    RowBox[{
     SubscriptBox["f", 
      RowBox[{"-", "1.25"}]], 
     RowBox[{"(", "z", ")"}]}], "=", 
    RowBox[{
     SuperscriptBox["z", "2"], "-", "1.25"}]}]}]]],
 ". "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Extra Solution 2.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "Here is the subroutine from the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "  Journal."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"juliaC", " ", "=", 
     RowBox[{"Compile", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"x", ",", "y", ",", "lim", ",", "cx", ",", "cy"}], "}"}], ",",
        "\[IndentingNewLine]", 
       RowBox[{"Module", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"z", ",", 
           RowBox[{"ct", "=", "0"}]}], "}"}], ",", 
         RowBox[{
          RowBox[{"z", "=", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "y"}]}]}], ";", " ", 
          "\[IndentingNewLine]", 
          RowBox[{"While", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"Abs", "[", "z", "]"}], "<", "2.0"}], " ", "&&", " ", 
             RowBox[{"ct", "\[LessEqual]", "lim"}]}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"z", "=", 
              RowBox[{
               SuperscriptBox["z", "2"], "+", 
               RowBox[{"(", 
                RowBox[{"cx", "+", 
                 RowBox[{"\[ImaginaryI]", " ", "cy"}]}], ")"}]}]}], ";", " ", 
             
             RowBox[{"++", "ct"}]}]}], "]"}], ";", " ", "ct"}]}], "]"}]}], 
      " ", "]"}]}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{
  3.399026685484375*^9, {3.400260225390625*^9, 3.400260243453125*^9}}],

Cell[TextData[{
 "Here is the Julia set generated by the value  ",
 Cell[BoxData[
  RowBox[{"c", "=", 
   RowBox[{"-", "1.25"}]}]],
  CellChangeTimes->{{3.399026936390625*^9, 3.39902694453125*^9}}],
 ".  This is a fuzzy picture of Color Plate 4.  Increase the number of \
PlotPoints to get a sharper picture.  Also, it will increase the computing \
time.  It takes quite a bit of time with  ",
 Cell[BoxData[
  RowBox[{"PlotPoints", "\[Rule]", "200"}]]],
 ".  Things start to look better with  ",
 Cell[BoxData[
  RowBox[{"PlotPoints", "\[Rule]", "500"}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 CellChangeTimes->{{3.39902694740625*^9, 3.399026952484375*^9}},
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"DensityPlot", "[", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"juliaC", "[", 
       RowBox[{"x", ",", "y", ",", "50", ",", 
        RowBox[{"-", "1.25"}], ",", "0"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "1.5"}], ",", "1.5"}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "1.0"}], ",", "1.0"}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "200"}], ",", 
     RowBox[{"Mesh", "\[Rule]", "False"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["2", "3"]}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The Julia set generated by the value c = -1.25\>\"", 
     "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39902669378125*^9, 3.399026695671875*^9}, {
  3.4002601581875*^9, 3.4002601610625*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Notice.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 "  ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " does not produce graphs with the color scheme indicated in the book!"
}], "Text"]
}, Closed]],

Cell[TextData[{
 StyleBox["1.",
  FontColor->RGBColor[0, 0, 1]],
 "  Compute  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["f", "c"], 
   RowBox[{"(", 
    SubscriptBox["z", 
     RowBox[{"i", " ", "j"}]], ")"}]}]]],
 ".  Continue computing successive iterates of this initial point until the \
absolute value of one of the iterations exceeds a certain bound (say, ",
 StyleBox["L",
  FontFamily->"Courier New"],
 "), or until the number of iterations has exceeded a preassigned maximum. \n\
",
 StyleBox["2.",
  FontColor->RGBColor[0, 0, 1]],
 "  If Step 1 leaves us with an iteration whose absolute value exceeds ",
 StyleBox["L",
  FontFamily->"Courier New"],
 ", we color the entire rectangle ",
 Cell[BoxData[
  SubscriptBox["R", 
   RowBox[{"i", " ", "j"}]]]],
 " with a color indicating the number of iterations needed before this value \
was attained (the more iterations required, the darker the color).  \
Otherwise, we assume that the orbits of the initial point ",
 Cell[BoxData[
  SubscriptBox["z", 
   RowBox[{"i", " ", "j"}]]]],
 " do not diverge to infinity, and we color the entire rectangle black.\n\n\t\
Note, again, that this algorithm doesn't prove anything.  It merely guides \
the direction of our efforts to do rigorous mathematics."
}], "Text"],

Cell[TextData[{
 "\tColor plate 5 shows the Julia set for the function ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["f", "c"], 
   RowBox[{"(", "z", ")"}]}]]],
 ", where ",
 Cell[BoxData[
  RowBox[{"c", "=", 
   RowBox[{
    RowBox[{"-", "0.11"}], "-", 
    RowBox[{"0.67", "\[ImaginaryI]"}]}]}]]],
 ".  The boundary of this set is different from the boundaries of the other \
sets we have seen, in that it is disconnected.  Julia and Fatou independently \
discovered a simple criterion that can be used to tell when the Julia set for \
 ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["f", "c"], 
   RowBox[{"(", "z", ")"}]}]]],
 "  is connected or disconnected.  We state their result, but omit the proof, \
as it is beyond the scope of this text."
}], "Text"],

Cell[TextData[{
 "\t\t",
 Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
  ImageSize->{350, 233},
  ImageMargins->0],
 "  \n\n\t\t",
 StyleBox[ButtonBox["Color Plate 5.",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/n2003/juliamandelbrotset/\
JuliaMandelbrotPlates/Links/JuliaMandelbrotPlates_lnk_5.html"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 "  ",
 StyleBox[ButtonBox["A disconnected Julia set for",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/n2003/juliamandelbrotset/\
JuliaMandelbrotPlates/Links/JuliaMandelbrotPlates_lnk_5.html"], None}],
  FontVariations->{"Underline"->True}],
 "  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["f", "c"], 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    SuperscriptBox["z", "2"], "-", "0.11", "-", 
    RowBox[{"0.67", "\[ImaginaryI]"}]}]}]],
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[".  ",
  FontColor->RGBColor[0, 0, 1]]
}], "Text",
 CellChangeTimes->{{3.39965005884375*^9, 3.399650062078125*^9}, 
   3.399650102484375*^9, 3.399650221484375*^9, {3.399650264734375*^9, 
   3.399650265046875*^9}, {3.399650346484375*^9, 3.39965035009375*^9}}],

Cell[TextData[{
 StyleBox["Theorem 4.9.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  The boundary of  ",
 Cell[BoxData[
  SubscriptBox["K", "c"]]],
 "  is connected if and only if  ",
 Cell[BoxData[
  RowBox[{"0", "\[Epsilon]", " ", 
   SubscriptBox["K", "c"]}]]],
 ".  In other words, the Julia set for  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["f", "c"], 
   RowBox[{"(", "z", ")"}]}]]],
 "  is connected if and only if the orbits of  0  are bounded."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 4.9 is beyond the scope of this \
book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["The reader is encouraged to research this topic.", "Text"],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Julia Sets",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/JuliaSetsBib.html"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 4.10.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Show that the Julia set for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["f", "\[ImaginaryI]"], 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    SuperscriptBox["z", "2"], "+", "\[ImaginaryI]"}]}]]],
 "  is connected."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "Solution.  We apply Theorem 4.9 and compute the orbits of ",
 StyleBox["0",
  FontFamily->"Courier New"],
 " for ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["f", "\[ImaginaryI]"], 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    SuperscriptBox["z", "2"], "+", "\[ImaginaryI]"}]}]]],
 ".  We have  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["f", "\[ImaginaryI]"], 
    RowBox[{"(", "0", ")"}]}], "=", "\[ImaginaryI]"}]]],
 ",  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["f", "\[ImaginaryI]"], 
    RowBox[{"(", "0", ")"}]}], "=", 
   RowBox[{
    RowBox[{"-", "1"}], "+", "\[ImaginaryI]"}]}]]],
 ",  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["f", "\[ImaginaryI]"], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "\[ImaginaryI]"}], ")"}]}], "=", 
   RowBox[{"-", "\[ImaginaryI]"}]}]]],
 ",  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["f", "\[ImaginaryI]"], 
    RowBox[{"(", 
     RowBox[{"-", "\[ImaginaryI]"}], ")"}]}], "=", 
   RowBox[{
    RowBox[{"-", "1"}], "+", "\[ImaginaryI]"}]}]]],
 ".  Thus the orbits of ",
 StyleBox["0",
  FontFamily->"Courier New"],
 "  are the sequence  ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{"0", ",", "\[ImaginaryI]", ",", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "\[ImaginaryI]"}], ",", 
    RowBox[{"-", "\[ImaginaryI]"}], ",", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "\[ImaginaryI]"}], ",", 
    RowBox[{"-", "\[ImaginaryI]"}], ",", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "\[ImaginaryI]"}], ",", 
    RowBox[{"-", "\[ImaginaryI]"}], ",", "..."}], "}"}]]],
 ",  which is clearly a bounded sequence.  Thus, by Theorem 4.9, the Julia \
set for ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["f", "\[ImaginaryI]"], 
   RowBox[{"(", "z", ")"}]}]]],
 " is connected."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Explore ",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 StyleBox["Solution 4.10.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "We apply Theorem 4.8 and compute the orbit of  0  for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["f", "\[ImaginaryI]"], 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    SuperscriptBox["z", "2"], "+", "\[ImaginaryI]"}]}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", 
     RowBox[{"z", ",", "Z"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "i"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", 
     RowBox[{
      SuperscriptBox["z", "2"], "+", "\[ImaginaryI]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Z", "=", 
     RowBox[{"NestList", "[", 
      RowBox[{"f", ",", "0", ",", "10"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(f\), \(\[ImaginaryI]\)]\)(z) = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(0\)]\) = \>\"", ",", "0"}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      SubscriptBox["\"\<z\>\"", "1"], ",", 
      "\"\< = \!\(\*SubscriptBox[\(f\), \(\[ImaginaryI]\)]\)(\>\"", ",", 
      SubscriptBox["\"\<z\>\"", "0"], ",", 
      "\"\<) =  \!\(\*SubscriptBox[\(f\), \(\[ImaginaryI]\)]\)(\>\"", ",", 
      "0", " ", ",", "\"\<) = \>\"", ",", "\"\<\\t\>\"", ",", 
      SubscriptBox["Z", 
       RowBox[{"\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]]}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"i", "=", "1"}], ",", 
      RowBox[{"i", "\[LessEqual]", "9"}], ",", 
      RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Print", "[", 
        RowBox[{
         SubscriptBox["\"\<z\>\"", 
          RowBox[{"i", "+", "1"}]], ",", 
         "\"\< = \!\(\*SubscriptBox[\(f\), \(\[ImaginaryI]\)]\)(\>\"", ",", 
         SubscriptBox["\"\<z\>\"", "i"], ",", 
         "\"\<) =  \!\(\*SubscriptBox[\(f\), \(\[ImaginaryI]\)]\)(\>\"", ",", 
         
         SubscriptBox["Z", 
          RowBox[{"\[LeftDoubleBracket]", 
           RowBox[{"i", "+", "1"}], "\[RightDoubleBracket]"}]], " ", ",", 
         "\"\<) = \>\"", ",", "\"\<\\t\>\"", ",", 
         SubscriptBox["Z", 
          RowBox[{"\[LeftDoubleBracket]", 
           RowBox[{"i", "+", "2"}], "\[RightDoubleBracket]"}]]}], "]"}], 
       ";"}]}], "  ", "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39902680759375*^9}],

Cell[TextData[{
 "Thus, the orbit of  0  is the sequence  ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{"0", ",", "\[ImaginaryI]", ",", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "\[ImaginaryI]"}], ",", 
    RowBox[{"-", "\[ImaginaryI]"}], ",", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "\[ImaginaryI]"}], ",", 
    RowBox[{"-", "\[ImaginaryI]"}], ",", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "\[ImaginaryI]"}], ",", 
    RowBox[{"-", "\[ImaginaryI]"}], ",", "..."}], "}"}]]],
 "  which is clearly a bounded sequence.  Thus, by Theorem 4.9, the Julia set \
for  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["f", "\[ImaginaryI]"], 
   RowBox[{"(", "z", ")"}]}]]],
 "  is connected."
}], "Text"]
}, Closed]],

Cell[TextData[{
 "\tIn 1980, the Polish born mathematician ",
 StyleBox[ButtonBox["Benoit Mandelbrot",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/\
Mandelbrot.html"], None}],
  FontVariations->{"Underline"->True}],
 " used computer graphics to study the following set:  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{"M", "  ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"c", ":", " ", 
     RowBox[{
      StyleBox["the",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox[" ",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox["Julia",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox[" ",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox["set",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox[" ",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox["for",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], " ", 
      SubscriptBox["f", "c"], 
      RowBox[{"(", "z", ")"}], " ", 
      StyleBox["is",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox[" ",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox["connected",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]]}]}], "}"}]}], "\n", 
  RowBox[{"M", "  ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"c", ":", " ", 
     RowBox[{
      StyleBox["the",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox[" ",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox["orbits",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox[" ",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox["of",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "  ", "0", "  ", 
      StyleBox["determined",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox[" ",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox["by",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], " ", 
      SubscriptBox["f", "c"], 
      RowBox[{"(", "z", ")"}], " ", 
      StyleBox["are",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox[" ",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox["bounded",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]]}]}], "}"}]}]}]],
 "   "
}], "Text"],

Cell[TextData[{
 "\tThe set ",
 StyleBox["M",
  FontFamily->"Courier New"],
 " has come to be known as the ",
 StyleBox[ButtonBox["Mandelbrot Set",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/MandelbrotSet.html"], None}],
  FontVariations->{"Underline"->True}],
 ".  Color plate 6 shows its intricate nature. Technically, the Mandelbrot \
set is not fractal because it is not self-similar (although it may look that \
way).  However, it is infinitely complex.  Color plate 7 shows a zoom over \
the upper portion of the set shown in color plate 6.  Likewise, color plate 8 \
zooms in on the upper portion of color plate 7.  In color plate 8 you can see \
the emergence of another structure very similar to the Mandelbrot set that we \
began with.  Although it isn't an exact replica, if you zoomed in on this set \
at almost any spot, you would eventually see yet another \"Mandelbrot clone\" \
and so on ad infinitum!  In the remainder of this section we look at some of \
the properties of this amazing set."
}], "Text"],

Cell[TextData[{
 "\t\t",
 Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
  ImageSize->{350, 233},
  ImageMargins->0],
 "  \n\n\t\t",
 StyleBox[ButtonBox["Color Plate 6.",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/n2003/juliamandelbrotset/\
JuliaMandelbrotPlates/Links/JuliaMandelbrotPlates_lnk_6.html"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 "  ",
 StyleBox[ButtonBox["The Mandelbrot set M.",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/n2003/juliamandelbrotset/\
JuliaMandelbrotPlates/Links/JuliaMandelbrotPlates_lnk_6.html"], None}],
  FontVariations->{"Underline"->True}]
}], "Text",
 CellChangeTimes->{{3.39965005884375*^9, 3.399650062078125*^9}, 
   3.3996500955*^9, {3.399650236203125*^9, 3.399650262140625*^9}, {
   3.3996503589375*^9, 3.399650360390625*^9}}],

Cell[TextData[{
 "\t\t",
 Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
  ImageSize->{350, 233},
  ImageMargins->0],
 "  \n\n\t\t",
 StyleBox[ButtonBox["Color Plate 7.",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/n2003/juliamandelbrotset/\
JuliaMandelbrotPlates/Links/JuliaMandelbrotPlates_lnk_7.html"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 "  ",
 StyleBox[ButtonBox["A zoom of the upper portion of the Mandelbrot set M.",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/n2003/juliamandelbrotset/\
JuliaMandelbrotPlates/Links/JuliaMandelbrotPlates_lnk_7.html"], None}],
  FontVariations->{"Underline"->True}]
}], "Text",
 CellChangeTimes->{{3.39965005884375*^9, 3.399650090171875*^9}, {
  3.39965024540625*^9, 3.39965026075*^9}, {3.399650362125*^9, 
  3.3996503636875*^9}}],

Cell[TextData[{
 "\t\t",
 Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
  ImageSize->{350, 233},
  ImageMargins->0],
 "  \n\n\t\t",
 StyleBox[ButtonBox["Color Plate 8.",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/n2003/juliamandelbrotset/\
JuliaMandelbrotPlates/Links/JuliaMandelbrotPlates_lnk_8.html"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 "  ",
 StyleBox[ButtonBox["A zoom of the upper portion of the Color Plate 7.",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/n2003/juliamandelbrotset/\
JuliaMandelbrotPlates/Links/JuliaMandelbrotPlates_lnk_8.html"], None}],
  FontVariations->{"Underline"->True}]
}], "Text",
 CellChangeTimes->{{3.39965005884375*^9, 3.399650086484375*^9}, {
  3.399650254578125*^9, 3.399650258796875*^9}, {3.39965036459375*^9, 
  3.399650365796875*^9}}],

Cell[TextData[{
 StyleBox["Example 4.11.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Show that ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{"c", ":", 
    RowBox[{"|", "z", "|", 
     RowBox[{"\[LessEqual]", 
      FractionBox["1", "4"]}]}]}], "}"}]]],
 " is a subset of the Mandelbrot set  M. "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "Solution.  Let ",
 Cell[BoxData[
  SubsuperscriptBox[
   RowBox[{"{", 
    SubscriptBox["a", "n"], "}"}], 
   RowBox[{"n", "=", "0"}], "\[Infinity]"]]],
 " be the orbits of ",
 StyleBox["0",
  FontFamily->"Courier New"],
 " generated by ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["f", "c"], 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    SuperscriptBox["z", "2"], "+", "c"}]}]]],
 ", where ",
 Cell[BoxData[
  RowBox[{"|", "z", "|", 
   RowBox[{"\[LessEqual]", 
    FractionBox["1", "4"]}]}]]],
 ".  Then\n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   SubscriptBox["a", "0"], " ", "=", " ", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "0", ")"}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{"0", "+", "c"}], " ", "=", " ", "c"}]}]}], "\n", 
  RowBox[{
   SubscriptBox["a", "1"], " ", "=", " ", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", 
      SubscriptBox["a", "0"], ")"}]}], " ", "=", " ", 
    RowBox[{
     SubsuperscriptBox["a", "0", "2"], "+", "c"}]}]}], "\n", 
  RowBox[{
   SubscriptBox["a", "2"], " ", "=", " ", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", 
      SubscriptBox["a", "1"], ")"}]}], " ", "=", " ", 
    RowBox[{
     SubsuperscriptBox["a", "1", "2"], "+", "c"}]}]}], "\n", 
  StyleBox[
   RowBox[{"in", " ", "general"}],
   FontFamily->"Times New Roman"], "\n", 
  RowBox[{
   SubscriptBox["a", 
    RowBox[{"n", "+", "1"}]], " ", "=", " ", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", 
      SubscriptBox["a", "n"], ")"}]}], " ", "=", " ", 
    RowBox[{
     SubsuperscriptBox["a", "n", "2"], "+", "c"}]}]}]}]],
 "  "
}], "Text"],

Cell[TextData[{
 "We show that ",
 Cell[BoxData[
  SubsuperscriptBox[
   RowBox[{"{", 
    SubscriptBox["a", "n"], "}"}], 
   RowBox[{"n", "=", "0"}], "\[Infinity]"]]],
 " is bounded, and, in particular, we show that ",
 Cell[BoxData[
  RowBox[{"|", 
   SubscriptBox["a", "n"], "|", 
   RowBox[{"\[LessEqual]", 
    FractionBox["1", "2"]}]}]]],
 " for all n by mathematical induction.  Clearly ",
 Cell[BoxData[
  RowBox[{"|", 
   SubscriptBox["a", "n"], "|", 
   RowBox[{"\[LessEqual]", 
    FractionBox["1", "2"]}]}]]],
 " if ",
 Cell[BoxData[
  RowBox[{"n", "=", 
   RowBox[{"0", " ", 
    StyleBox["or",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], " ", "1"}]}]]],
 ".  We assume that ",
 Cell[BoxData[
  RowBox[{"|", 
   SubscriptBox["a", "n"], "|", 
   RowBox[{"\[LessEqual]", 
    FractionBox["1", "2"]}]}]]],
 " for some value of ",
 Cell[BoxData[
  RowBox[{"n", "\[GreaterEqual]", "1"}]]],
 " (our goal is to show ",
 Cell[BoxData[
  RowBox[{"|", 
   SubscriptBox["a", 
    RowBox[{"n", "+", "1"}]], "|", 
   RowBox[{"\[LessEqual]", 
    FractionBox["1", "2"]}]}]]],
 ").  Now,  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", 
    SubscriptBox["a", 
     RowBox[{"n", "+", "1"}]], "|"}], "  ", "=", "  ", 
   RowBox[{"|", 
    RowBox[{
     SubsuperscriptBox["a", "n", "2"], "+", "c"}], "|", " "}]}]]],
 "\n\t\t\t",
 Cell[BoxData[
  RowBox[{"                 ", 
   RowBox[{"\[LessEqual]", "  ", 
    RowBox[{"|", 
     SubsuperscriptBox["a", "n", "2"], "|", 
     RowBox[{"+", 
      RowBox[{"|", "c", "|", "  "}]}]}]}]}]]],
 "\n\t\t\t",
 Cell[BoxData[
  RowBox[{"                 ", 
   RowBox[{
    RowBox[{"\[LessEqual]", "  ", 
     RowBox[{
      FractionBox["1", "4"], "+", 
      FractionBox["1", "4"]}]}], " ", "=", " ", 
    FractionBox["1", "2"]}]}]]],
 " "
}], "Text"],

Cell[TextData[{
 "\tIn the exercises, we ask you to show that, if ",
 Cell[BoxData[
  RowBox[{"|", "c", "|", 
   RowBox[{">", "2"}]}]]],
 ", then ",
 StyleBox["c",
  FontFamily->"Courier New"],
 " is not in the set ",
 StyleBox["M",
  FontFamily->"Courier New"],
 ".  Thus the Mandelbrot set depicted in color plate 6 contains \nthe disk  \
",
 Cell[BoxData[
  RowBox[{
   OverscriptBox[
    SubscriptBox["D", 
     FractionBox["1", "4"]], "_"], 
   RowBox[{"(", "0", ")"}]}]]],
 " and is contained in the disk ",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{
    OverscriptBox[
     SubscriptBox["D", "2"], "_"], 
    RowBox[{"(", "0", ")"}]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "    \tWe can use other methods to determine which points belong to ",
 StyleBox["M",
  FontFamily->"Courier New"],
 ".  To do so, we need some additional vocabulary."
}], "Text"],

Cell[TextData[{
 StyleBox["Definition 4.6 (Fixed Point).",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  The point  ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 "  is a fixed point for the function  ",
 StyleBox["f",
  FontFamily->"Courier New"],
 "  if  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}], "=", 
   SubscriptBox["z", "0"]}]]],
 "."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Definition 4.7 (Attracting Point).",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  The point  ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 "  is an attracting point for the function  ",
 StyleBox["f",
  FontFamily->"Courier New"],
 "  if  ",
 Cell[BoxData[
  RowBox[{"|", 
   RowBox[{
    RowBox[{"f", "'"}], 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}], "|", 
   RowBox[{"<", " ", "1"}]}]]],
 "."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
\tTheorems 4.10 and 4.11 explain the significance of these terms.\
\>", "Text"],

Cell[TextData[{
 StyleBox["Theorem 4.10.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Suppose that ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 "  is an attracting fixed point for the function  f.  Then there is a disk  \
",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["D", "r"], 
   RowBox[{"(", 
    SubscriptBox["z", "0"], ")"}]}]]],
 "  about  ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 "  such that the iterates of all the points in ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["D", "r"], 
   RowBox[{"(", 
    SubscriptBox["z", "0"], ")"}]}]]],
 "  are dawn toward the point  ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 "  in the sense that, if  ",
 Cell[BoxData[
  RowBox[{"z", "\[Element]", 
   RowBox[{
    SubsuperscriptBox["D", "r", "*"], 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}]}]]],
 ", then  ",
 Cell[BoxData[
  RowBox[{"|", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "-", 
    SubscriptBox["z", "0"]}], "|", 
   RowBox[{"<", 
    RowBox[{"|", 
     RowBox[{"z", "-", 
      SubscriptBox["z", "0"]}], "|"}]}]}]]],
 ".  In fact, if ",
 Cell[BoxData[
  SubscriptBox["z", "k"]]],
 " is the ",
 Cell[BoxData[
  SuperscriptBox["k", "th"]]],
 " iterate of ",
 Cell[BoxData[
  RowBox[{"z", "\[Element]", 
   RowBox[{
    SubsuperscriptBox["D", "r", "*"], 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}]}]]],
 ", then ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    UnderscriptBox["lim", 
     RowBox[{"k", "\[Rule]", "\[Infinity]"}]], " ", 
    SubscriptBox["z", "k"]}], " ", "=", " ", 
   SubscriptBox["z", "0"]}]]],
 ". "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 4.10 is in the book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
 "\tIn 1905, ",
 StyleBox[ButtonBox["Pierre Fatou",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Fatou.\
html"], None}],
  FontVariations->{"Underline"->True}],
 " showed that, if the function ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["f", "c"], 
   RowBox[{"(", "z", ")"}]}]]],
 " defined by ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["f", "c"], 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    SuperscriptBox["z", "2"], "+", "c"}]}]]],
 " has attracting fixed points, then the orbits of ",
 StyleBox["0",
  FontFamily->"Courier New"],
 " determined by ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["f", "c"], 
   RowBox[{"(", "z", ")"}]}]]],
 " must converge to one of them.  Because a convergent sequence is bounded, \
this condition implies that c must belong to M.  In the exercises we ask you \
to show that the main cardioid-shaped body of M in color plate 6 is composed \
of those points c for which ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["f", "c"], 
   RowBox[{"(", "z", ")"}]}]]],
 " has attracting fixed points.  You will find Theorem 4.10 to be a useful \
characterization of those points."
}], "Text"],

Cell[TextData[{
 StyleBox["Theorem 4.11.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  The function ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["f", "c"], 
   RowBox[{"(", "z", ")"}]}]]],
 " defined by ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["f", "c"], 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    SuperscriptBox["z", "2"], "+", "c"}]}]]],
 " has attracting fixed points iff ",
 Cell[BoxData[
  RowBox[{"|", 
   RowBox[{"1", "+", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"4", "c"}]}], ")"}], 
     RowBox[{"1", "/", "2"}]]}], "|", 
   RowBox[{"<", " ", "1"}]}]]],
 "  or  ",
 Cell[BoxData[
  RowBox[{"|", 
   RowBox[{"1", "-", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"4", "c"}]}], ")"}], 
     RowBox[{"1", "/", "2"}]]}], "|", 
   RowBox[{"<", " ", "1"}]}]]],
 ",  where the square root designates the principal square root function. "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 4.11 is in the book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
 StyleBox["Definition 4.8 (",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["n-Cycle",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/MapCycle.html"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 StyleBox[").",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  An n-cycle for a function  f  is a set  ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{
    SubscriptBox["z", "0"], ",", 
    SubscriptBox["z", "1"], ",", "...", ",", 
    SubscriptBox["z", 
     RowBox[{"n", "-", "1"}]]}], "}"}]]],
 "  of  n  complex numbers such that  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "k"], "=", 
   RowBox[{"f", 
    RowBox[{"(", 
     SubscriptBox["z", 
      RowBox[{"k", "-", "1"}]], ")"}]}]}]]],
 "  for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"k", "=", "1"}], ",", "2", ",", "...", ",", 
   RowBox[{"n", "-", "1"}]}]]],
 ",  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", 
     SubscriptBox["z", 
      RowBox[{"n", "-", "1"}]], ")"}]}], "=", 
   SubscriptBox["z", "0"]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Definition 4.9 (Attracting n-Cycle).",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  An n-cycle  ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{
    SubscriptBox["z", "0"], ",", 
    SubscriptBox["z", "1"], ",", "...", ",", 
    SubscriptBox["z", 
     RowBox[{"n", "-", "1"}]]}], "}"}]]],
 "  for a function  f   is said to be attracting if  ",
 Cell[BoxData[
  RowBox[{"|", 
   RowBox[{
    SubsuperscriptBox["g", "n", "'"], 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}], "|", 
   RowBox[{"<", " ", "1"}]}]]],
 ",  where  ",
 Cell[BoxData[
  SubscriptBox["g", "n"]]],
 "  is the composition of  f  with itself  n  times.  For example, if n = 2, \
then ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["g", "2"], 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{"f", 
    RowBox[{"(", 
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], ")"}]}]}]]],
 ". "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Example 4.12.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Example 4.10 shows that  ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "1"}], "+", "\[ImaginaryI]"}], ",", 
    RowBox[{"-", "\[ImaginaryI]"}]}], "}"}]]],
 "  is a 2-cycle for the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["f", "\[ImaginaryI]"], 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    SuperscriptBox["z", "2"], "+", "\[ImaginaryI]"}]}]]],
 ".  It is not an attracting 2-cycle because  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["g", "2"], 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    SuperscriptBox["z", "4"], "+", 
    RowBox[{"2", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["z", "2"]}], "+", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "\[ImaginaryI]"}], ")"}]}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubsuperscriptBox["g", "2", "'"], 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"4", " ", 
     SuperscriptBox["z", "3"]}], "+", 
    RowBox[{"4", " ", "\[ImaginaryI]", " ", "z"}]}]}]]],
 ".  Hence  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", 
    RowBox[{
     SubsuperscriptBox["g", "2", "'"], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "\[ImaginaryI]"}], ")"}]}], "|"}], " ", "=", 
   " ", 
   RowBox[{
    RowBox[{"|", 
     RowBox[{
      RowBox[{"4", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[ImaginaryI]"}], ")"}], "3"]}], "+", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[ImaginaryI]"}], ")"}]}]}], "|"}], " ", 
    "=", " ", 
    RowBox[{"|", 
     RowBox[{"4", "+", 
      RowBox[{"4", " ", "\[ImaginaryI]"}]}], "|"}]}]}]]],
 ",  so that  ",
 Cell[BoxData[
  RowBox[{"|", 
   RowBox[{
    SubsuperscriptBox["g", "2", "'"], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "\[ImaginaryI]"}], ")"}]}], "|", 
   RowBox[{">", "1"}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 4.12.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "Enter the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], "=", 
   RowBox[{
    SuperscriptBox["z", "2"], "+", "\[ImaginaryI]"}]}]]],
 "  and point  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "0"], "=", 
   RowBox[{
    RowBox[{"-", "1"}], "+", "\[ImaginaryI]"}]}]]],
 "  and determine if  ",
 Cell[BoxData[
  RowBox[{"|", 
   RowBox[{
    SubsuperscriptBox["g", "n", "'"], 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}], "|", 
   RowBox[{"<", " ", "1"}]}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", 
     RowBox[{"z", ",", "Z"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "g2"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", 
     RowBox[{
      SuperscriptBox["z", "2"], "+", "\[ImaginaryI]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"g2", "[", "z_", "]"}], "=", 
     RowBox[{"Apart", "[", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"f", "[", 
        RowBox[{"f", "[", "z", "]"}], "]"}], "]"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "0"], "=", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "\[ImaginaryI]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(f\), \(\[ImaginaryI]\)]\)[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<\!\(\*SubscriptBox[\(g\), \(2\)]\)[z] = \!\(\*SubscriptBox[\(f\), \
\(\[ImaginaryI]\)]\)[\!\(\*SubscriptBox[\(f\), \(\[ImaginaryI]\)]\)[z]]\>\"", 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(g\), \(2\)]\)[z] = \!\(\*SubscriptBox[\(f\), \
\(\[ImaginaryI]\)]\)[\>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\<]\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(g\), \(2\)]\)[z] = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"f", "[", "z", "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(g\), \(2\)]\)[z] = \>\"", ",", 
      RowBox[{"g2", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(g\), \(2\), \('\)]\)[z] = \>\"", ",", 
      RowBox[{
       RowBox[{"g2", "'"}], "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< \!\(\*SubsuperscriptBox[\(g\), \(2\), \('\)]\)[\>\"", ",", 
      SubscriptBox["Z", "0"], ",", "\"\<]  =  \>\"", ",", 
      RowBox[{
       RowBox[{"g2", "'"}], "[", 
       SubscriptBox["Z", "0"], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<|\!\(\*SubsuperscriptBox[\(g\), \(2\), \('\)]\)[\>\"", ",", 
      SubscriptBox["Z", "0"], ",", "\"\<]| = |\>\"", ",", 
      RowBox[{
       RowBox[{"g2", "'"}], "[", 
       SubscriptBox["Z", "0"], "]"}], ",", "\"\<|\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<|\!\(\*SubsuperscriptBox[\(g\), \(2\), \('\)]\)[\>\"", ",", 
      SubscriptBox["Z", "0"], ",", "\"\<]| = \>\"", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{
        RowBox[{"g2", "'"}], "[", 
        SubscriptBox["Z", "0"], "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Is  |\!\(\*SubsuperscriptBox[\(g\), \(2\), \('\)]\)[\>\"", ",", 
      SubscriptBox["Z", "0"], ",", "\"\<]| < 1 ?  \>\"", ",", 
      RowBox[{
       RowBox[{"Abs", "[", 
        RowBox[{
         RowBox[{"g2", "'"}], "[", 
         SubscriptBox["Z", "0"], "]"}], "]"}], "<", "1"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Is  |\!\(\*SubsuperscriptBox[\(g\), \(2\), \('\)]\)[\>\"", ",", 
      SubscriptBox["Z", "0"], ",", "\"\<]| > 1 ?  \>\"", ",", 
      RowBox[{
       RowBox[{"Abs", "[", 
        RowBox[{
         RowBox[{"g2", "'"}], "[", 
         SubscriptBox["Z", "0"], "]"}], "]"}], ">", "1"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399026826390625*^9}],

Cell[TextData[{
 "We have shown that ",
 Cell[BoxData[
  RowBox[{"|", 
   RowBox[{
    SubsuperscriptBox["g", "2", "'"], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "\[ImaginaryI]"}], ")"}]}], "|", 
   RowBox[{">", "1"}]}]]],
 ".  Therefore,  ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "1"}], "+", "\[ImaginaryI]"}], ",", 
    RowBox[{"-", "\[ImaginaryI]"}]}], "}"}]]],
 "  is not an attracting 2-cycle."
}], "Text"]
}, Closed]],

Cell[TextData[{
 "\tIn the exercises, we ask you to show that, if ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{
    SubscriptBox["z", "0"], ",", 
    SubscriptBox["z", "1"], ",", "...", ",", 
    SubscriptBox["z", 
     RowBox[{"n", "-", "1"}]]}], "}"}]]],
 " is an attracting ",
 StyleBox["n",
  FontFamily->"Courier New"],
 "-cycle for a function ",
 StyleBox["f",
  FontFamily->"Courier New"],
 ", then not only does ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 " \nsatisfy  ",
 Cell[BoxData[
  RowBox[{"|", 
   RowBox[{
    SubsuperscriptBox["g", "n", "'"], 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}], "|", 
   RowBox[{"<", " ", "1"}]}]]],
 ",  but also that  ",
 Cell[BoxData[
  RowBox[{"|", 
   RowBox[{
    SubsuperscriptBox["g", "n", "'"], 
    RowBox[{"(", 
     SubscriptBox["z", "k"], ")"}]}], "|", 
   RowBox[{"<", " ", "1"}]}]]],
 ",  for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"k", "=", "1"}], ",", "2", ",", "...", ",", 
   RowBox[{"n", "-", "1"}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "\tIt turns out that the large disk to the left of the cardioid in color \
plate 6 consists of those points c for which ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["f", "c"], 
   RowBox[{"(", "z", ")"}]}]]],
 " has a 2-cycle.  The large disks above and below the main cardioid disk are \
the points c for which ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["f", "c"], 
   RowBox[{"(", "z", ")"}]}]]],
 " has a 3-cycle."
}], "Text"],

Cell["\<\
\tContinuing with this scheme, we see that the idea of n-cycles explains the \
appearance of the \"buds\" that you see on color plate 6.  It does not, \
however, begin to do justice to the enormous complexity of the entire set.  \
Even color plates 7 and 8 are mere glimpses into its awesome beauty.  In the \
exercises, we suggest several references for projects that you could pursue \
for a more detailed study of topics relating to those covered in this \
section.\
\>", "Text"],

Cell[TextData[{
 StyleBox["Extra Example 3.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 " Plot the Mandelbrot set."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Extra Solution 3.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "This modification of the  juliaC  code can be used to plot the Mandelbrot \
set.\n\nHere is the subroutine from the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "  Journal."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"mandelbrotC", "=", 
     RowBox[{"Compile", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"x", ",", "y", ",", "lim"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Module", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"z", ",", 
           RowBox[{"ct", "=", "0"}]}], "}"}], ",", 
         RowBox[{
          RowBox[{"z", "=", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "y"}]}]}], ";", " ", 
          "\[IndentingNewLine]", 
          RowBox[{"While", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"Abs", "[", "z", "]"}], "<", "2.0"}], " ", "&&", " ", 
             RowBox[{"ct", "\[LessEqual]", "lim"}]}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"z", "=", 
              RowBox[{
               SuperscriptBox["z", "2"], "+", 
               RowBox[{"(", 
                RowBox[{"x", "+", 
                 RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}]}], ";", " ", 
             RowBox[{"++", "ct"}]}]}], "]"}], ";", " ", "ct"}]}], "]"}]}], 
      " ", "]"}]}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399026835734375*^9}],

Cell[TextData[{
 "This is a fuzzy picture of Color Plate 6. Increase the number of PlotPoints \
to get a sharper picture.  Also, it will increase the computing time.  It \
takes quite a bit of time with  ",
 Cell[BoxData[
  RowBox[{"PlotPoints", "\[Rule]", "200"}]]],
 ".  Things start to look better with  ",
 Cell[BoxData[
  RowBox[{"PlotPoints", "\[Rule]", "500"}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"DensityPlot", "[", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"mandelbrotC", "[", 
       RowBox[{"x", ",", "y", ",", "50"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "2.0"}], ",", "0.55"}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "1.15"}], ",", "1.15"}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "200"}], ",", " ", 
     RowBox[{"Mesh", "\[Rule]", "False"}], ",", 
     RowBox[{"Frame", "\[Rule]", "False"}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The Mandelbrot set.\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39902684115625*^9, 3.39902684353125*^9}, {
  3.400260171578125*^9, 3.400260173453125*^9}}],

Cell[TextData[{
 StyleBox["Notice.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 "  ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " does not produce graphs with the color scheme indicated in the book!"
}], "Text"]
}, Closed]],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Julia Sets",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/JuliaSetsBib.html"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Mandelbrot Set",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/MandelbrotSetBib.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Fractals",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/FractalBib.html"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/complex.html"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2008 John H. Mathews, Russell W. \
Howell",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/"], None}],
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[0, 1, 0]]], "Text",
 CellChangeTimes->{{3.399026362140625*^9, 3.399026362265625*^9}}]
},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{946, 622},
WindowMargins->{{17, Automatic}, {Automatic, 0}},
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "CHAPTER 1"->{
  Cell[568, 21, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"],
  Cell[439471, 8731, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"],
  Cell[442404, 8840, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"CHAPTER 1", 460172, 9443}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"],
Cell[905, 32, 118, 2, 29, "Text"],
Cell[1026, 36, 640, 14, 65, "Text"],
Cell[1669, 52, 3471, 115, 159, "Text"],
Cell[5143, 169, 677, 27, 35, "Text",
 Evaluatable->False],
Cell[5823, 198, 653, 23, 41, "Text"],
Cell[6479, 223, 696, 23, 47, "Text"],
Cell[7178, 248, 3951, 110, 179, "Text"],
Cell[11132, 360, 4877, 208, 288, "Text"],
Cell[CellGroupData[{
Cell[16034, 572, 156, 4, 29, "Text",
 Evaluatable->False],
Cell[16193, 578, 213, 8, 29, "Text"],
Cell[16409, 588, 2260, 65, 323, "Input"],
Cell[18672, 655, 228, 9, 29, "Text"],
Cell[18903, 666, 1351, 37, 132, "Input"],
Cell[20257, 705, 205, 8, 29, "Text"],
Cell[20465, 715, 2312, 65, 193, "Input"],
Cell[22780, 782, 431, 15, 47, "Text"]
}, Closed]],
Cell[23226, 800, 300, 5, 44, "Text"],
Cell[23529, 807, 393, 14, 29, "Text",
 Evaluatable->False],
Cell[23925, 823, 1871, 67, 95, "Text"],
Cell[25799, 892, 922, 36, 62, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[26746, 932, 160, 4, 29, "Text",
 Evaluatable->False],
Cell[26909, 938, 200, 8, 29, "Text"],
Cell[27112, 948, 2884, 81, 312, "Input"],
Cell[29999, 1031, 1039, 37, 62, "Text"],
Cell[31041, 1070, 567, 18, 110, "Input"],
Cell[31611, 1090, 541, 18, 44, "Text"],
Cell[32155, 1110, 2440, 64, 280, "Input"],
Cell[34598, 1176, 249, 9, 29, "Text"],
Cell[34850, 1187, 1428, 34, 235, "Input"],
Cell[36281, 1223, 325, 10, 29, "Text"],
Cell[36609, 1235, 232, 8, 29, "Text"]
}, Closed]],
Cell[36856, 1246, 1407, 45, 97, "Text"],
Cell[38266, 1293, 1219, 43, 59, "Text"],
Cell[39488, 1338, 542, 17, 51, "Text"],
Cell[40033, 1357, 2204, 51, 190, "Text"],
Cell[42240, 1410, 25107, 428, 286, "Text"],
Cell[67350, 1840, 1381, 37, 101, "Text"],
Cell[68734, 1879, 77346, 1286, 286, "Text"],
Cell[146083, 3167, 70813, 1179, 286, "Text"],
Cell[216899, 4348, 2594, 76, 137, "Text"],
Cell[219496, 4426, 678, 29, 29, "Text",
 Evaluatable->False],
Cell[220177, 4457, 653, 24, 47, "Text"],
Cell[220833, 4483, 2674, 105, 101, "Text"],
Cell[223510, 4590, 33942, 576, 286, "Text"],
Cell[257455, 5168, 480, 20, 29, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[257960, 5192, 160, 4, 29, "Text",
 Evaluatable->False],
Cell[258123, 5198, 173, 7, 29, "Text",
 Evaluatable->False],
Cell[258299, 5207, 1392, 38, 141, "Input"],
Cell[259694, 5247, 687, 18, 47, "Text",
 Evaluatable->False],
Cell[260384, 5267, 1025, 27, 133, "Input"],
Cell[261412, 5296, 232, 8, 29, "Text"]
}, Closed]],
Cell[261659, 5307, 1269, 34, 140, "Text"],
Cell[262931, 5343, 759, 22, 65, "Text"],
Cell[263693, 5367, 25681, 437, 286, "Text"],
Cell[289377, 5806, 531, 19, 29, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[289933, 5829, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[290077, 5835, 190, 5, 29, "Text",
 Evaluatable->False],
Cell[290270, 5842, 64, 0, 29, "Text"],
Cell[290337, 5844, 281, 7, 29, "Text"],
Cell[290621, 5853, 263, 6, 29, "Text"]
}, Closed]],
Cell[290899, 5862, 396, 15, 26, "Text",
 Evaluatable->False],
Cell[291298, 5879, 1844, 67, 65, "Text"],
Cell[CellGroupData[{
Cell[293167, 5950, 233, 9, 29, "Text",
 Evaluatable->False],
Cell[293403, 5961, 280, 10, 29, "Text"],
Cell[293686, 5973, 2598, 67, 252, "Input"],
Cell[296287, 6042, 699, 21, 47, "Text"]
}, Closed]],
Cell[297001, 6066, 5932, 191, 82, "Text"],
Cell[302936, 6259, 1058, 20, 101, "Text"],
Cell[303997, 6281, 33814, 564, 286, "Text"],
Cell[337814, 6847, 41219, 685, 286, "Text"],
Cell[379036, 7534, 52547, 871, 286, "Text"],
Cell[431586, 8407, 370, 14, 35, "Text",
 Evaluatable->False],
Cell[431959, 8423, 1607, 61, 148, "Text"],
Cell[433569, 8486, 1961, 74, 143, "Text"],
Cell[435533, 8562, 665, 27, 57, "Text"],
Cell[436201, 8591, 196, 5, 29, "Text"],
Cell[436400, 8598, 471, 20, 29, "Text",
 Evaluatable->False],
Cell[436874, 8620, 508, 21, 29, "Text",
 Evaluatable->False],
Cell[437385, 8643, 89, 2, 29, "Text"],
Cell[437477, 8647, 1651, 68, 65, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[439153, 8719, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[439297, 8725, 171, 4, 29, "Text",
 Evaluatable->False],
Cell[439471, 8731, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"]
}, Closed]],
Cell[439820, 8743, 1223, 39, 80, "Text"],
Cell[441046, 8784, 1015, 40, 50, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[442086, 8828, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[442230, 8834, 171, 4, 29, "Text",
 Evaluatable->False],
Cell[442404, 8840, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"]
}, Closed]],
Cell[442753, 8852, 1175, 45, 44, "Text",
 Evaluatable->False],
Cell[443931, 8899, 982, 37, 50, "Text",
 Evaluatable->False],
Cell[444916, 8938, 2162, 80, 71, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[447103, 9022, 157, 4, 29, "Text",
 Evaluatable->False],
Cell[447263, 9028, 536, 22, 32, "Text"],
Cell[447802, 9052, 4384, 123, 446, "Input"],
Cell[452189, 9177, 470, 18, 32, "Text"]
}, Closed]],
Cell[452674, 9198, 1003, 40, 47, "Text"],
Cell[453680, 9240, 448, 14, 47, "Text"],
Cell[454131, 9256, 492, 8, 65, "Text"],
Cell[454626, 9266, 187, 7, 29, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[454838, 9277, 160, 4, 29, "Text",
 Evaluatable->False],
Cell[455001, 9283, 257, 8, 65, "Text",
 Evaluatable->False],
Cell[455261, 9293, 1305, 36, 141, "Input"],
Cell[456569, 9331, 435, 12, 47, "Text",
 Evaluatable->False],
Cell[457007, 9345, 908, 23, 112, "Input"],
Cell[457918, 9370, 232, 8, 29, "Text"]
}, Closed]],
Cell[458165, 9381, 281, 7, 26, "Text"],
Cell[458449, 9390, 263, 6, 29, "Text"],
Cell[458715, 9398, 275, 7, 29, "Text"],
Cell[458993, 9407, 259, 6, 29, "Text"],
Cell[459255, 9415, 249, 5, 29, "Text"],
Cell[459507, 9422, 320, 7, 29, "Text"]
}
]
*)

(* End of internal cache information *)
