(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    216587,       6392]
NotebookOptionsPosition[    206993,       6091]
NotebookOutlinePosition[    207968,       6130]
CellTagsIndexPosition[    207894,       6125]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["4.3  Geometric Series and Convergence Theorems",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
 "\tWe begin this section by presenting a series of the form   ",
 Cell[BoxData[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"n", "=", "0"}], "\[Infinity]"], 
   SuperscriptBox["z", "n"]}]]],
 ",  ",
 "which is called a geometric series and is one of the most important series \
in mathematics."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Real Exploration.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "\tThe complex geometric series is a generalization of the real geometric \
series  ",
 Cell[BoxData[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"n", "=", "0"}], "\[Infinity]"], " ", 
   SuperscriptBox["x", "n"]}]]],
 "  that is studied in calculus.  The partial sums ",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{
    RowBox[{
     SubscriptBox["S", "n"], 
     RowBox[{"(", "x", ")"}]}], " ", "=", " ", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"k", "=", "0"}], "n"], " ", 
     SuperscriptBox["x", "k"]}]}]}]]],
 " converge to the infinite series  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"S", 
    RowBox[{"(", "x", ")"}]}], " ", "=", " ", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", "0"}], "\[Infinity]"], " ", 
    SuperscriptBox["x", "n"]}]}]]],
 "  on the interval ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"-", "1"}], "<", "x", "<", "1"}]]],
 ", and the infinite sum is  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"S", 
    RowBox[{"(", "x", ")"}]}], "=", 
   FractionBox["1", 
    RowBox[{"1", " ", "-", " ", "x"}]]}]]],
 ". "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"S", "=", "0"}], ";", 
    RowBox[{"Remove", "[", "S", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["S", "n_"], "[", "x_", "]"}], " ", "=", " ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"k", "=", "0"}], "n"], " ", 
      SuperscriptBox["x", "k"]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"m", "=", "0"}], ",", 
      RowBox[{"m", "\[LessEqual]", "10"}], ",", 
      RowBox[{"m", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Print", "[", 
        RowBox[{
         SubscriptBox["\"\<S\>\"", "m"], ",", "\"\<(x) = \>\"", ",", 
         RowBox[{"Apart", "[", 
          RowBox[{
           SubscriptBox["S", "m"], "[", "x", "]"}], "]"}]}], " ", "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{
         SubscriptBox["\"\<S\>\"", "m"], ",", "\"\<(x) = \>\"", ",", 
         RowBox[{
          SubscriptBox["S", "m"], "[", "x", "]"}]}], " ", "]"}], ";"}]}], " ",
      "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(S\), \(n\)]\)\>\"", ",", "\"\<(x) = \>\"", ",",
       
      RowBox[{"Apart", "[", 
       RowBox[{
        SubscriptBox["S", "5"], "[", "x", "]"}], "]"}], " ", ",", 
      "\"\< +...+ \!\(\*SuperscriptBox[\(x\), \(n - 1\)]\)+ \
\!\(\*SuperscriptBox[\(x\), \(n\)]\)\>\""}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(S\), \(n\)]\)\>\"", ",", "\"\<(x) = \>\"", ",",
       
      RowBox[{
       SubscriptBox["S", "n"], "[", "x", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<If |x|<1, then \>\"", ",", 
      UnderscriptBox["\"\<lim\>\"", 
       RowBox[{"n", "\[Rule]", "\[Infinity]"}]], ",", 
      "\"\< \!\(\*SuperscriptBox[\(x\), \(n\)]\) = 0  and we get\>\""}], 
     "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      UnderscriptBox["\"\<lim\>\"", 
       RowBox[{"n", "\[Rule]", "\[Infinity]"}]], ",", 
      "\"\< \!\(\*SubscriptBox[\(S\), \(n\)]\)\>\"", ",", "\"\<(x) = \>\"", 
      ",", 
      UnderscriptBox["\"\<lim\>\"", 
       RowBox[{"n", "\[Rule]", "\[Infinity]"}]], ",", "\"\<(\>\"", ",", 
      RowBox[{
       SubscriptBox["S", "n"], "[", "x", "]"}], ",", "\"\<)\>\""}], " ", 
     "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      UnderscriptBox["\"\<lim\>\"", 
       RowBox[{"n", "\[Rule]", "\[Infinity]"}]], ",", 
      "\"\< \!\(\*SubscriptBox[\(S\), \(n\)]\)\>\"", ",", "\"\<(x) = \>\"", 
      ",", 
      UnderscriptBox["\"\<lim\>\"", 
       RowBox[{"n", "\[Rule]", "\[Infinity]"}]], ",", "\"\<(\>\"", ",", 
      RowBox[{"Apart", "[", 
       RowBox[{
        SubscriptBox["S", "n"], "[", "x", "]"}], "]"}], ",", "\"\<)\>\""}], 
     " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      UnderscriptBox["\"\<lim\>\"", 
       RowBox[{"n", "\[Rule]", "\[Infinity]"}]], ",", 
      "\"\< \!\(\*SubscriptBox[\(S\), \(n\)]\)\>\"", ",", "\"\<(x) = \>\"", 
      ",", " ", 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"k", "=", "0"}], "\[Infinity]"], " ", 
       SuperscriptBox["x", "k"]}], ",", "\"\< + 0\>\""}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      UnderscriptBox["\"\<lim\>\"", 
       RowBox[{"n", "\[Rule]", "\[Infinity]"}]], ",", 
      "\"\< \!\(\*SubscriptBox[\(S\), \(n\)]\)\>\"", ",", "\"\<(x) = \>\"", 
      ",", " ", 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"k", "=", "0"}], "\[Infinity]"], " ", 
       SuperscriptBox["x", "k"]}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39911454309375*^9, 3.39911454578125*^9}}],

Cell[TextData[{
 "We can use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to draw a series of graph which illustrate the convergence of the partial \
sums to the infinite sum. "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "x_", "]"}], "=", 
     FractionBox["1", 
      RowBox[{"1", "-", "x"}]]}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dot", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"Green", ",", 
         RowBox[{"PointSize", "[", "0.025", "]"}], ",", 
         RowBox[{"Point", "[", 
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{"f", "[", "0", "]"}]}], "}"}], "]"}]}], "}"}], "}"}], 
      "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ends", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Cyan", ",", 
          RowBox[{"Line", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "1.0"}], ",", "0.0"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "1.0"}], ",", "1.0"}], "}"}]}], "}"}], "]"}]}], 
         "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Cyan", ",", 
          RowBox[{"Line", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"1.0", ",", "0.0"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.0", ",", "10.5"}], "}"}]}], "}"}], "]"}]}], "}"}]}], 
       "}"}], "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{"For", "[", 
    RowBox[{
     RowBox[{"m", "=", "1"}], ",", 
     RowBox[{"m", "\[LessEqual]", "21"}], ",", 
     RowBox[{"m", "++"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"S", "[", "x_", "]"}], " ", "=", " ", 
       RowBox[{"Normal", "[", 
        RowBox[{"Series", "[", 
         RowBox[{
          RowBox[{"f", "[", "x", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"x", ",", "0", ",", "m"}], "}"}]}], "]"}], "]"}]}], ";", 
      "  ", "\[IndentingNewLine]", 
      RowBox[{"graph", "=", 
       RowBox[{"Plot", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"f", "[", "x", "]"}], ",", 
           RowBox[{"S", "[", "x", "]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", 
           RowBox[{"-", "1.25"}], ",", "1.25"}], "}"}], ",", 
         RowBox[{"PlotStyle", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"Blue", ",", "Red"}], "}"}]}], ",", 
         RowBox[{"PlotRange", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.25"}], ",", "1.25"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.0", ",", "10.5"}], "}"}]}], "}"}]}], ",", 
         RowBox[{"Ticks", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Range", "[", 
             RowBox[{
              RowBox[{"-", "1.5"}], ",", "1.5", ",", "0.5"}], "]"}], ",", 
            RowBox[{"Range", "[", 
             RowBox[{"0", ",", "10", ",", "2"}], "]"}]}], "}"}]}]}], "]"}]}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"g0", "=", 
       RowBox[{"Show", "[", 
        RowBox[{"graph", ",", "dot", ",", "ends"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Print", "[", "g0", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{"\"\<f(x) = \>\"", ",", 
        RowBox[{"f", "[", "x", "]"}], ",", "\"\< \[TildeTilde] \>\"", ",", 
        SubscriptBox["\"\<S\>\"", "m"], ",", "\"\<(x) = \>\"", ",", 
        RowBox[{"S", "[", "x", "]"}], ",", "\"\<\\n\>\"", ",", 
        "\"\<\\n\>\""}], " ", " ", "]"}], ";"}]}], "  ", "]"}], 
   "  "}]}]], "Input",
 CellChangeTimes->{{3.3991145543125*^9, 3.399114623890625*^9}, {
  3.399798518843502*^9, 3.3997985191091275`*^9}, {3.40026110803125*^9, 
  3.400261119859375*^9}}],

Cell["\<\
The following might give an insight into what happens when a complex number \
is used instead of a real number.\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"S", "=", 
   RowBox[{"X", "=", 
    RowBox[{"Y", "=", "0"}]}]}], ";", 
  RowBox[{"Remove", "[", 
   RowBox[{"S", ",", "X", ",", "Y"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"S", ",", "X", ",", "Y"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    SubscriptBox["S", "n_"], "[", "y_", "]"}], " ", "=", " ", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"k", "=", "0"}], "n"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"\[ImaginaryI]", " ", "y"}], ")"}], "k"]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    SubscriptBox["X", "n_"], "[", "y_", "]"}], " ", ":=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"Re", "[", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"Apart", "[", 
        RowBox[{
         SubscriptBox["S", "n"], "[", "y", "]"}], "]"}], "]"}], "]"}], ",", 
     RowBox[{"y", "\[Element]", "Reals"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    SubscriptBox["Y", "n_"], "[", "y_", "]"}], " ", ":=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"Im", "[", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"Apart", "[", 
        RowBox[{
         SubscriptBox["S", "n"], "[", "y", "]"}], "]"}], "]"}], "]"}], ",", 
     RowBox[{"y", "\[Element]", "Reals"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"X", "[", "n_", "]"}], "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Sum", "[", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"\[ImaginaryI]", " ", "y"}], ")"}], "k"], ",", 
      RowBox[{"{", 
       RowBox[{"k", ",", "0", ",", "n", ",", "2"}], "}"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Y", "[", "n_", "]"}], "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Sum", "[", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"\[ImaginaryI]", " ", "y"}], ")"}], "k"], ",", 
      RowBox[{"{", 
       RowBox[{"k", ",", "1", ",", "n", ",", "2"}], "}"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"m", "=", "0"}], ",", 
    RowBox[{"m", "\[LessEqual]", "10"}], ",", 
    RowBox[{"m", "++"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Print", "[", 
      RowBox[{
       SubscriptBox["\"\<S\>\"", "m"], ",", "\"\<(\[ImaginaryI] y) = \>\"", 
       ",", 
       RowBox[{"Apart", "[", 
        RowBox[{
         SubscriptBox["S", "m"], "[", "y", "]"}], "]"}]}], " ", "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Print", "[", 
      RowBox[{
       SubscriptBox["\"\<S\>\"", "m"], ",", "\"\<(\[ImaginaryI] y) = \>\"", 
       ",", 
       RowBox[{
        RowBox[{
         SubscriptBox["X", "m"], "[", "y", "]"}], "+", 
        RowBox[{"\[ImaginaryI]", "  ", 
         RowBox[{
          SubscriptBox["Y", "m"], "[", "y", "]"}]}]}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Print", "[", 
      RowBox[{
       SubscriptBox["\"\<S\>\"", "m"], ",", "\"\<(\[ImaginaryI] y) = \>\"", 
       ",", 
       RowBox[{
        RowBox[{"X", "[", "m", "]"}], "+", " ", 
        RowBox[{"Y", "[", "m", "]"}]}]}], " ", "]"}], ";"}]}], " ", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", "\"\<There are two cases, n = 2k, 2k+1\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{
   "\"\< \!\(\*SubscriptBox[\(S\), \(2  k\)]\)\>\"", ",", 
    "\"\<(\[ImaginaryI] y) = \!\(\*FractionBox[\(1 + \*SuperscriptBox[\(y\), \
\(2\\\ k + 2\)]\), \(1 + \*SuperscriptBox[\(y\), \(2\)]\)]\) + \
\[ImaginaryI]\!\(\*FractionBox[\(\(\\\ \)\(y\\\ \((1 - \
\*SuperscriptBox[\(y\), \(2\\\ k\)])\)\)\), \(1 + \*SuperscriptBox[\(y\), \(2\
\)]\)]\)\>\""}], " ", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{
   "\"\<\!\(\*SubscriptBox[\(S\), \(2  k + 1\)]\)\>\"", ",", 
    "\"\<(\[ImaginaryI] y) = \!\(\*FractionBox[\(1 + \*SuperscriptBox[\(y\), \
\(2\\\ k + 2\)]\), \(1 + \*SuperscriptBox[\(y\), \(2\)]\)]\) + \
\!\(\*FractionBox[\(\[ImaginaryI]\\\ y\\\ \((1 + \*SuperscriptBox[\(y\), \
\(2\\\ k + 2\)])\)\), \(1 + \*SuperscriptBox[\(y\), \(2\)]\)]\)\>\""}], " ", 
   "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<If |y|<1, then \>\"", ",", 
    UnderscriptBox["\"\<lim\>\"", 
     RowBox[{"k", "\[Rule]", "\[Infinity]"}]], ",", 
    "\"\< \!\(\*SuperscriptBox[\(y\), \(2\\\ k + 2\)]\) = 0  and we \
get\>\""}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{
    UnderscriptBox["\"\<lim\>\"", 
     RowBox[{"n", "\[Rule]", "\[Infinity]"}]], ",", 
    "\"\< \!\(\*SubscriptBox[\(S\), \(n\)]\)\>\"", ",", 
    "\"\<(\[ImaginaryI] y) =  \!\(\*FractionBox[\(1 + 0\), \(1 + \
\*SuperscriptBox[\(y\), \(2\)]\)]\) + \!\(\*FractionBox[\(\[ImaginaryI]\\\ \
y\\\ \((1 + 0)\)\), \(1 + \*SuperscriptBox[\(y\), \(2\)]\)]\)\>\""}], " ", 
   "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{
    UnderscriptBox["\"\<lim\>\"", 
     RowBox[{"n", "\[Rule]", "\[Infinity]"}]], ",", 
    "\"\< \!\(\*SubscriptBox[\(S\), \(n\)]\)\>\"", ",", 
    "\"\<(\[ImaginaryI] y) =  \!\(\*FractionBox[\(1\), \(1 + \
\*SuperscriptBox[\(y\), \(2\)]\)]\) + \[ImaginaryI]\!\(\*FractionBox[\(\(\\\ \
\)\(y\)\), \(1 + \*SuperscriptBox[\(y\), \(2\)]\)]\)\>\""}], " ", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "Print", "[", 
   "\"\<Of course this is the same as the simple computation\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "Print", "[", 
   "\"\<\!\(\*FractionBox[\(1\), \(1 - \[ImaginaryI]\\\ y\)]\) = \
\!\(\*FractionBox[\(1\), \(1 - \[ImaginaryI]\\\ y\)]\)\!\(\*FractionBox[\(1 + \
\[ImaginaryI]\\\ y\), \(1 + \[ImaginaryI]\\\ y\)]\) = \!\(\*FractionBox[\(1 + \
\[ImaginaryI]\\\ y\), \(\((1 - \[ImaginaryI]\\\ y)\) \((1 + \[ImaginaryI]\\\ \
y)\)\)]\) = \!\(\*FractionBox[\(1 + \[ImaginaryI]\\\ y\), \(1 + \
\*SuperscriptBox[\(y\), \(2\)]\)]\)\>\"", "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.399798710593502*^9, 3.399798747687252*^9}}],

Cell[BoxData[""], "Input"],

Cell["\<\
In this module we extend geometric series to the complex numbers.\
\>", "Text"]
}, Closed]],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{605, 250},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 StyleBox["Theorem 4.12 (",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Geometric Series",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/GeometricSeries.html"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 StyleBox[").",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[" ",
  FontColor->RGBColor[0, 0, 1]],
 " If  ",
 Cell[BoxData[
  RowBox[{"|", "z", "|", 
   RowBox[{"<", "1"}]}]]],
 ",  the series  ",
 Cell[BoxData[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"n", "=", "0"}], "\[Infinity]"], 
   SuperscriptBox["z", "n"]}]]],
 "  converges to  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   FractionBox["1", 
    RowBox[{"1", " ", "-", " ", "z"}]]}]]],
 ".  That is, if  ",
 Cell[BoxData[
  RowBox[{"|", "z", "|", 
   RowBox[{"<", "1"}]}]]],
 "  then  \n\n",
 StyleBox["(4-11)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", "0"}], "\[Infinity]"], 
    SuperscriptBox["z", "n"]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"1", "+", "z", "+", 
        SuperscriptBox["z", "2"], "+"}], "..."}], "+", 
      SuperscriptBox["z", "k"], "+"}], "..."}], " ", "=", " ", 
    FractionBox["1", 
     RowBox[{"1", " ", "-", " ", "z"}]]}]}]]],
 ".  \n\nIf  ",
 Cell[BoxData[
  RowBox[{"|", "z", "|", 
   RowBox[{"\[GreaterEqual]", "1"}]}]]],
 ",  the series diverges.  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 4.12 is in the book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "We can use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to plot the images of the disk   ",
 Cell[BoxData[
  RowBox[{"|", "z", "|", 
   RowBox[{"\[LessEqual]", 
    FractionBox["6", "10"]}]}]]],
 "  under the mappings  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["S", "n"], 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"k", "=", "0"}], "n"], 
    SuperscriptBox["z", "k"]}]}]]],
 ".  \n\nHence we can view how the complex geometric series converges to its \
limit function ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   FractionBox["1", 
    RowBox[{"1", " ", "-", " ", "z"}]]}]]],
 ". "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"g", ",", "k", ",", "m", ",", "n", ",", "s"}], "]"}], ";"}], " ",
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"s", "[", 
      RowBox[{"z_", ",", "n_"}], "]"}], "=", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"k", "=", "0"}], "n"], 
      SuperscriptBox["z", "k"]}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", 
     FractionBox["1", 
      RowBox[{"1", " ", "-", " ", "z"}]]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"For", " ", "[", 
     RowBox[{
      RowBox[{"m", "=", "2"}], ",", 
      RowBox[{"m", "\[LessEqual]", "10"}], ",", 
      RowBox[{"m", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"g", "[", "z_", "]"}], "=", 
        RowBox[{"s", "[", 
         RowBox[{"z", ",", "m"}], "]"}]}], ";", " ", "\[IndentingNewLine]", 
       RowBox[{"gr", "=", 
        RowBox[{"PolarMap", "[", 
         RowBox[{"g", " ", ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0.6", ",", "0.075"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{"2", "\[Pi]"}], ",", 
            FractionBox["\[Pi]", "12"]}], "}"}], ",", "\[IndentingNewLine]", 
          RowBox[{"PlotRange", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0.4", ",", "2.6"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "1.0"}], ",", "1.0"}], "}"}]}], "}"}]}], ",", 
          RowBox[{"AspectRatio", "\[Rule]", 
           FractionBox["2.0", "2.2"]}], ",", "\[IndentingNewLine]", 
          RowBox[{"Ticks", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Range", "[", 
              RowBox[{"0", ",", "3", ",", "1"}], "]"}], ",", 
             RowBox[{"Range", "[", 
              RowBox[{
               RowBox[{"-", 
                FractionBox["3", "2"]}], ",", 
               FractionBox["3", "2"], ",", 
               FractionBox["1", "2"]}], "]"}]}], "}"}]}], ",", 
          RowBox[{"AxesLabel", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
          RowBox[{"PlotStyle", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"Blue", ",", "Red"}], "}"}]}], ",", 
          RowBox[{"AxesOrigin", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"0.4", ",", "0"}], "}"}]}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Print", "[", "gr", "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{"\"\<w = \>\"", ",", 
         SubscriptBox["\"\<S\>\"", "m"], ",", "\"\<(z) = \>\"", ",", 
         RowBox[{"Apart", "[", 
          RowBox[{"s", "[", 
           RowBox[{"z", ",", "m"}], "]"}], "]"}], ",", "\"\<\\n\>\"", " ", 
         ",", "\"\<\\n\>\""}], " ", " ", "]"}], ";"}]}], "  ", "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g1", "=", 
     RowBox[{"PolarMap", "[", 
      RowBox[{"f", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.6", ",", "0.075"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"2", "\[Pi]"}], ",", 
         FractionBox["\[Pi]", "12"]}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0.4", ",", "2.6"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.0"}], ",", "1.0"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", 
        FractionBox["2.0", "2.2"]}], ",", "\[IndentingNewLine]", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"1", ",", "3", ",", "1"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}]}], "}"}]}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", "Red"}], "}"}]}], ",", 
       RowBox[{"AxesOrigin", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"0.4", ",", "0"}], "}"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "g1", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<The limit function is w = f(z) = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39910874709375*^9, 3.39910882296875*^9}, {
  3.399114656796875*^9, 3.39911465709375*^9}, {3.399114749109375*^9, 
  3.3991147613125*^9}, {3.399201751078125*^9, 3.39920176075*^9}, {
  3.399798528687252*^9, 3.399798528906002*^9}}]
}, Closed]],

Cell[TextData[{
 StyleBox["Corollary 4.2. ",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[" ",
  FontColor->RGBColor[0, 0, 1]],
 " If  ",
 Cell[BoxData[
  RowBox[{"|", "z", "|", 
   RowBox[{">", "1"}]}]]],
 ",  the series  ",
 Cell[BoxData[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"n", "=", "1"}], "\[Infinity]"], 
   SuperscriptBox["z", 
    RowBox[{"-", "n"}]]}]]],
 " ",
 " converges to ",
 " ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   FractionBox["1", 
    RowBox[{"z", "-", " ", "1"}]]}]]],
 ".  That is, if ",
 Cell[BoxData[
  RowBox[{"|", "z", "|", 
   RowBox[{">", "1"}]}]]],
 " then  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"    ", 
   RowBox[{
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", "1"}], "\[Infinity]"], 
     SuperscriptBox["z", 
      RowBox[{"-", "n"}]]}], "  ", "=", "   ", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox["z", 
          RowBox[{"-", "1"}]], "+", 
         SuperscriptBox["z", 
          RowBox[{"-", "2"}]], "+"}], "..."}], "+", 
       SuperscriptBox["z", 
        RowBox[{"-", "4"}]], "+"}], "..."}], " ", "=", " ", 
     FractionBox["1", 
      RowBox[{"z", "-", " ", "1"}]]}]}]}]]],
 ",  \nor equivalently,\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"-", " ", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", "1"}], "\[Infinity]"], 
     SuperscriptBox["z", 
      RowBox[{"-", "n"}]]}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"-", " ", 
         SuperscriptBox["z", 
          RowBox[{"-", "1"}]]}], "-", 
        SuperscriptBox["z", 
         RowBox[{"-", "2"}]], "-"}], "..."}], "-", 
      SuperscriptBox["z", 
       RowBox[{"-", "4"}]], "-"}], "..."}], " ", "=", " ", 
    FractionBox["1", 
     RowBox[{"1", "-", "z"}]]}]}]]],
 ".  \n\nIf  ",
 Cell[BoxData[
  RowBox[{"|", "z", "|", 
   RowBox[{"\[LessEqual]", "1"}]}]]],
 ",  t",
 "he series diverges. "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Corollary 4.2 is in the book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"]
}, Closed]],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{614, 250},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "We can use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to plot the images of the disk   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    FractionBox["3", "2"], "\[LessEqual]"}], "|", "z", "|", 
   RowBox[{"\[LessEqual]", 
    FractionBox["7", "2"]}]}]]],
 "  under the mappings  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["S", "n"], 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"k", "=", "1"}], "n"], 
    SuperscriptBox["z", 
     RowBox[{"-", "n"}]]}]}]]],
 ".  \n\nHence we can view how the complex geometric series converges to its \
limit function ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   FractionBox["1", 
    RowBox[{"z", "-", "1"}]]}]]],
 ". "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"g", ",", "k", ",", "m", ",", "n", ",", "s"}], "]"}], ";"}], " ",
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"s", "[", 
      RowBox[{"z_", ",", "n_"}], "]"}], "=", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"k", "=", "1"}], "n"], 
      SuperscriptBox["z", 
       RowBox[{"-", "k"}]]}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", 
     FractionBox["1", 
      RowBox[{"z", "-", "1"}]]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"For", " ", "[", 
     RowBox[{
      RowBox[{"m", "=", "1"}], ",", 
      RowBox[{"m", "\[LessEqual]", "10"}], ",", 
      RowBox[{"m", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"g", "[", "z_", "]"}], "=", 
        RowBox[{"s", "[", 
         RowBox[{"z", ",", "m"}], "]"}]}], ";", " ", "\[IndentingNewLine]", 
       RowBox[{"g0", "=", 
        RowBox[{"PolarMap", "[", 
         RowBox[{"g", " ", ",", 
          RowBox[{"{", 
           RowBox[{"1.5", ",", "3.5", ",", "0.4"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{"2", "\[Pi]"}], ",", 
            FractionBox["\[Pi]", "16"]}], "}"}], ",", "\[IndentingNewLine]", 
          RowBox[{"PlotRange", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "0.7"}], ",", "2.0"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "1.35"}], ",", "1.35"}], "}"}]}], "}"}]}], ",", 
          RowBox[{"AspectRatio", "\[Rule]", 
           FractionBox["2.7", "2.7"]}], ",", "\[IndentingNewLine]", 
          RowBox[{"Ticks", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               FractionBox["1", "4"], ",", "1", ",", 
               FractionBox["3", "2"], ",", "2"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "1"}], ",", 
               FractionBox["1", "8"], ",", "1"}], "}"}]}], "}"}]}], ",", 
          RowBox[{"AxesLabel", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
          RowBox[{"PlotStyle", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"Blue", ",", "Red"}], "}"}]}], ",", 
          RowBox[{"AxesOrigin", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"0", ",", "0"}], "}"}]}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Print", "[", "g0", "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{"\"\<w = \>\"", ",", 
         SubscriptBox["\"\<S\>\"", "m"], ",", "\"\<(z) = \>\"", ",", 
         RowBox[{"Apart", "[", 
          RowBox[{"s", "[", 
           RowBox[{"z", ",", "m"}], "]"}], "]"}], ",", "\"\<\\n\>\"", " ", 
         ",", "\"\<\\n\>\""}], " ", " ", "]"}], ";"}]}], "  ", "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g1", "=", 
     RowBox[{"PolarMap", "[", 
      RowBox[{"f", ",", 
       RowBox[{"{", 
        RowBox[{"1.5", ",", "3.5", ",", "0.4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"2", "\[Pi]"}], ",", 
         FractionBox["\[Pi]", "16"]}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.7"}], ",", "2.0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.35"}], ",", "1.35"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", 
        FractionBox["2.7", "2.7"]}], ",", "\[IndentingNewLine]", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            FractionBox["1", "4"], ",", "1", ",", 
            FractionBox["3", "2"], ",", "2"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", 
            FractionBox["1", "8"], ",", "1"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", "Red"}], "}"}]}], ",", 
       RowBox[{"AxesOrigin", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0"}], "}"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "g1", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<The limit function is w = f(z) = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399114699546875*^9, 3.39911473865625*^9}, {
  3.399114781296875*^9, 3.399114788453125*^9}, {3.3997985391403775`*^9, 
  3.399798539312252*^9}}]
}, Closed]],

Cell[TextData[{
 StyleBox["Corollary 4.3. ",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[" ",
  FontColor->RGBColor[0, 0, 1]],
 " If  ",
 Cell[BoxData[
  RowBox[{"z", "\[NotEqual]", "1"}]]],
 ",  then for all ",
 StyleBox["n",
  FontFamily->"Courier New"],
 ",  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   FractionBox["1", 
    RowBox[{"1", " ", "-", " ", "z"}]], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"1", "+", "z", "+", 
      SuperscriptBox["z", "2"], "+"}], "..."}], "+", 
    SuperscriptBox["z", 
     RowBox[{"n", "-", "1"}]], "+", 
    FractionBox[
     SuperscriptBox["z", "n"], 
     RowBox[{"1", " ", "-", " ", "z"}]]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Corollary 4.3 is mentioned in the book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "We can explore the situation for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"n", "=", "1"}], ",", "2", ",", "...", ",", "10"}]]],
 ". "
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"m", "=", "1"}], ",", 
    RowBox[{"m", "\[LessEqual]", "10"}], ",", 
    RowBox[{"m", "++"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Print", "[", 
      RowBox[{
       OverscriptBox["\"\<\!\(\*UnderscriptBox[\(\[Sum]\), \(k = 0\)]\)\>\"", 
        
        RowBox[{"m", "-", "1"}]], ",", 
       "\"\<\!\(\*SuperscriptBox[\(z\), \(k\)]\) + \>\"", ",", 
       FractionBox[
        SuperscriptBox["z", "m"], 
        RowBox[{"1", " ", "-", " ", "z"}]], ",", "\"\< = \>\"", ",", 
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"k", "=", "0"}], 
         RowBox[{"m", "-", "1"}]], 
        SuperscriptBox["z", "k"]}], ",", "\"\< + \>\"", ",", 
       FractionBox[
        SuperscriptBox["z", "m"], 
        RowBox[{"1", " ", "-", " ", "z"}]]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Print", "[", 
      RowBox[{"\"\<             = \>\"", ",", 
       RowBox[{"Together", "[", 
        RowBox[{"Together", "[", 
         RowBox[{
          RowBox[{
           UnderoverscriptBox["\[Sum]", 
            RowBox[{"k", "=", "0"}], 
            RowBox[{"m", "-", "1"}]], 
           SuperscriptBox["z", "k"]}], "+", " ", 
          FractionBox[
           SuperscriptBox["z", "m"], 
           RowBox[{"1", " ", "-", " ", "z"}]]}], "]"}], "]"}]}], "]"}], 
     ";"}]}], " ", "]"}], ";"}]], "Input"],

Cell["In general we have.", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", "n", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{
   "\"\<\!\(\*UnderoverscriptBox[\(\[Sum]\), \(k = 0\), \(n - \
1\)]\)\!\(\*SuperscriptBox[\(z\), \
\(k\)]\)+\!\(\*FractionBox[SuperscriptBox[\(z\), \(n\)], \(1\\\  - \\\ z\)]\) \
= \>\"", ",", 
    RowBox[{
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"k", "=", "0"}], 
       RowBox[{"n", "-", "1"}]], 
      SuperscriptBox["z", "k"]}], "+", 
     FractionBox[
      SuperscriptBox["z", "n"], 
      RowBox[{"1", " ", "-", " ", "z"}]]}]}], " ", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{
   "\"\<\!\(\*UnderoverscriptBox[\(\[Sum]\), \(k = 0\), \(n - \
1\)]\)\!\(\*SuperscriptBox[\(z\), \
\(k\)]\)+\!\(\*FractionBox[SuperscriptBox[\(z\), \(n\)], \(1\\\  - \\\ z\)]\) \
= \>\"", ",", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"k", "=", "0"}], 
        RowBox[{"n", "-", "1"}]], 
       SuperscriptBox["z", "k"]}], "+", 
      FractionBox[
       SuperscriptBox["z", "n"], 
       RowBox[{"1", " ", "-", " ", "z"}]]}], "]"}]}], " ", "]"}], 
  ";"}]}], "Input"]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 4.13.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Show that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", "0"}], "\[Infinity]"], 
    FractionBox[
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", " ", "-", " ", "\[ImaginaryI]"}], ")"}], "n"], 
     SuperscriptBox["2", "n"]]}], " ", "=", " ", 
   RowBox[{"1", "-", "\[ImaginaryI]"}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "Solution.  If we set  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   FractionBox[
    RowBox[{"1", "-", "\[ImaginaryI]"}], "2"]}]]],
 ",  then  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", "z", "|"}], " ", "=", " ", 
   RowBox[{
    RowBox[{"|", 
     FractionBox[
      RowBox[{"1", "-", "\[ImaginaryI]"}], "2"], "|"}], " ", "=", " ", 
    RowBox[{
     FractionBox[
      SqrtBox["2"], "2"], " ", "<", " ", "1"}]}]}]]],
 ".  By Theorem 4.12, the sum is  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"1", "/", 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      FractionBox[
       RowBox[{"1", "-", "\[ImaginaryI]"}], "2"]}], ")"}]}], " ", "=", " ", 
   RowBox[{
    FractionBox["2", 
     RowBox[{"2", "-", "1", "+", "\[ImaginaryI]"}]], " ", "=", " ", 
    RowBox[{
     FractionBox["2", 
      RowBox[{"1", "+", "\[ImaginaryI]"}]], " ", "=", " ", 
     RowBox[{"1", "-", "\[ImaginaryI]"}]}]}]}]]],
 ". "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 4.13.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell["\<\
We can use the definition of convergence of a series and find the limit of \
the partial sums.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", 
     RowBox[{"S", ",", "z"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"k", ",", "lim", ",", "n", ",", "sum", ",", "Z"}], "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "k_"], " ", "=", " ", 
     FractionBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", " ", "-", " ", "\[ImaginaryI]"}], ")"}], "k"], 
      SuperscriptBox["2", "k"]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["S", "n_"], " ", "=", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"k", "=", "0"}], "n"], 
      FractionBox[
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "-", "\[ImaginaryI]"}], ")"}], "k"], 
       SuperscriptBox["2", "k"]]}]}], 
    StyleBox[";",
     FontSize->14]}], 
   StyleBox[" ",
    FontSize->14], "\n", 
   RowBox[{
    RowBox[{"sum", " ", "=", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"k", "=", "0"}], "\[Infinity]"], 
      FractionBox[
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "-", "\[ImaginaryI]"}], ")"}], "k"], 
       SuperscriptBox["2", "k"]]}]}], 
    StyleBox[";",
     FontSize->14]}], 
   StyleBox[" ",
    FontSize->14], "\n", 
   RowBox[{
    RowBox[{"lim", " ", "=", " ", 
     RowBox[{"Limit", "[", 
      RowBox[{
       SubscriptBox["S", "n"], ",", 
       RowBox[{"n", 
        StyleBox["\[Rule]",
         FontWeight->"Plain"], 
        StyleBox["\[Infinity]",
         FontWeight->"Plain"]}]}], "]"}]}], ";"}], " ", "\[IndentingNewLine]",
    
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(k\)]\) = \>\"", ",", 
      SubscriptBox["z", "k"]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(S\), \(n\)]\) = \!\(\*UnderoverscriptBox[\(\
\[Sum]\), \(k = 0\), \(n\)]\)\!\(\*FractionBox[SuperscriptBox[\((1 - \
\[ImaginaryI])\), \(k\)], SuperscriptBox[\(2\), \(k\)]]\) = \>\"", ",", 
      SubscriptBox["S", "n"]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(lim\), \(n \[Rule] \[Infinity]\)]\) \>\"", 
      ",", "\"\<\!\(\*SubscriptBox[\(S\), \(n\)]\) = \>\"", ",", "lim"}], 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderoverscriptBox[\(\[Sum]\), \(k = 0\), \
\(\[Infinity]\)]\)\!\(\*FractionBox[SuperscriptBox[\((1 - \[ImaginaryI])\), \
\(k\)], SuperscriptBox[\(2\), \(k\)]]\) = \>\"", ",", "sum"}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399114819609375*^9, 3.399114820703125*^9}}],

Cell[TextData[{
 "Or we can see that this is an infinite geometric series with ratio  ",
 Cell[BoxData[
  RowBox[{"Z", "=", 
   RowBox[{
    FractionBox["1", "2"], "-", 
    FractionBox["\[ImaginaryI]", "2"]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Z", " ", "=", " ", 
     FractionBox[
      SubscriptBox["z", 
       RowBox[{"k", "+", "1"}]], 
      SubscriptBox["z", "k"]]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< \!\(\*SubscriptBox[\(z\), \(k\)]\) = \>\"", ",", 
      SubscriptBox["z", "k"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(k + 1\)]\) = \>\"", ",", 
      SubscriptBox["z", 
       RowBox[{"k", "+", "1"}]]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<  Z = \!\(\*FractionBox[SubscriptBox[\(z\), \(k + 1\)], \
SubscriptBox[\(z\), \(k\)]]\) = \>\"", ",", "Z"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.3991148258125*^9}],

Cell["The sum of the infinite geometric series is now found.", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<          Z = \>\"", ",", "Z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<        |Z| = \>\"", ",", 
      RowBox[{"Abs", "[", "Z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<     Is |Z| < 1 ?  \>\"", ",", 
      RowBox[{
       RowBox[{"Abs", "[", "Z", "]"}], "<", " ", "1"}]}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<      \!\(\*FractionBox[\(1\), \(1 - Z\)]\) = \!\(\*FractionBox[\(1\
\), \(1 - \((\*FractionBox[\(1\), \(2\)] - \*FractionBox[\(\[ImaginaryI]\), \
\(2\)])\)\)]\)\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<      \!\(\*FractionBox[\(1\), \(1 - Z\)]\) = \>\"", ",", " ", 
      FractionBox["1", 
       RowBox[{"1", "-", 
        RowBox[{"(", 
         RowBox[{
          FractionBox["1", "2"], "-", 
          FractionBox[
           RowBox[{" ", "\[ImaginaryI]"}], "2"]}], ")"}]}]]}], "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderoverscriptBox[\(\[Sum]\), \(k = 0\), \
\(\[Infinity]\)]\)\!\(\*FractionBox[SuperscriptBox[\((1 - \[ImaginaryI])\), \
\(k\)], SuperscriptBox[\(2\), \(k\)]]\) = \>\"", ",", 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"k", "=", "0"}], "\[Infinity]"], 
       FractionBox[
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "-", "\[ImaginaryI]"}], ")"}], "k"], 
        SuperscriptBox["2", "k"]]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399114830078125*^9}],

Cell[TextData[{
 "The series of absolute values converges, therefore the series converges.\n\n\
Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to construct some of the partial sums of the infinite series."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["S", "n_"], " ", "=", " ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"k", "=", "0"}], "n"], 
      FractionBox[
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "-", "\[ImaginaryI]"}], ")"}], "k"], 
       SuperscriptBox["2", "k"]]}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"table", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"FullSimplify", "[", 
        SubscriptBox["S", "n"], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "0", ",", "10"}], "}"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"table", "=", 
     RowBox[{"Append", "[", 
      RowBox[{"table", ",", "\"\<...\>\""}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(S\), \(n\)]\)} = \>\"", ",", "table"}], "]"}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<{\!\(\*SubscriptBox[\(S\), \(n\)]\)} = \>\"", ",", 
      RowBox[{"N", "[", "table", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderoverscriptBox[\(\[Sum]\), \(k = 0\), \
\(\[Infinity]\)]\)\!\(\*FractionBox[SuperscriptBox[\((1 - \[ImaginaryI])\), \
\(k\)], SuperscriptBox[\(2\), \(k\)]]\) = \>\"", ",", 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"k", "=", "0"}], "\[Infinity]"], 
       FractionBox[
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "-", "\[ImaginaryI]"}], ")"}], "k"], 
        SuperscriptBox["2", "k"]]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399114835640625*^9}],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to plot some of the partial sums of the infinite series."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"set", " ", "=", "  ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          SubscriptBox["S", "n"], "]"}], ",", 
         RowBox[{"Im", "[", 
          SubscriptBox["S", "n"], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "0", ",", "15"}], "}"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dot", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"PointSize", "[", "0.021", "]"}], ",", "Red", ",", 
        RowBox[{"Point", "[", 
         RowBox[{"{", 
          RowBox[{"1", ",", 
           RowBox[{"-", "1"}]}], "}"}], "]"}]}], "}"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"graph", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"set", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"PointSize", "[", "0.02", "]"}], ",", "Blue"}], "}"}]}], 
       ",", "\[IndentingNewLine]", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "1.55"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.3"}], ",", "0.1"}], "}"}]}], "}"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "1.6", ",", "0.2"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "1.4"}], ",", "0", ",", "0.2"}], "]"}]}], "}"}]}]}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"graph2", "=", 
     RowBox[{"Show", "[", 
      RowBox[{"graph", ",", "dot"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "graph2", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<{\!\(\*SubscriptBox[\(S\), \(n\)]\)} = \>\"", ",", 
      RowBox[{"N", "[", "table", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderoverscriptBox[\(\[Sum]\), \(k = 0\), \
\(\[Infinity]\)]\)\!\(\*FractionBox[SuperscriptBox[\((1 - \[ImaginaryI])\), \
\(k\)], SuperscriptBox[\(2\), \(k\)]]\) = \>\"", ",", "sum"}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39911484221875*^9, 3.3991148799375*^9}, {
  3.399201803921875*^9, 3.399201820734375*^9}, {3.399798544281002*^9, 
  3.399798544468502*^9}, {3.400261140421875*^9, 3.40026114490625*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "We see that the sum of the infinite geometric series  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", "0"}], "\[Infinity]"], 
    RowBox[{
     FractionBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", " ", "-", " ", "\[ImaginaryI]"}], ")"}], "n"], 
      SuperscriptBox["2", "n"]], "   ", "is", "   ", "1"}]}], "-", 
   "\[ImaginaryI]"}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 4.14.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Evaluate  ",
 Cell[BoxData[
  StyleBox[
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", "3"}], "\[Infinity]"], 
    FractionBox[
     RowBox[{" ", 
      SuperscriptBox["\[ImaginaryI]", "n"]}], 
     SuperscriptBox["2", "n"]]}],
   FontSize->14]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "Solution.  We can put this expression in the form of a geometric series:  \n\
\t\t\t\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", "3"}], "\[Infinity]"], 
     FractionBox[
      SuperscriptBox["\[ImaginaryI]", "n"], 
      SuperscriptBox["2", "n"]]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "3"}], "\[Infinity]"], 
      SuperscriptBox[
       RowBox[{"(", 
        FractionBox["\[ImaginaryI]", "2"], ")"}], "n"]}], "  ", "=", "   ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "3"}], "\[Infinity]"], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         FractionBox["\[ImaginaryI]", "2"], ")"}], "3"], 
       SuperscriptBox[
        RowBox[{"(", 
         FractionBox["\[ImaginaryI]", "2"], ")"}], 
        RowBox[{"n", "-", "3"}]]}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                  ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         FractionBox["\[ImaginaryI]", "2"], ")"}], "3"], " ", 
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"n", "=", "3"}], "\[Infinity]"], 
        SuperscriptBox[
         RowBox[{"(", 
          FractionBox["\[ImaginaryI]", "2"], ")"}], 
         RowBox[{"n", "-", "3"}]]}]}], "  ", "=", "  ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         FractionBox["\[ImaginaryI]", "2"], ")"}], "3"], " ", 
       FractionBox["1", 
        RowBox[{"1", "-", 
         FractionBox["\[ImaginaryI]", "2"]}]]}]}]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                  ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FractionBox["\[ImaginaryI]", "8"]}], 
       FractionBox["1", 
        RowBox[{"1", "-", 
         FractionBox["\[ImaginaryI]", "2"]}]]}], "  ", "=", "  ", 
      FractionBox[
       RowBox[{"-", "\[ImaginaryI]"}], 
       RowBox[{"8", "-", 
        RowBox[{"4", "\[ImaginaryI]"}]}]]}]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                  ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      RowBox[{
       FractionBox[
        RowBox[{"-", "\[ImaginaryI]"}], 
        RowBox[{"8", "-", 
         RowBox[{"4", "\[ImaginaryI]"}]}]], " ", 
       FractionBox[
        RowBox[{"8", "+", 
         RowBox[{"4", "\[ImaginaryI]"}]}], 
        RowBox[{"8", "+", 
         RowBox[{"4", "\[ImaginaryI]"}]}]]}], "  ", "=", "  ", 
      FractionBox[
       RowBox[{"4", "-", 
        RowBox[{"8", " ", "\[ImaginaryI]"}]}], "80"]}]}], " ", 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                  ", 
   RowBox[{"=", "  ", 
    RowBox[{
     FractionBox["1", "20"], "-", 
     FractionBox["\[ImaginaryI]", "10"], " "}]}]}]}]],
 "  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 4.14.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell["\<\
We can use the definition of convergence of a series and find the limit of \
the partial sums.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", 
     RowBox[{"S", ",", "z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"k", ",", "lim", ",", "n", ",", "sum", ",", "Z"}], "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "k_"], " ", "=", 
     FractionBox[
      RowBox[{" ", 
       SuperscriptBox["\[ImaginaryI]", "k"]}], 
      SuperscriptBox["2", "k"]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["S", "n_"], " ", "=", " ", 
     StyleBox[
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"k", "=", "3"}], "\[Infinity]"], 
       FractionBox[
        SuperscriptBox["\[ImaginaryI]", "k"], 
        SuperscriptBox["2", "k"]]}],
      FontSize->14]}], 
    StyleBox[";",
     FontSize->14]}], 
   StyleBox[" ",
    FontSize->14], "\n", 
   RowBox[{
    RowBox[{"sum", " ", "=", " ", 
     StyleBox[
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"k", "=", "3"}], "\[Infinity]"], 
       FractionBox[
        RowBox[{" ", 
         SuperscriptBox["\[ImaginaryI]", "k"]}], 
        SuperscriptBox["2", "k"]]}],
      FontSize->14]}], 
    StyleBox[";",
     FontSize->14]}], 
   StyleBox[" ",
    FontSize->14], "\n", 
   RowBox[{
    RowBox[{"lim", " ", "=", " ", 
     RowBox[{"Limit", "[", 
      RowBox[{
       SubscriptBox["S", "n"], ",", 
       RowBox[{"n", 
        StyleBox["\[Rule]",
         FontWeight->"Plain"], 
        StyleBox["\[Infinity]",
         FontWeight->"Plain"]}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(k\)]\) = \>\"", ",", 
      SubscriptBox["z", "k"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(S\), \(n\)]\) = \!\(\*UnderoverscriptBox[\(\
\[Sum]\), \(k = 3\), \(n\)]\)\!\(\*FractionBox[SuperscriptBox[\(\[ImaginaryI]\
\), \(k\)], SuperscriptBox[\(2\), \(k\)]]\) = \>\"", ",", 
      SubscriptBox["S", "n"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<      \!\(\*UnderscriptBox[\(lim\), \(n \[Rule] \[Infinity]\)]\) \>\
\"", ",", "\"\<\!\(\*SubscriptBox[\(S\), \(n\)]\) = \>\"", ",", "lim"}], 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<     \!\(\*UnderoverscriptBox[\(\[Sum]\), \(k = 3\), \
\(\[Infinity]\)]\)\!\(\*FractionBox[SuperscriptBox[\(\[ImaginaryI]\), \(k\)], \
SuperscriptBox[\(2\), \(k\)]]\) = \>\"", ",", "sum"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399114906921875*^9, 3.3991149085*^9}}],

Cell[TextData[{
 "Or we can see that this is an infinite geometric series with ratio  ",
 Cell[BoxData[
  RowBox[{"Z", "=", 
   FractionBox["\[ImaginaryI]", "2"]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Z", " ", "=", " ", 
     FractionBox[
      SubscriptBox["z", 
       RowBox[{"k", "+", "1"}]], 
      SubscriptBox["z", "k"]]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< \!\(\*SubscriptBox[\(z\), \(k\)]\) = \>\"", ",", 
      SubscriptBox["z", "k"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(k + 1\)]\) = \>\"", ",", 
      SubscriptBox["z", 
       RowBox[{"k", "+", "1"}]]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<  Z = \!\(\*FractionBox[SubscriptBox[\(z\), \(k + 1\)], \
SubscriptBox[\(z\), \(k\)]]\) = \>\"", ",", "Z"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399114911921875*^9}],

Cell["The sum of the infinite geometric series is now found.", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"a", " ", "=", " ", 
     SubscriptBox["z", "3"]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<        a = (\!\(\*FractionBox[\(\[ImaginaryI]\), \
\(2\)]\)\!\(\*SuperscriptBox[\()\), \(3\)]\) = \>\"", ",", "a"}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<        Z = \>\"", ",", "Z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<      |Z| = \>\"", ",", 
      RowBox[{"Abs", "[", "Z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<   Is |Z| < 1 ?  \>\"", ",", 
      RowBox[{
       RowBox[{"Abs", "[", "Z", "]"}], "<", " ", "1"}]}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<     \!\(\*FractionBox[\(a\), \(1 - Z\)]\) = \
\!\(\*FractionBox[SuperscriptBox[\((\*FractionBox[\(\[ImaginaryI]\), \
\(2\)])\), \(3\)], \(1 - \*FractionBox[\(\[ImaginaryI]\), \(2\)]\)]\)\>\"", 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<     \!\(\*FractionBox[\(a\), \(1 - Z\)]\) = \>\"", ",", 
      FractionBox["a", 
       RowBox[{"1", "-", "Z"}]]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<    \!\(\*UnderoverscriptBox[\(\[Sum]\), \(k = 3\), \
\(\[Infinity]\)]\)\!\(\*FractionBox[SuperscriptBox[\(\[ImaginaryI]\), \(k\)], \
SuperscriptBox[\(2\), \(k\)]]\) = \>\"", ",", 
      StyleBox[
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"k", "=", "3"}], "\[Infinity]"], 
        FractionBox[
         SuperscriptBox["\[ImaginaryI]", "k"], 
         SuperscriptBox["2", "k"]]}],
       FontSize->14]}], "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",\

 CellChangeTimes->{{3.399114916484375*^9, 3.3991149176875*^9}}],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to construct some of the partial sums of the infinite series."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["S", "n_"], " ", "=", " ", 
     StyleBox[
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"k", "=", "3"}], "n"], 
       FractionBox[
        SuperscriptBox["\[ImaginaryI]", "k"], 
        SuperscriptBox["2", "k"]]}],
      FontSize->14]}], 
    StyleBox[";",
     FontSize->14]}], 
   StyleBox[" ",
    FontSize->14], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"table", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"FullSimplify", "[", 
        SubscriptBox["S", "n"], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "0", ",", "10"}], "}"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"table", "=", 
     RowBox[{"Append", "[", 
      RowBox[{"table", ",", "\"\<...\>\""}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(S\), \(n\)]\)} = \>\"", ",", "table"}], "]"}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<{\!\(\*SubscriptBox[\(S\), \(n\)]\)} = \>\"", ",", 
      RowBox[{"N", "[", "table", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderoverscriptBox[\(\[Sum]\), \(k = 3\), \
\(\[Infinity]\)]\)\!\(\*FractionBox[SuperscriptBox[\(\[ImaginaryI]\), \(k\)], \
SuperscriptBox[\(2\), \(k\)]]\) = \>\"", ",", 
      StyleBox["sum",
       FontSize->14]}], "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",\

 CellChangeTimes->{{3.399114920421875*^9, 3.399114922046875*^9}}],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to plot some of the partial sums of the infinite series."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"set", " ", "=", "  ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          SubscriptBox["S", "n"], "]"}], ",", 
         RowBox[{"Im", "[", 
          SubscriptBox["S", "n"], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "0", ",", "10"}], "}"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dot", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"PointSize", "[", "0.023", "]"}], ",", "Red", ",", 
        RowBox[{"Point", "[", 
         RowBox[{"{", 
          RowBox[{
           FractionBox["1", "20"], ",", 
           RowBox[{"-", 
            FractionBox["1", "10"]}]}], "}"}], "]"}]}], "}"}], "]"}]}], ";"}],
    " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"graph", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"set", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"PointSize", "[", "0.02", "]"}], ",", "Blue"}], "}"}]}], 
       ",", "\[IndentingNewLine]", 
       RowBox[{"PlotRange", "\[Rule]", "All"}], ",", "\[IndentingNewLine]", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "0.5", ",", "0.1"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "0.5"}], ",", "0", ",", "0.1"}], "]"}]}], "}"}]}]}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"graph2", "=", 
     RowBox[{"Show", "[", 
      RowBox[{"graph", ",", "dot"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "graph2", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<{\!\(\*SubscriptBox[\(S\), \(n\)]\)} = \>\"", ",", 
      RowBox[{"N", "[", "table", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderoverscriptBox[\(\[Sum]\), \(k = 3\), \
\(\[Infinity]\)]\)\!\(\*FractionBox[SuperscriptBox[\(\[ImaginaryI]\), \(k\)], \
SuperscriptBox[\(2\), \(k\)]]\) = \>\"", ",", 
      StyleBox["sum",
       FontSize->14]}], "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",\

 CellChangeTimes->{{3.399114924703125*^9, 3.39911494040625*^9}, {
  3.399201855125*^9, 3.399201866109375*^9}, {3.3997985489216275`*^9, 
  3.3997985491091275`*^9}, {3.400261157921875*^9, 3.40026116721875*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "We see that the sum of the infinite geometric series  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    StyleBox[
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", "3"}], "\[Infinity]"],
     FontSize->14], 
    RowBox[{
     StyleBox[
      FractionBox[
       RowBox[{" ", 
        SuperscriptBox["\[ImaginaryI]", "n"]}], 
       SuperscriptBox["2", "n"]],
      FontSize->14], 
     StyleBox["  ",
      FontSize->14], 
     StyleBox["is",
      FontSize->14], 
     StyleBox["  ",
      FontSize->14], 
     FractionBox["1", "20"]}]}], "-", 
   FractionBox["\[ImaginaryI]", "10"]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Remark 4.3.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  The equality given in Example 4.14 illustrates an important point when \
evaluating a geometric series whose beginning index is other than zero.  The \
value of ",
 Cell[BoxData[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"n", "=", "r"}], "\[Infinity]"], 
   SuperscriptBox["z", "n"]}]]],
 " equals",
 Cell[BoxData[
  FractionBox[
   SuperscriptBox["z", "r"], 
   RowBox[{"1", " ", "-", " ", "z"}]]]],
 ".  If we think of z as the \"ratio'' by which a given term of the series is \
multiplied to generate successive terms, we see that the sum of a geometric \
series equals ",
 Cell[BoxData[
  FractionBox[
   RowBox[{"first", " ", "term"}], 
   RowBox[{"1", " ", "-", " ", "ratio"}]]]],
 ", provided  ",
 Cell[BoxData[
  RowBox[{"|", "ratio", "|", 
   RowBox[{"<", "1"}]}]]],
 ".  "
}], "Text",
 CellChangeTimes->{{3.399116740875*^9, 3.39911674384375*^9}}],

Cell["\<\
\tThe geometric series is used in the proof of Theorem 4.12, which is known \
as the ratio test. It is one of the most commonly used tests for determining \
the convergence or divergence of series.  The proof is similar to the one \
used for real series, and we leave it for you to do.\
\>", "Text"],

Cell[TextData[{
 StyleBox["Theorem 4.13 (",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["d'Alembert's Ratio Test",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/RatioTest.html"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 StyleBox[").",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  If  ",
 Cell[BoxData[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"n", "=", "0"}], "\[Infinity]"], 
   SubscriptBox["\[Zeta]", "n"]}]]],
 "  is a complex series with the property that  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    UnderscriptBox["lim", 
     RowBox[{"n", " ", "\[Rule]", " ", "\[Infinity]"}]], " ", 
    FractionBox[
     RowBox[{"|", 
      SubscriptBox["\[Zeta]", 
       RowBox[{"n", "+", "1"}]], "|"}], 
     RowBox[{"|", 
      SubscriptBox["\[Zeta]", "n"], "|"}]]}], "=", "L"}]]],
 ",  \n\nthen the series converges absolutely if  ",
 Cell[BoxData[
  RowBox[{"L", "<", "1"}]]],
 "  and diverges if  ",
 Cell[BoxData[
  RowBox[{"L", ">", "1"}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 4.13 is left for the reader to do in \
the book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 4.15.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Show that  ",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", "0"}], "\[Infinity]"], 
    FractionBox[
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", " ", "-", " ", "\[ImaginaryI]"}], ")"}], "n"], 
     RowBox[{"n", "!"}]]}]}]]],
 "  converges."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "Solution.  Using the ratio test, we find that  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"n", " ", "\[Rule]", " ", "\[Infinity]"}]], " ", 
     RowBox[{"|", 
      RowBox[{
       FractionBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"1", " ", "-", " ", "\[ImaginaryI]"}], ")"}], 
          RowBox[{"n", "+", "1"}]], " "}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"n", "+", "1"}], ")"}], "!"}]], "/", 
       FractionBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"1", " ", "-", " ", "\[ImaginaryI]"}], ")"}], "n"], " "}], 
        
        RowBox[{"n", "!"}]]}], "|"}]}], "   ", "=", "   ", 
    RowBox[{
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"n", " ", "\[Rule]", " ", "\[Infinity]"}]], " ", 
      RowBox[{"|", 
       FractionBox[
        RowBox[{
         RowBox[{"n", "!"}], 
         RowBox[{"(", 
          RowBox[{"1", "-", "\[ImaginaryI]"}], ")"}], " "}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"n", "+", "1"}], ")"}], "!"}]], "|"}]}], 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     "                                                           ", 
     RowBox[{"=", "   ", 
      RowBox[{
       RowBox[{
        UnderscriptBox["lim", 
         RowBox[{"n", " ", "\[Rule]", " ", "\[Infinity]"}]], " ", 
        RowBox[{"|", 
         FractionBox[
          RowBox[{
           RowBox[{"n", "!"}], 
           RowBox[{"(", 
            RowBox[{"1", "-", "\[ImaginaryI]"}], ")"}], " "}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"n", "+", "1"}], ")"}], "!"}]], "|"}]}], 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       "                                                         ", 
       RowBox[{"=", "   ", 
        RowBox[{
         UnderscriptBox["lim", 
          RowBox[{"n", " ", "\[Rule]", " ", "\[Infinity]"}]], " ", 
         FractionBox[
          RowBox[{
           RowBox[{"n", "!"}], "|", 
           RowBox[{"1", "-", "\[ImaginaryI]"}], "|", " "}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"n", "+", "1"}], ")"}], "!"}]]}]}]}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                                                                ", 
   
   RowBox[{
    RowBox[{"=", "   ", 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"n", " ", "\[Rule]", " ", "\[Infinity]"}]], " ", 
      FractionBox[
       RowBox[{
        RowBox[{"n", "!"}], "|", 
        RowBox[{"1", "-", "\[ImaginaryI]"}], "|", " "}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"n", "+", "1"}], ")"}], "!"}]]}]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                                                                ", 
   
   RowBox[{
    RowBox[{"=", "   ", 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"n", " ", "\[Rule]", " ", "\[Infinity]"}]], " ", 
      FractionBox[
       RowBox[{"|", 
        RowBox[{"1", "-", "\[ImaginaryI]"}], "|", " "}], 
       RowBox[{"n", "+", "1"}]]}]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                                                                ", 
   
   RowBox[{
    RowBox[{"=", "   ", 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"n", " ", "\[Rule]", " ", "\[Infinity]"}]], " ", 
      FractionBox[
       RowBox[{
        SqrtBox["2"], " "}], 
       RowBox[{"n", "+", "1"}]]}]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                                                                ", 
   
   RowBox[{"=", "  ", 
    RowBox[{"0", "  ", "=", "  ", "L", " "}]}]}]}]],
 "   \n\nBecause  ",
 Cell[BoxData[
  RowBox[{"L", "<", "1"}]]],
 ",  the series converges."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 4.15.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell["Enter the formula for the terms in the series.", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", "z", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"L", ",", "n", ",", "sum", ",", "r"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "n_"], " ", "=", " ", 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", " ", "-", " ", "\[ImaginaryI]"}], ")"}], "n"], " "}], 
      RowBox[{"n", "!"}]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(n\)]\) = \>\"", ",", 
      SubscriptBox["z", "n"]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.3991149563125*^9}],

Cell["\<\
  Use d'Alembert's ratio test. First, find the ratio of consecutive terms.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<         \!\(\*SubscriptBox[\(z\), \(n + 1\)]\) = \>\"", ",", 
      SubscriptBox["z", 
       RowBox[{"n", "+", "1"}]]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<          \!\(\*SubscriptBox[\(z\), \(n\)]\) = \>\"", ",", 
      SubscriptBox["z", "n"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"r", " ", "=", " ", 
     FractionBox[
      SubscriptBox["z", 
       RowBox[{"n", "+", "1"}]], 
      SubscriptBox["z", "n"]]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<        \!\(\*FractionBox[SubscriptBox[\(z\), \(n + 1\)], \
SubscriptBox[\(z\), \(n\)]]\) = \>\"", ",", "r"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"r", " ", "=", " ", 
     RowBox[{"FullSimplify", "[", "r", "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<        \!\(\*FractionBox[SubscriptBox[\(z\), \(n + 1\)], \
SubscriptBox[\(z\), \(n\)]]\) = \>\"", ",", "r"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<       |\!\(\*FractionBox[SubscriptBox[\(z\), \(n + 1\)], \
SubscriptBox[\(z\), \(n\)]]\)| = \>\"", ",", 
      FractionBox[
       RowBox[{"Abs", "[", 
        RowBox[{"Numerator", "[", "r", "]"}], "]"}], 
       RowBox[{"Denominator", "[", "r", "]"}]]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"L", " ", "=", " ", 
     RowBox[{"Limit", "[", " ", 
      RowBox[{"r", " ", ",", " ", 
       RowBox[{"n", "\[Rule]", "\[Infinity]"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<L = \!\(\*UnderscriptBox[\(lim\), \(n \[Rule] \[Infinity]\)]\) \
|\!\(\*FractionBox[SubscriptBox[\(z\), \(n + 1\)], SubscriptBox[\(z\), \
\(n\)]]\)| = \>\"", ",", "L"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39911496003125*^9}],

Cell[TextData[{
 "Since L < 1, the series converges.   \n\nWe can use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to find the sum of series."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"sum", "  ", "=", "  ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "0"}], "\[Infinity]"], 
      FractionBox[
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "-", "\[ImaginaryI]"}], ")"}], "n"], 
       RowBox[{"n", "!"}]]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 0\), \
\(\[Infinity]\)]\)\!\(\*FractionBox[SuperscriptBox[\((1 - \[ImaginaryI])\), \
\(n\)], \(n!\)]\) = \>\"", ",", "sum"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399114964828125*^9}],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to construct some of the partial sums of the infinite series."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["S", "n_"], " ", "=", " ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"k", "=", "0"}], "n"], 
      FractionBox[
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "-", "\[ImaginaryI]"}], ")"}], "k"], 
       RowBox[{"k", "!"}]]}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"table", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"FullSimplify", "[", 
        SubscriptBox["S", "n"], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "0", ",", "10"}], "}"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"table", "=", 
     RowBox[{"Append", "[", 
      RowBox[{"table", ",", "\"\<...\>\""}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(S\), \(n\)]\)} = \>\"", ",", "table"}], "]"}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<{\!\(\*SubscriptBox[\(S\), \(n\)]\)} = \>\"", ",", 
      RowBox[{"N", "[", "table", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 0\), \
\(\[Infinity]\)]\)\!\(\*FractionBox[SuperscriptBox[\((1 - \[ImaginaryI])\), \
\(n\)], \(n!\)]\) = \>\"", ",", "sum"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39911497090625*^9}],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to plot some of the partial sums of the infinite series."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"set", " ", "=", "  ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          SubscriptBox["S", "n"], "]"}], ",", 
         RowBox[{"Im", "[", 
          SubscriptBox["S", "n"], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "0", ",", "10"}], "}"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dot", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"PointSize", "[", "0.023", "]"}], ",", "Red", ",", 
        RowBox[{"Point", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Re", "[", "sum", "]"}], ",", 
           RowBox[{"Im", "[", "sum", "]"}]}], "}"}], "]"}]}], "}"}], "]"}]}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"graph", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"set", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"PointSize", "[", "0.02", "]"}], ",", "Blue"}], "}"}]}], 
       ",", "\[IndentingNewLine]", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.05"}], ",", "2.35"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2.4"}], ",", "0.05"}], "}"}]}], "}"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "2.5", ",", "0.5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "2.5"}], ",", "0", ",", "0.5"}], "]"}]}], "}"}]}]}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"graph2", "=", 
     RowBox[{"Show", "[", 
      RowBox[{"graph", ",", "dot"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "graph2", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<{\!\(\*SubscriptBox[\(S\), \(n\)]\)} = \>\"", ",", 
      RowBox[{"N", "[", "table", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 0\), \
\(\[Infinity]\)]\)\!\(\*FractionBox[SuperscriptBox[\((1 - \[ImaginaryI])\), \
\(n\)], \(n!\)]\) = \>\"", ",", "sum"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3991149753125*^9, 3.39911498903125*^9}, {
  3.399201893546875*^9, 3.399201920234375*^9}, {3.399798553187252*^9, 
  3.399798553374752*^9}, {3.400261178328125*^9, 3.4002611815625*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "We see that the infinite series  ",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", "0"}], "\[Infinity]"], 
    FractionBox[
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", " ", "-", " ", "\[ImaginaryI]"}], ")"}], "n"], 
     RowBox[{"n", "!"}]]}]}]]],
 "  converges and that its sum is  ",
 Cell[BoxData[
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{"1", "-", "\[ImaginaryI]"}]]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 4.16.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Show that  ",
 Cell[BoxData[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"n", "=", "0"}], "\[Infinity]"], 
   FractionBox[
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"z", " ", "-", " ", "\[ImaginaryI]"}], ")"}], "n"], 
    SuperscriptBox["2", "n"]]}]]],
 " converges for all  z  in the disk  ",
 Cell[BoxData[
  RowBox[{"|", 
   RowBox[{"z", "-", "\[ImaginaryI]"}], "|", 
   RowBox[{"<", " ", "2"}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "Solution.  Using the ratio test, we find that  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   UnderscriptBox["lim", 
    RowBox[{"n", " ", "\[Rule]", " ", "\[Infinity]"}]], " ", 
   RowBox[{"|", 
    RowBox[{
     FractionBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", " ", "-", " ", "\[ImaginaryI]"}], ")"}], 
       RowBox[{"n", "+", "1"}]], 
      SuperscriptBox["2", 
       RowBox[{"n", "+", "1"}]]], "/", 
     FractionBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", " ", "-", " ", "\[ImaginaryI]"}], ")"}], "n"], 
      SuperscriptBox["2", "n"]]}], "|", " ", 
    RowBox[{"\[Equal]", " ", 
     UnderscriptBox["lim", 
      RowBox[{"n", " ", "\[Rule]", " ", "\[Infinity]"}]]}], " ", "|", 
    FractionBox[
     RowBox[{"z", "-", "\[ImaginaryI]"}], "2"], "|", " ", 
    RowBox[{"\[Equal]", " ", 
     FractionBox[
      RowBox[{"|", 
       RowBox[{"z", "-", "\[ImaginaryI]"}], "|"}], "2"], " ", "\[Equal]", " ",
      "L"}]}]}]]],
 ".\n\nIf  ",
 Cell[BoxData[
  RowBox[{"|", 
   RowBox[{"z", "-", "\[ImaginaryI]"}], "|", 
   RowBox[{"<", " ", "2"}]}]]],
 ",  then  ",
 Cell[BoxData[
  RowBox[{
   FractionBox[
    RowBox[{"|", 
     RowBox[{"z", "-", "\[ImaginaryI]"}], "|"}], "2"], " ", "=", "  ", 
   RowBox[{"L", " ", "<", " ", "1"}]}]]],
 ",  and the series converges.  \n\nIf  ",
 Cell[BoxData[
  RowBox[{"|", 
   RowBox[{"z", "-", "\[ImaginaryI]"}], "|", 
   RowBox[{">", " ", "2"}]}]]],
 ",  then  ",
 Cell[BoxData[
  RowBox[{"L", ">", "1"}]]],
 ",  and the series diverges."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 4.16.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell["Enter the formula for the terms in the series.", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", "z", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"L", ",", "n", ",", "sum", ",", "r", ",", "Z"}], "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "n_"], " ", "=", " ", 
     FractionBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", " ", "-", " ", "\[ImaginaryI]"}], ")"}], "n"], 
      SuperscriptBox["2", "n"]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(n\)]\) = \>\"", ",", 
      SubscriptBox["z", "n"]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.3991149968125*^9}],

Cell["\<\
Use d'Alembert's ratio test. First, find the ratio of consecutive terms.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"r", " ", "=", " ", 
     FractionBox[
      SubscriptBox["z", 
       RowBox[{"n", "+", "1"}]], 
      SubscriptBox["z", "n"]]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"L", " ", "=", " ", 
     RowBox[{"Limit", "[", " ", 
      RowBox[{"r", " ", ",", " ", 
       RowBox[{"n", "\[Rule]", "\[Infinity]"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<         \!\(\*SubscriptBox[\(z\), \(n + 1\)]\) = \>\"", ",", 
      SubscriptBox["z", 
       RowBox[{"n", "+", "1"}]]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<          \!\(\*SubscriptBox[\(z\), \(n\)]\) = \>\"", ",", 
      SubscriptBox["z", "n"]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<        \!\(\*FractionBox[SubscriptBox[\(z\), \(n + 1\)], \
SubscriptBox[\(z\), \(n\)]]\) = \>\"", ",", "r"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<L = \!\(\*UnderscriptBox[\(lim\), \(n \[Rule] \[Infinity]\)]\) \
|\!\(\*FractionBox[SubscriptBox[\(z\), \(n + 1\)], SubscriptBox[\(z\), \
\(n\)]]\)| = \>\"", ",", 
      RowBox[{"Abs", "[", "L", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399115000265625*^9}],

Cell[TextData[{
 "When  L < 1, the series will converge.  Solve ",
 Cell[BoxData[
  RowBox[{"|", 
   FractionBox[
    RowBox[{"z", " ", "-", " ", "\[ImaginaryI]"}], "2"], "|", 
   RowBox[{"<", "1"}]}]]],
 "  and obtain the disk  ",
 Cell[BoxData[
  RowBox[{"|", 
   RowBox[{"z", "-", "\[ImaginaryI]"}], "|", 
   RowBox[{"<", " ", "2"}]}]]],
 ".  \n\nUse ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to find the sum of the infinite series."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     StyleBox[
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"n", "=", "0"}], "\[Infinity]"], 
       FractionBox[
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"z", "-", "\[ImaginaryI]"}], ")"}], "n"], 
        SuperscriptBox["2", "n"]]}],
      FontSize->14]}], 
    StyleBox[";",
     FontSize->14]}], 
   StyleBox[" ",
    FontSize->14], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<f[z] = \!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 0\), \
\(\[Infinity]\)]\)\!\(\*FractionBox[SuperscriptBox[\((z - \[ImaginaryI])\), \
\(n\)], SuperscriptBox[\(2\), \(n\)]]\) = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399115004578125*^9, 3.3991150058125*^9}}],

Cell[TextData[{
 "We can investigate the convergence by plotting several partial sums of this \
series.\n\nSince convergence will be more rapid in a smaller disk  ",
 Cell[BoxData[
  RowBox[{"|", 
   RowBox[{"z", "-", "\[ImaginaryI]"}], "|", 
   RowBox[{"<", " ", "r"}]}]]],
 ",  the following plot will be a smaller disk with  ",
 Cell[BoxData[
  RowBox[{"r", "=", "1"}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"F", ",", "G", ",", "m"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"f", "[", 
      RowBox[{"z", "+", "\[ImaginaryI]"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"S", "[", 
      RowBox[{"z_", ",", "n_"}], "]"}], "=", 
     StyleBox[
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"n", "=", "0"}], "n"], 
       FractionBox[
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"z", "-", "\[ImaginaryI]"}], ")"}], "n"], 
        SuperscriptBox["2", "n"]]}],
      FontSize->14]}], 
    StyleBox[";",
     FontSize->14]}], 
   StyleBox[" ",
    FontSize->14], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"For", " ", "[", 
     RowBox[{
      RowBox[{"m", "=", "3"}], ",", 
      RowBox[{"m", "\[LessEqual]", "6"}], ",", 
      RowBox[{"m", "++"}], ",", "\n", 
      RowBox[{
       RowBox[{
        RowBox[{"G", "[", "z_", "]"}], " ", "=", " ", 
        RowBox[{"S", "[", 
         RowBox[{
          RowBox[{"z", "+", "\[ImaginaryI]"}], ",", "m"}], "]"}]}], ";", " ", 
       "\n", 
       RowBox[{"g0", "=", 
        RowBox[{"PolarMap", "[", 
         RowBox[{"G", " ", ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1.0", ",", "0.2"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{"2", "\[Pi]"}], ",", 
            FractionBox["\[Pi]", "12"]}], "}"}], ",", "\[IndentingNewLine]", 
          RowBox[{"PlotRange", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", "2"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "0.7"}], ",", "0.7"}], "}"}]}], "}"}]}], ",", 
          RowBox[{"AspectRatio", "\[Rule]", 
           FractionBox["7", "10"]}], ",", "\[IndentingNewLine]", 
          RowBox[{"Ticks", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               FractionBox["1", "4"], ",", 
               FractionBox["1", "2"], ",", 
               FractionBox["3", "2"], ",", "2"}], "}"}], ",", 
             RowBox[{"Range", "[", 
              RowBox[{
               RowBox[{"-", "1"}], ",", "1", ",", 
               FractionBox["1", "4"]}], "]"}]}], "}"}]}], ",", 
          RowBox[{"AxesLabel", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"\"\<u\>\"", ",", "\"\<u\>\""}], "}"}]}], ",", 
          RowBox[{"PlotStyle", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"Red", ",", "Blue"}], "}"}]}]}], "]"}]}], ";", " ", 
       "\[IndentingNewLine]", 
       RowBox[{"Print", "[", "g0", "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{"\"\<w = \>\"", ",", 
         SubscriptBox["\"\<S\>\"", "m"], ",", "\"\<(z) = \>\"", ",", 
         RowBox[{"Normal", "[", 
          RowBox[{"Series", "[", 
           RowBox[{
            RowBox[{"S", "[", 
             RowBox[{"z", ",", "m"}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"z", ",", "\[ImaginaryI]", ",", "m"}], "}"}]}], "]"}], 
          "]"}], ",", "\"\<\\n\>\"", " ", ",", "\"\<\\n\>\""}], " ", "]"}], 
       ";"}]}], "  ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g1", "=", 
     RowBox[{"PolarMap", "[", 
      RowBox[{"F", " ", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "1.0", ",", "0.2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"2", "\[Pi]"}], ",", 
         FractionBox["\[Pi]", "12"]}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "2"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.7"}], ",", "0.7"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", 
        FractionBox["7", "10"]}], ",", "\[IndentingNewLine]", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            FractionBox["1", "4"], ",", 
            FractionBox["1", "2"], ",", 
            FractionBox["3", "2"], ",", "2"}], "}"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "1", ",", 
            FractionBox["1", "4"]}], "]"}]}], "}"}]}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Red", ",", "Blue"}], "}"}]}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "g1", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<The limit function is w = f(z) = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399116200359375*^9, 3.3991162823125*^9}}],

Cell[TextData[{
 "Convergence will be slower in a larger disk  ",
 Cell[BoxData[
  RowBox[{"|", 
   RowBox[{"z", "-", "\[ImaginaryI]"}], "|", 
   RowBox[{"<", " ", "r"}]}]]],
 ",  the following plot will be from a larger disk with  ",
 Cell[BoxData[
  RowBox[{"r", "=", "1.6"}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"F", ",", "G", ",", "j", ",", "m"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"f", "[", 
      RowBox[{"z", "+", "\[ImaginaryI]"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"S", "[", 
      RowBox[{"z_", ",", "n_"}], "]"}], "=", 
     StyleBox[
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"n", "=", "0"}], "n"], 
       FractionBox[
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"z", "-", "\[ImaginaryI]"}], ")"}], "n"], 
        SuperscriptBox["2", "n"]]}],
      FontSize->14]}], 
    StyleBox[";",
     FontSize->14]}], 
   StyleBox[" ",
    FontSize->14], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"For", " ", "[", 
     RowBox[{
      RowBox[{"j", "=", "3"}], ",", 
      RowBox[{"j", "\[LessEqual]", "5"}], ",", 
      RowBox[{"j", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"m", "=", 
        RowBox[{"5", "*", "j"}]}], ";", " ", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"G", "[", "z_", "]"}], " ", "=", " ", 
        RowBox[{"S", "[", 
         RowBox[{
          RowBox[{"z", "+", "\[ImaginaryI]"}], ",", "m"}], "]"}]}], ";", " ", 
       "\[IndentingNewLine]", 
       RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"g0", "=", 
        RowBox[{"PolarMap", "[", 
         RowBox[{"G", " ", ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1.6", ",", "0.2"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{"2", "\[Pi]"}], ",", 
            FractionBox["\[Pi]", "12"]}], "}"}], ",", "\[IndentingNewLine]", 
          RowBox[{"PlotRange", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", "2"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "0.7"}], ",", "0.7"}], "}"}]}], "}"}]}], ",", 
          RowBox[{"AspectRatio", "\[Rule]", 
           FractionBox["7", "10"]}], ",", "\[IndentingNewLine]", 
          RowBox[{"Ticks", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               FractionBox["1", "4"], ",", 
               FractionBox["1", "2"], ",", 
               FractionBox["3", "2"], ",", "2"}], "}"}], ",", 
             RowBox[{"Range", "[", 
              RowBox[{
               RowBox[{"-", "1"}], ",", "1", ",", 
               FractionBox["1", "4"]}], "]"}]}], "}"}]}], ",", 
          RowBox[{"AxesLabel", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"\"\<u\>\"", ",", "\"\<u\>\""}], "}"}]}], ",", 
          RowBox[{"PlotStyle", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], ";", " ", 
       "\[IndentingNewLine]", 
       RowBox[{"Print", "[", "g0", "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{"\"\<w = \>\"", ",", 
         SubscriptBox["\"\<S\>\"", "m"], ",", "\"\<(z) = \>\"", ",", 
         RowBox[{"Normal", "[", 
          RowBox[{"Series", "[", 
           RowBox[{
            RowBox[{"S", "[", 
             RowBox[{"z", ",", "m"}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"z", ",", "\[ImaginaryI]", ",", "m"}], "}"}]}], "]"}], 
          "]"}], ",", "\"\<\\n\>\"", ",", "\"\<\\n\>\""}], "]"}], ";"}]}], 
     "  ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g1", "=", 
     RowBox[{"PolarMap", "[", 
      RowBox[{"F", " ", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "1.6", ",", "0.2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"2", "\[Pi]"}], ",", 
         FractionBox["\[Pi]", "12"]}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "2"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.7"}], ",", "0.7"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", 
        FractionBox["7", "10"]}], ",", "\[IndentingNewLine]", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            FractionBox["1", "4"], ",", 
            FractionBox["1", "2"], ",", 
            FractionBox["3", "2"], ",", "2"}], "}"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "1", ",", 
            FractionBox["1", "4"]}], "]"}]}], "}"}]}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "g1", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<The limit function is w = f(z) = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399116296578125*^9, 3.399116366671875*^9}, {
  3.3997985582966275`*^9, 3.3997985585153775`*^9}}],

Cell["\<\
We see that the sequence of functions {S[x,n]} is converging to f[z].\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"funs", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         SubscriptBox["s", "m"], "[", "z", "]"}], ",", "\"\<=\>\"", ",", 
        RowBox[{"S", "[", 
         RowBox[{"z", ",", "m"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"m", ",", "1", ",", "5"}], "}"}]}], "]"}]}], ";"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"funs", "=", 
    RowBox[{"Append", "[", 
     RowBox[{"funs", ",", 
      RowBox[{"{", 
       RowBox[{"\"\<...\>\"", ",", "\"\<\>\"", ",", "\"\<...\>\""}], "}"}]}], 
     "]"}]}], ";"}], " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"funs", "=", 
    RowBox[{"Append", "[", 
     RowBox[{"funs", ",", 
      RowBox[{"{", 
       RowBox[{"\"\<f[z]\>\"", ",", "\"\<=\>\"", ",", 
        RowBox[{"f", "[", "z", "]"}]}], "}"}]}], "]"}]}], ";"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{"TableForm", "[", "funs", "]"}], "\[IndentingNewLine]"}], "Input"]
}, Closed]],

Cell["\<\
\tOur next result, known as the root test, is slightly more powerful than the \
ratio test.  Before we present this test, we need to discuss a rather \
sophisticated idea used with it-the limit supremum.\
\>", "Text",
 CellChangeTimes->{3.399116752375*^9}],

Cell[TextData[{
 StyleBox["Definition 4.10 (",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Limit Supremum",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/SupremumLimit.html"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 StyleBox[").",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Let  ",
 Cell[BoxData[
  RowBox[{"{", 
   SubscriptBox["t", "n"], "}"}]]],
 "  be a sequence of positive real numbers.  The ",
 StyleBox[ButtonBox["limit supremum",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/SupremumLimit.html"], None}],
  FontVariations->{"Underline"->True}],
 " of the sequence  (denoted by ",
 Cell[BoxData[
  RowBox[{
   UnderscriptBox[
    RowBox[{"lim", " ", "sup"}], 
    RowBox[{"n", " ", "\[Rule]", " ", "\[Infinity]"}]], " ", 
   SubscriptBox["t", "n"]}]]],
 ")  is the smallest real number  L  with the property that for any  ",
 Cell[BoxData[
  RowBox[{"\[Epsilon]", ">", "0"}]]],
 "  there are at most finitely many terms in the sequence that are larger \
than  ",
 Cell[BoxData[
  RowBox[{"L", "+", "\[Epsilon]"}]]],
 ".  If there is no such number  L,  then we set  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    UnderscriptBox[
     RowBox[{"lim", " ", "sup"}], 
     RowBox[{"n", " ", "\[Rule]", " ", "\[Infinity]"}]], " ", 
    SubscriptBox["t", "n"]}], "=", "\[Infinity]"}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 StyleBox["Example 4.17.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  The limit supremum of the sequence  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"{", 
    SubscriptBox["t", "n"], "}"}], "=", 
   RowBox[{"{", 
    RowBox[{
    "4.1", ",", "5.1", ",", "4.01", ",", "5.01", ",", "4.001", ",", "5.001", 
     ",", "..."}], "}"}]}]]],
 "  is   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    UnderscriptBox[
     RowBox[{"lim", " ", "sup"}], 
     RowBox[{"n", "\[Rule]", "\[Infinity]"}]], " ", 
    SubscriptBox["t", "n"]}], "=", "5"}]]],
 ",   because if we set  ",
 Cell[BoxData[
  RowBox[{"L", "=", "5"}]]],
 ",  then for any  ",
 Cell[BoxData[
  RowBox[{"\[Element]", 
   RowBox[{">", "0"}]}]]],
 ",  there are only finitely many terms in the sequence larger than  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"L", "+"}], "\[Element]"}], "=", 
   RowBox[{
    RowBox[{"5", "+"}], "\[Element]"}]}]]],
 ".  Additionally, if ",
 StyleBox["L",
  FontFamily->"Courier New"],
 " is smaller than ",
 StyleBox["5",
  FontFamily->"Courier New"],
 ", then by setting  ",
 Cell[BoxData[
  RowBox[{"\[Element]", 
   RowBox[{"=", 
    RowBox[{"5", "-", "L"}]}]}]]],
 ",  we can find infinitely many terms in the sequence larger than  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"L", "+"}], "\[Element]"}]]],
 "  (because  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"L", "+"}], "\[Element]"}], "=", "5"}]]],
 ")."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 4.17.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "In this case the even terms  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["t", 
    RowBox[{"2", " ", "k"}]], "=", 
   RowBox[{"4", "+", 
    SuperscriptBox["10", 
     RowBox[{
      RowBox[{"-", "1"}], "-", "k"}]]}]}]]],
 "  tend to the limit 4 and the odd terms  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["t", 
    RowBox[{
     RowBox[{"2", " ", "k"}], "+", "1"}]], "=", 
   RowBox[{"5", "+", 
    SuperscriptBox["10", 
     RowBox[{
      RowBox[{"-", "1"}], "-", "k"}]]}]}]]],
 "  tend to the limit 5."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", "t", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"limsup", ",", "k", ",", "n", ",", "table"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["t", 
      RowBox[{"even", ",", "k_"}]], "=", 
     RowBox[{"4", "+", 
      FractionBox["1", 
       SuperscriptBox["10", 
        RowBox[{"k", "+", "1"}]]]}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["t", 
      RowBox[{"odd", ",", "k_"}]], "=", 
     RowBox[{"5", "+", 
      FractionBox["1", 
       SuperscriptBox["10", 
        RowBox[{"k", "+", "1"}]]]}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"lim1", "=", 
     RowBox[{"Limit", "[", 
      RowBox[{
       SubscriptBox["t", 
        RowBox[{"even", ",", "k"}]], ",", 
       RowBox[{"k", "\[Rule]", "\[Infinity]"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"lim2", "=", 
     RowBox[{"Limit", "[", 
      RowBox[{
       SubscriptBox["t", 
        RowBox[{"odd", ",", "k"}]], ",", 
       RowBox[{"k", "\[Rule]", "\[Infinity]"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"limsup", "=", 
     RowBox[{"Max", "[", 
      RowBox[{"lim1", ",", "lim2"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"table", "=", 
     RowBox[{"Flatten", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          SubscriptBox["t", 
           RowBox[{"even", ",", "k"}]], ",", 
          SubscriptBox["t", 
           RowBox[{"odd", ",", "k"}]]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", "0", ",", "4"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"table", "=", 
     RowBox[{"Append", "[", 
      RowBox[{"table", ",", "\"\<...\>\""}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(t\), \(n\)]\)} = \>\"", ",", "table"}], "]"}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  \!\(\*SubscriptBox[\(t\), \(2  k\)]\) = (\>\"", ",", 
      SubscriptBox["t", 
       RowBox[{"even", ",", "k"}]], ",", "\"\<)\>\""}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< \!\(\*SubscriptBox[\(t\), \(2  k + 1\)]\) = (\>\"", ",", 
      SubscriptBox["t", 
       RowBox[{"odd", ",", "k"}]], " ", ",", "\"\<)\>\""}], "]"}], ";"}], " ",
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< \!\(\*UnderscriptBox[\(lim\), \(k \[Rule] \[Infinity]\)]\) \
\!\(\*SubscriptBox[\(t\), \(2  k\)]\) = \!\(\*UnderscriptBox[\(lim\), \(k \
\[Rule] \[Infinity]\)]\) (\>\"", ",", 
      SubscriptBox["t", 
       RowBox[{"even", ",", "k"}]], " ", ",", "\"\<) = \>\"", ",", "lim1"}], 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(lim\), \(k \[Rule] \[Infinity]\)]\) \
\!\(\*SubscriptBox[\(t\), \(2  k + 1\)]\) = \!\(\*UnderscriptBox[\(lim\), \(k \
\[Rule] \[Infinity]\)]\) (\>\"", ",", 
      SubscriptBox["t", 
       RowBox[{"odd", ",", "k"}]], " ", ",", "\"\<) = \>\"", ",", "lim2"}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(limsup\), \(n \[Rule] \[Infinity]\)]\) \
\!\(\*SubscriptBox[\(t\), \(n\)]\) = Max[\>\"", ",", "lim1", ",", "\"\<,\>\"",
       ",", "lim2", ",", "\"\<]\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(limsup\), \(n \[Rule] \[Infinity]\)]\) \
\!\(\*SubscriptBox[\(t\), \(n\)]\) = \>\"", ",", "limsup"}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.3991163963125*^9}],

Cell[TextData[{
 "The limit superior is the largest limit point of a subsequence of  ",
 Cell[BoxData[
  RowBox[{"{", 
   SubscriptBox["t", "n"], "}"}]]],
 ".  \n\nWe can use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to graph the sequence and look for the largest limit point of a \
subsequence."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"pts0", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"Green", ",", 
         RowBox[{"PointSize", "[", "0.02", "]"}], ",", 
         RowBox[{"Point", "[", 
          RowBox[{"N", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"2", "k"}], ",", 
             SubscriptBox["t", 
              RowBox[{"even", ",", 
               RowBox[{"2", "k"}]}]]}], "}"}], "]"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "0", ",", "10"}], "}"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"pts1", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"Red", ",", 
         RowBox[{"PointSize", "[", "0.02", "]"}], ",", 
         RowBox[{"Point", "[", 
          RowBox[{"N", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"2", "k"}], "+", "1"}], ",", 
             SubscriptBox["t", 
              RowBox[{"odd", ",", 
               RowBox[{
                RowBox[{"2", "k"}], "+", "1"}]}]]}], "}"}], "]"}], "]"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "0", ",", "10"}], "}"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"pts", "=", 
     RowBox[{"Union", "[", 
      RowBox[{"pts0", ",", "pts1"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g0", "=", 
     RowBox[{"Show", "[", 
      RowBox[{
       RowBox[{"Graphics", "[", "pts", "]"}], ",", 
       RowBox[{"Axes", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "20"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "6"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
         "\"\<k\>\"", ",", "\"\<\!\(\*SubscriptBox[\(t\), \(k\)]\)\>\""}], 
         "}"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "20", ",", "2"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "6", ",", "1"}], "]"}]}], "}"}]}]}], "]"}]}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "g0", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<{\!\(\*SubscriptBox[\(t\), \(n\)]\)} = \>\"", ",", 
      RowBox[{"N", "[", "table", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3991164015625*^9, 3.3991164230625*^9}, {
  3.3992019581875*^9, 3.39920199990625*^9}, {3.399798563593502*^9, 
  3.399798563781002*^9}}],

Cell[TextData[{
 "We see that the limit supremum of the sequence ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"{", 
    SubscriptBox["t", "n"], "}"}], "=", 
   RowBox[{"{", 
    RowBox[{
    "4.1", ",", "5.1", ",", "4.01", ",", "5.01", ",", "4.001", ",", "5.001", 
     ",", "..."}], "}"}]}]]],
 "  is  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    UnderscriptBox[
     RowBox[{"lim", " ", "sup"}], 
     RowBox[{"n", "\[Rule]", "\[Infinity]"}]], " ", 
    SubscriptBox["t", "n"]}], "=", "5"}]]],
 ".  "
}], "Text"]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 4.18.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  The limit supremum of the sequence ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"{", 
    SubscriptBox["t", "n"], "}"}], "=", 
   RowBox[{"{", 
    RowBox[{
    "1", ",", "2", ",", "3", ",", "1", ",", "2", ",", "3", ",", "1", ",", "2",
      ",", "3", ",", "..."}], "}"}]}]]],
 "  is   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    UnderscriptBox[
     RowBox[{"lim", " ", "sup"}], 
     RowBox[{"n", "\[Rule]", "\[Infinity]"}]], " ", 
    SubscriptBox["t", "n"]}], "=", "3"}]]],
 ",   because if we set  ",
 Cell[BoxData[
  RowBox[{"L", "=", "3"}]]],
 ",  then for any  ",
 Cell[BoxData[
  RowBox[{"\[Element]", 
   RowBox[{">", "0"}]}]]],
 ",  there are only finitely many terms (actually, there are none) in the \
sequence larger than  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"L", "+"}], "\[Element]"}], "=", 
   RowBox[{
    RowBox[{"3", "+"}], "\[Element]"}]}]]],
 ".  Additionally, if ",
 StyleBox["L",
  FontFamily->"Courier New"],
 " is smaller than ",
 StyleBox["3",
  FontFamily->"Courier New"],
 ", then by setting  ",
 Cell[BoxData[
  RowBox[{"\[Element]", 
   RowBox[{"=", 
    FractionBox[
     RowBox[{"3", "-", "L"}], "2"]}]}]]],
 "  we can find infinitely many terms in the sequence larger than  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"L", "+"}], "\[Element]"}]]],
 ",  because  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"L", "+"}], "\[Element]", 
   RowBox[{"<", " ", "3"}]}]]],
 ",  as the following calculation shows:  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"L", "+"}], "\[Element]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{"L", "+", 
     FractionBox[
      RowBox[{"3", "-", "L"}], "2"]}], " ", "=", " ", 
    RowBox[{
     FractionBox[
      RowBox[{"3", "+", "L"}], "2"], " ", "=", " ", 
     RowBox[{
      RowBox[{
       RowBox[{
        FractionBox["3", "2"], "+", 
        FractionBox["L", "2"]}], " ", "<", " ", 
       RowBox[{
        FractionBox["3", "2"], "+", 
        FractionBox["3", "2"]}]}], " ", "=", " ", "3"}]}]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 4.18.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell["\<\
In this case there are only three different values for the terms in the \
sequence.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", "k", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"table", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"1", "+", 
        RowBox[{"Mod", "[", 
         RowBox[{"k", ",", "3"}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "0", ",", "15"}], "}"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"table", "=", 
     RowBox[{"Append", "[", 
      RowBox[{"table", ",", "\"\<...\>\""}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(t\), \(n\)]\)} = \>\"", ",", "table"}], "]"}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<\!\(\*UnderscriptBox[\(limsup\), \(n \[Rule] \[Infinity]\)]\) \
\!\(\*SubscriptBox[\(t\), \(n\)]\) = Max[1,2,3]\>\"", "]"}], ";"}], " ", "\n",
    
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(limsup\), \(n \[Rule] \[Infinity]\)]\) \
\!\(\*SubscriptBox[\(t\), \(n\)]\) = \>\"", ",", 
      RowBox[{"Max", "[", 
       RowBox[{"1", ",", "2", ",", "3"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399116431484375*^9}],

Cell[TextData[{
 "The limit superior is the largest limit point of a subsequence of  ",
 Cell[BoxData[
  RowBox[{"{", 
   SubscriptBox["t", "n"], "}"}]]],
 ".  \n\nWe can use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to graph the sequence and look for the largest limit point of a \
subsequence."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"pts0", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"Green", ",", 
         RowBox[{"PointSize", "[", "0.02", "]"}], ",", 
         RowBox[{"Point", "[", 
          RowBox[{"N", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"3", "k"}], ",", "1"}], "}"}], "]"}], "]"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "0", ",", "10"}], "}"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"pts1", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"Blue", ",", 
         RowBox[{"PointSize", "[", "0.02", "]"}], ",", 
         RowBox[{"Point", "[", 
          RowBox[{"N", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"3", "k"}], "+", "1"}], ",", "2"}], "}"}], "]"}], 
          "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "0", ",", "10"}], "}"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"pts2", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"Red", ",", 
         RowBox[{"PointSize", "[", "0.02", "]"}], ",", 
         RowBox[{"Point", "[", 
          RowBox[{"N", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"3", "k"}], "+", "2"}], ",", "3"}], "}"}], "]"}], 
          "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "0", ",", "10"}], "}"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"pts", "=", 
     RowBox[{"Union", "[", 
      RowBox[{"pts0", ",", "pts1", ",", "pts2"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g0", "=", 
     RowBox[{"Show", "[", 
      RowBox[{
       RowBox[{"Graphics", "[", "pts", "]"}], ",", 
       RowBox[{"Axes", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "30"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "3.5"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
         "\"\<k\>\"", ",", "\"\<\!\(\*SubscriptBox[\(t\), \(k\)]\)\>\""}], 
         "}"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "30", ",", "3"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "4", ",", "1"}], "]"}]}], "}"}]}]}], "]"}]}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "g0", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(t\), \(n\)]\)} = \>\"", ",", "table"}], "]"}],
     ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399116435625*^9, 3.39911644984375*^9}, {
  3.399202013546875*^9, 3.39920204075*^9}, {3.3997985689216275`*^9, 
  3.399798569124752*^9}}],

Cell[TextData[{
 "We see that the limit supremum of the sequence ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"{", 
    SubscriptBox["t", "n"], "}"}], "=", 
   RowBox[{"{", 
    RowBox[{
    "1", ",", "2", ",", "3", ",", "1", ",", "2", ",", "3", ",", "1", ",", "2",
      ",", "3", ",", "..."}], "}"}]}]]],
 "  is  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    UnderscriptBox[
     RowBox[{"lim", " ", "sup"}], 
     RowBox[{"n", "\[Rule]", "\[Infinity]"}]], " ", 
    SubscriptBox["t", "n"]}], "=", "3"}]]],
 ".  "
}], "Text"]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 4.19.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  The limit supremum of the Fibonacci sequence  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"{", 
    SubscriptBox["t", "n"], "}"}], "=", " "}]]],
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{
   "1", ",", "1", ",", "2", ",", "3", ",", "5", ",", "8", ",", "13", ",", 
    "21", ",", "34", ",", "..."}], "}"}]]],
 "  is   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    UnderscriptBox[
     RowBox[{"lim", " ", "sup"}], 
     RowBox[{"n", "\[Rule]", "\[Infinity]"}]], " ", 
    SubscriptBox["t", "n"]}], " ", "=", " ", "\[Infinity]"}]]],
 ".  \n\n(The Fibonacci sequence satisfies the relation  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["t", "n"], " ", "=", " ", 
   RowBox[{
    SubscriptBox["t", 
     RowBox[{"n", "-", "1"}]], "+", 
    SubscriptBox["t", 
     RowBox[{"n", "-", "2"}]]}]}]]],
 "  for  ",
 Cell[BoxData[
  RowBox[{"n", ">", "2"}]]],
 ").  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 4.19.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "In this case the sequence has  ",
 Cell[BoxData["\[Infinity]"]],
 "  as its limit, and hence the limit supremum  is also  ",
 Cell[BoxData["\[Infinity]"]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", "t", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", "n", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["t", "n_"], "=", 
     RowBox[{
      RowBox[{
       FractionBox[
        RowBox[{"-", 
         SqrtBox["5"]}], "5"], " ", 
       SuperscriptBox["2", 
        RowBox[{
         RowBox[{"-", "1"}], "-", "n"}]], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "-", 
          SqrtBox["5"]}], ")"}], 
        RowBox[{"n", "+", "1"}]]}], " ", "+", 
      FractionBox[
       SuperscriptBox[
        RowBox[{"(", 
         FractionBox["2", 
          RowBox[{"1", "+", 
           SqrtBox["5"]}]], ")"}], 
        RowBox[{
         RowBox[{"-", "1"}], "-", "n"}]], 
       SqrtBox["5"]]}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"table", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Simplify", "[", 
        SubscriptBox["t", "n"], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "0", ",", "12"}], "}"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"table", "=", 
     RowBox[{"Append", "[", 
      RowBox[{"table", ",", "\"\<...\>\""}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(t\), \(n\)]\)} = \>\"", ",", "table"}], "]"}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(t\), \(n\)]\) = \>\"", ",", 
      SubscriptBox["t", "n"]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(lim\), \(n \[Rule] \[Infinity]\)]\) \
\!\(\*SubscriptBox[\(t\), \(n\)]\) = \>\"", ",", 
      RowBox[{"Limit", "[", 
       RowBox[{
        SubscriptBox["t", "n"], ",", 
        RowBox[{"n", "\[Rule]", "\[Infinity]"}]}], "]"}]}], "]"}], ";"}], " ",
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(limsup\), \(n \[Rule] \[Infinity]\)]\) \
\!\(\*SubscriptBox[\(t\), \(n\)]\) = \>\"", ",", 
      RowBox[{"Limit", "[", 
       RowBox[{
        SubscriptBox["t", "n"], ",", 
        RowBox[{"n", "\[Rule]", "\[Infinity]"}]}], "]"}]}], "]"}], ";"}], " ",
    "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39911645840625*^9}],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to plot some of the terms in the sequence."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"set", " ", "=", "  ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"n", ",", 
         RowBox[{"Simplify", "[", 
          SubscriptBox["t", "n"], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "1", ",", "12"}], "}"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g0", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"set", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"PointSize", "[", "0.02", "]"}], ",", "Blue"}], "}"}]}], 
       ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "12.2"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "5"}], ",", "250"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
         "\"\<n\>\"", ",", "\"\<\!\(\*SubscriptBox[\(t\), \(n\)]\)\>\""}], 
         "}"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "12", ",", "1"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "250", ",", "50"}], "]"}]}], "}"}]}]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "g0", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(t\), \(n\)]\)} = \>\"", ",", "table"}], "]"}],
     ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399116466953125*^9, 3.399116508265625*^9}, {
  3.399202051703125*^9, 3.399202061859375*^9}, {3.3992022178125*^9, 
  3.39920224825*^9}, {3.399798574062252*^9, 3.3997985742341275`*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "We see that the limit supremum of the Fibonacci sequence ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"{", 
    SubscriptBox["t", "n"], "}"}], "=", 
   RowBox[{"{", 
    RowBox[{
    "1", ",", "1", ",", "2", ",", "3", ",", "5", ",", "8", ",", "13", ",", 
     "21", ",", "34", ",", "..."}], "}"}]}]]],
 " is  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    UnderscriptBox[
     RowBox[{"lim", " ", "sup"}], 
     RowBox[{"n", "\[Rule]", "\[Infinity]"}]], " ", 
    SubscriptBox["t", "n"]}], "=", "\[Infinity]"}]]],
 ".  "
}], "Text"]
}, Closed]],

Cell["\<\
\tThe limit supremum is a powerful idea because the limit supremum of a \
sequence always exists, which is not true for the ordinary limit.  However, \
Example 4.20 illustrates the fact that, if the limit of a sequence does \
exist, then it will be the same as the limit supremum.\
\>", "Text"],

Cell[TextData[{
 StyleBox["Example 4.20.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  The sequence  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"{", 
    SubscriptBox["t", "n"], "}"}], "=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", "+", 
      FractionBox["1", "n"]}], "}"}], "=", " "}]}]]],
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{"2", ",", "1.5", ",", 
    RowBox[{"1.3", 
     OverscriptBox[
      RowBox[{"3", " "}], "_"]}], ",", "1.25", ",", "1.2", ",", "..."}], 
   "}"}]]],
 "  has  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    UnderscriptBox[
     RowBox[{"lim", " ", "sup"}], 
     RowBox[{"n", "\[Rule]", "\[Infinity]"}]], " ", 
    SubscriptBox["t", "n"]}], "=", "1"}]]],
 ".  \n",
 "We leave verification of this as an exercise."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 4.20.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell["\<\
In this case the sequence has  1  as its limit, and hence the limit supremum  \
is also  1.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", "t", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", "n", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["t", "n_"], "=", 
     RowBox[{"1", "+", 
      FractionBox["1", "n"]}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"table", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       SubscriptBox["t", "n"], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "1", ",", "20"}], "}"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"table", "=", 
     RowBox[{"Append", "[", 
      RowBox[{"table", ",", "\"\<...\>\""}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(t\), \(n\)]\)} = \>\"", ",", "table"}], "]"}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<{\!\(\*SubscriptBox[\(t\), \(n\)]\)} = \>\"", ",", 
      RowBox[{"N", "[", "table", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(t\), \(n\)]\) = \>\"", ",", 
      SubscriptBox["t", "n"]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(lim\), \(n \[Rule] \[Infinity]\)]\) \
\!\(\*SubscriptBox[\(t\), \(n\)]\) = \>\"", ",", 
      RowBox[{"Limit", "[", 
       RowBox[{
        SubscriptBox["t", "n"], ",", 
        RowBox[{"n", "\[Rule]", "\[Infinity]"}]}], "]"}]}], "]"}], ";"}], " ",
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(limsup\), \(n \[Rule] \[Infinity]\)]\) \
\!\(\*SubscriptBox[\(t\), \(n\)]\) = \>\"", ",", 
      RowBox[{"Limit", "[", 
       RowBox[{
        SubscriptBox["t", "n"], ",", 
        RowBox[{"n", "\[Rule]", "\[Infinity]"}]}], "]"}]}], "]"}], ";"}], " ",
    "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.3991165325625*^9}],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to plot some of the terms in the sequence."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"set", " ", "=", "  ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"n", ",", 
         RowBox[{"Simplify", "[", 
          SubscriptBox["t", "n"], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "1", ",", "20"}], "}"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g0", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"set", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"PointSize", "[", "0.02", "]"}], ",", "Green"}], "}"}]}], 
       ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "20.3"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "2.1"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
         "\"\<n\>\"", ",", "\"\<\!\(\*SubscriptBox[\(t\), \(n\)]\)\>\""}], 
         "}"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "20", ",", "2"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "2", ",", "1"}], "]"}]}], "}"}]}]}], "]"}]}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "g0", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(t\), \(n\)]\)} = \>\"", ",", "table"}], "]"}],
     ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399116539*^9, 3.3991165555*^9}, {3.399202260859375*^9, 
  3.39920227628125*^9}, {3.399798578937252*^9, 3.3997985791091275`*^9}},
 AspectRatioFixed->True],

Cell["\<\
In this case the sequence has  1  as its limit, and hence the limit supremum  \
is also  1.\
\>", "Text"]
}, Closed]],

Cell[TextData[{
 StyleBox["Theorem 4.14 (",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Root Test",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/RootTest.html"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 StyleBox[").",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Suppose that the series  ",
 Cell[BoxData[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"n", "=", "0"}], "\[Infinity]"], 
   SubscriptBox["\[Zeta]", "n"]}]]],
 ",  has  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    UnderscriptBox[
     RowBox[{"lim", " ", "sup"}], 
     RowBox[{"n", " ", "\[Rule]", " ", "\[Infinity]"}]], "  ", "|", 
    SubscriptBox["\[Zeta]", "n"], 
    SuperscriptBox["|", 
     FractionBox["1", "n"]]}], "=", "L"}]]],
 "   (i.e.  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    UnderscriptBox[
     RowBox[{"lim", " ", "sup"}], 
     RowBox[{"n", " ", "\[Rule]", " ", "\[Infinity]"}]], "  ", 
    RadicalBox[
     StyleBox[
      RowBox[{"\[VerticalSeparator]", 
       RowBox[{
        SubscriptBox["\[Zeta]", "n"], "\[VerticalSeparator]"}]}],
      FontSize->12], "n"]}], "=", "L"}]]],
 ").  \nThen the series is absolutely convergent if  ",
 Cell[BoxData[
  RowBox[{"L", "<", "1"}]]],
 "  and divergent if  ",
 Cell[BoxData[
  RowBox[{"L", ">", "1"}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 4.14 is in the book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
 "\tNote that in applying either Theorems 4.13 or 4.14, if",
 "  ",
 Cell[BoxData[
  RowBox[{"L", "=", "1"}]]],
 "  ",
 "the convergence or divergence of the series is unknown,  and further \
analysis is required to determine the true state of affairs. "
}], "Text"],

Cell[TextData[{
 StyleBox["Extra Example 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Find the radius of convergence of the infinite series  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"S", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    RowBox[{"1", "+", 
     FractionBox["z", "2"], "+", 
     FractionBox[
      SuperscriptBox["z", "2"], 
      SuperscriptBox["3", "2"]], "+", 
     FractionBox[
      SuperscriptBox["z", "3"], 
      SuperscriptBox["2", "3"]], "+", 
     FractionBox[
      SuperscriptBox["z", "4"], 
      SuperscriptBox["3", "4"]], "+", 
     FractionBox[
      SuperscriptBox["z", "5"], 
      SuperscriptBox["2", "5"]], "+", 
     FractionBox[
      SuperscriptBox["z", "6"], 
      SuperscriptBox["3", "6"]], "+", 
     FractionBox[
      SuperscriptBox["z", "7"], 
      SuperscriptBox["2", "7"]], "+", 
     FractionBox[
      SuperscriptBox["z", "8"], 
      SuperscriptBox["3", "8"]], "+", 
     FractionBox[
      SuperscriptBox["z", "9"], 
      SuperscriptBox["2", "9"]], "+", 
     FractionBox[
      SuperscriptBox["z", "10"], 
      SuperscriptBox["3", "10"]], "+", 
     FractionBox[
      SuperscriptBox["z", "11"], 
      SuperscriptBox["2", "11"]], "+"}], "..."}]}]]],
 ". "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Extra Solution 1.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "The sequence of coefficients is  ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{"1", ",", 
    FractionBox["1", "2"], ",", 
    FractionBox["1", 
     SuperscriptBox["3", "2"]], ",", 
    FractionBox["1", 
     SuperscriptBox["2", "3"]], ",", 
    FractionBox["1", 
     SuperscriptBox["3", "4"]], ",", 
    FractionBox["1", 
     SuperscriptBox["2", "5"]], ",", 
    FractionBox["1", 
     SuperscriptBox["3", "6"]], ",", 
    FractionBox["1", 
     SuperscriptBox["2", "7"]], ",", 
    FractionBox["1", 
     SuperscriptBox["3", "8"]], ",", 
    FractionBox["1", 
     SuperscriptBox["2", "9"]], ",", 
    FractionBox["1", 
     SuperscriptBox["3", "10"]], ",", 
    FractionBox["1", 
     SuperscriptBox["2", "11"]], ",", "..."}], "}"}]]],
 ".   \nThe coefficients with even subscripts are ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["a", 
    RowBox[{"2", "k"}]], "=", 
   FractionBox["1", 
    SuperscriptBox["3", 
     RowBox[{"2", "k"}]]]}]]],
 ", and the coefficients with odd subscripts are  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["a", 
    RowBox[{
     RowBox[{"2", "k"}], "+", "1"}]], "=", 
   FractionBox["1", 
    SuperscriptBox["2", 
     RowBox[{
      RowBox[{"2", "k"}], "+", "1"}]]]}]]],
 ".  \nSo that we have \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[VerticalSeparator]", 
    SubscriptBox["a", 
     RowBox[{"2", "k"}]], 
    StyleBox[
     SuperscriptBox["\[VerticalSeparator]", 
      FractionBox["1", 
       RowBox[{"2", " ", "k"}]]],
     FontSize->12]}], "=", 
   RowBox[{
    StyleBox[
     SuperscriptBox[
      RowBox[{"(", 
       FractionBox["1", 
        SuperscriptBox["3", 
         RowBox[{"2", "k"}]]], ")"}], 
      FractionBox["1", 
       RowBox[{"2", " ", "k"}]]],
     FontSize->12], "  ", "=", " ", 
    FractionBox["1", "3"]}]}]]],
 "    and    ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[VerticalSeparator]", 
    SubscriptBox["a", 
     RowBox[{
      RowBox[{"2", "k"}], "+", "1"}]], 
    StyleBox[
     SuperscriptBox["\[VerticalSeparator]", 
      FractionBox["1", 
       RowBox[{
        RowBox[{"2", " ", "k"}], "+", "1"}]]],
     FontSize->12]}], "=", " ", 
   RowBox[{
    StyleBox[
     SuperscriptBox[
      RowBox[{"(", 
       FractionBox["1", 
        SuperscriptBox["2", 
         RowBox[{
          RowBox[{"2", "k"}], "+", "1"}]]], ")"}], 
      FractionBox["1", 
       RowBox[{
        RowBox[{"2", " ", "k"}], "+", "1"}]]],
     FontSize->12], " ", "=", " ", 
    FractionBox["1", "2"]}]}]]],
 ".  \n\nIt follows that   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    UnderscriptBox[
     RowBox[{"lim", " ", "sup"}], 
     RowBox[{"n", " ", "\[Rule]", " ", "\[Infinity]"}]], "  ", 
    RadicalBox[
     StyleBox[
      RowBox[{"\[VerticalSeparator]", 
       RowBox[{
        SubscriptBox["a", "n"], 
        SuperscriptBox["z", "n"]}], "\[VerticalSeparator]"}],
      FontSize->12], "n"]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     FractionBox["1", "2"], "|", "z", "|"}], " ", "=", " ", "L"}]}]]],
 ".   \nIf  ",
 Cell[BoxData[
  RowBox[{"|", "z", "|", 
   RowBox[{"<", " ", "2"}]}]]],
 ",  then  ",
 Cell[BoxData[
  RowBox[{
   FractionBox[
    RowBox[{"|", "z", "|"}], "2"], " ", "=", "  ", 
   RowBox[{"L", " ", "<", " ", "1"}]}]]],
 ",  and the series converges.   \nIf  ",
 Cell[BoxData[
  RowBox[{"|", "z", "|", 
   RowBox[{">", " ", "2"}]}]]],
 ",  the series diverges.  "
}], "Text"],

Cell["\<\
We are done.
\
\>", "Text"],

Cell[TextData[{
 StyleBox["Aside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  The given series is the sum of two geometric series:   ",
 Cell[BoxData[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"k", "=", "0"}], "\[Infinity]"], 
   FractionBox[
    SuperscriptBox["z", 
     RowBox[{"2", "k"}]], 
    SuperscriptBox["3", 
     RowBox[{"2", "k"}]]]}]]],
 "   and   ",
 Cell[BoxData[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"k", "=", "0"}], "\[Infinity]"], 
   FractionBox[
    SuperscriptBox["z", 
     RowBox[{
      RowBox[{"2", "k"}], "+", "1"}]], 
    SuperscriptBox["2", 
     RowBox[{
      RowBox[{"2", "k"}], "+", "1"}]]]}]]],
 ",  and are known to have radii of convergence ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["R", "1"], "=", "3"}]]],
 " and ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["R", "2"], "=", "2"}]]],
 ", respectively.  Hence their sum has radii of convergence ",
 Cell[BoxData[
  RowBox[{"R", "=", 
   RowBox[{
    RowBox[{"min", 
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["R", "1"], ",", 
       SubscriptBox["R", "2"]}], "}"}]}], "=", "2"}]}]]],
 ".\n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"1", "+", 
      FractionBox["z", "2"], "+", 
      FractionBox[
       SuperscriptBox["z", "2"], 
       SuperscriptBox["3", "2"]], "+", 
      FractionBox[
       SuperscriptBox["z", "3"], 
       SuperscriptBox["2", "3"]], "+", 
      FractionBox[
       SuperscriptBox["z", "4"], 
       SuperscriptBox["3", "4"]], "+", 
      FractionBox[
       SuperscriptBox["z", "5"], 
       SuperscriptBox["2", "5"]], "+", 
      FractionBox[
       SuperscriptBox["z", "6"], 
       SuperscriptBox["3", "6"]], "+", 
      FractionBox[
       SuperscriptBox["z", "7"], 
       SuperscriptBox["2", "7"]], "+", 
      FractionBox[
       SuperscriptBox["z", "8"], 
       SuperscriptBox["3", "8"]], "+", 
      FractionBox[
       SuperscriptBox["z", "9"], 
       SuperscriptBox["2", "9"]], "+", 
      FractionBox[
       SuperscriptBox["z", "10"], 
       SuperscriptBox["3", "10"]], "+", 
      FractionBox[
       SuperscriptBox["z", "11"], 
       SuperscriptBox["2", "11"]], "+"}], "..."}], "\[IndentingNewLine]"}], 
   "  "}], "\[IndentingNewLine]", 
  RowBox[{"=", "  ", 
   RowBox[{
    RowBox[{"1", "+", 
     FractionBox["z", "2"], "+", 
     FractionBox[
      SuperscriptBox["z", "2"], "9"], "+", 
     FractionBox[
      SuperscriptBox["z", "3"], "8"], "+", 
     FractionBox[
      SuperscriptBox["z", "4"], "81"], "+", 
     FractionBox[
      SuperscriptBox["z", "5"], "32"], "+", 
     FractionBox[
      SuperscriptBox["z", "6"], "729"], "+", 
     FractionBox[
      SuperscriptBox["z", "7"], "128"], "+", 
     FractionBox[
      SuperscriptBox["z", "8"], "6561"], "+", 
     FractionBox[
      SuperscriptBox["z", "9"], "512"], "+", 
     FractionBox[
      SuperscriptBox["z", "10"], "59049"], "+", 
     FractionBox[
      SuperscriptBox["z", "11"], "2048"], "+"}], "..."}]}]}]],
 "  "
}], "Text"],

Cell[TextData[{
 "The even and odd series are:\n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"1", "+", 
     FractionBox[
      SuperscriptBox["z", "2"], "9"], "+", 
     FractionBox[
      SuperscriptBox["z", "4"], "81"], "+", 
     FractionBox[
      SuperscriptBox["z", "6"], "729"], "+", 
     FractionBox[
      SuperscriptBox["z", "8"], "6561"], "+", 
     FractionBox[
      SuperscriptBox["z", "10"], "59049"], "+"}], "..."}], "  ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"k", "=", "0"}], "\[Infinity]"], 
      FractionBox[
       SuperscriptBox["z", 
        RowBox[{"2", "k"}]], 
       SuperscriptBox["3", 
        RowBox[{"2", "k"}]]]}], "  ", "=", "  ", 
     RowBox[{
      RowBox[{"1", "/", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         FractionBox[
          SuperscriptBox["z", "2"], 
          SuperscriptBox["3", "2"]]}], ")"}]}], " ", "=", " ", 
      FractionBox[
       SuperscriptBox["3", "2"], 
       RowBox[{
        SuperscriptBox["3", "2"], "-", 
        SuperscriptBox["z", "2"]}]]}]}]}], "  ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"=", " ", 
   FractionBox["9", 
    RowBox[{"9", "-", 
     SuperscriptBox["z", "2"]}]]}]}]],
 "    \n\n\n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     FractionBox["z", "2"], "+", 
     FractionBox[
      SuperscriptBox["z", "3"], "8"], "+", 
     FractionBox[
      SuperscriptBox["z", "5"], "32"], "+", 
     FractionBox[
      SuperscriptBox["z", "7"], "128"], "+", 
     FractionBox[
      SuperscriptBox["z", "9"], "512"], "+", 
     FractionBox[
      SuperscriptBox["z", "11"], "2048"], "+"}], "..."}], "  ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"k", "=", "0"}], "\[Infinity]"], 
      FractionBox[
       SuperscriptBox["z", 
        RowBox[{
         RowBox[{"2", "k"}], "+", "1"}]], 
       SuperscriptBox["2", 
        RowBox[{
         RowBox[{"2", "k"}], "+", "1"}]]]}], " ", "=", " ", 
     RowBox[{
      FractionBox["z", "2"], 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"k", "=", "0"}], "\[Infinity]"], 
       FractionBox[
        SuperscriptBox["z", 
         RowBox[{"2", "k"}]], 
        SuperscriptBox["2", 
         RowBox[{"2", "k"}]]]}]}]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"=", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       FractionBox["z", "2"], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        FractionBox[
         SuperscriptBox["z", "2"], 
         SuperscriptBox["2", "2"]]}], ")"}]}], " ", "=", "  ", 
     RowBox[{
      RowBox[{"(", 
       FractionBox["z", "2"], ")"}], 
      RowBox[{"(", 
       FractionBox["4", 
        RowBox[{"4", "-", 
         SuperscriptBox["z", "2"]}]], ")"}]}]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"=", " ", 
   FractionBox[
    RowBox[{"2", "z"}], 
    RowBox[{"4", "-", 
     SuperscriptBox["z", "2"]}]]}]}]],
 "  \n\nTherefore, S(z) is the sum of two geometric series:\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"S", 
    RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
   RowBox[{
    FractionBox["9", 
     RowBox[{"9", "-", 
      SuperscriptBox["z", "2"]}]], " ", "+", " ", 
    FractionBox[
     RowBox[{"2", "z"}], 
     RowBox[{"4", "-", 
      SuperscriptBox["z", "2"]}]]}]}]]],
 "\n\nwhich might be printed by ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " as  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"S", 
    RowBox[{"(", "z", ")"}]}], "  ", "=", "   ", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["9", 
      RowBox[{
       RowBox[{"-", "9"}], "+", 
       SuperscriptBox["z", "2"]}]]}], " ", "+", " ", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"2", " ", "z"}], 
      RowBox[{
       RowBox[{"-", "4"}], "+", 
       SuperscriptBox["z", "2"]}]]}]}]}]]]
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<S(z) = \!\(\*FractionBox[\(9\), \(9 - \*SuperscriptBox[\(z\), \
\(2\)]\)]\) + \!\(\*FractionBox[\(2  z\), \(4 - \*SuperscriptBox[\(z\), \
\(2\)]\)]\)\>\"", " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S(z) = \>\"", ",", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{
         FractionBox["9", 
          RowBox[{"9", "-", 
           SuperscriptBox["z", "2"]}]], "+", 
         FractionBox[
          RowBox[{"2", "z"}], 
          RowBox[{"4", "-", 
           SuperscriptBox["z", "2"]}]]}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", "0", ",", "11"}], "}"}]}], "]"}]}], " ", "]"}], 
    ";"}], "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39911660828125*^9, 3.399202296171875*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"k", "=", "0"}], "\[Infinity]"], 
      FractionBox[
       SuperscriptBox["z", 
        RowBox[{"2", "k"}]], 
       SuperscriptBox["3", 
        RowBox[{"2", "k"}]]]}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"g", "[", "z_", "]"}], "=", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"k", "=", "0"}], "\[Infinity]"], 
      FractionBox[
       SuperscriptBox["z", 
        RowBox[{
         RowBox[{"2", "k"}], "+", "1"}]], 
       SuperscriptBox["2", 
        RowBox[{
         RowBox[{"2", "k"}], "+", "1"}]]]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"S", "[", "z_", "]"}], "=", 
     RowBox[{
      RowBox[{"f", "[", "z", "]"}], " ", "+", " ", 
      RowBox[{"g", "[", "z", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<f[z] = \!\(\*FractionBox[\(9\), \(9 - \*SuperscriptBox[\(z\), \
\(2\)]\)]\) = \!\(\*UnderoverscriptBox[\(\[Sum]\), \(k = 0\), \
\(\[Infinity]\)]\)\!\(\*FractionBox[SuperscriptBox[\(z\), \(2  k\)], \
SuperscriptBox[\(3\), \(2  k\)]]\) = \>\"", ",", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{"f", "[", "z", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", "0", ",", "11"}], "}"}]}], "]"}]}], " ", "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<g[z] = \!\(\*FractionBox[\(2  z\), \(4 - \*SuperscriptBox[\(z\), \
\(2\)]\)]\) = \!\(\*UnderoverscriptBox[\(\[Sum]\), \(k = 0\), \
\(\[Infinity]\)]\)\!\(\*FractionBox[SuperscriptBox[\(z\), \(2  k + 1\)], \
SuperscriptBox[\(2\), \(2  k + 1\)]]\) = \>\"", ",", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{"g", "[", "z", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", "0", ",", "11"}], "}"}]}], "]"}]}], " ", "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<S[z] = \!\(\*FractionBox[\(9\), \(9 - \*SuperscriptBox[\(z\), \
\(2\)]\)]\) + \!\(\*FractionBox[\(2  z\), \(4 - \*SuperscriptBox[\(z\), \
\(2\)]\)]\) = \!\(\*UnderoverscriptBox[\(\[Sum]\), \(k = 0\), \
\(\[Infinity]\)]\)\!\(\*FractionBox[SuperscriptBox[\(z\), \(2  k\)], \
SuperscriptBox[\(3\), \(2  k\)]]\) + \!\(\*UnderoverscriptBox[\(\[Sum]\), \(k \
= 0\), \(\[Infinity]\)]\)\!\(\*FractionBox[SuperscriptBox[\(z\), \(2  k + \
1\)], SuperscriptBox[\(2\), \(2  k + 1\)]]\)\>\"", " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[z] = \>\"", ",", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{"S", "[", "z", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", "0", ",", "11"}], "}"}]}], "]"}]}], " ", "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<f[z] = \!\(\*FractionBox[\(9\), \(9 - \*SuperscriptBox[\(z\), \
\(2\)]\)]\) = \!\(\*UnderoverscriptBox[\(\[Sum]\), \(k = 0\), \
\(\[Infinity]\)]\)\!\(\*FractionBox[SuperscriptBox[\(z\), \(2  k\)], \
SuperscriptBox[\(3\), \(2  k\)]]\) = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<g[z] = \!\(\*FractionBox[\(2  z\), \(4 - \*SuperscriptBox[\(z\), \
\(2\)]\)]\) = \!\(\*UnderoverscriptBox[\(\[Sum]\), \(k = 0\), \
\(\[Infinity]\)]\)\!\(\*FractionBox[SuperscriptBox[\(z\), \(2  k + 1\)], \
SuperscriptBox[\(2\), \(2  k + 1\)]]\) = \>\"", ",", 
      RowBox[{"g", "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<S[z] = \!\(\*FractionBox[\(9\), \(9 - \*SuperscriptBox[\(z\), \
\(2\)]\)]\) + \!\(\*FractionBox[\(2  z\), \(4 - \*SuperscriptBox[\(z\), \
\(2\)]\)]\) = \!\(\*UnderoverscriptBox[\(\[Sum]\), \(k = 0\), \
\(\[Infinity]\)]\)\!\(\*FractionBox[SuperscriptBox[\(z\), \(2  k\)], \
SuperscriptBox[\(3\), \(2  k\)]]\) + \!\(\*UnderoverscriptBox[\(\[Sum]\), \(k \
= 0\), \(\[Infinity]\)]\)\!\(\*FractionBox[SuperscriptBox[\(z\), \(2  k + \
1\)], SuperscriptBox[\(2\), \(2  k + 1\)]]\)\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[z] = \>\"", ",", 
      RowBox[{"S", "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{
  3.399116610375*^9, {3.399202287375*^9, 3.399202300078125*^9}}],

Cell[TextData[{
 "We are done.\n\n",
 StyleBox["Aside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  We can investigate what happens as ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", "z", "|"}], "\[Rule]", " ", "2"}]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[z] = \>\"", ",", 
      RowBox[{"S", "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[1] = \>\"", ",", 
      RowBox[{"S", "[", "1", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[\!\(\*FractionBox[\(19\), \(10\)]\)] = \>\"", ",", 
      RowBox[{"S", "[", 
       FractionBox["19", "10"], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[\!\(\*FractionBox[\(199\), \(100\)]\)] = \>\"", ",", 
      RowBox[{"S", "[", 
       FractionBox["199", "100"], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[\!\(\*FractionBox[\(1999\), \(1000\)]\)] = \>\"", ",", 
      RowBox[{"S", "[", 
       FractionBox["1999", "1000"], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[\!\(\*FractionBox[\(19999\), \(10000\)]\)] = \>\"", ",", 
      RowBox[{"S", "[", 
       FractionBox["19999", "10000"], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<S[2] =  \!\(\*UnderoverscriptBox[\(\[Sum]\), \(k = 0\), \(\
\[Infinity]\)]\)\!\(\*FractionBox[SuperscriptBox[\((2)\), \(2  k\)], \
SuperscriptBox[\(3\), \(2  k\)]]\) + \!\(\*UnderoverscriptBox[\(\[Sum]\), \(k \
= 0\), \(\[Infinity]\)]\)\!\(\*FractionBox[SuperscriptBox[\((2)\), \(2  k + 1\
\)], SuperscriptBox[\(2\), \(2  k + 1\)]]\)\>\"", " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[2] = \>\"", ",", " ", 
      RowBox[{
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"k", "=", "0"}], "\[Infinity]"], 
        FractionBox[
         SuperscriptBox[
          RowBox[{"(", "2", ")"}], 
          RowBox[{"2", "k"}]], 
         SuperscriptBox["3", 
          RowBox[{"2", "k"}]]]}], " ", "+", " ", 
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"k", "=", "0"}], "\[Infinity]"], 
        FractionBox[
         SuperscriptBox[
          RowBox[{"(", "2", ")"}], 
          RowBox[{
           RowBox[{"2", "k"}], "+", "1"}]], 
         SuperscriptBox["2", 
          RowBox[{
           RowBox[{"2", "k"}], "+", "1"}]]]}]}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39911661640625*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[z] = \>\"", ",", 
      RowBox[{"S", "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[\[ImaginaryI]] = \>\"", ",", 
      RowBox[{"S", "[", "\[ImaginaryI]", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<S[\!\(\*FractionBox[\(19\), \(10\)]\)\[ImaginaryI]] = \>\"", ",", 
      RowBox[{"S", "[", 
       RowBox[{
        FractionBox["19", "10"], "\[ImaginaryI]"}], "]"}]}], " ", "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<S[\!\(\*FractionBox[\(199\), \(100\)]\)\[ImaginaryI]] = \>\"", ",", 
      
      RowBox[{"S", "[", 
       RowBox[{
        FractionBox["199", "100"], "\[ImaginaryI]"}], "]"}]}], " ", "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<S[\!\(\*FractionBox[\(1999\), \(1000\)]\)\[ImaginaryI]] = \>\"", 
      ",", 
      RowBox[{"S", "[", 
       RowBox[{
        FractionBox["1999", "1000"], "\[ImaginaryI]"}], "]"}]}], " ", "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<S[\!\(\*FractionBox[\(19999\), \(10000\)]\)\[ImaginaryI]] = \>\"", 
      ",", 
      RowBox[{"S", "[", 
       RowBox[{
        FractionBox["19999", "10000"], "\[ImaginaryI]"}], "]"}]}], " ", "]"}],
     ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<S[2\[ImaginaryI]] =  \!\(\*UnderoverscriptBox[\(\[Sum]\), \(k = \
0\), \(\[Infinity]\)]\)\!\(\*FractionBox[SuperscriptBox[\((2\\\ \
\[ImaginaryI])\), \(2  k\)], SuperscriptBox[\(3\), \(2  k\)]]\) + \
\!\(\*UnderoverscriptBox[\(\[Sum]\), \(k = 0\), \
\(\[Infinity]\)]\)\!\(\*FractionBox[SuperscriptBox[\((2\\\ \[ImaginaryI])\), \
\(2  k + 1\)], SuperscriptBox[\(2\), \(2  k + 1\)]]\)\>\"", " ", "]"}], ";"}],
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[2\[ImaginaryI]] = \>\"", ",", " ", 
      RowBox[{
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"k", "=", "0"}], "\[Infinity]"], 
        FractionBox[
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"2", " ", "\[ImaginaryI]"}], ")"}], 
          RowBox[{"2", "k"}]], 
         SuperscriptBox["3", 
          RowBox[{"2", "k"}]]]}], " ", "+", " ", 
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"k", "=", "0"}], "\[Infinity]"], 
        FractionBox[
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"2", " ", "\[ImaginaryI]"}], ")"}], 
          RowBox[{
           RowBox[{"2", "k"}], "+", "1"}]], 
         SuperscriptBox["2", 
          RowBox[{
           RowBox[{"2", "k"}], "+", "1"}]]]}]}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.3991166216875*^9}],

Cell[TextData[{
 StyleBox["Caveat.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  In some cases involving complex numbers, earlier versions of ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " will report a sum when the series actually diverges.  In ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " 4.1 the following series converges."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", "0"}], "\[Infinity]"], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox[
       RowBox[{"3", "+", 
        RowBox[{"4", "\[ImaginaryI]"}]}], "5"], ")"}], "n"]}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399116626625*^9, 3.39911662771875*^9}}],

Cell[TextData[{
 "The above series actually diverges because ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox[
       RowBox[{"3", "+", 
        RowBox[{"4", "\[ImaginaryI]"}]}], "5"], ")"}], "n"], "|"}], " ", "=", 
   " ", 
   RowBox[{
    RowBox[{"|", 
     FractionBox[
      RowBox[{"3", "+", 
       RowBox[{"4", "\[ImaginaryI]"}]}], "5"], 
     SuperscriptBox["|", "n"]}], " ", "=", " ", "1"}]}]]],
 "  for all ",
 StyleBox["n",
  FontFamily->"Courier New"],
 ".\n\nMost likely this occurs because ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " 4.2 is summing the series and then making a substitution."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"1", "/", 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      FractionBox[
       RowBox[{"3", "+", 
        RowBox[{"4", "\[ImaginaryI]"}]}], "5"]}], ")"}]}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399116630515625*^9, 3.39911663159375*^9}}],

Cell["Now try another value.", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", "0"}], "\[Infinity]"], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox[
       RowBox[{"3", "+", 
        RowBox[{"4", "\[ImaginaryI]"}]}], "4"], ")"}], "n"]}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3991166503125*^9, 3.399116651453125*^9}}],

Cell[TextData[{
 "Indeed, the above series diverges because ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox[
       RowBox[{"3", "+", 
        RowBox[{"4", "\[ImaginaryI]"}]}], "5"], ")"}], "n"], "|"}], " ", "=", 
   " ", 
   RowBox[{
    RowBox[{"|", 
     FractionBox[
      RowBox[{"3", "+", 
       RowBox[{"4", "\[ImaginaryI]"}]}], "4"], 
     SuperscriptBox["|", "n"]}], " ", "=", " ", 
    RowBox[{
     FractionBox["5", "4"], " ", ">", " ", "1"}]}]}]]],
 "  for all ",
 StyleBox["n",
  FontFamily->"Courier New"],
 ".\n\nThis bug has been correct in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " 5.1 and the above series does not converge.\n\nHowever, you have been \
given a warning!"
}], "Text"],

Cell[TextData[{
 StyleBox["Caveat.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  The mathematical analysis proves that the series ",
 Cell[BoxData[
  RowBox[{"  ", 
   RowBox[{
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"k", "=", "0"}], "\[Infinity]"], 
     FractionBox[
      SuperscriptBox[
       RowBox[{"(", 
        FractionBox[
         RowBox[{"6", "+", 
          RowBox[{"8", "\[ImaginaryI]"}]}], "5"], ")"}], 
       RowBox[{"2", "k"}]], 
      SuperscriptBox["3", 
       RowBox[{"2", "k"}]]]}], " ", "+", " ", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"k", "=", "0"}], "\[Infinity]"], 
     FractionBox[
      SuperscriptBox[
       RowBox[{"(", 
        FractionBox[
         RowBox[{"6", "+", 
          RowBox[{"8", "\[ImaginaryI]"}]}], "5"], ")"}], 
       RowBox[{
        RowBox[{"2", "k"}], "+", "1"}]], 
      SuperscriptBox["2", 
       RowBox[{
        RowBox[{"2", "k"}], "+", "1"}]]]}]}]}]]],
 " diverges.  But for some reason ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " 4.1 will compute a sum.  For sure it is a mistake which is equivalent to \
substituting ",
 Cell[BoxData[
  RowBox[{"Z", "=", 
   FractionBox[
    RowBox[{"6", "+", 
     RowBox[{"8", "\[ImaginaryI]"}]}], "5"]}]]],
 " into the formula  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"S", "[", "z", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["9", 
      RowBox[{
       RowBox[{"-", "9"}], "+", 
       SuperscriptBox["z", "2"]}]]}], "-", 
    FractionBox[
     RowBox[{"2", " ", "z"}], 
     RowBox[{
      RowBox[{"-", "4"}], "+", 
      SuperscriptBox["z", "2"]}]]}]}]]],
 ".  This bug has been corrected in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " 5.1."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Z", "=", 
     FractionBox[
      RowBox[{"6", "+", 
       RowBox[{"8", "\[ImaginaryI]"}]}], "5"]}], ";"}], "\[IndentingNewLine]",
    
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<|\>\"", ",", "Z", ",", "\"\<| = \>\"", ",", 
      RowBox[{"Abs", "[", "Z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39911667575*^9, 3.399202332734375*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"S", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["9", 
        RowBox[{
         RowBox[{"-", "9"}], "+", 
         SuperscriptBox["z", "2"]}]]}], "-", 
      FractionBox[
       RowBox[{"2", " ", "z"}], 
       RowBox[{
        RowBox[{"-", "4"}], "+", 
        SuperscriptBox["z", "2"]}]]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<      S[z] = \>\"", ",", 
      RowBox[{"S", "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[\>\"", ",", "Z", ",", "\"\<] = \>\"", ",", 
      RowBox[{"S", "[", "Z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399202320609375*^9, 3.399202335859375*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[z] = \>\"", ",", 
      RowBox[{"S", "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[\>\"", ",", 
      RowBox[{
       FractionBox["1", "2"], "Z"}], ",", "\"\<] = \>\"", ",", 
      RowBox[{"S", "[", 
       RowBox[{
        FractionBox["1", "2"], "Z"}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[\>\"", ",", 
      RowBox[{
       FractionBox["19", "10"], "Z"}], ",", "\"\<] = \>\"", ",", 
      RowBox[{"S", "[", 
       RowBox[{
        FractionBox["19", "10"], "Z"}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[\>\"", ",", 
      RowBox[{
       FractionBox["199", "100"], "Z"}], ",", "\"\<] = \>\"", ",", 
      RowBox[{"S", "[", 
       RowBox[{
        FractionBox["199", "100"], "Z"}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[\>\"", ",", 
      RowBox[{
       FractionBox["1999", "1000"], "Z"}], ",", "\"\<] = \>\"", ",", 
      RowBox[{"S", "[", 
       RowBox[{
        FractionBox["1999", "1000"], "Z"}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[\>\"", ",", 
      RowBox[{
       FractionBox["19999", "10000"], "Z"}], ",", "\"\<] = \>\"", ",", 
      RowBox[{"S", "[", 
       RowBox[{
        FractionBox["19999", "10000"], "Z"}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<S[\!\(\*FractionBox[\(6 + 8  \[ImaginaryI]\), \(5\)]\)] =  \
\!\(\*UnderoverscriptBox[\(\[Sum]\), \(k = 0\), \
\(\[Infinity]\)]\)\!\(\*FractionBox[SuperscriptBox[\((\*FractionBox[\(6 + 8  \
\[ImaginaryI]\), \(5\)])\), \(2  k\)], SuperscriptBox[\(3\), \(2  k\)]]\) + \
\!\(\*UnderoverscriptBox[\(\[Sum]\), \(k = 0\), \
\(\[Infinity]\)]\)\!\(\*FractionBox[SuperscriptBox[\((\*FractionBox[\(6 + 8  \
\[ImaginaryI]\), \(5\)])\), \(2  k + 1\)], SuperscriptBox[\(2\), \(2  k + \
1\)]]\)\>\"", " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<S[\!\(\*FractionBox[\(6 + 8  \[ImaginaryI]\), \(5\)]\)] = \>\"", 
      ",", " ", 
      RowBox[{
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"k", "=", "0"}], "\[Infinity]"], 
        FractionBox[
         SuperscriptBox[
          RowBox[{"(", 
           FractionBox[
            RowBox[{"6", "+", 
             RowBox[{"8", "\[ImaginaryI]"}]}], "5"], ")"}], 
          RowBox[{"2", "k"}]], 
         SuperscriptBox["3", 
          RowBox[{"2", "k"}]]]}], " ", "+", " ", 
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"k", "=", "0"}], "\[Infinity]"], 
        FractionBox[
         SuperscriptBox[
          RowBox[{"(", 
           FractionBox[
            RowBox[{"6", "+", 
             RowBox[{"8", "\[ImaginaryI]"}]}], "5"], ")"}], 
          RowBox[{
           RowBox[{"2", "k"}], "+", "1"}]], 
         SuperscriptBox["2", 
          RowBox[{
           RowBox[{"2", "k"}], "+", "1"}]]]}]}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<WARNING. The series diverges.\>\"", "]"}], 
    ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399116678*^9, 3.399202339921875*^9}]
}, Closed]],

Cell["\<\
The \"legacy version\" being used to implement the commands \"CartesianMap \
and PolarMap.\"  The following Initialization Cell will load these \
subroutines. \
\>", "Text",
 CellChangeTimes->{{3.399722161203125*^9, 3.399722165296875*^9}, {
  3.39972222759375*^9, 3.3997223229375*^9}, {3.399722389046875*^9, 
  3.399722641234375*^9}, {3.399722683734375*^9, 3.3997227230625*^9}, {
  3.3997227559375*^9, 3.399722850765625*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Initialization Cell",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text",
 CellChangeTimes->{{3.399722161203125*^9, 3.399722165296875*^9}, {
  3.39972222759375*^9, 3.3997223229375*^9}, {3.399722389046875*^9, 
  3.399722641234375*^9}, {3.399722683734375*^9, 3.3997227230625*^9}, {
  3.3997227559375*^9, 3.399722850765625*^9}, {3.399742279828125*^9, 
  3.39974228209375*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}]], "Input",\

 InitializationCell->True]
}, Closed]],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Geometric Series",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/GeometricSeriesBib.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Convergence of Series",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/SeriesConvergenceBib.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Power Series",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/PowerSeriesBib.html"], None}],
 
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/complex.html"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2008 John H. Mathews, Russell W. \
Howell",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/"], None}],
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[0, 1, 0]]], "Text",
 CellChangeTimes->{{3.3991166945625*^9, 3.399116694828125*^9}}]
},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{979, 643},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "CHAPTER 1"->{
  Cell[568, 21, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"],
  Cell[34502, 841, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"],
  Cell[43371, 1124, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"],
  Cell[66452, 1619, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"],
  Cell[102265, 2753, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"],
  Cell[170217, 4905, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"CHAPTER 1", 207333, 6103}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"],
Cell[905, 32, 134, 2, 29, "Text"],
Cell[1042, 36, 335, 10, 29, "Text"],
Cell[CellGroupData[{
Cell[1402, 50, 152, 4, 29, "Text",
 Evaluatable->False],
Cell[1557, 56, 1118, 40, 54, "Text"],
Cell[2678, 98, 4342, 115, 455, "Input"],
Cell[7023, 215, 199, 6, 29, "Text"],
Cell[7225, 223, 3890, 106, 246, "Input"],
Cell[11118, 331, 135, 3, 29, "Text"],
Cell[11256, 336, 6571, 175, 618, "Input"],
Cell[17830, 513, 26, 0, 31, "Input"],
Cell[17859, 515, 89, 2, 29, "Text"]
}, Closed]],
Cell[17963, 520, 14559, 241, 261, "Text",
 Evaluatable->False],
Cell[32525, 763, 1634, 62, 115, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[34184, 829, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[34328, 835, 171, 4, 29, "Text",
 Evaluatable->False],
Cell[34502, 841, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"]
}, Closed]],
Cell[CellGroupData[{
Cell[34873, 855, 147, 4, 26, "Text",
 Evaluatable->False],
Cell[35023, 861, 732, 28, 78, "Text"],
Cell[35758, 891, 5142, 131, 499, "Input"]
}, Closed]],
Cell[40915, 1025, 2112, 83, 154, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[43052, 1112, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[43196, 1118, 172, 4, 29, "Text",
 Evaluatable->False],
Cell[43371, 1124, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"]
}, Closed]],
Cell[43720, 1136, 15446, 256, 261, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[59191, 1396, 147, 4, 29, "Text",
 Evaluatable->False],
Cell[59341, 1402, 800, 31, 77, "Text"],
Cell[60144, 1435, 5205, 136, 503, "Input"]
}, Closed]],
Cell[65364, 1574, 734, 29, 71, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[66123, 1607, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[66267, 1613, 182, 4, 29, "Text",
 Evaluatable->False],
Cell[66452, 1619, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"]
}, Closed]],
Cell[CellGroupData[{
Cell[66823, 1633, 147, 4, 26, "Text",
 Evaluatable->False],
Cell[66973, 1639, 163, 6, 29, "Text"],
Cell[67139, 1647, 1421, 39, 128, "Input"],
Cell[68563, 1688, 35, 0, 29, "Text"],
Cell[68601, 1690, 1234, 37, 121, "Input"]
}, Closed]],
Cell[69850, 1730, 473, 17, 36, "Text"],
Cell[70326, 1749, 934, 33, 89, "Text"],
Cell[CellGroupData[{
Cell[71285, 1786, 157, 4, 29, "Text",
 Evaluatable->False],
Cell[71445, 1792, 118, 3, 29, "Text"],
Cell[71566, 1797, 2970, 86, 420, "Input"],
Cell[74539, 1885, 279, 10, 35, "Text",
 Evaluatable->False],
Cell[74821, 1897, 959, 26, 180, "Input"],
Cell[75783, 1925, 116, 2, 29, "Text",
 Evaluatable->False],
Cell[75902, 1929, 1829, 51, 270, "Input"],
Cell[77734, 1982, 229, 6, 65, "Text"],
Cell[77966, 1990, 2025, 58, 262, "Input"],
Cell[79994, 2050, 146, 5, 29, "Text"],
Cell[80143, 2057, 3025, 81, 297, "Input"],
Cell[83171, 2140, 493, 17, 39, "Text",
 Evaluatable->False]
}, Closed]],
Cell[83679, 2160, 436, 18, 33, "Text",
 Evaluatable->False],
Cell[84118, 2180, 2987, 93, 273, "Text"],
Cell[CellGroupData[{
Cell[87130, 2277, 157, 4, 29, "Text",
 Evaluatable->False],
Cell[87290, 2283, 118, 3, 29, "Text"],
Cell[87411, 2288, 2773, 83, 410, "Input"],
Cell[90187, 2373, 231, 8, 35, "Text",
 Evaluatable->False],
Cell[90421, 2383, 961, 26, 180, "Input"],
Cell[91385, 2411, 116, 2, 29, "Text",
 Evaluatable->False],
Cell[91504, 2415, 2198, 59, 369, "Input"],
Cell[93705, 2476, 151, 5, 29, "Text"],
Cell[93859, 2483, 1867, 56, 267, "Input"],
Cell[95729, 2541, 146, 5, 29, "Text"],
Cell[95878, 2548, 2895, 77, 311, "Input"],
Cell[98776, 2627, 675, 27, 37, "Text",
 Evaluatable->False]
}, Closed]],
Cell[99466, 2657, 970, 30, 71, "Text"],
Cell[100439, 2689, 309, 5, 47, "Text"],
Cell[100751, 2696, 1143, 40, 114, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[101919, 2740, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[102063, 2746, 199, 5, 29, "Text",
 Evaluatable->False],
Cell[102265, 2753, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"]
}, Closed]],
Cell[102614, 2765, 471, 18, 36, "Text",
 Evaluatable->False],
Cell[103088, 2785, 3879, 116, 409, "Text"],
Cell[CellGroupData[{
Cell[106992, 2905, 157, 4, 29, "Text",
 Evaluatable->False],
Cell[107152, 2911, 62, 0, 29, "Text"],
Cell[107217, 2913, 774, 22, 148, "Input"],
Cell[107994, 2937, 98, 2, 29, "Text"],
Cell[108095, 2941, 2330, 63, 366, "Input"],
Cell[110428, 3006, 210, 7, 65, "Text",
 Evaluatable->False],
Cell[110641, 3015, 714, 20, 139, "Input"],
Cell[111358, 3037, 151, 5, 29, "Text"],
Cell[111512, 3044, 1735, 50, 261, "Input"],
Cell[113250, 3096, 146, 5, 29, "Text"],
Cell[113399, 3103, 3088, 83, 296, "Input"],
Cell[116490, 3188, 533, 19, 39, "Text",
 Evaluatable->False]
}, Closed]],
Cell[117038, 3210, 592, 22, 36, "Text",
 Evaluatable->False],
Cell[117633, 3234, 1557, 51, 160, "Text"],
Cell[CellGroupData[{
Cell[119215, 3289, 157, 4, 29, "Text",
 Evaluatable->False],
Cell[119375, 3295, 62, 0, 29, "Text"],
Cell[119440, 3297, 769, 22, 148, "Input"],
Cell[120212, 3321, 96, 2, 29, "Text"],
Cell[120311, 3325, 1606, 43, 254, "Input"],
Cell[121920, 3370, 507, 18, 71, "Text",
 Evaluatable->False],
Cell[122430, 3390, 939, 28, 146, "Input"],
Cell[123372, 3420, 393, 11, 65, "Text"],
Cell[123768, 3433, 5169, 140, 476, "Input"],
Cell[128940, 3575, 299, 10, 29, "Text"],
Cell[129242, 3587, 5456, 145, 516, "Input"],
Cell[134701, 3734, 93, 2, 29, "Text"],
Cell[134797, 3738, 1035, 32, 112, "Input"]
}, Closed]],
Cell[135847, 3773, 266, 5, 44, "Text"],
Cell[136116, 3780, 1453, 46, 69, "Text"],
Cell[137572, 3828, 1501, 58, 76, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[139098, 3890, 157, 4, 29, "Text",
 Evaluatable->False],
Cell[139258, 3896, 541, 21, 29, "Text"],
Cell[139802, 3919, 4270, 120, 509, "Input"],
Cell[144075, 4041, 321, 10, 65, "Text"],
Cell[144399, 4053, 2884, 82, 192, "Input"],
Cell[147286, 4137, 509, 19, 40, "Text"]
}, Closed]],
Cell[147810, 4159, 2159, 80, 121, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[149994, 4243, 157, 4, 29, "Text",
 Evaluatable->False],
Cell[150154, 4249, 107, 3, 29, "Text"],
Cell[150264, 4254, 1443, 42, 217, "Input"],
Cell[151710, 4298, 321, 10, 65, "Text"],
Cell[152034, 4310, 3190, 93, 212, "Input"],
Cell[155227, 4405, 521, 19, 40, "Text"]
}, Closed]],
Cell[155763, 4427, 1009, 37, 73, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[156797, 4468, 157, 4, 29, "Text",
 Evaluatable->False],
Cell[156957, 4474, 192, 6, 29, "Text"],
Cell[157152, 4482, 2623, 78, 334, "Input"],
Cell[159778, 4562, 132, 5, 29, "Text"],
Cell[159913, 4569, 1961, 54, 152, "Input"],
Cell[161877, 4625, 543, 19, 40, "Text"]
}, Closed]],
Cell[162435, 4647, 304, 5, 44, "Text"],
Cell[162742, 4654, 820, 32, 58, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[163587, 4690, 157, 4, 29, "Text",
 Evaluatable->False],
Cell[163747, 4696, 115, 3, 29, "Text"],
Cell[163865, 4701, 2433, 68, 369, "Input"],
Cell[166301, 4771, 132, 5, 29, "Text"],
Cell[166436, 4778, 1881, 52, 152, "Input"],
Cell[168320, 4832, 115, 3, 29, "Text"]
}, Closed]],
Cell[168450, 4838, 1424, 51, 62, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[169899, 4893, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[170043, 4899, 171, 4, 29, "Text",
 Evaluatable->False],
Cell[170217, 4905, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"]
}, Closed]],
Cell[170566, 4917, 282, 8, 44, "Text"],
Cell[170851, 4927, 1293, 45, 40, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[172169, 4976, 160, 4, 29, "Text",
 Evaluatable->False],
Cell[172332, 4982, 3392, 124, 223, "Text"],
Cell[175727, 5108, 37, 3, 47, "Text"],
Cell[175767, 5113, 3029, 106, 151, "Text"],
Cell[178799, 5221, 4105, 143, 511, "Text"],
Cell[182907, 5366, 891, 25, 124, "Input"],
Cell[183801, 5393, 4874, 121, 529, "Input"],
Cell[188678, 5516, 249, 10, 65, "Text"],
Cell[188930, 5528, 2590, 71, 317, "Input"],
Cell[191523, 5601, 3008, 85, 317, "Input"],
Cell[194534, 5688, 372, 11, 47, "Text"],
Cell[194909, 5701, 400, 12, 96, "Input"],
Cell[195312, 5715, 683, 24, 71, "Text"],
Cell[195998, 5741, 331, 10, 89, "Input"],
Cell[196332, 5753, 38, 0, 29, "Text"],
Cell[196373, 5755, 402, 12, 96, "Input"],
Cell[196778, 5769, 769, 27, 107, "Text"],
Cell[197550, 5798, 1765, 63, 75, "Text"],
Cell[199318, 5863, 481, 14, 108, "Input"],
Cell[199802, 5879, 900, 27, 128, "Input"],
Cell[200705, 5908, 3555, 100, 389, "Input"]
}, Closed]],
Cell[204275, 6011, 435, 8, 26, "Text"],
Cell[CellGroupData[{
Cell[204735, 6023, 407, 7, 29, "Text"],
Cell[205145, 6032, 132, 4, 31, "Input",
 InitializationCell->True]
}, Closed]],
Cell[205292, 6039, 281, 7, 26, "Text"],
Cell[205576, 6048, 279, 7, 29, "Text"],
Cell[205858, 6057, 286, 7, 29, "Text"],
Cell[206147, 6066, 269, 7, 29, "Text"],
Cell[206419, 6075, 249, 5, 29, "Text"],
Cell[206671, 6082, 318, 7, 29, "Text"]
}
]
*)

(* End of internal cache information *)
