(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    148822,       4888]
NotebookOptionsPosition[    142282,       4680]
NotebookOutlinePosition[    143074,       4713]
CellTagsIndexPosition[    143000,       4708]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["4.4  Power Series Functions",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
 "\tSuppose that we have a series ",
 Cell[BoxData[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"n", "=", "0"}], "\[Infinity]"], 
   SubscriptBox["\[Xi]", "n"]}]]],
 "  where ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["\[Xi]", "n"], "=", 
   RowBox[{
    SubscriptBox["c", "n"], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"z", "-", "\[Alpha]"}], ")"}], "n"]}]}]]],
 ".  If ",
 Cell[BoxData["\[Alpha]"]],
 " and the collection of ",
 Cell[BoxData[
  SubscriptBox["c", "n"]]],
 " are fixed complex numbers, we will get different series by selecting \
different values for ",
 StyleBox["z",
  FontFamily->"Courier New"],
 ".  For example, if ",
 Cell[BoxData[
  RowBox[{"\[Alpha]", "=", "2"}]]],
 " and ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["c", "n"], "=", 
   FractionBox["1", 
    RowBox[{"n", "!"}]]}]]],
 " for all ",
 StyleBox["n",
  FontFamily->"Courier New"],
 ", we get the series  ",
 Cell[BoxData[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"n", "=", "0"}], "\[Infinity]"], 
   RowBox[{
    FractionBox["1", 
     RowBox[{"n", "!"}]], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       FractionBox["\[ImaginaryI]", "2"], "-", "2"}], ")"}], "n"]}]}]]],
 " if ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   FractionBox["\[ImaginaryI]", "2"]}]]],
 ",  and  ",
 Cell[BoxData[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"n", "=", "0"}], "\[Infinity]"], 
   RowBox[{
    FractionBox["1", 
     RowBox[{"n", "!"}]], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"2", "+", "\[ImaginaryI]"}], ")"}], "n"]}]}]]],
 " if ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{"4", "+", "\[ImaginaryI]"}]}]]],
 ".  Note that when  ",
 Cell[BoxData[
  RowBox[{"\[Alpha]", "=", "0"}]]],
 " and ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["c", "n"], "=", "1"}]]],
 " for all ",
 StyleBox["n",
  FontFamily->"Courier New"],
 ", we get a geometric series.  The collection of points for which the series \
",
 Cell[BoxData[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"n", "=", "0"}], "\[Infinity]"], 
   RowBox[{
    SubscriptBox["c", "n"], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"z", "-", "\[Alpha]"}], ")"}], "n"]}]}]]],
 " converges is the domain of a function ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", "0"}], "\[Infinity]"], 
    RowBox[{
     SubscriptBox["c", "n"], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "\[Alpha]"}], ")"}], "n"]}]}]}]]],
 ", which we call a power series function.  Technically, this series is \
undefined if  ",
 Cell[BoxData[
  RowBox[{"z", "=", "\[Alpha]"}]]],
 " and ",
 Cell[BoxData[
  RowBox[{"n", "=", "0"}]],
  CellChangeTimes->{3.399280337296875*^9}],
 ", since ",
 Cell[BoxData[
  SuperscriptBox["0", "0"]]],
 " is undefined.  We get around this difficulty by stipulating that the \
series ",
 Cell[BoxData[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"n", "=", "0"}], "\[Infinity]"], 
   RowBox[{
    SubscriptBox["c", "n"], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"z", "-", "\[Alpha]"}], ")"}], "n"]}]}]]],
 " is really compact notation for ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["c", "0"], "+", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", "1"}], "\[Infinity]"], 
    RowBox[{
     SubscriptBox["c", "n"], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "\[Alpha]"}], ")"}], "n"]}]}]}]]],
 ".  In this section we present some results that are useful in helping \
establish properties of functions defined by power series."
}], "Text",
 CellChangeTimes->{{3.39928034221875*^9, 3.399280346984375*^9}}],

Cell[TextData[{
 StyleBox["Definition (",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Power Series",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/PowerSeries.html"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 StyleBox[").",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  The function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", "0"}], "\[Infinity]"], 
    RowBox[{
     SubscriptBox["c", "n"], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "\[Alpha]"}], ")"}], "n"]}]}]}]]],
 "  is called a power series, with center  ",
 Cell[BoxData[
  RowBox[{"z", "=", "\[Alpha]"}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Theorem 4.15.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Suppose  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", "0"}], "\[Infinity]"], 
    RowBox[{
     SubscriptBox["c", "n"], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "\[Alpha]"}], ")"}], "n"]}]}]}]]],
 " .  Then the set of points z for which the series converges is one of the \
following:\n\n",
 StyleBox["(i)",
  FontColor->RGBColor[0, 0, 1]],
 "    The single point  ",
 Cell[BoxData[
  RowBox[{"z", "=", "\[Alpha]"}]]],
 ".  \n\n",
 StyleBox["(ii)",
  FontColor->RGBColor[0, 0, 1]],
 "   The disk  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["D", "\[Rho]"], 
    RowBox[{"(", "\[Alpha]", ")"}]}], "=", 
   RowBox[{"{", 
    RowBox[{"z", ":", " ", 
     RowBox[{"|", 
      RowBox[{"z", "-", "\[Alpha]"}], "|", 
      RowBox[{"<", " ", "\[Rho]"}]}]}], "}"}]}]]],
 ",  along with part (either none, or some or all) of the circle  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["C", "\[Rho]"], 
    RowBox[{"(", "\[Alpha]", ")"}]}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"z", ":", " ", 
      RowBox[{"|", 
       RowBox[{"z", "-", "\[Alpha]"}], "|"}]}], "=", "  ", "\[Rho]"}], 
    "}"}]}]]],
 ".  \n\n",
 StyleBox["(iii)",
  FontColor->RGBColor[0, 0, 1]],
 "  The entire complex plane."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 4.15 is in the book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
 "\tAnother way to phrase case (ii) of Theorem 4.15 is to say that the power \
series ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", "0"}], "\[Infinity]"], 
    RowBox[{
     SubscriptBox["c", "n"], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "\[Alpha]"}], ")"}], "n"]}]}]}]]],
 " converges if ",
 Cell[BoxData[
  RowBox[{"|", 
   RowBox[{"z", "-", "\[Alpha]"}], "|", 
   RowBox[{"<", " ", "\[Rho]"}]}]]],
 " and diverges if  ",
 Cell[BoxData[
  RowBox[{"|", 
   RowBox[{"z", "-", "\[Alpha]"}], "|", 
   RowBox[{">", " ", "\[Rho]"}]}]]],
 ".  We call the number ",
 Cell[BoxData["\[Rho]"]],
 " the ",
 StyleBox[ButtonBox["radius of convergence",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/RadiusofConvergence.html"], None}],
  FontVariations->{"Underline"->True}],
 " of the power series (see Figure 4.3).  For case (i) of Theorem 4.15, we \
say that the radius of convergence is zero and that the radius of convergence \
is infinity for case (iii)."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "\t\t\t",
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .66667 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8  scalefont  setfont
% Scaling calculations
0.0869565 0.289855 0.0740741 0.246914 [
[ 0 0 0 0 ]
[ 1 .66667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .66667 L
0 .66667 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-15. 3.75 moveto 0 0 lineto
-15. -3.75 lineto fill
-15. 3.75 moveto 0 0 lineto
-15. -3.75 lineto
-15. 3.75 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.941 1 .941 r
0 0 m
.95652 0 L
.95652 .62963 L
0 .62963 L
0 0 L
F
0 1 1 r
.37681 .32099 m
matrix currentmatrix
0.217391 0.185185 scale
1.73333 1.73335 1 0 365.73 arc
setmatrix F
0 0 1 r
.022 w
.37681 .32099 Mdot
.5 Mabswid
[ .0265 .0265 ] 0 setdash
newpath
matrix currentmatrix
0.217391 0.185185 scale
1.73333 1.73335 1 0 365.73 arc
setmatrix s
[ ] 0 setdash
.37681 .32099 m
.22309 .19004 L
s
% Start of user PostScript
1. 1. 0.46967 0.46967 MAarrowhead1
% End of user PostScript
0 g
gsave
.66667 .55556 -98.9375 -9.96875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.9375 translate 1 -1 scale
63.000 12.688 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.688 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Divergence) show
134.875 12.688 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.37681 .40741 -102.531 -9.71875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.4375 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Convergence) show
142.063 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.98551 .09877 -66.5938 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.188 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.11594 .64198 -66.5938 -9.71875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.4375 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
70.188 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.41449 .32099 -66.5938 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.188 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
70.188 12.188 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.34783 .24691 -66.5938 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.188 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
70.188 12.188 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 0 r
0 .07407 m
1 .07407 L
s
.08696 0 m
.08696 .66667 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 192},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
  ImageRangeCache->{{{0, 287}, {191, 0}} -> {0, 0, 0, 0}}],
 StyleBox["  \n\t\t\tFigure 4.3",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  The radius of convergence of a power series.  \n\t\t\t    What happens on \
the boundary circle may be unknown. "
}], "Text"],

Cell[TextData[{
 StyleBox["Theorem 4.16 (",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Radius of Convergence",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/RadiusofConvergence.html"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 StyleBox[").",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  For the power series function ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", "0"}], "\[Infinity]"], 
    RowBox[{
     SubscriptBox["c", "n"], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "\[Alpha]"}], ")"}], "n"]}]}]}]]],
 ",  we can find  ",
 Cell[BoxData["\[Rho]"]],
 " , its ",
 StyleBox[ButtonBox["radius of convergence",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/RadiusofConvergence.html"], None}],
  FontVariations->{"Underline"->True}],
 ", by any of the following methods:\n\n\t",
 StyleBox["(i)    ",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Cauchy's Root Test",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/RootTest.html"], None}],
  FontVariations->{"Underline"->True}],
 StyleBox[":",
  FontColor->RGBColor[0, 0, 1]],
 "   ",
 Cell[BoxData[
  RowBox[{"\[Rho]", "=", 
   FractionBox["1", 
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"n", "\[Rule]", "\[Infinity]"}]], "  ", 
     RowBox[{"|", 
      SubscriptBox["c", "n"], 
      SuperscriptBox["|", 
       FractionBox["1", "n"]]}]}]]}]]],
 "     (provided that the limit exists.)  \n\n\t",
 StyleBox["(ii)   ",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Cauchy-Hadamard Formula",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/Cauchy-HadamardTheorem.html"], None}],
  FontVariations->{"Underline"->True}],
 StyleBox[":",
  FontColor->RGBColor[0, 0, 1]],
 "   ",
 Cell[BoxData[
  RowBox[{"\[Rho]", "=", 
   FractionBox["1", 
    RowBox[{
     UnderscriptBox[
      RowBox[{"lim", " ", "sup"}], 
      RowBox[{"n", "\[Rule]", "\[Infinity]"}]], "  ", 
     RowBox[{"|", 
      SubscriptBox["c", "n"], 
      SuperscriptBox["|", 
       FractionBox["1", "n"]]}]}]]}]]],
 "     (the limit superior always exists.)  \n\n\t",
 StyleBox["(iii)  ",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["d'Alembert's Ratio Test",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/RatioTest.html"], None}],
  FontVariations->{"Underline"->True}],
 StyleBox[":",
  FontColor->RGBColor[0, 0, 1]],
 "   ",
 Cell[BoxData[
  RowBox[{"\[Rho]", "=", " ", 
   FractionBox["1", 
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"n", "\[Rule]", "\[Infinity]"}]], " ", 
     RowBox[{"|", 
      FractionBox[
       SubscriptBox["c", 
        RowBox[{"n", "+", "1"}]], 
       SubscriptBox["c", "n"]], "|"}]}]]}]]],
 "     (provided that the limit exists.)\n\nWe set  ",
 Cell[BoxData[
  RowBox[{"\[Rho]", "=", "\[Infinity]"}]]],
 "  if the limit equals  0,  and  ",
 Cell[BoxData[
  RowBox[{"\[Rho]", "=", "0"}]]],
 "  if the  limit equals  ",
 Cell[BoxData["\[Infinity]"]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 4.16 is in the book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"]
}, Closed]],

Cell["\tWe now give an example illustrating each of these cases.", "Text"],

Cell[TextData[{
 StyleBox["Example 4.21.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  The infinite series  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", "0"}], "\[Infinity]"], 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       FractionBox[
        RowBox[{"n", " ", "+", " ", "2"}], 
        RowBox[{
         RowBox[{"3", "n"}], " ", "+", " ", "1"}]], ")"}], "n"], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "4"}], ")"}], "n"]}]}]}]]],
 "  has radius of convergence ",
 Cell[BoxData[
  RowBox[{"\[Rho]", "=", "3"}]]],
 " Cauchy's root test because  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    UnderscriptBox["lim", 
     RowBox[{"n", "\[Rule]", "\[Infinity]"}]], " ", 
    RowBox[{"|", 
     SubscriptBox["c", "n"], 
     SuperscriptBox["|", 
      FractionBox["1", "n"]]}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"n", "\[Rule]", "\[Infinity]"}]], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       SuperscriptBox[
        RowBox[{"(", 
         FractionBox[
          RowBox[{"n", "+", "2"}], 
          RowBox[{
           RowBox[{"3", "n"}], "+", "1"}]], ")"}], "n"], ")"}], 
      FractionBox["1", "n"]]}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"n", "\[Rule]", "\[Infinity]"}]], " ", 
      FractionBox[
       RowBox[{"n", "+", "2"}], 
       RowBox[{
        RowBox[{"3", "n"}], "+", "1"}]]}], " ", "=", " ", 
     FractionBox["1", "3"]}]}]}]]],
 ",  \n\nhence   ",
 Cell[BoxData[
  RowBox[{"\[Rho]", "=", 
   RowBox[{
    FractionBox["1", 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"n", "\[Rule]", "\[Infinity]"}]], "  ", 
      RowBox[{"|", 
       SubscriptBox["c", "n"], 
       SuperscriptBox["|", 
        FractionBox["1", "n"]]}]}]], "=", " ", 
    RowBox[{
     FractionBox["1", 
      FractionBox["1", "3"]], " ", "=", " ", "3"}]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 4.21.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell["Enter the formula for the coefficients.  ", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", "c", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"L", ",", "n", ",", "Pn", ",", "R"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["c", "n_"], " ", "=", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       FractionBox[
        RowBox[{"n", "+", "2"}], 
        RowBox[{
         RowBox[{"3", "n"}], "+", "1"}]], ")"}], "n"]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["p", "n_"], "=", 
     SuperscriptBox[
      RowBox[{"(", 
       SubscriptBox["c", "n"], ")"}], 
      RowBox[{"1", "/", "n"}]]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(c\), \(n\)]\) = \>\"", ",", 
      SubscriptBox["c", "n"]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"Text", "[", 
       RadicalBox["\"\<|\!\(\*SubscriptBox[\(c\), \(n\)]\)|\>\"", "n"], "]"}],
       ",", "\"\< = \>\"", ",", 
      SubscriptBox["p", "n"]}], " ", "]"}], ";"}], " ", "\[IndentingNewLine]",
    
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"Text", "[", 
       RadicalBox["\"\<|\!\(\*SubscriptBox[\(c\), \(n\)]\)|\>\"", "n"], "]"}],
       ",", "\"\< = \>\"", ",", 
      RowBox[{"PowerExpand", "[", 
       SubscriptBox["p", "n"], "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{
  3.399116810859375*^9, {3.39911689271875*^9, 3.399116899078125*^9}, {
   3.399116975359375*^9, 3.399117003078125*^9}}],

Cell["\<\
Use the Cauchy root test and find the limit and then the radius of \
convergence R.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"L", " ", "=", " ", 
     RowBox[{"Limit", "[", " ", 
      RowBox[{
       SubscriptBox["p", "n"], ",", " ", 
       RowBox[{"n", "\[Rule]", "\[Infinity]"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"\[Rho]", " ", "=", 
     FractionBox[
      RowBox[{" ", "1"}], "L"]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<L = \!\(\*UnderscriptBox[\(lim\), \(n \[Rule] \[Infinity]\)]\) \
\>\"", ",", 
      RowBox[{"Text", "[", 
       RadicalBox["\"\<|\!\(\*SubscriptBox[\(c\), \(n\)]\)|\>\"", "n"], "]"}],
       ",", "\"\< = \!\(\*UnderscriptBox[\(lim\), \(n \[Rule] \
\[Infinity]\)]\) \>\"", ",", 
      SubscriptBox["p", "n"]}], " ", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<L = \!\(\*UnderscriptBox[\(lim\), \(n \[Rule] \[Infinity]\)]\) \
\>\"", ",", 
      RowBox[{"Text", "[", 
       RadicalBox["\"\<|\!\(\*SubscriptBox[\(c\), \(n\)]\)|\>\"", "n"], "]"}],
       ",", "\"\< = \!\(\*UnderscriptBox[\(lim\), \(n \[Rule] \
\[Infinity]\)]\) \>\"", ",", 
      RowBox[{"PowerExpand", "[", 
       SubscriptBox["p", "n"], "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<L = \!\(\*UnderscriptBox[\(lim\), \(n \[Rule] \[Infinity]\)]\) \
\>\"", ",", 
      RowBox[{"Text", "[", 
       RadicalBox["\"\<|\!\(\*SubscriptBox[\(c\), \(n\)]\)|\>\"", "n"], "]"}],
       ",", "\"\< = \>\"", ",", "L"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<The limit is  L = \>\"", ",", "L"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<The radius of convergence is \[Rho] = \!\(\*FractionBox[\(1\), \
\(L\)]\) = \>\"", ",", "\[Rho]"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39911701690625*^9, 3.399117105765625*^9}}],

Cell[TextData[{
 "The series  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", "0"}], "\[Infinity]"], 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       FractionBox[
        RowBox[{"n", " ", "+", " ", "2"}], 
        RowBox[{
         RowBox[{"3", "n"}], " ", "+", " ", "1"}]], ")"}], "n"], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "4"}], ")"}], "n"]}]}]}]]],
 "  will converge in the disk  ",
 Cell[BoxData[
  RowBox[{"|", 
   RowBox[{"z", "-", "4"}], "|", 
   RowBox[{"<", "3"}]}]]],
 ".  \n\nWe can plot some of the partial sums and see that they converge. \
Convergence will be faster if we choose a smaller disk ",
 Cell[BoxData[
  RowBox[{"|", 
   RowBox[{"z", "-", "4"}], "|", 
   RowBox[{"<", "r"}]}]]],
 "  the following graphs use the smaller disk with  ",
 Cell[BoxData[
  RowBox[{"r", "=", "1"}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"g", ",", "k", ",", "m", ",", "n", ",", "s"}], "]"}], ";"}], " ",
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"s", "[", 
      RowBox[{"z_", ",", "n_"}], "]"}], "=", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"k", "=", "0"}], "n"], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         FractionBox[
          RowBox[{"k", "+", "2"}], 
          RowBox[{
           RowBox[{"3", "k"}], "+", "1"}]], ")"}], "k"], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"z", "-", "4"}], ")"}], "k"]}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"For", " ", "[", 
     RowBox[{
      RowBox[{"m", "=", "2"}], ",", 
      RowBox[{"m", "\[LessEqual]", "7"}], ",", 
      RowBox[{"m", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"g", "[", "z_", "]"}], "=", 
        RowBox[{"s", "[", 
         RowBox[{
          RowBox[{"z", "+", "4"}], ",", "m"}], "]"}]}], ";", " ", 
       "\[IndentingNewLine]", 
       RowBox[{"g0", "=", 
        RowBox[{"PolarMap", "[", 
         RowBox[{"g", " ", ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1.0", ",", "0.2"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{"2", "\[Pi]"}], ",", 
            FractionBox["\[Pi]", "12"]}], "}"}], ",", "\[IndentingNewLine]", 
          RowBox[{"PlotRange", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", "3"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "1.5"}], ",", "1.5"}], "}"}]}], "}"}]}], ",", 
          RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", "\[IndentingNewLine]",
           
          RowBox[{"Ticks", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Range", "[", 
              RowBox[{"0", ",", "3", ",", "1"}], "]"}], ",", 
             RowBox[{"Range", "[", 
              RowBox[{
               RowBox[{"-", 
                FractionBox["3", "2"]}], ",", 
               FractionBox["3", "2"], ",", 
               FractionBox["1", "2"]}], "]"}]}], "}"}]}], ",", 
          RowBox[{"AxesLabel", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
          RowBox[{"PlotStyle", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"Red", ",", "Blue"}], "}"}]}]}], "]"}]}], ";", " ", 
       "\[IndentingNewLine]", 
       RowBox[{"Print", "[", "g0", "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{"\"\<s[z,\>\"", ",", "m", ",", "\"\<] = \>\"", ",", 
         RowBox[{"s", "[", 
          RowBox[{"z", ",", "m"}], "]"}], ",", "\"\<\\n\>\"", ",", 
         "\"\<\\n\>\""}], "]"}], ";"}]}], "  ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399117120015625*^9, 3.399117162890625*^9}, 
   3.399117297453125*^9, {3.399799174156002*^9, 3.399799174343502*^9}}],

Cell[TextData[{
 "We see that the series  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", "0"}], "\[Infinity]"], 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       FractionBox[
        RowBox[{"n", " ", "+", " ", "2"}], 
        RowBox[{
         RowBox[{"3", "n"}], " ", "+", " ", "1"}]], ")"}], "n"], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "4"}], ")"}], "n"]}]}]}]]],
 "  is converging in the smaller disk  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", 
    RowBox[{"z", "-", "4"}], "|", 
    RowBox[{"<", " ", 
     RowBox[{"r", "   ", 
      StyleBox["where",
       FontFamily->"Times New Roman"], "   ", "r"}]}]}], "=", 
   RowBox[{"1", "<", "3"}]}]]],
 ".  \n\n",
 StyleBox["Aside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  We can let ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " try to determine the \"sum\" of this series."
}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"k", ",", "z"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  UnderoverscriptBox["\[Sum]", 
   RowBox[{"k", "=", "0"}], "\[Infinity]"], 
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     FractionBox[
      RowBox[{"k", "+", "2"}], 
      RowBox[{
       RowBox[{"3", "k"}], "+", "1"}]], ")"}], "k"], 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"z", "-", "4"}], ")"}], 
    "k"]}]}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.399117230671875*^9, 3.399117270203125*^9}}],

Cell["\<\
Unfortunately, there is no known closed formula.  This is an instance where \
the infinite series is \"the answer.\"\
\>", "Text"]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 4.22.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "   The infinite series  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", "1"}], "\[Infinity]"], 
     RowBox[{
      SubscriptBox["c", "n"], 
      SuperscriptBox["z", "n"]}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"4", "z"}], "+", 
      RowBox[{
       SuperscriptBox["5", "2"], " ", 
       SuperscriptBox["z", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["4", "3"], 
       SuperscriptBox["z", "3"]}], "+", 
      RowBox[{
       SuperscriptBox["5", "4"], " ", 
       SuperscriptBox["z", "4"]}], "+", 
      RowBox[{
       SuperscriptBox["4", "5"], 
       SuperscriptBox["z", "5"]}], "+", 
      RowBox[{
       SuperscriptBox["5", "6"], " ", 
       SuperscriptBox["z", "6"]}], "+"}], "..."}]}]}]]],
 "  has radius of convergence ",
 Cell[BoxData[
  RowBox[{"\[Rho]", "=", 
   FractionBox["1", "5"]}]]],
 " by the Cauchy-Hadamard formula.  We see this by calculating   \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"{", 
    RowBox[{"|", 
     SubscriptBox["c", "n"], 
     SuperscriptBox["|", 
      FractionBox["1", "n"]]}], "}"}], " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
    "4", ",", "5", ",", "4", ",", "5", ",", "4", ",", "5", ",", "..."}], 
    "}"}]}]]],
 ",  so  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    UnderscriptBox[
     RowBox[{"lim", " ", "sup"}], 
     RowBox[{"n", "\[Rule]", "\[Infinity]"}]], " ", "|", 
    SubscriptBox["c", "n"], 
    SuperscriptBox["|", 
     FractionBox["1", "n"]]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     UnderscriptBox[
      RowBox[{"lim", " ", "sup"}], 
      RowBox[{"n", "\[Rule]", "\[Infinity]"}]], " ", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "5", ",", "4", ",", "5", ",", "4", ",", "5", ",", "..."}], 
      "}"}]}], " ", "=", " ", "5"}]}]]],
 ", \n\nhence  ",
 Cell[BoxData[
  RowBox[{"\[Rho]", "=", 
   RowBox[{
    FractionBox["1", 
     RowBox[{
      UnderscriptBox[
       RowBox[{"lim", " ", "sup"}], 
       RowBox[{"n", "\[Rule]", "\[Infinity]"}]], "  ", 
      RowBox[{"|", 
       SubscriptBox["c", "n"], 
       SuperscriptBox["|", 
        FractionBox["1", "n"]]}]}]], " ", "=", " ", 
    FractionBox["1", "5"]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 4.22.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell["\<\
Enter the formula for the coefficients.  There is a formula for the even \
subscripts and a different formula for the odd subscripts.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", "c", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"k", ",", "limsup", ",", "n", ",", "\[Rho]", ",", "R"}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["c", 
      RowBox[{"even", ",", "k_"}]], "=", 
     SuperscriptBox["5", "k"]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["c", 
      RowBox[{"odd", ",", "k_"}]], "=", 
     SuperscriptBox["4", "k"]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"table", "=", 
     RowBox[{"Flatten", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          SubscriptBox["c", 
           RowBox[{"even", ",", 
            RowBox[{"2", "k"}]}]], ",", 
          SubscriptBox["c", 
           RowBox[{"odd", ",", 
            RowBox[{
             RowBox[{"2", "k"}], "+", "1"}]}]]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", "0", ",", "4"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"table", "=", 
     RowBox[{"Append", "[", 
      RowBox[{"table", ",", "\"\<...\>\""}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(c\), \(n\)]\)} = \>\"", ",", "table"}], "]"}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  \!\(\*SubscriptBox[\(c\), \(2  k\)]\) = \>\"", ",", 
      SubscriptBox["c", 
       RowBox[{"even", ",", 
        RowBox[{"2", "k"}]}]]}], " ", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< \!\(\*SubscriptBox[\(c\), \(2  k + 1\)]\) = \>\"", ",", 
      SubscriptBox["c", 
       RowBox[{"odd", ",", 
        RowBox[{
         RowBox[{"2", "k"}], "+", "1"}]}]]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399117326078125*^9}],

Cell["\<\
Use the Cauchy-Hadamard formula and find the radius of convergence R.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"Text", "[", 
  RadicalBox["\"\<|\!\(\*SubscriptBox[\(c\), \(2  k\)]\)|\>\"", 
   RowBox[{"2", "k"}]], "]"}]], "Input",
 CellChangeTimes->{{3.399117597546875*^9, 3.39911761153125*^9}}],

Cell[BoxData[
 RowBox[{"Text", "[", 
  RadicalBox["\"\<|\!\(\*SubscriptBox[\(c\), \(n\)]\)|\>\"", "n"], 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"lim1", "=", 
     RowBox[{"Limit", "[", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         SubscriptBox["c", 
          RowBox[{"even", ",", 
           RowBox[{"2", "k"}]}]], ")"}], 
        FractionBox["1", 
         RowBox[{"2", "k"}]]], ",", 
       RowBox[{"k", "\[Rule]", "\[Infinity]"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"lim2", "=", 
     RowBox[{"Limit", "[", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         SubscriptBox["c", 
          RowBox[{"odd", ",", 
           RowBox[{
            RowBox[{"2", "k"}], "+", "1"}]}]], ")"}], 
        FractionBox["1", 
         RowBox[{
          RowBox[{"2", "k"}], "+", "1"}]]], ",", 
       RowBox[{"k", "\[Rule]", "\[Infinity]"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"L", "=", 
     RowBox[{"Max", "[", 
      RowBox[{"lim1", ",", "lim2"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<   \!\(\*UnderscriptBox[\(lim\), \(k \[Rule] \[Infinity]\)]\) \>\"",
       ",", 
      RowBox[{"Text", "[", 
       RadicalBox["\"\<|\!\(\*SubscriptBox[\(c\), \(2  k\)]\)|\>\"", 
        RowBox[{"2", "k"}]], "]"}], ",", "\"\<  =  \>\"", ",", 
      "\"\<\!\(\*UnderscriptBox[\(lim\), \(k \[Rule] \[Infinity]\)]\) \>\"", 
      ",", 
      SuperscriptBox[
       RowBox[{"(", 
        SubscriptBox["c", 
         RowBox[{"even", ",", 
          RowBox[{"2", "k"}]}]], ")"}], 
       FractionBox["1", 
        RowBox[{"2", "k"}]]], ",", "\"\<  = \>\"", ",", "lim1"}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(lim\), \(k \[Rule] \[Infinity]\)]\) \>\"", 
      ",", 
      RowBox[{"Text", "[", 
       RadicalBox["\"\<|\!\(\*SubscriptBox[\(c\), \(2  k + 1\)]\)|\>\"", 
        RowBox[{
         RowBox[{"2", "k"}], "+", "1"}]], "]"}], ",", "\"\<  =  \>\"", ",", 
      "\"\<\!\(\*UnderscriptBox[\(lim\), \(k \[Rule] \[Infinity]\)]\) \>\"", 
      ",", 
      SuperscriptBox[
       RowBox[{"(", 
        SubscriptBox["c", 
         RowBox[{"odd", ",", 
          RowBox[{
           RowBox[{"2", "k"}], "+", "1"}]}]], ")"}], 
       FractionBox["1", 
        RowBox[{
         RowBox[{"2", "k"}], "+", "1"}]]], ",", "\"\< = \>\"", ",", "lim2"}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<L = \>\"", ",", 
      "\"\<\!\(\*UnderscriptBox[\(lim\), \(k \[Rule] \[Infinity]\)]\) \>\"", 
      ",", 
      RowBox[{"Text", "[", 
       RadicalBox["\"\<|\!\(\*SubscriptBox[\(c\), \(n\)]\)|\>\"", "n"], "]"}],
       ",", "\"\<   =  Max[\>\"", ",", "lim1", ",", "\"\<,\>\"", ",", "lim2", 
      ",", "\"\<] = \>\"", ",", 
      RowBox[{"Max", "[", 
       RowBox[{"lim1", ",", "lim2"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<L = \>\"", ",", 
      "\"\<\!\(\*UnderscriptBox[\(lim\), \(k \[Rule] \[Infinity]\)]\) \>\"", 
      ",", 
      RowBox[{"Text", "[", 
       RadicalBox["\"\<|\!\(\*SubscriptBox[\(c\), \(n\)]\)|\>\"", "n"], "]"}],
       ",", "\"\<   =  \!\(\*FractionBox[\(1\), \(\[Rho]\)]\)\>\""}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<The radius of convergence is \[Rho] = \!\(\*FractionBox[\(1\), \
\(L\)]\) = \>\"", ",", 
      FractionBox["1", "L"]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{
  3.3991173320625*^9, {3.399117628734375*^9, 3.399117777765625*^9}, {
   3.399117809140625*^9, 3.39911782853125*^9}, {3.399117867875*^9, 
   3.39911796834375*^9}}],

Cell[TextData[{
 "The series  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", "1"}], "\[Infinity]"], 
     RowBox[{
      SubscriptBox["c", "n"], 
      SuperscriptBox["z", "n"]}]}], "=", 
    RowBox[{
     RowBox[{"1", "+", 
      RowBox[{"4", "z"}], "+", 
      RowBox[{
       SuperscriptBox["5", "2"], " ", 
       SuperscriptBox["z", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["4", "3"], 
       SuperscriptBox["z", "3"]}], "+", 
      RowBox[{
       SuperscriptBox["5", "4"], " ", 
       SuperscriptBox["z", "4"]}], "+", 
      RowBox[{
       SuperscriptBox["4", "5"], 
       SuperscriptBox["z", "5"]}], "+", 
      RowBox[{
       SuperscriptBox["5", "6"], " ", 
       SuperscriptBox["z", "6"]}], "+"}], "..."}]}]}]]],
 "  has radius of convergence  ",
 Cell[BoxData[
  RowBox[{"\[Rho]", "=", 
   FractionBox["1", "5"]}]]],
 "  by the Cauchy-Hadamard formula because   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    UnderscriptBox[
     RowBox[{"lim", " ", "sup"}], 
     RowBox[{"n", "\[Rule]", "\[Infinity]"}]], " ", 
    RadicalBox[
     RowBox[{"\[VerticalBar]", 
      SubscriptBox["c", "n"], "\[VerticalBar]"}], "n"]}], " ", "=", "5"}]]],
 ".  \n\nWe can let ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " find the sum of this series."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f0", "[", "z_", "]"}], "=", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"k", "=", "0"}], "\[Infinity]"], 
      RowBox[{
       SuperscriptBox["5", 
        RowBox[{"2", " ", "k"}]], 
       SuperscriptBox["z", 
        RowBox[{"2", " ", "k"}]]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f1", "[", "z_", "]"}], "=", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"k", "=", "0"}], "\[Infinity]"], 
      RowBox[{
       SuperscriptBox["4", 
        RowBox[{
         RowBox[{"2", " ", "k"}], "+", "1"}]], 
       SuperscriptBox["z", 
        RowBox[{
         RowBox[{"2", " ", "k"}], "+", "1"}]]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", 
     RowBox[{
      RowBox[{"f0", "[", "z", "]"}], "+", 
      RowBox[{"f1", "[", "z", "]"}]}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(f\), \(1\)]\)[z] = \!\(\*UnderoverscriptBox[\(\
\[Sum]\), \(k = 0\), \(\[Infinity]\)]\)\!\(\*SuperscriptBox[\(5\), \(2\\\ \
k\)]\)\!\(\*SuperscriptBox[\(z\), \(2\\\ k\)]\) = \>\"", ",", 
      RowBox[{"f0", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(f\), \(2\)]\)[z] = \!\(\*UnderoverscriptBox[\(\
\[Sum]\), \(k = 0\), \(\[Infinity]\)]\)\!\(\*SuperscriptBox[\(4\), \(2\\\ k + \
1\)]\)\!\(\*SuperscriptBox[\(z\), \(2\\\ k + 1\)]\) = \>\"", ",", 
      RowBox[{"f1", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<f[z] = \!\(\*SubscriptBox[\(f\), \(1\)]\)[z] + \
\!\(\*SubscriptBox[\(f\), \(2\)]\)[z]\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399117338109375*^9}],

Cell[TextData[{
 "Thus we see that f[z] is composed of two \"infinite geometric series\"  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["f", "1"], "[", "z", "]"}], "  ", "and", "   ", 
   RowBox[{
    SubscriptBox["f", "2"], "[", "z", "]"}]}]]],
 ", whose radius of convergence are  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["R", "1"], "=", 
   RowBox[{
    RowBox[{
     FractionBox["1", "5"], "  ", 
     StyleBox["and",
      FontFamily->"Times New Roman"], "   ", 
     SubscriptBox["R", "2"]}], "=", 
    FractionBox["1", "4"]}]}]]],
 ", respectively. Hence the radius of convergence of f[z] must be  ",
 Cell[BoxData[
  RowBox[{"\[Rho]", "=", 
   RowBox[{
    RowBox[{"min", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "5"], ",", 
       FractionBox["1", "4"]}], "}"}]}], "=", 
    FractionBox["1", "5"]}]}]]],
 ".  \n\nWe can use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to compute the first few terms in the Maclaurin series for f[z] and \
compare them with the formula that was given."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"s", "[", "z_", "]"}], "=", 
     RowBox[{"Series", "[", 
      RowBox[{
       RowBox[{"f", "[", "z", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"z", ",", "0", ",", "10"}], "}"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"s", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399117342484375*^9}],

Cell[TextData[{
 "We can plot some of the partial sums and see that they converge. \
Convergence will be faster if we choose a smaller disk ",
 Cell[BoxData[
  RowBox[{"|", "z", "|", 
   RowBox[{"<", "r"}]}]]],
 "  the following graphs use the smaller disk with  ",
 Cell[BoxData[
  RowBox[{"r", "=", 
   RowBox[{"0.06", 
    RowBox[{"<<", 
     FractionBox["1", "5"]}]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 CellChangeTimes->{
  3.39911816378125*^9, {3.399118413890625*^9, 3.399118417421875*^9}},
 AspectRatioFixed->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Clear", "[", 
    RowBox[{"g", ",", "k", ",", "m", ",", "n"}], "]"}], ";"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"For", " ", "[", 
  RowBox[{
   RowBox[{"m", "=", "3"}], ",", 
   RowBox[{"m", "\[LessEqual]", "7"}], ",", 
   RowBox[{"m", "++"}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"g", "[", "z_", "]"}], "=", 
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{"f", "[", "z", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", "0", ",", "m"}], "}"}]}], "]"}], "]"}]}], ";", " ",
     "\[IndentingNewLine]", 
    RowBox[{"g0", "=", 
     RowBox[{"PolarMap", "[", 
      RowBox[{"g", " ", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.06", ",", "0.01"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"2", "\[Pi]"}], ",", 
         FractionBox["\[Pi]", "12"]}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0.5", ",", "1.5"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.5"}], ",", "0.5"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0.5", ",", "1.5"}], "}"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}]}], "}"}]}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], ";", " ", 
    "\[IndentingNewLine]", 
    RowBox[{"Print", "[", "g0", "]"}], ";", "\[IndentingNewLine]", 
    RowBox[{"Print", "[", 
     RowBox[{"\"\<s[z,\>\"", ",", "m", ",", "\"\<] = \>\"", ",", 
      RowBox[{"g", "[", "z", "]"}], ",", "\"\<\\n\>\"", ",", "\"\<\\n\>\""}], 
     "]"}], ";"}]}], "  ", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"g1", "=", 
    RowBox[{"PolarMap", "[", 
     RowBox[{"f", ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0.06", ",", "0.01"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"2", "\[Pi]"}], ",", 
        FractionBox["\[Pi]", "12"]}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0.5", ",", "1.5"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "0.5"}], ",", "0.5"}], "}"}]}], "}"}]}], ",", 
      RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
      RowBox[{"Ticks", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0.5", ",", "1.5"}], "}"}], ",", 
         RowBox[{"Range", "[", 
          RowBox[{
           RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}]}], "}"}]}], ",", 
      RowBox[{"AxesLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], ";"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", "g1", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Print", "[", 
    RowBox[{"\"\<The limit function is f[z] = \>\"", ",", 
     RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], 
  " "}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.3991173550625*^9, 3.399117402125*^9}, {
  3.399117447046875*^9, 3.39911745046875*^9}, {3.399118060125*^9, 
  3.399118062515625*^9}, {3.399118107890625*^9, 3.3991181303125*^9}, {
  3.3991182258125*^9, 3.399118241140625*^9}, {3.399118282640625*^9, 
  3.3991183719375*^9}, {3.399799181656002*^9, 3.399799181843502*^9}}],

Cell[TextData[{
 "Convergence will be fast if we choose a small disk ",
 Cell[BoxData[
  RowBox[{"|", "z", "|", 
   RowBox[{"<", "r"}]}]]],
 "  the following graphs use the smaller disk with  ",
 Cell[BoxData[
  RowBox[{"r", "=", 
   RowBox[{"0.1", "<", 
    FractionBox["1", "5"]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 CellChangeTimes->{
  3.39911816378125*^9, {3.399118424703125*^9, 3.39911845965625*^9}},
 AspectRatioFixed->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Clear", "[", 
    RowBox[{"g", ",", "k", ",", "m", ",", "n"}], "]"}], ";"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"For", " ", "[", 
  RowBox[{
   RowBox[{"m", "=", "3"}], ",", 
   RowBox[{"m", "\[LessEqual]", "7"}], ",", 
   RowBox[{"m", "++"}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"g", "[", "z_", "]"}], "=", 
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{"f", "[", "z", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", "0", ",", "m"}], "}"}]}], "]"}], "]"}]}], ";", " ",
     "\[IndentingNewLine]", 
    RowBox[{"g0", "=", 
     RowBox[{"PolarMap", "[", 
      RowBox[{"g", " ", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.1", ",", "0.02"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"2", "\[Pi]"}], ",", 
         FractionBox["\[Pi]", "12"]}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "2.8"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.4"}], ",", "1.4"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "3", ",", "1"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}]}], "}"}]}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], ";", " ", 
    "\[IndentingNewLine]", 
    RowBox[{"Print", "[", "g0", "]"}], ";", "\[IndentingNewLine]", 
    RowBox[{"Print", "[", 
     RowBox[{"\"\<s[z,\>\"", ",", "m", ",", "\"\<] = \>\"", ",", 
      RowBox[{"g", "[", "z", "]"}], ",", "\"\<\\n\>\"", ",", "\"\<\\n\>\""}], 
     "]"}], ";"}]}], "  ", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"g1", "=", 
    RowBox[{"PolarMap", "[", 
     RowBox[{"f", ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0.1", ",", "0.02"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"2", "\[Pi]"}], ",", 
        FractionBox["\[Pi]", "12"]}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "2.8"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "1.4"}], ",", "1.4"}], "}"}]}], "}"}]}], ",", 
      RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
      RowBox[{"Ticks", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Range", "[", 
          RowBox[{"0", ",", "3", ",", "1"}], "]"}], ",", 
         RowBox[{"Range", "[", 
          RowBox[{
           RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}]}], "}"}]}], ",", 
      RowBox[{"AxesLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], ";"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", "g1", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Print", "[", 
    RowBox[{"\"\<The limit function is f[z] = \>\"", ",", 
     RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], 
  " "}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.3991173550625*^9, 3.399117402125*^9}, {
  3.399117447046875*^9, 3.39911745046875*^9}, {3.39911817*^9, 
  3.399118172375*^9}, {3.399799187249752*^9, 3.399799187437252*^9}}],

Cell[TextData[{
 "The following graphs use the disk with  ",
 Cell[BoxData[
  RowBox[{"r", "=", 
   RowBox[{"0.16", "<", 
    FractionBox["1", "5"]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 CellChangeTimes->{{3.3991184705*^9, 3.399118491234375*^9}},
 AspectRatioFixed->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Clear", "[", 
    RowBox[{"g", ",", "k", ",", "m", ",", "n"}], "]"}], ";"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"For", " ", "[", 
  RowBox[{
   RowBox[{"m", "=", "3"}], ",", 
   RowBox[{"m", "\[LessEqual]", "7"}], ",", 
   RowBox[{"m", "++"}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"g", "[", "z_", "]"}], "=", 
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{"f", "[", "z", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", "0", ",", "m"}], "}"}]}], "]"}], "]"}]}], ";", " ",
     "\[IndentingNewLine]", 
    RowBox[{"g0", "=", 
     RowBox[{"PolarMap", "[", 
      RowBox[{"g", " ", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.16", ",", "0.02"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"2", "\[Pi]"}], ",", 
         FractionBox["\[Pi]", "12"]}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "2.8"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.4"}], ",", "1.4"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "3", ",", "1"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}]}], "}"}]}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], ";", " ", 
    "\[IndentingNewLine]", 
    RowBox[{"Print", "[", "g0", "]"}], ";", "\[IndentingNewLine]", 
    RowBox[{"Print", "[", 
     RowBox[{"\"\<s[z,\>\"", ",", "m", ",", "\"\<] = \>\"", ",", 
      RowBox[{"g", "[", "z", "]"}], ",", "\"\<\\n\>\"", ",", "\"\<\\n\>\""}], 
     "]"}], ";"}]}], "  ", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"g1", "=", 
    RowBox[{"PolarMap", "[", 
     RowBox[{"f", ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0.16", ",", "0.02"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"2", "\[Pi]"}], ",", 
        FractionBox["\[Pi]", "12"]}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "2.8"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "1.4"}], ",", "1.4"}], "}"}]}], "}"}]}], ",", 
      RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
      RowBox[{"Ticks", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Range", "[", 
          RowBox[{"0", ",", "3", ",", "1"}], "]"}], ",", 
         RowBox[{"Range", "[", 
          RowBox[{
           RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}]}], "}"}]}], ",", 
      RowBox[{"AxesLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], ";"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", "g1", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Print", "[", 
    RowBox[{"\"\<The limit function is f[z] = \>\"", ",", 
     RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], 
  " "}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.3991173550625*^9, 3.399117402125*^9}, {
  3.399117447046875*^9, 3.39911745046875*^9}, {3.3997991923278775`*^9, 
  3.3997991925153775`*^9}}]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 4.23.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  The infinite series  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", "0"}], "\[Infinity]"], 
    FractionBox[
     SuperscriptBox["z", "n"], 
     RowBox[{"n", "!"}]]}]}]]],
 "  has radius of convergence ",
 Cell[BoxData[
  RowBox[{"\[Rho]", "=", "8"}]]],
 " by the ratio test because \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    UnderscriptBox["lim", 
     RowBox[{"n", "\[Rule]", "\[Infinity]"}]], " ", 
    RowBox[{"|", 
     FractionBox[
      SubscriptBox["c", 
       RowBox[{"n", "+", "1"}]], 
      SubscriptBox["c", "n"]], "|"}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"n", "\[Rule]", "\[Infinity]"}]], " ", 
     RowBox[{"|", 
      FractionBox[
       RowBox[{"n", "!"}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"n", "+", "1"}], ")"}], "!"}]], "|"}]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"n", "\[Rule]", "\[Infinity]"}]], " ", 
      FractionBox["1", 
       RowBox[{"n", "+", "1"}]]}], " ", "=", " ", "0"}]}]}]]],
 ".\n\nSince the limit equals  0,  we set  ",
 Cell[BoxData[
  RowBox[{"\[Rho]", "=", "\[Infinity]"}]]],
 ".    "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 4.23.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell["Enter the formula for the coefficients.", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", 
     RowBox[{"c", ",", "q"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"L", ",", "n", ",", "R", ",", "z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["c", "n_"], " ", "=", " ", 
     FractionBox["1", 
      RowBox[{"n", "!"}]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "n_"], " ", "=", " ", 
     FractionBox[
      SubscriptBox["c", 
       RowBox[{"n", "+", "1"}]], 
      SubscriptBox["c", "n"]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<    \!\(\*SubscriptBox[\(c\), \(n\)]\) = \>\"", ",", 
      SubscriptBox["c", "n"]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<|\!\(\*FractionBox[SubscriptBox[\(c\), \(n + 1\)], SubscriptBox[\(c\
\), \(n\)]]\)| = \>\"", ",", 
      SubscriptBox["q", "n"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "n_"], " ", "=", " ", 
     RowBox[{"FullSimplify", "[", 
      SubscriptBox["q", "n"], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<|\!\(\*FractionBox[SubscriptBox[\(c\), \(n + 1\)], SubscriptBox[\(c\
\), \(n\)]]\)| = \>\"", ",", 
      SubscriptBox["q", "n"]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399118615953125*^9}],

Cell["\<\
Use d'Alembert's ratio test and find the limit and then the radius of \
convergence R.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"L", " ", "=", " ", 
     RowBox[{"Limit", "[", " ", 
      RowBox[{
       SubscriptBox["q", "n"], ",", " ", 
       RowBox[{"n", "\[Rule]", "\[Infinity]"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"R", " ", "=", " ", 
     RowBox[{"Limit", "[", " ", 
      RowBox[{
       FractionBox["1", 
        SubscriptBox["q", "n"]], ",", " ", 
       RowBox[{"n", "\[Rule]", "\[Infinity]"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<  L = \!\(\*UnderscriptBox[\(lim\), \(n \[Rule] \[Infinity]\)]\) \
|\!\(\*FractionBox[SubscriptBox[\(c\), \(n + 1\)], SubscriptBox[\(c\), \
\(n\)]]\)| = \!\(\*UnderscriptBox[\(lim\), \(n \[Rule] \[Infinity]\)]\) \
(\>\"", ",", 
      SubscriptBox["q", "n"], ",", "\"\<) = \>\"", ",", "L"}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<The limit  is  L = \>\"", ",", "L"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<The radius of convergence is R = \>\"", " ", ",", 
      FractionBox["1", "\"\<L\>\""], ",", "\"\< = \>\"", ",", "R"}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399118621828125*^9}],

Cell["The sum of the series is a well known function.", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "0"}], "\[Infinity]"], 
      FractionBox[
       SuperscriptBox["z", "n"], 
       RowBox[{"n", "!"}]]}]}], 
    StyleBox[";",
     FontSize->14]}], 
   StyleBox[" ",
    FontSize->14], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<f(z) = \!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 0\), \
\(\[Infinity]\)]\)\!\(\*FractionBox[SuperscriptBox[\(z\), \(n\)], \(n!\)]\) = \
\>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399118626484375*^9, 3.399118629390625*^9}}],

Cell["\<\
We can plot some of the partial sums and see that they converge to f[z].\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"g", ",", "k", ",", "m", ",", "n", ",", "s"}], "]"}], ";"}], " ",
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"terms", "[", "n_", "]"}], ":=", 
     RowBox[{"Table", "[", 
      RowBox[{
       FractionBox[
        SuperscriptBox["z", "k"], 
        RowBox[{"k", "!"}]], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "0", ",", "n"}], "}"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"For", " ", "[", 
    RowBox[{
     RowBox[{"m", "=", "2"}], ",", 
     RowBox[{"m", "\[LessEqual]", "5"}], ",", 
     RowBox[{"m", "++"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"g", "[", "z_", "]"}], "=", 
       RowBox[{"ReplaceAll", "[", 
        RowBox[{
         RowBox[{"terms", "[", "m", "]"}], ",", 
         RowBox[{"List", "\[Rule]", "Plus"}]}], "]"}]}], ";", " ", 
      "\[IndentingNewLine]", 
      RowBox[{"g0", "=", 
       RowBox[{"PolarMap", "[", 
        RowBox[{"g", " ", ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "1.0", ",", "0.2"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", 
           RowBox[{"2", "\[Pi]"}], ",", 
           FractionBox["\[Pi]", "12"]}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"PlotRange", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", "3"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.5"}], ",", "1.5"}], "}"}]}], "}"}]}], ",", 
         RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
         
         RowBox[{"Ticks", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Range", "[", 
             RowBox[{"0", ",", "3", ",", "1"}], "]"}], ",", 
            RowBox[{"Range", "[", 
             RowBox[{
              RowBox[{"-", 
               FractionBox["3", "2"]}], ",", 
              FractionBox["3", "2"], ",", 
              FractionBox["1", "2"]}], "]"}]}], "}"}]}], ",", 
         RowBox[{"AxesLabel", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
         RowBox[{"PlotStyle", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"Red", ",", "Blue"}], "}"}]}]}], "]"}]}], ";", " ", 
      "\[IndentingNewLine]", 
      RowBox[{"Print", "[", "g0", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{"\"\<s[z,\>\"", ",", "m", ",", "\"\<] = \>\"", ",", 
        RowBox[{"g", "[", "z", "]"}], ",", "\"\<\\n\>\"", ",", 
        "\"\<\\n\>\""}], "]"}], ";"}]}], "  ", "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g1", "=", 
     RowBox[{"PolarMap", "[", 
      RowBox[{"f", " ", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "1.0", ",", "0.2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"2", "\[Pi]"}], ",", 
         FractionBox["\[Pi]", "12"]}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "3"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.5"}], ",", "1.5"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "3", ",", "1"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", 
             FractionBox["3", "2"]}], ",", 
            FractionBox["3", "2"], ",", 
            FractionBox["1", "2"]}], "]"}]}], "}"}]}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<u\>\"", ",", "\"\<u\>\""}], "}"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Red", ",", "Blue"}], "}"}]}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "g1", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<The limit function is f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399118632359375*^9, 3.399118685453125*^9}, {
  3.399799198031002*^9, 3.399799198187252*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"g", ",", "k", ",", "m", ",", "n", ",", "s"}], "]"}], ";"}], " ",
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"terms", "[", "n_", "]"}], ":=", 
     RowBox[{"Table", "[", 
      RowBox[{
       FractionBox[
        SuperscriptBox["z", "k"], 
        RowBox[{"k", "!"}]], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "0", ",", "n"}], "}"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"For", " ", "[", 
    RowBox[{
     RowBox[{"m", "=", "2"}], ",", 
     RowBox[{"m", "\[LessEqual]", "5"}], ",", 
     RowBox[{"m", "++"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"g", "[", "z_", "]"}], "=", 
       RowBox[{"ReplaceAll", "[", 
        RowBox[{
         RowBox[{"terms", "[", "m", "]"}], ",", 
         RowBox[{"List", "\[Rule]", "Plus"}]}], "]"}]}], ";", " ", 
      "\[IndentingNewLine]", 
      RowBox[{"g0", "=", 
       RowBox[{"CartesianMap", "[", 
        RowBox[{"g", " ", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "1"}], ",", "1", ",", "0.2"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "1"}], ",", "1", ",", "0.2"}], "}"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"PlotRange", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", "3"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.5"}], ",", "2.5"}], "}"}]}], "}"}]}], ",", 
         RowBox[{"AspectRatio", "\[Rule]", 
          FractionBox["5", "3"]}], ",", "\[IndentingNewLine]", 
         RowBox[{"Ticks", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Range", "[", 
             RowBox[{"0", ",", "3", ",", "1"}], "]"}], ",", 
            RowBox[{"Range", "[", 
             RowBox[{
              RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}], ",",
          
         RowBox[{"AxesLabel", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
         RowBox[{"PlotStyle", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], ";", " ", 
      "\[IndentingNewLine]", 
      RowBox[{"Print", "[", "g0", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{"\"\<s[z,\>\"", ",", "m", ",", "\"\<] = \>\"", ",", 
        RowBox[{"g", "[", "z", "]"}], ",", "\"\<\\n\>\"", ",", 
        "\"\<\\n\>\""}], "]"}], ";"}]}], "  ", "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g1", "=", 
     RowBox[{"CartesianMap", "[", 
      RowBox[{"f", " ", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "1", ",", "0.2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "1", ",", "0.2"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "3"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2.5"}], ",", "2.5"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", 
        FractionBox["5", "3"]}], ",", "\[IndentingNewLine]", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "3", ",", "1"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<u\>\"", ",", "\"\<u\>\""}], "}"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "g1", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<The limit function is f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399118699796875*^9, 3.39911877659375*^9}, {
  3.399202532953125*^9, 3.399202556109375*^9}, {3.399799203843502*^9, 
  3.3997992040153775`*^9}}]
}, Closed]],

Cell[TextData[{
 StyleBox["Extra Example 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Find the radius of convergence of the infinite series  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"S", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    RowBox[{"1", "+", 
     FractionBox["z", "2"], "+", 
     FractionBox[
      SuperscriptBox["z", "2"], 
      SuperscriptBox["3", "2"]], "+", 
     FractionBox[
      SuperscriptBox["z", "3"], 
      SuperscriptBox["2", "3"]], "+", 
     FractionBox[
      SuperscriptBox["z", "4"], 
      SuperscriptBox["3", "4"]], "+", 
     FractionBox[
      SuperscriptBox["z", "5"], 
      SuperscriptBox["2", "5"]], "+", 
     FractionBox[
      SuperscriptBox["z", "6"], 
      SuperscriptBox["3", "6"]], "+", 
     FractionBox[
      SuperscriptBox["z", "7"], 
      SuperscriptBox["2", "7"]], "+", 
     FractionBox[
      SuperscriptBox["z", "8"], 
      SuperscriptBox["3", "8"]], "+", 
     FractionBox[
      SuperscriptBox["z", "9"], 
      SuperscriptBox["2", "9"]], "+", 
     FractionBox[
      SuperscriptBox["z", "10"], 
      SuperscriptBox["3", "10"]], "+", 
     FractionBox[
      SuperscriptBox["z", "11"], 
      SuperscriptBox["2", "11"]], "+"}], "..."}]}]]],
 ". "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Extra Solution 1.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "The sequence of coefficients is  ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{"1", ",", 
    FractionBox["1", "2"], ",", 
    FractionBox["1", 
     SuperscriptBox["3", "2"]], ",", 
    FractionBox["1", 
     SuperscriptBox["2", "3"]], ",", 
    FractionBox["1", 
     SuperscriptBox["3", "4"]], ",", 
    FractionBox["1", 
     SuperscriptBox["2", "5"]], ",", 
    FractionBox["1", 
     SuperscriptBox["3", "6"]], ",", 
    FractionBox["1", 
     SuperscriptBox["2", "7"]], ",", 
    FractionBox["1", 
     SuperscriptBox["3", "8"]], ",", 
    FractionBox["1", 
     SuperscriptBox["2", "9"]], ",", 
    FractionBox["1", 
     SuperscriptBox["3", "10"]], ",", 
    FractionBox["1", 
     SuperscriptBox["2", "11"]], ",", "..."}], "}"}]]],
 ".   \nThe coefficients with even subscripts are ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["a", 
    RowBox[{"2", "k"}]], "=", 
   FractionBox["1", 
    SuperscriptBox["3", 
     RowBox[{"2", "k"}]]]}]]],
 ", and the coefficients with odd subscripts are  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["a", 
    RowBox[{
     RowBox[{"2", "k"}], "+", "1"}]], "=", 
   FractionBox["1", 
    SuperscriptBox["2", 
     RowBox[{
      RowBox[{"2", "k"}], "+", "1"}]]]}]]],
 ".  \nSo that we have \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[VerticalSeparator]", 
    SubscriptBox["a", 
     RowBox[{"2", "k"}]], 
    StyleBox[
     SuperscriptBox["\[VerticalSeparator]", 
      FractionBox["1", 
       RowBox[{"2", " ", "k"}]]],
     FontSize->12]}], "=", 
   RowBox[{
    StyleBox[
     SuperscriptBox[
      RowBox[{"(", 
       FractionBox["1", 
        SuperscriptBox["3", 
         RowBox[{"2", "k"}]]], ")"}], 
      FractionBox["1", 
       RowBox[{"2", " ", "k"}]]],
     FontSize->12], "  ", "=", " ", 
    FractionBox["1", "3"]}]}]]],
 "    and    ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[VerticalSeparator]", 
    SubscriptBox["a", 
     RowBox[{
      RowBox[{"2", "k"}], "+", "1"}]], 
    StyleBox[
     SuperscriptBox["\[VerticalSeparator]", 
      FractionBox["1", 
       RowBox[{
        RowBox[{"2", " ", "k"}], "+", "1"}]]],
     FontSize->12]}], "=", " ", 
   RowBox[{
    StyleBox[
     SuperscriptBox[
      RowBox[{"(", 
       FractionBox["1", 
        SuperscriptBox["2", 
         RowBox[{
          RowBox[{"2", "k"}], "+", "1"}]]], ")"}], 
      FractionBox["1", 
       RowBox[{
        RowBox[{"2", " ", "k"}], "+", "1"}]]],
     FontSize->12], " ", "=", " ", 
    FractionBox["1", "2"]}]}]]],
 ".  \n\nIt follows that   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    UnderscriptBox[
     RowBox[{"lim", " ", "sup"}], 
     RowBox[{"n", " ", "\[Rule]", " ", "\[Infinity]"}]], "  ", 
    RadicalBox[
     StyleBox[
      RowBox[{"\[VerticalSeparator]", 
       RowBox[{
        SubscriptBox["a", "n"], 
        SuperscriptBox["z", "n"]}], "\[VerticalSeparator]"}],
      FontSize->12], "n"]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     UnderscriptBox[
      RowBox[{"lim", " ", "sup"}], 
      RowBox[{"n", " ", "\[Rule]", " ", "\[Infinity]"}]], " ", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       FractionBox["1", "2"], ",", 
       FractionBox["1", "3"], ",", 
       FractionBox["1", "2"], ",", 
       FractionBox["1", "3"], ",", 
       FractionBox["1", "2"], ",", 
       FractionBox["1", "3"], ",", "..."}], "}"}]}], " ", "=", " ", 
    FractionBox["1", "2"]}]}]]],
 ".   \nhence  ",
 Cell[BoxData[
  RowBox[{"\[Rho]", "=", 
   RowBox[{
    FractionBox["1", 
     RowBox[{
      UnderscriptBox[
       RowBox[{"lim", " ", "sup"}], 
       RowBox[{"n", "\[Rule]", "\[Infinity]"}]], "  ", 
      RowBox[{"|", 
       SubscriptBox["c", "n"], 
       SuperscriptBox["|", 
        FractionBox["1", "n"]]}]}]], " ", "=", " ", 
    RowBox[{
     FractionBox["1", 
      FractionBox["1", "2"]], " ", "=", " ", "2"}]}]}]]],
 ".  "
}], "Text"],

Cell["We are done.", "Text"],

Cell[TextData[{
 StyleBox["Aside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  The given series is the sum of two geometric series:   ",
 Cell[BoxData[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"k", "=", "0"}], "\[Infinity]"], 
   FractionBox[
    SuperscriptBox["z", 
     RowBox[{"2", "k"}]], 
    SuperscriptBox["3", 
     RowBox[{"2", "k"}]]]}]]],
 "   and   ",
 Cell[BoxData[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"k", "=", "0"}], "\[Infinity]"], 
   FractionBox[
    SuperscriptBox["z", 
     RowBox[{
      RowBox[{"2", "k"}], "+", "1"}]], 
    SuperscriptBox["2", 
     RowBox[{
      RowBox[{"2", "k"}], "+", "1"}]]]}]]],
 ",  and are known to have radii of convergence ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["R", "1"], "=", "3"}]]],
 " and ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["R", "2"], "=", "2"}]]],
 ", respectively.  Hence their sum has radii of convergence ",
 Cell[BoxData[
  RowBox[{"R", "=", 
   RowBox[{
    RowBox[{"min", 
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["R", "1"], ",", 
       SubscriptBox["R", "2"]}], "}"}]}], "=", "2"}]}]]],
 ".\n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"1", "+", 
      FractionBox["z", "2"], "+", 
      FractionBox[
       SuperscriptBox["z", "2"], 
       SuperscriptBox["3", "2"]], "+", 
      FractionBox[
       SuperscriptBox["z", "3"], 
       SuperscriptBox["2", "3"]], "+", 
      FractionBox[
       SuperscriptBox["z", "4"], 
       SuperscriptBox["3", "4"]], "+", 
      FractionBox[
       SuperscriptBox["z", "5"], 
       SuperscriptBox["2", "5"]], "+", 
      FractionBox[
       SuperscriptBox["z", "6"], 
       SuperscriptBox["3", "6"]], "+", 
      FractionBox[
       SuperscriptBox["z", "7"], 
       SuperscriptBox["2", "7"]], "+", 
      FractionBox[
       SuperscriptBox["z", "8"], 
       SuperscriptBox["3", "8"]], "+", 
      FractionBox[
       SuperscriptBox["z", "9"], 
       SuperscriptBox["2", "9"]], "+", 
      FractionBox[
       SuperscriptBox["z", "10"], 
       SuperscriptBox["3", "10"]], "+", 
      FractionBox[
       SuperscriptBox["z", "11"], 
       SuperscriptBox["2", "11"]], "+"}], "..."}], "\[IndentingNewLine]"}], 
   "  "}], "\[IndentingNewLine]", 
  RowBox[{"=", "  ", 
   RowBox[{
    RowBox[{"1", "+", 
     FractionBox["z", "2"], "+", 
     FractionBox[
      SuperscriptBox["z", "2"], "9"], "+", 
     FractionBox[
      SuperscriptBox["z", "3"], "8"], "+", 
     FractionBox[
      SuperscriptBox["z", "4"], "81"], "+", 
     FractionBox[
      SuperscriptBox["z", "5"], "32"], "+", 
     FractionBox[
      SuperscriptBox["z", "6"], "729"], "+", 
     FractionBox[
      SuperscriptBox["z", "7"], "128"], "+", 
     FractionBox[
      SuperscriptBox["z", "8"], "6561"], "+", 
     FractionBox[
      SuperscriptBox["z", "9"], "512"], "+", 
     FractionBox[
      SuperscriptBox["z", "10"], "59049"], "+", 
     FractionBox[
      SuperscriptBox["z", "11"], "2048"], "+"}], "..."}]}]}]],
 "  "
}], "Text"],

Cell[TextData[{
 "The even and odd series are:\n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"1", "+", 
     FractionBox[
      SuperscriptBox["z", "2"], "9"], "+", 
     FractionBox[
      SuperscriptBox["z", "4"], "81"], "+", 
     FractionBox[
      SuperscriptBox["z", "6"], "729"], "+", 
     FractionBox[
      SuperscriptBox["z", "8"], "6561"], "+", 
     FractionBox[
      SuperscriptBox["z", "10"], "59049"], "+"}], "..."}], "  ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"k", "=", "0"}], "\[Infinity]"], 
      FractionBox[
       SuperscriptBox["z", 
        RowBox[{"2", "k"}]], 
       SuperscriptBox["3", 
        RowBox[{"2", "k"}]]]}], "  ", "=", "  ", 
     RowBox[{
      RowBox[{"1", "/", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         FractionBox[
          SuperscriptBox["z", "2"], 
          SuperscriptBox["3", "2"]]}], ")"}]}], " ", "=", " ", 
      FractionBox[
       SuperscriptBox["3", "2"], 
       RowBox[{
        SuperscriptBox["3", "2"], "-", 
        SuperscriptBox["z", "2"]}]]}]}]}], "  ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"=", " ", 
   FractionBox["9", 
    RowBox[{"9", "-", 
     SuperscriptBox["z", "2"]}]]}]}]],
 "    \n\n\n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     FractionBox["z", "2"], "+", 
     FractionBox[
      SuperscriptBox["z", "3"], "8"], "+", 
     FractionBox[
      SuperscriptBox["z", "5"], "32"], "+", 
     FractionBox[
      SuperscriptBox["z", "7"], "128"], "+", 
     FractionBox[
      SuperscriptBox["z", "9"], "512"], "+", 
     FractionBox[
      SuperscriptBox["z", "11"], "2048"], "+"}], "..."}], "  ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"k", "=", "0"}], "\[Infinity]"], 
      FractionBox[
       SuperscriptBox["z", 
        RowBox[{
         RowBox[{"2", "k"}], "+", "1"}]], 
       SuperscriptBox["2", 
        RowBox[{
         RowBox[{"2", "k"}], "+", "1"}]]]}], " ", "=", " ", 
     RowBox[{
      FractionBox["z", "2"], 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"k", "=", "0"}], "\[Infinity]"], 
       FractionBox[
        SuperscriptBox["z", 
         RowBox[{"2", "k"}]], 
        SuperscriptBox["2", 
         RowBox[{"2", "k"}]]]}]}]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"=", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       FractionBox["z", "2"], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        FractionBox[
         SuperscriptBox["z", "2"], 
         SuperscriptBox["2", "2"]]}], ")"}]}], " ", "=", "  ", 
     RowBox[{
      RowBox[{"(", 
       FractionBox["z", "2"], ")"}], 
      RowBox[{"(", 
       FractionBox["4", 
        RowBox[{"4", "-", 
         SuperscriptBox["z", "2"]}]], ")"}]}]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"=", " ", 
   FractionBox[
    RowBox[{"2", "z"}], 
    RowBox[{"4", "-", 
     SuperscriptBox["z", "2"]}]]}]}]],
 "  \n\nTherefore, S(z) is the sum of two geometric series:\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"S", 
    RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
   RowBox[{
    FractionBox["9", 
     RowBox[{"9", "-", 
      SuperscriptBox["z", "2"]}]], " ", "+", " ", 
    FractionBox[
     RowBox[{"2", "z"}], 
     RowBox[{"4", "-", 
      SuperscriptBox["z", "2"]}]]}]}]]],
 "\n\nwhich might be printed by ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " as  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"S", 
    RowBox[{"(", "z", ")"}]}], "  ", "=", "   ", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["9", 
      RowBox[{
       RowBox[{"-", "9"}], "+", 
       SuperscriptBox["z", "2"]}]]}], " ", "+", " ", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"2", " ", "z"}], 
      RowBox[{
       RowBox[{"-", "4"}], "+", 
       SuperscriptBox["z", "2"]}]]}]}]}]]]
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<S(z) = \!\(\*FractionBox[\(9\), \(9 - \*SuperscriptBox[\(z\), \
\(2\)]\)]\) + \!\(\*FractionBox[\(2  z\), \(4 - \*SuperscriptBox[\(z\), \
\(2\)]\)]\)\>\"", " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S(z) = \>\"", ",", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{
         FractionBox["9", 
          RowBox[{"9", "-", 
           SuperscriptBox["z", "2"]}]], "+", 
         FractionBox[
          RowBox[{"2", "z"}], 
          RowBox[{"4", "-", 
           SuperscriptBox["z", "2"]}]]}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", "0", ",", "11"}], "}"}]}], "]"}]}], " ", "]"}], 
    ";"}]}]}]], "Input",
 CellChangeTimes->{3.399118802234375*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"f", "[", "z_", "]"}], "=", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"k", "=", "0"}], "\[Infinity]"], 
     FractionBox[
      SuperscriptBox["z", 
       RowBox[{"2", "k"}]], 
      SuperscriptBox["3", 
       RowBox[{"2", "k"}]]]}]}], ";"}], " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"g", "[", "z_", "]"}], "=", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"k", "=", "0"}], "\[Infinity]"], 
     FractionBox[
      SuperscriptBox["z", 
       RowBox[{
        RowBox[{"2", "k"}], "+", "1"}]], 
      SuperscriptBox["2", 
       RowBox[{
        RowBox[{"2", "k"}], "+", "1"}]]]}]}], ";"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"S", "[", "z_", "]"}], "=", 
   RowBox[{
    RowBox[{"f", "[", "z", "]"}], " ", "+", " ", 
    RowBox[{"g", "[", "z", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{
   "\"\<f[z] = \!\(\*FractionBox[\(9\), \(9 - \*SuperscriptBox[\(z\), \
\(2\)]\)]\) = \!\(\*UnderoverscriptBox[\(\[Sum]\), \(k = 0\), \
\(\[Infinity]\)]\)\!\(\*FractionBox[SuperscriptBox[\(z\), \(2  k\)], \
SuperscriptBox[\(3\), \(2  k\)]]\) = \>\"", ",", 
    RowBox[{"Series", "[", 
     RowBox[{
      RowBox[{"f", "[", "z", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"z", ",", "0", ",", "11"}], "}"}]}], "]"}]}], " ", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{
   "\"\<g[z] = \!\(\*FractionBox[\(2  z\), \(4 - \*SuperscriptBox[\(z\), \
\(2\)]\)]\) = \!\(\*UnderoverscriptBox[\(\[Sum]\), \(k = 0\), \
\(\[Infinity]\)]\)\!\(\*FractionBox[SuperscriptBox[\(z\), \(2  k + 1\)], \
SuperscriptBox[\(2\), \(2  k + 1\)]]\) = \>\"", ",", 
    RowBox[{"Series", "[", 
     RowBox[{
      RowBox[{"g", "[", "z", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"z", ",", "0", ",", "11"}], "}"}]}], "]"}]}], " ", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "Print", "[", 
   "\"\<S[z] = \!\(\*FractionBox[\(9\), \(9 - \*SuperscriptBox[\(z\), \
\(2\)]\)]\) + \!\(\*FractionBox[\(2  z\), \(4 - \*SuperscriptBox[\(z\), \
\(2\)]\)]\) = \!\(\*UnderoverscriptBox[\(\[Sum]\), \(k = 0\), \
\(\[Infinity]\)]\)\!\(\*FractionBox[SuperscriptBox[\(z\), \(2  k\)], \
SuperscriptBox[\(3\), \(2  k\)]]\) + \!\(\*UnderoverscriptBox[\(\[Sum]\), \(k \
= 0\), \(\[Infinity]\)]\)\!\(\*FractionBox[SuperscriptBox[\(z\), \(2  k + \
1\)], SuperscriptBox[\(2\), \(2  k + 1\)]]\)\>\"", " ", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<S[z] = \>\"", ",", 
    RowBox[{"Series", "[", 
     RowBox[{
      RowBox[{"S", "[", "z", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"z", ",", "0", ",", "11"}], "}"}]}], "]"}]}], " ", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{
   "\"\<f[z] = \!\(\*FractionBox[\(9\), \(9 - \*SuperscriptBox[\(z\), \
\(2\)]\)]\) = \!\(\*UnderoverscriptBox[\(\[Sum]\), \(k = 0\), \
\(\[Infinity]\)]\)\!\(\*FractionBox[SuperscriptBox[\(z\), \(2  k\)], \
SuperscriptBox[\(3\), \(2  k\)]]\) = \>\"", ",", 
    RowBox[{"f", "[", "z", "]"}]}], " ", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{
   "\"\<g[z] = \!\(\*FractionBox[\(2  z\), \(4 - \*SuperscriptBox[\(z\), \
\(2\)]\)]\) = \!\(\*UnderoverscriptBox[\(\[Sum]\), \(k = 0\), \
\(\[Infinity]\)]\)\!\(\*FractionBox[SuperscriptBox[\(z\), \(2  k + 1\)], \
SuperscriptBox[\(2\), \(2  k + 1\)]]\) = \>\"", ",", 
    RowBox[{"g", "[", "z", "]"}]}], " ", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "Print", "[", 
   "\"\<S[z] = \!\(\*FractionBox[\(9\), \(9 - \*SuperscriptBox[\(z\), \
\(2\)]\)]\) + \!\(\*FractionBox[\(2  z\), \(4 - \*SuperscriptBox[\(z\), \
\(2\)]\)]\) = \!\(\*UnderoverscriptBox[\(\[Sum]\), \(k = 0\), \
\(\[Infinity]\)]\)\!\(\*FractionBox[SuperscriptBox[\(z\), \(2  k\)], \
SuperscriptBox[\(3\), \(2  k\)]]\) + \!\(\*UnderoverscriptBox[\(\[Sum]\), \(k \
= 0\), \(\[Infinity]\)]\)\!\(\*FractionBox[SuperscriptBox[\(z\), \(2  k + \
1\)], SuperscriptBox[\(2\), \(2  k + 1\)]]\)\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<S[z] = \>\"", ",", 
    RowBox[{"S", "[", "z", "]"}]}], " ", "]"}], 
  ";"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{3.3991188050625*^9}],

Cell[TextData[{
 "We are done.\n\n",
 StyleBox["Aside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  We can investigate what happens as ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", "z", "|"}], "\[Rule]", " ", "2"}]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[z] = \>\"", ",", 
      RowBox[{"S", "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[1] = \>\"", ",", 
      RowBox[{"S", "[", "1", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[\!\(\*FractionBox[\(19\), \(10\)]\)] = \>\"", ",", 
      RowBox[{"S", "[", 
       FractionBox["19", "10"], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[\!\(\*FractionBox[\(199\), \(100\)]\)] = \>\"", ",", 
      RowBox[{"S", "[", 
       FractionBox["199", "100"], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[\!\(\*FractionBox[\(1999\), \(1000\)]\)] = \>\"", ",", 
      RowBox[{"S", "[", 
       FractionBox["1999", "1000"], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[\!\(\*FractionBox[\(19999\), \(10000\)]\)] = \>\"", ",", 
      RowBox[{"S", "[", 
       FractionBox["19999", "10000"], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<S[2] =  \!\(\*UnderoverscriptBox[\(\[Sum]\), \(k = 0\), \(\
\[Infinity]\)]\)\!\(\*FractionBox[SuperscriptBox[\((2)\), \(2  k\)], \
SuperscriptBox[\(3\), \(2  k\)]]\) + \!\(\*UnderoverscriptBox[\(\[Sum]\), \(k \
= 0\), \(\[Infinity]\)]\)\!\(\*FractionBox[SuperscriptBox[\((2)\), \(2  k + 1\
\)], SuperscriptBox[\(2\), \(2  k + 1\)]]\)\>\"", " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[2] = \>\"", ",", " ", 
      RowBox[{
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"k", "=", "0"}], "\[Infinity]"], 
        FractionBox[
         SuperscriptBox[
          RowBox[{"(", "2", ")"}], 
          RowBox[{"2", "k"}]], 
         SuperscriptBox["3", 
          RowBox[{"2", "k"}]]]}], " ", "+", " ", 
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"k", "=", "0"}], "\[Infinity]"], 
        FractionBox[
         SuperscriptBox[
          RowBox[{"(", "2", ")"}], 
          RowBox[{
           RowBox[{"2", "k"}], "+", "1"}]], 
         SuperscriptBox["2", 
          RowBox[{
           RowBox[{"2", "k"}], "+", "1"}]]]}]}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39911880965625*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[z] = \>\"", ",", 
      RowBox[{"S", "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[\[ImaginaryI]] = \>\"", ",", 
      RowBox[{"S", "[", "\[ImaginaryI]", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<S[\!\(\*FractionBox[\(19\), \(10\)]\)\[ImaginaryI]] = \>\"", ",", 
      RowBox[{"S", "[", 
       RowBox[{
        FractionBox["19", "10"], "\[ImaginaryI]"}], "]"}]}], " ", "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<S[\!\(\*FractionBox[\(199\), \(100\)]\)\[ImaginaryI]] = \>\"", ",", 
      
      RowBox[{"S", "[", 
       RowBox[{
        FractionBox["199", "100"], "\[ImaginaryI]"}], "]"}]}], " ", "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<S[\!\(\*FractionBox[\(1999\), \(1000\)]\)\[ImaginaryI]] = \>\"", 
      ",", 
      RowBox[{"S", "[", 
       RowBox[{
        FractionBox["1999", "1000"], "\[ImaginaryI]"}], "]"}]}], " ", "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<S[\!\(\*FractionBox[\(19999\), \(10000\)]\)\[ImaginaryI]] = \>\"", 
      ",", 
      RowBox[{"S", "[", 
       RowBox[{
        FractionBox["19999", "10000"], "\[ImaginaryI]"}], "]"}]}], " ", "]"}],
     ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<S[2\[ImaginaryI]] =  \!\(\*UnderoverscriptBox[\(\[Sum]\), \(k = \
0\), \(\[Infinity]\)]\)\!\(\*FractionBox[SuperscriptBox[\((2\\\ \
\[ImaginaryI])\), \(2  k\)], SuperscriptBox[\(3\), \(2  k\)]]\) + \
\!\(\*UnderoverscriptBox[\(\[Sum]\), \(k = 0\), \
\(\[Infinity]\)]\)\!\(\*FractionBox[SuperscriptBox[\((2\\\ \[ImaginaryI])\), \
\(2  k + 1\)], SuperscriptBox[\(2\), \(2  k + 1\)]]\)\>\"", " ", "]"}], ";"}],
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[2\[ImaginaryI]] = \>\"", ",", " ", 
      RowBox[{
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"k", "=", "0"}], "\[Infinity]"], 
        FractionBox[
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"2", " ", "\[ImaginaryI]"}], ")"}], 
          RowBox[{"2", "k"}]], 
         SuperscriptBox["3", 
          RowBox[{"2", "k"}]]]}], " ", "+", " ", 
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"k", "=", "0"}], "\[Infinity]"], 
        FractionBox[
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"2", " ", "\[ImaginaryI]"}], ")"}], 
          RowBox[{
           RowBox[{"2", "k"}], "+", "1"}]], 
         SuperscriptBox["2", 
          RowBox[{
           RowBox[{"2", "k"}], "+", "1"}]]]}]}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399118815109375*^9}],

Cell[TextData[{
 StyleBox["Caveat.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  In some cases involving complex numbers, earlier versions of ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " will report a sum when the series actually diverges.  In ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " 4.1 the following series converges."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", "0"}], "\[Infinity]"], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox[
       RowBox[{"3", "+", 
        RowBox[{"4", "\[ImaginaryI]"}]}], "5"], ")"}], "n"]}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399118820375*^9, 3.399118821234375*^9}}],

Cell[TextData[{
 "The above series actually diverges because ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox[
       RowBox[{"3", "+", 
        RowBox[{"4", "\[ImaginaryI]"}]}], "5"], ")"}], "n"], "|"}], " ", "=", 
   " ", 
   RowBox[{
    RowBox[{"|", 
     FractionBox[
      RowBox[{"3", "+", 
       RowBox[{"4", "\[ImaginaryI]"}]}], "5"], 
     SuperscriptBox["|", "n"]}], " ", "=", " ", "1"}]}]]],
 "  for all ",
 StyleBox["n",
  FontFamily->"Courier New"],
 ".\n\nMost likely this occurs because ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " 4.2 is summing the series and then making a substitution."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"1", "/", 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      FractionBox[
       RowBox[{"3", "+", 
        RowBox[{"4", "\[ImaginaryI]"}]}], "5"]}], ")"}]}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399118823796875*^9, 3.3991188246875*^9}}],

Cell["Now try another value.", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", "0"}], "\[Infinity]"], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox[
       RowBox[{"3", "+", 
        RowBox[{"4", "\[ImaginaryI]"}]}], "4"], ")"}], "n"]}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39911882684375*^9, 3.399118829015625*^9}}],

Cell[TextData[{
 "Indeed, the above series diverges because ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox[
       RowBox[{"3", "+", 
        RowBox[{"4", "\[ImaginaryI]"}]}], "5"], ")"}], "n"], "|"}], " ", "=", 
   " ", 
   RowBox[{
    RowBox[{"|", 
     FractionBox[
      RowBox[{"3", "+", 
       RowBox[{"4", "\[ImaginaryI]"}]}], "4"], 
     SuperscriptBox["|", "n"]}], " ", "=", " ", 
    RowBox[{
     FractionBox["5", "4"], " ", ">", " ", "1"}]}]}]]],
 "  for all ",
 StyleBox["n",
  FontFamily->"Courier New"],
 ".\n\nThis bug has been correct in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " 5.1 and the above series does not converge.\n\nHowever, you have been \
given a warning!"
}], "Text"],

Cell[TextData[{
 StyleBox["Caveat.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  The mathematical analysis proves that the series ",
 Cell[BoxData[
  RowBox[{"  ", 
   RowBox[{
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"k", "=", "0"}], "\[Infinity]"], 
     FractionBox[
      SuperscriptBox[
       RowBox[{"(", 
        FractionBox[
         RowBox[{"6", "+", 
          RowBox[{"8", "\[ImaginaryI]"}]}], "5"], ")"}], 
       RowBox[{"2", "k"}]], 
      SuperscriptBox["3", 
       RowBox[{"2", "k"}]]]}], " ", "+", " ", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"k", "=", "0"}], "\[Infinity]"], 
     FractionBox[
      SuperscriptBox[
       RowBox[{"(", 
        FractionBox[
         RowBox[{"6", "+", 
          RowBox[{"8", "\[ImaginaryI]"}]}], "5"], ")"}], 
       RowBox[{
        RowBox[{"2", "k"}], "+", "1"}]], 
      SuperscriptBox["2", 
       RowBox[{
        RowBox[{"2", "k"}], "+", "1"}]]]}]}]}]]],
 " diverges.  But for some reason ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " 4.1 will compute a sum.  For sure it is a mistake which is equivalent to \
substituting ",
 Cell[BoxData[
  RowBox[{"Z", "=", 
   FractionBox[
    RowBox[{"6", "+", 
     RowBox[{"8", "\[ImaginaryI]"}]}], "5"]}]]],
 " into the formula  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"S", "[", "z", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["9", 
      RowBox[{
       RowBox[{"-", "9"}], "+", 
       SuperscriptBox["z", "2"]}]]}], "-", 
    FractionBox[
     RowBox[{"2", " ", "z"}], 
     RowBox[{
      RowBox[{"-", "4"}], "+", 
      SuperscriptBox["z", "2"]}]]}]}]]],
 ".  This bug has been corrected in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " 5.1."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Z", "=", 
     FractionBox[
      RowBox[{"6", "+", 
       RowBox[{"8", "\[ImaginaryI]"}]}], "5"]}], ";"}], "\[IndentingNewLine]",
    
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<|\>\"", ",", "Z", ",", "\"\<| = \>\"", ",", 
      RowBox[{"Abs", "[", "Z", "]"}]}], " ", "]"}], ";"}]}]}]], "Input",
 CellChangeTimes->{3.399118833765625*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"S", "[", "z_", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["9", 
      RowBox[{
       RowBox[{"-", "9"}], "+", 
       SuperscriptBox["z", "2"]}]]}], "-", 
    FractionBox[
     RowBox[{"2", " ", "z"}], 
     RowBox[{
      RowBox[{"-", "4"}], "+", 
      SuperscriptBox["z", "2"]}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<      S[z] = \>\"", ",", 
    RowBox[{"S", "[", "z", "]"}]}], " ", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<S[\>\"", ",", "Z", ",", "\"\<] = \>\"", ",", 
    RowBox[{"S", "[", "Z", "]"}]}], " ", "]"}], ";"}]}], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<S[z] = \>\"", ",", 
    RowBox[{"S", "[", "z", "]"}]}], " ", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<S[\>\"", ",", 
    RowBox[{
     FractionBox["1", "2"], "Z"}], ",", "\"\<] = \>\"", ",", 
    RowBox[{"S", "[", 
     RowBox[{
      FractionBox["1", "2"], "Z"}], "]"}]}], " ", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<S[\>\"", ",", 
    RowBox[{
     FractionBox["19", "10"], "Z"}], ",", "\"\<] = \>\"", ",", 
    RowBox[{"S", "[", 
     RowBox[{
      FractionBox["19", "10"], "Z"}], "]"}]}], " ", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<S[\>\"", ",", 
    RowBox[{
     FractionBox["199", "100"], "Z"}], ",", "\"\<] = \>\"", ",", 
    RowBox[{"S", "[", 
     RowBox[{
      FractionBox["199", "100"], "Z"}], "]"}]}], " ", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<S[\>\"", ",", 
    RowBox[{
     FractionBox["1999", "1000"], "Z"}], ",", "\"\<] = \>\"", ",", 
    RowBox[{"S", "[", 
     RowBox[{
      FractionBox["1999", "1000"], "Z"}], "]"}]}], " ", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<S[\>\"", ",", 
    RowBox[{
     FractionBox["19999", "10000"], "Z"}], ",", "\"\<] = \>\"", ",", 
    RowBox[{"S", "[", 
     RowBox[{
      FractionBox["19999", "10000"], "Z"}], "]"}]}], " ", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "Print", "[", 
   "\"\<S[\!\(\*FractionBox[\(6 + 8  \[ImaginaryI]\), \(5\)]\)] =  \
\!\(\*UnderoverscriptBox[\(\[Sum]\), \(k = 0\), \
\(\[Infinity]\)]\)\!\(\*FractionBox[SuperscriptBox[\((\*FractionBox[\(6 + 8  \
\[ImaginaryI]\), \(5\)])\), \(2  k\)], SuperscriptBox[\(3\), \(2  k\)]]\) + \
\!\(\*UnderoverscriptBox[\(\[Sum]\), \(k = 0\), \
\(\[Infinity]\)]\)\!\(\*FractionBox[SuperscriptBox[\((\*FractionBox[\(6 + 8  \
\[ImaginaryI]\), \(5\)])\), \(2  k + 1\)], SuperscriptBox[\(2\), \(2  k + \
1\)]]\)\>\"", " ", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{
   "\"\<S[\!\(\*FractionBox[\(6 + 8  \[ImaginaryI]\), \(5\)]\)] = \>\"", ",", 
    " ", 
    RowBox[{
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"k", "=", "0"}], "\[Infinity]"], 
      FractionBox[
       SuperscriptBox[
        RowBox[{"(", 
         FractionBox[
          RowBox[{"6", "+", 
           RowBox[{"8", "\[ImaginaryI]"}]}], "5"], ")"}], 
        RowBox[{"2", "k"}]], 
       SuperscriptBox["3", 
        RowBox[{"2", "k"}]]]}], " ", "+", " ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"k", "=", "0"}], "\[Infinity]"], 
      FractionBox[
       SuperscriptBox[
        RowBox[{"(", 
         FractionBox[
          RowBox[{"6", "+", 
           RowBox[{"8", "\[ImaginaryI]"}]}], "5"], ")"}], 
        RowBox[{
         RowBox[{"2", "k"}], "+", "1"}]], 
       SuperscriptBox["2", 
        RowBox[{
         RowBox[{"2", "k"}], "+", "1"}]]]}]}]}], " ", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", "\"\<WARNING. The series diverges.\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]"}], "Input"]
}, Closed]],

Cell["\tWe come now to the main result of this section.", "Text"],

Cell[TextData[{
 StyleBox["Theorem 4.17.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Suppose the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", "0"}], "\[Infinity]"], 
    RowBox[{
     SubscriptBox["c", "n"], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "\[Alpha]"}], ")"}], "n"]}]}]}]]],
 "  has radius of convergence  ",
 Cell[BoxData[
  RowBox[{"\[Rho]", ">", "0"}]]],
 ".  Then\n\n",
 StyleBox["(i)",
  FontColor->RGBColor[0, 0, 1]],
 "    ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", "z", ")"}]}]]],
 "  is infinitely differentiable for all ",
 Cell[BoxData[
  RowBox[{"z", " ", "\[Epsilon]", " ", 
   SubscriptBox["D", "\[Rho]"], 
   RowBox[{"(", "\[Alpha]", ")"}]}]]],
 ".  In fact\n\n",
 StyleBox["(ii)",
  FontColor->RGBColor[0, 0, 1]],
 "   for all  ",
 StyleBox["k",
  FontFamily->"Courier New"],
 ",   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["f", 
     RowBox[{"(", "k", ")"}]], 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "0"}], "\[Infinity]"], 
      RowBox[{"n", 
       RowBox[{"(", 
        RowBox[{"n", "-", "1"}], ")"}]}]}], 
     StyleBox["...",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]]}], 
    RowBox[{"(", 
     RowBox[{"n", "-", "k", "+", "1"}], ")"}], 
    SubscriptBox["c", "n"], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"z", "-", "\[Alpha]"}], ")"}], 
     RowBox[{"n", "-", "k"}]]}]}]]],
 ";   and\n\n",
 StyleBox["(iii)",
  FontColor->RGBColor[0, 0, 1]],
 "  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["c", "k"], "=", 
   FractionBox[
    RowBox[{
     SuperscriptBox["f", 
      RowBox[{"(", "k", ")"}]], 
     RowBox[{"(", "\[Alpha]", ")"}]}], 
    RowBox[{"k", "!"}]]}]]],
 "  where  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["f", 
    RowBox[{"(", "k", ")"}]], 
   RowBox[{"(", "\[Alpha]", ")"}]}]]],
 "  denotes the ",
 Cell[BoxData[
  SuperscriptBox["k", "th"]]],
 " derivative of ",
 StyleBox["f",
  FontFamily->"Courier New"],
 ".  (When ",
 Cell[BoxData[
  RowBox[{"k", "=", "0"}]]],
 ",  ",
 Cell[BoxData[
  SuperscriptBox["f", 
   RowBox[{"(", "k", ")"}]]]],
 " denotes the function ",
 Cell[BoxData["f"]],
 " itself so that ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["f", 
     RowBox[{"(", "0", ")"}]], 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}]}]]],
 " for all z.)"
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 4.17 is in the book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 4.24.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Show that   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"g", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", "0"}], "\[Infinity]"], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"n", "+", "1"}], ")"}], 
      SuperscriptBox["z", "n"]}]}], " ", "=", " ", 
    FractionBox["1", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", " ", "-", " ", "z"}], ")"}], "2"]]}]}]]],
 "   for all  ",
 Cell[BoxData[
  RowBox[{"z", " ", "\[Epsilon]", " ", 
   SubscriptBox["D", "1"], 
   RowBox[{"(", "0", ")"}]}]]]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "Solution.  We know from Theorem 4.12 that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"(", 
      RowBox[{"1", " ", "-", " ", "z"}], ")"}]], " ", "=", " ", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", "0"}], "\[Infinity]"], 
     SuperscriptBox["z", "n"], " "}]}]}]]],
 "  for all  ",
 Cell[BoxData[
  RowBox[{"z", " ", "\[Epsilon]", " ", 
   SubscriptBox["D", "1"], 
   RowBox[{"(", "0", ")"}]}]]],
 ".  If we set k=1 in Theorem 4.16, part (ii), then\n\n\t\t\t  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"f", "'"}], 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    FractionBox["1", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", " ", "-", " ", "z"}], ")"}], "2"]], " ", "=", " ", 
    RowBox[{
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "1"}], "\[Infinity]"], " ", 
      RowBox[{"n", " ", 
       SuperscriptBox["z", 
        RowBox[{"n", "-", "1"}]]}]}], "  ", "=", " ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "0"}], "\[Infinity]"], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"n", "+", "1"}], ")"}], 
       SuperscriptBox["z", "n"]}]}]}]}]}]]],
 ", \n\nfor all  ",
 Cell[BoxData[
  RowBox[{"z", " ", "\[Epsilon]", " ", 
   SubscriptBox["D", "1"], 
   RowBox[{"(", "0", ")"}]}]]],
 ". "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 4.24.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "Use the fact that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"S", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", "0"}], "\[Infinity]"], 
     SuperscriptBox["z", "n"]}], "=", 
    FractionBox["1", 
     RowBox[{"1", " ", "-", " ", "z"}]]}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"S", "'"}], 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{"g", 
    RowBox[{"(", "z", ")"}]}]}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", "z", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "n", ",", "f", ",", "f"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "  ", "=", "  ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "0"}], "\[Infinity]"], 
      SuperscriptBox["z", "n"]}]}], 
    StyleBox[";",
     FontSize->14]}], 
   StyleBox[" ",
    FontSize->14], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< f[z] = \!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 0\), \(\
\[Infinity]\)]\)\!\(\*SuperscriptBox[\(z\), \(n\)]\) = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Differentiate f[z] and obtain\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f'[z] = \>\"", ",", 
      RowBox[{
       RowBox[{"f", "'"}], "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399118855890625*^9, 3.399118857125*^9}}],

Cell["Or sum the infinite series directly.", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"g", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "0"}], "\[Infinity]"], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"n", "+", "1"}], ")"}], 
       SuperscriptBox["z", "n"]}]}]}], 
    StyleBox[";",
     FontSize->14]}], 
   StyleBox[" ",
    FontSize->14], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f'[z] = \>\"", ",", 
      RowBox[{
       RowBox[{"f", "'"}], "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<f'[z] = \!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 0\), \(\
\[Infinity]\)]\)(n+1)\!\(\*SuperscriptBox[\(z\), \(n\)]\) = \>\"", ",", 
      RowBox[{"g", "[", "z", "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Also\>\"", "]"}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<f'[z] = \!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 0\), \(\
\[Infinity]\)]\) \!\(\*SuperscriptBox[\(nz\), \(n - 1\)]\) = \>\"", ",", 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"n", "=", "0"}], "\[Infinity]"], " ", 
       RowBox[{"n", " ", 
        SuperscriptBox["z", 
         RowBox[{"n", "-", "1"}]]}]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<f'[z] = \!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 1\), \(\
\[Infinity]\)]\) \!\(\*SuperscriptBox[\(nz\), \(n - 1\)]\) = \>\"", ",", 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"n", "=", "1"}], "\[Infinity]"], " ", 
       RowBox[{"n", " ", 
        SuperscriptBox["z", 
         RowBox[{"n", "-", "1"}]]}]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<f'[z] = \!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 0\), \(\
\[Infinity]\)]\) (n+1)\!\(\*SuperscriptBox[\(z\), \(n\)]\) = \>\"", ",", 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"n", "=", "0"}], "\[Infinity]"], " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"n", "+", "1"}], ")"}], " ", 
        SuperscriptBox["z", "n"]}]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39911886021875*^9, 3.399118861828125*^9}}]
}, Closed]],

Cell[TextData[{
 StyleBox["Extra Example 2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Show that   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"h", 
    RowBox[{"(", "z", ")"}]}], " ", "=", 
   RowBox[{
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", "0"}], "\[Infinity]"], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"n", "+", "2"}], ")"}], 
      RowBox[{"(", 
       RowBox[{"n", "+", "1"}], ")"}], 
      SuperscriptBox["z", "n"]}]}], " ", "=", " ", 
    FractionBox["2", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "-", "z"}], ")"}], "3"]]}]}]]],
 "   for all  ",
 Cell[BoxData[
  RowBox[{"z", " ", "\[Epsilon]", " ", 
   SubscriptBox["D", "1"], 
   RowBox[{"(", "0", ")"}]}]]]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Extra Solution 2.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "Use the fact that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", "0"}], "\[Infinity]"], 
     SuperscriptBox["z", "n"]}], "=", 
    FractionBox["1", 
     RowBox[{"1", " ", "-", " ", "z"}]]}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"f", "''"}], 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{"h", 
    RowBox[{"(", "z", ")"}]}]}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", "z", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"h", ",", "n", ",", "f", ",", "f"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "  ", "=", "  ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "0"}], "\[Infinity]"], 
      SuperscriptBox["z", "n"]}]}], 
    StyleBox[";",
     FontSize->14]}], 
   StyleBox[" ",
    FontSize->14], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<  f[z] = \!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 0\), \(\
\[Infinity]\)]\)\!\(\*SuperscriptBox[\(z\), \(n\)]\) = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Differentiate f[z] and obtain\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f'[z] = \>\"", ",", 
      RowBox[{
       RowBox[{"f", "'"}], "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f''[z] = \>\"", ",", 
      RowBox[{
       RowBox[{"f", "''"}], "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399118869125*^9, 3.39911887271875*^9}}],

Cell["Or sum the infinite series directly.", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"h", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "0"}], "\[Infinity]"], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"n", "+", "2"}], ")"}], 
       RowBox[{"(", 
        RowBox[{"n", "+", "1"}], ")"}], 
       SuperscriptBox["z", "n"]}]}]}], 
    StyleBox[";",
     FontSize->14]}], 
   StyleBox[" ",
    FontSize->14], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f''[z] = \>\"", ",", 
      RowBox[{
       RowBox[{"f", "''"}], "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<f''[z] = \!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 0\), \(\
\[Infinity]\)]\)(n+2)(n+1)\!\(\*SuperscriptBox[\(z\), \(n\)]\) = \>\"", ",", 
      RowBox[{"h", "[", "z", "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Also\>\"", "]"}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<f''[z] = \!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 0\), \(\
\[Infinity]\)]\)(n+2)(n+1)\!\(\*SuperscriptBox[\(z\), \(n\)]\) = \>\"", ",", 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"n", "=", "0"}], "\[Infinity]"], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"n", "+", "2"}], ")"}], 
        RowBox[{"(", 
         RowBox[{"n", "+", "1"}], ")"}], 
        SuperscriptBox["z", "n"]}]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<f''[z] =  \!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 2\), \(\
\[Infinity]\)]\) n(n-1)\!\(\*SuperscriptBox[\(z\), \(n - 2\)]\) = \>\"", ",", 
      
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"n", "=", "2"}], "\[Infinity]"], " ", 
       RowBox[{"n", 
        RowBox[{"(", 
         RowBox[{"n", "-", "1"}], ")"}], 
        SuperscriptBox["z", 
         RowBox[{"n", "-", "2"}]]}]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39911887128125*^9, 3.399118873828125*^9}}]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 4.25.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  The Bessel function ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["J", "0"], 
   RowBox[{"(", "z", ")"}]}]]],
 " of order zero is defined by  \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["J", "0"], 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", "0"}], "\[Infinity]"], 
     RowBox[{
      FractionBox[
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], "n"], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"n", "!"}], ")"}], "2"]], 
      SuperscriptBox[
       RowBox[{"(", 
        FractionBox["z", "2"], ")"}], 
       RowBox[{"2", "n"}]]}]}], "  ", "=", " ", 
    RowBox[{
     RowBox[{"1", "-", 
      FractionBox[
       SuperscriptBox["z", "2"], 
       SuperscriptBox[
        RowBox[{"(", "2", ")"}], "2"]], "+", 
      FractionBox[
       SuperscriptBox["z", "4"], 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", "2", ")"}], "2"], 
        SuperscriptBox[
         RowBox[{"(", "4", ")"}], "2"]}]], "-", 
      FractionBox[
       SuperscriptBox["z", "6"], 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", "2", ")"}], "2"], 
        SuperscriptBox[
         RowBox[{"(", "4", ")"}], "2"], 
        SuperscriptBox[
         RowBox[{"(", "6", ")"}], "2"]}]], "+", 
      FractionBox[
       SuperscriptBox["z", "8"], 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", "2", ")"}], "2"], 
        SuperscriptBox[
         RowBox[{"(", "4", ")"}], "2"], 
        SuperscriptBox[
         RowBox[{"(", "6", ")"}], "2"], 
        SuperscriptBox[
         RowBox[{"(", "8", ")"}], "2"]}]], "-"}], "..."}]}]}]]],
 ",  \n\nand termwise differentiation shows that its derivative is  \n \n \t\t\
",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", "0"}], "\[Infinity]"], 
     RowBox[{
      FractionBox["d", "dz"], 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"-", "1"}], ")"}], "n"], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"n", "!"}], ")"}], "2"]], 
        SuperscriptBox[
         RowBox[{"(", 
          FractionBox["z", "2"], ")"}], 
         RowBox[{"2", "n"}]]}], ")"}]}]}], "  ", "=", "  ", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", "0"}], "\[Infinity]"], 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"-", "1"}], ")"}], "n"], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"n", "!"}], ")"}], "2"]], "2", "n", 
       SuperscriptBox[
        RowBox[{"(", 
         FractionBox["z", "2"], ")"}], 
        RowBox[{
         RowBox[{"2", "n"}], "-", "1"}]], 
       RowBox[{"(", 
        FractionBox["1", "2"], ")"}]}], ")"}]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                                                ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "0"}], "\[Infinity]"], 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"-", "1"}], ")"}], "n"], 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"n", "-", "1"}], ")"}], "!"}], "  ", 
          RowBox[{"n", "!"}]}]], 
        SuperscriptBox[
         RowBox[{"(", 
          FractionBox["z", "2"], ")"}], 
         RowBox[{
          RowBox[{"2", "n"}], "-", "1"}]]}], ")"}]}]}], "  ", 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                                                ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "1"}], "\[Infinity]"], 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"-", "1"}], ")"}], "n"], 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"n", "-", "1"}], ")"}], "!"}], "  ", 
          RowBox[{"n", "!"}]}]], 
        SuperscriptBox[
         RowBox[{"(", 
          FractionBox["z", "2"], ")"}], 
         RowBox[{
          RowBox[{"2", "n"}], "-", "1"}]]}], ")"}]}]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                                                ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "0"}], "\[Infinity]"], 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"-", "1"}], ")"}], 
          RowBox[{"n", "+", "1"}]], 
         RowBox[{" ", 
          RowBox[{
           RowBox[{"n", "!"}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"n", "+", "1"}], ")"}], "!"}]}]}]], 
        SuperscriptBox[
         RowBox[{"(", 
          FractionBox["z", "2"], ")"}], 
         RowBox[{
          RowBox[{"2", "n"}], "+", "1"}]]}], ")"}]}]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                                                ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["z", "2"]}], "+", 
      RowBox[{
       FractionBox["1", 
        RowBox[{
         RowBox[{"1", "!"}], " ", 
         RowBox[{"2", "!"}]}]], 
       SuperscriptBox[
        RowBox[{"(", 
         FractionBox["z", "2"], ")"}], "3"]}], "-", 
      RowBox[{
       FractionBox["1", 
        RowBox[{
         RowBox[{"2", "!"}], " ", 
         RowBox[{"3", "!"}]}]], 
       SuperscriptBox[
        RowBox[{"(", 
         FractionBox["z", "2"], ")"}], "5"]}], "+", 
      RowBox[{
       FractionBox["1", 
        RowBox[{
         RowBox[{"3", "!"}], " ", 
         RowBox[{"4", "!"}]}]], 
       SuperscriptBox[
        RowBox[{"(", 
         FractionBox["z", "2"], ")"}], "7"]}], "-"}], "..."}]}]}]}]],
 "    \n\nWe leave as an exercise to show that the radius of convergence of \
these series is infinity.  The Bessel function ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["J", "1"], 
   RowBox[{"(", "z", ")"}]}]]],
 " of order ",
 StyleBox["1",
  FontFamily->"Courier New"],
 " is known to satisfy the differential equation  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["J", "1"], 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"-", 
     SubsuperscriptBox["J", "0", "'"]}], 
    RowBox[{"(", "z", ")"}]}]}]]],
 ". "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 4.25.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "Look at some of the coefficients of and observe the relationship between \
the coefficients of  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["J", "0"], 
    RowBox[{"(", "z", ")"}]}], ",", " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["J", "0"], "'"}], 
    RowBox[{"(", "z", ")"}], "  ", "and", "   ", 
    SubscriptBox["J", "1"], 
    RowBox[{"(", "z", ")"}]}]}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"J0", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"Series", "[", 
      RowBox[{
       RowBox[{"BesselJ", "[", 
        RowBox[{"0", ",", "z"}], "]"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"z", ",", "0", ",", "10"}], "}"}]}], "]"}]}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"J1", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"Series", "[", 
      RowBox[{
       RowBox[{"BesselJ", "[", 
        RowBox[{"1", ",", "z"}], "]"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"z", ",", "0", ",", "9"}], "}"}]}], "]"}]}], ";"}], " ", "\n",
    
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< \!\(\*SubscriptBox[\(J\), \(0\)]\)(z) = \>\"", ",", 
      RowBox[{"J0", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(J\), \(0\)]\)'[z] = \>\"", ",", 
      RowBox[{
       RowBox[{"J0", "'"}], "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< \!\(\*SubscriptBox[\(J\), \(1\)]\)[z] = \>\"", ",", 
      RowBox[{"J1", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.3991188889375*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "We see that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["J", "0"], "'"}], 
   RowBox[{"(", "z", ")"}]}]]],
 " =",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{
    RowBox[{"-", " ", 
     SubscriptBox["J", "1"]}], 
    RowBox[{"(", "z", ")"}]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 StyleBox["Aside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  What does the Bessel function  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["J", "0"], 
   RowBox[{"(", "z", ")"}]}]],
  AspectRatioFixed->True],
 "  look like ?  Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to graph the transformation  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    SubscriptBox["J", "0"], 
    RowBox[{"(", "z", ")"}]}]}]],
  AspectRatioFixed->True],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"J0", "[", "z_", "]"}], "=", 
     RowBox[{"BesselJ", "[", 
      RowBox[{"0", ",", "z"}], "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g0", "=", 
     RowBox[{"CartesianMap", "[", 
      RowBox[{"J0", " ", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "3.6", ",", "0.2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2.0"}], ",", "2.0", ",", "0.2"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.6"}], ",", "2.4"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2"}], ",", "2"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "3"}], ",", "3", ",", "1"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<u\>\"", ",", "\"\<u\>\""}], "}"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "g0", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(J\), \(0\)]\)[z] = \>\"", ",", 
      RowBox[{"J0", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3991188926875*^9, 3.39911890590625*^9}, {
  3.399202585609375*^9, 3.399202590734375*^9}, {3.399799209031002*^9, 
  3.3997992092028775`*^9}}],

Cell[TextData[{
 "The rectangle ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"0", "\[LessEqual]", "x", "\[LessEqual]", "3.6"}], ",", 
   RowBox[{
    RowBox[{"-", "2.2"}], "\[LessEqual]", "y", "\[LessEqual]", "2.2"}]}]]],
 "  was used because the graph of the real function  ",
 Cell[BoxData[
  RowBox[{"y", "=", 
   RowBox[{
    SubscriptBox["J", "0"], "[", "x", "]"}]}]]],
 "  is decreasing on the interval ",
 Cell[BoxData[
  RowBox[{"[", 
   RowBox[{"0", ",", "3.83171"}], "]"}]]],
 ".  "
}], "Text"]
}, Closed]],

Cell["\<\
The \"legacy version\" being used to implement the commands \"CartesianMap \
and PolarMap.\"  The following Initialization Cell will load these \
subroutines. \
\>", "Text",
 CellChangeTimes->{{3.399722161203125*^9, 3.399722165296875*^9}, {
  3.39972222759375*^9, 3.3997223229375*^9}, {3.399722389046875*^9, 
  3.399722641234375*^9}, {3.399722683734375*^9, 3.3997227230625*^9}, {
  3.3997227559375*^9, 3.399722850765625*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Initialization Cell",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text",
 CellChangeTimes->{{3.399722161203125*^9, 3.399722165296875*^9}, {
  3.39972222759375*^9, 3.3997223229375*^9}, {3.399722389046875*^9, 
  3.399722641234375*^9}, {3.399722683734375*^9, 3.3997227230625*^9}, {
  3.3997227559375*^9, 3.399722850765625*^9}, {3.399742279828125*^9, 
  3.39974228209375*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}]], "Input",\

 InitializationCell->True]
}, Closed]],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Geometric Series",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/GeometricSeriesBib.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Convergence of Series",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/SeriesConvergenceBib.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Power Series",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/PowerSeriesBib.html"], None}],
 
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/complex.html"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2008 John H. Mathews, Russell W. \
Howell",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/"], None}],
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[0, 1, 0]]], "Text",
 CellChangeTimes->{{3.399118919765625*^9, 3.399118919890625*^9}}]
},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{934, 636},
WindowMargins->{{2, Automatic}, {Automatic, 2}},
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "CHAPTER 1"->{
  Cell[568, 21, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"],
  Cell[7508, 283, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"],
  Cell[22291, 840, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"],
  Cell[114566, 3751, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"CHAPTER 1", 142622, 4692}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"],
Cell[905, 32, 115, 2, 29, "Text"],
Cell[1023, 36, 3750, 139, 125, "Text"],
Cell[4776, 177, 873, 32, 29, "Text",
 Evaluatable->False],
Cell[5652, 211, 1513, 56, 137, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[7190, 271, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[7334, 277, 171, 4, 29, "Text",
 Evaluatable->False],
Cell[7508, 283, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"]
}, Closed]],
Cell[7857, 295, 1189, 38, 62, "Text",
 Evaluatable->False],
Cell[9049, 335, 9614, 377, 245, "Text"],
Cell[18666, 714, 3282, 110, 251, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[21973, 828, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[22117, 834, 171, 4, 29, "Text",
 Evaluatable->False],
Cell[22291, 840, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"]
}, Closed]],
Cell[22640, 852, 74, 0, 26, "Text"],
Cell[22717, 854, 2109, 75, 141, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[24851, 933, 157, 4, 29, "Text",
 Evaluatable->False],
Cell[25011, 939, 57, 0, 29, "Text"],
Cell[25071, 941, 1704, 49, 224, "Input"],
Cell[26778, 992, 153, 5, 29, "Text",
 Evaluatable->False],
Cell[26934, 999, 2099, 56, 273, "Input"],
Cell[29036, 1057, 970, 34, 92, "Text"],
Cell[30009, 1093, 3233, 86, 316, "Input"],
Cell[33245, 1181, 1015, 37, 74, "Text"],
Cell[34263, 1220, 558, 18, 96, "Input"],
Cell[34824, 1240, 140, 3, 29, "Text"]
}, Closed]],
Cell[34979, 1246, 2448, 86, 214, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[37452, 1336, 157, 4, 29, "Text",
 Evaluatable->False],
Cell[37612, 1342, 157, 3, 29, "Text"],
Cell[37772, 1347, 2127, 62, 252, "Input"],
Cell[39902, 1411, 139, 4, 29, "Text",
 Evaluatable->False],
Cell[40044, 1417, 207, 4, 41, "Input"],
Cell[40254, 1423, 123, 3, 39, "Input"],
Cell[40380, 1428, 3958, 111, 355, "Input"],
Cell[44341, 1541, 1398, 49, 102, "Text"],
Cell[45742, 1592, 2212, 63, 306, "Input"],
Cell[47957, 1657, 1050, 34, 95, "Text"],
Cell[49010, 1693, 713, 22, 112, "Input"],
Cell[49726, 1717, 531, 17, 53, "Text",
 Evaluatable->False],
Cell[50260, 1736, 4155, 109, 364, "Input"],
Cell[54418, 1847, 441, 15, 35, "Text",
 Evaluatable->False],
Cell[54862, 1864, 4034, 107, 364, "Input"],
Cell[58899, 1973, 280, 10, 35, "Text",
 Evaluatable->False],
Cell[59182, 1985, 4004, 107, 364, "Input"]
}, Closed]],
Cell[63201, 2095, 1441, 51, 116, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[64667, 2150, 157, 4, 29, "Text",
 Evaluatable->False],
Cell[64827, 2156, 55, 0, 29, "Text"],
Cell[64885, 2158, 1569, 45, 288, "Input"],
Cell[66457, 2205, 156, 5, 29, "Text",
 Evaluatable->False],
Cell[66616, 2212, 1485, 38, 238, "Input"],
Cell[68104, 2252, 109, 2, 29, "Text",
 Evaluatable->False],
Cell[68216, 2256, 775, 24, 139, "Input"],
Cell[68994, 2282, 142, 4, 29, "Text",
 Evaluatable->False],
Cell[69139, 2288, 4600, 121, 436, "Input"],
Cell[73742, 2411, 4514, 120, 440, "Input"]
}, Closed]],
Cell[78271, 2534, 1293, 45, 37, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[79589, 2583, 160, 4, 29, "Text",
 Evaluatable->False],
Cell[79752, 2589, 3842, 137, 225, "Text"],
Cell[83597, 2728, 28, 0, 29, "Text"],
Cell[83628, 2730, 3029, 106, 151, "Text"],
Cell[86660, 2838, 4105, 143, 511, "Text"],
Cell[90768, 2983, 847, 25, 102, "Input"],
Cell[91618, 3010, 4651, 120, 508, "Input"],
Cell[96272, 3132, 249, 10, 65, "Text"],
Cell[96524, 3144, 2590, 71, 317, "Input"],
Cell[99117, 3217, 3010, 85, 317, "Input"],
Cell[102130, 3304, 372, 11, 47, "Text"],
Cell[102505, 3317, 401, 12, 96, "Input"],
Cell[102909, 3331, 683, 24, 71, "Text"],
Cell[103595, 3357, 330, 10, 89, "Input"],
Cell[103928, 3369, 38, 0, 29, "Text"],
Cell[103969, 3371, 403, 12, 96, "Input"],
Cell[104375, 3385, 769, 27, 107, "Text"],
Cell[105147, 3414, 1765, 63, 75, "Text"],
Cell[106915, 3479, 436, 13, 88, "Input"],
Cell[107354, 3494, 716, 23, 88, "Input"],
Cell[108073, 3519, 3255, 97, 349, "Input"]
}, Closed]],
Cell[111343, 3619, 65, 0, 26, "Text"],
Cell[111411, 3621, 2812, 114, 148, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[114248, 3739, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[114392, 3745, 171, 4, 29, "Text",
 Evaluatable->False],
Cell[114566, 3751, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"]
}, Closed]],
Cell[114915, 3763, 754, 28, 35, "Text",
 Evaluatable->False],
Cell[115672, 3793, 1464, 50, 118, "Text"],
Cell[CellGroupData[{
Cell[117161, 3847, 157, 4, 29, "Text",
 Evaluatable->False],
Cell[117321, 3853, 518, 22, 36, "Text"],
Cell[117842, 3877, 1396, 40, 259, "Input"],
Cell[119241, 3919, 98, 2, 29, "Text",
 Evaluatable->False],
Cell[119342, 3923, 2456, 70, 310, "Input"]
}, Closed]],
Cell[121813, 3996, 802, 30, 35, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[122640, 4030, 160, 4, 29, "Text",
 Evaluatable->False],
Cell[122803, 4036, 519, 22, 36, "Text"],
Cell[123325, 4060, 1661, 48, 299, "Input"],
Cell[124989, 4110, 98, 2, 29, "Text",
 Evaluatable->False],
Cell[125090, 4114, 2211, 65, 267, "Input"]
}, Closed]],
Cell[127316, 4182, 6776, 230, 407, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[134117, 4416, 157, 4, 29, "Text",
 Evaluatable->False],
Cell[134277, 4422, 420, 15, 29, "Text"],
Cell[134700, 4439, 1425, 41, 172, "Input"],
Cell[136128, 4482, 298, 15, 29, "Text"],
Cell[136429, 4499, 505, 21, 29, "Text"],
Cell[136937, 4522, 2108, 56, 192, "Input"],
Cell[139048, 4580, 499, 17, 29, "Text"]
}, Closed]],
Cell[139562, 4600, 435, 8, 26, "Text"],
Cell[CellGroupData[{
Cell[140022, 4612, 407, 7, 29, "Text"],
Cell[140432, 4621, 132, 4, 31, "Input",
 InitializationCell->True]
}, Closed]],
Cell[140579, 4628, 281, 7, 26, "Text"],
Cell[140863, 4637, 279, 7, 29, "Text"],
Cell[141145, 4646, 286, 7, 29, "Text"],
Cell[141434, 4655, 269, 7, 29, "Text"],
Cell[141706, 4664, 249, 5, 29, "Text"],
Cell[141958, 4671, 320, 7, 29, "Text"]
}
]
*)

(* End of internal cache information *)
