(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    243441,      10968]
NotebookOptionsPosition[    239397,      10840]
NotebookOutlinePosition[    240008,      10867]
CellTagsIndexPosition[    239933,      10862]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["Chapter 5  Elementary Functions",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["Overview",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
 "\tHow should complex-valued functions such as  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[ExponentialE]", "z"], ",", 
   RowBox[{"log", 
    RowBox[{"(", "z", ")"}]}], ",", " ", 
   RowBox[{"sin", 
    RowBox[{"(", "z", ")"}]}]}]]],
 ",  etc., be defined ?  Clearly, any responsible definition should satisfy \
the following criteria:  \n\n",
 StyleBox["(i)",
  FontColor->RGBColor[0, 0, 1]],
 "  The functions so defined must give the same values as the corresponding \
functions for real variables when the number ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " is a real number.\n\n",
 StyleBox["(ii)",
  FontColor->RGBColor[0, 0, 1]],
 "  As far as possible, the properties of these new functions must correspond \
with their real counterparts.  For example, we would want  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     SubscriptBox["z", "1"]], 
    SuperscriptBox["\[ExponentialE]", 
     SubscriptBox["z", "2"]]}], "=", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     SubscriptBox["z", "1"], "+", 
     SubscriptBox["z", "2"]}]]}]]],
 "  to be valid regardless of whether ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " were real or complex. \n\n\tThese requirements may seem like a tall order \
to fill.  There is a procedure, however that offers promising results.  It is \
to put in complex form the expansion of the real functions  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[ExponentialE]", "x"], ",", 
   RowBox[{"ln", 
    RowBox[{"(", "x", ")"}]}], ",", " ", 
   RowBox[{"sin", 
    RowBox[{"(", "x", ")"}]}]}]]],
 ",  etc., as power series into complex form.  We use this strategy in this \
chapter."
}], "Text"],

Cell[TextData[StyleBox["5.1 The Complex Exponential Function",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
 "\tRecall that the real exponential function can be represented by the power \
series  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[ExponentialE]", "x"], " ", "=", " ", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", "0"}], "\[Infinity]"], 
    RowBox[{
     FractionBox["1", 
      RowBox[{"n", "!"}]], 
     SuperscriptBox["x", "n"]}]}]}]]],
 ".  Thus it is only natural to define the complex exponential  ",
 Cell[BoxData[
  SuperscriptBox["\[ExponentialE]", "z"]]],
 ",  also written as ",
 Cell[BoxData[
  RowBox[{"exp", 
   RowBox[{"(", "z", ")"}]}]]],
 ", in the following way: "
}], "Text"],

Cell[TextData[{
 "\n",
 StyleBox["Definition 5.1 (",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Exponential Function",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/ExponentialFunction.html"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 StyleBox[")",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[".",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  The definition of  ",
 StyleBox["exp(z)",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[" ",
  FontColor->RGBColor[1, 0, 1]],
 " is  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"exp", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", "z"], " ", "=", " ", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", "0"}], "\[Infinity]"], 
     RowBox[{
      FractionBox["1", 
       RowBox[{"n", "!"}]], 
      SuperscriptBox["z", "n"]}]}]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Demonstration for Definition 5.1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 StyleBox["  ",
  FontColor->RGBColor[1, 0, 1]]
}], "Text"],

Cell[TextData[{
 "We can use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to sum a power series."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["\[ExponentialE]", "z"], "\[Equal]", 
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"n", "=", "0"}], "\[Infinity]"], 
   FractionBox[
    SuperscriptBox["z", "n"], 
    RowBox[{"n", "!"}]]}]}]], "Input",
 CellChangeTimes->{3.399119109375*^9, 3.399280475515625*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Exp", "[", "z", "]"}], "\[Equal]", 
   SuperscriptBox["\[ExponentialE]", "z"]}], "\[IndentingNewLine]"}]], "Input",\

 CellChangeTimes->{3.399119109375*^9, 3.399280475515625*^9}],

Cell["\<\

The ratio test can be used to show that the infinite series converges for all \
values of   z.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", "z", "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"lim", ",", "n", ",", "q"}], "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"q1", "=", 
     RowBox[{
      RowBox[{"(", 
       FractionBox[
        SuperscriptBox["z", 
         RowBox[{"n", "+", "1"}]], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"n", "+", "1"}], ")"}], "!"}]], ")"}], "/", 
      RowBox[{"(", 
       FractionBox[
        SuperscriptBox["z", "n"], 
        RowBox[{"n", "!"}]], ")"}]}]}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"q2", "=", 
     RowBox[{"FullSimplify", "[", "q1", "]"}]}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"lim", "=", 
     RowBox[{"Limit", "[", 
      RowBox[{"q2", ",", 
       RowBox[{"n", "\[Rule]", "\[Infinity]"}]}], "]"}]}], ";"}], "  ", "\n", 
   
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*FractionBox[FractionBox[SuperscriptBox[\(z\), \(n + 1\)], \
\(\((n + 1)\)!\)], FractionBox[SuperscriptBox[\(z\), \(n\)], \(n!\)]]\) = \
\>\"", ",", "q1", ",", "\"\< = \>\"", ",", "q2"}], "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<L = \!\(\*UnderscriptBox[\(lim\), \(n \[Rule] \[Infinity]\)]\) \!\(\
\*FractionBox[FractionBox[SuperscriptBox[\(z\), \(n + 1\)], \(\((n + \
1)\)!\)], FractionBox[SuperscriptBox[\(z\), \(n\)], \(n!\)]]\)\>\"", "]"}], 
    ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<L = \!\(\*UnderscriptBox[\(lim\), \(n \[Rule] \[Infinity]\)]\) \
\>\"", ",", "q1"}], "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<L = \!\(\*UnderscriptBox[\(lim\), \(n \[Rule] \[Infinity]\)]\) \
\>\"", ",", "q2", ",", "\"\< = \>\"", ",", "lim"}], "]"}], ";"}], "  ", "\n", 
   
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The radius of convergence of the series is\>\"", "]"}],
     ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<R = \!\(\*FractionBox[\(1\), \(L\)]\) = \[Infinity]\>\"", "]"}], 
    ";"}], "  ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399119132125*^9}]
}, Closed]],

Cell[TextData[{
 "\n\tClearly, this definition agrees with that of the real exponential \
function when z is a real number.  We now show that this complex exponential \
has two of the key properties associated with its real counterpart and verify \
the identity  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]], "=", 
   RowBox[{
    RowBox[{"cos", " ", "\[Theta]"}], "+", 
    RowBox[{"\[ImaginaryI]", " ", "sin", " ", "\[Theta]"}]}]}]]],
 ",  which, back in Chapter 1 (see identity ",
 StyleBox["(1-30)",
  FontColor->RGBColor[0, 0, 1]],
 " of Section 1.4), we promised to establish."
}], "Text"],

Cell[TextData[{
 StyleBox["\nTheorem 5.1 (The exponential function).",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  The function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"exp", 
    RowBox[{"(", "z", ")"}]}], "=", 
   SuperscriptBox["\[ExponentialE]", "z"]}]]],
 "  is an entire function satisfying the following conditions:\n\n",
 "  ",
 StyleBox["(i).",
  FontColor->RGBColor[0, 0, 1]],
 "   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    FractionBox["d", "dz"], "exp", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    RowBox[{"exp", 
     RowBox[{"(", "z", ")"}]}], "=", 
    SuperscriptBox["\[ExponentialE]", "z"]}]}]]],
 ",  using Leibniz notation  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    FractionBox["d", "dz"], 
    SuperscriptBox["\[ExponentialE]", "z"]}], "=", 
   SuperscriptBox["\[ExponentialE]", "z"]}]]],
 ".  \n\n",
 " ",
 StyleBox["(ii).",
  FontColor->RGBColor[0, 0, 1]],
 "   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"exp", 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["z", "1"], "+", 
      SubscriptBox["z", "2"]}], ")"}]}], "=", 
   RowBox[{"exp", 
    RowBox[{"(", 
     SubscriptBox["z", "1"], ")"}], "exp", 
    RowBox[{"(", 
     SubscriptBox["z", "2"], ")"}]}]}]]],
 ",   i.e.   ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     SubscriptBox["z", "1"], "+", 
     SubscriptBox["z", "2"]}]], "=", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     SubscriptBox["z", "1"]], 
    SuperscriptBox["\[ExponentialE]", 
     SubscriptBox["z", "2"]]}]}]]],
 ".  \n\n",
 StyleBox["(iii).",
  FontColor->RGBColor[0, 0, 1]],
 "   If  ",
 Cell[BoxData["\[Theta]"]],
 "  is a real number, then   ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]], "=", 
   RowBox[{
    RowBox[{"cos", " ", "\[Theta]"}], "+", 
    RowBox[{"\[ImaginaryI]", " ", "sin", " ", "\[Theta]"}]}]}]]],
 ".  \n\nThe exponential function is a solution to the differential equation  \
",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"f", "'"}], 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}]}]]],
 "  with the initial condition  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "0", ")"}]}], "=", "1"}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof of Theorem 5.1.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 "\tBy the ratio test, the series in Definition 5.1 has an infinite radius of \
convergence, so  ",
 Cell[BoxData[
  RowBox[{"exp", 
   RowBox[{"(", "z", ")"}]}]]],
 "  is an function.  Using termwise differentiation, we get  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    FractionBox["d", "dz"], "exp", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", "1"}], "\[Infinity]"], 
     RowBox[{
      FractionBox["n", 
       RowBox[{"n", "!"}]], 
      SuperscriptBox["z", 
       RowBox[{"n", "-", "1"}]]}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "1"}], "\[Infinity]"], 
      RowBox[{
       FractionBox["1", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"n", "-", "1"}], ")"}], "!"}]], 
       SuperscriptBox["z", 
        RowBox[{"n", "-", "1"}]]}]}], " ", "=", " ", 
     RowBox[{
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"n", "=", "0"}], "\[Infinity]"], 
       RowBox[{
        FractionBox["1", 
         RowBox[{"n", "!"}]], 
        SuperscriptBox["z", "n"]}]}], " ", "=", " ", 
      RowBox[{"exp", 
       RowBox[{"(", "z", ")"}]}]}]}]}]}]]],
 ",  \n\nwhich gives us part ",
 StyleBox["(i)",
  FontColor->RGBColor[0, 0, 1]],
 " of Theorem 5.1."
}], "Text"],

Cell[TextData[{
 "To prove part ",
 StyleBox["(ii)",
  FontColor->RGBColor[0, 0, 1]],
 ", we let ",
 Cell[BoxData["\[Zeta]"]],
 " be an arbitrary complex number and define ",
 Cell[BoxData[
  RowBox[{"g", 
   RowBox[{"(", "z", ")"}]}]]],
 " to be \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"g", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{"exp", 
    RowBox[{"(", "z", ")"}], "exp", 
    RowBox[{"(", 
     RowBox[{"\[Zeta]", "-", "z"}], ")"}]}]}]]],
 ".\n\nUsing the product rule, chain rule, and part (i), we have \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"g", "'"}], 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"exp", 
     RowBox[{"(", "z", ")"}], "exp", 
     RowBox[{"(", 
      RowBox[{"\[Zeta]", "-", "z"}], ")"}]}], "+", 
    RowBox[{"exp", 
     RowBox[{
      RowBox[{"(", "z", ")"}], "[", 
      RowBox[{
       RowBox[{"-", "exp"}], 
       RowBox[{"(", 
        RowBox[{"\[Zeta]", "-", "z"}], ")"}]}], 
      "]"}]}]}]}], "\[IndentingNewLine]", 
  RowBox[{"              ", 
   RowBox[{"=", 
    RowBox[{
     RowBox[{"exp", 
      RowBox[{"(", "z", ")"}], "exp", 
      RowBox[{"(", 
       RowBox[{"\[Zeta]", "-", "z"}], ")"}]}], "-", 
     RowBox[{"exp", 
      RowBox[{"(", "z", ")"}], "exp", 
      RowBox[{"(", 
       RowBox[{"\[Zeta]", "-", "z"}], ")"}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"g", "'"}], 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{"0", "    ", 
    StyleBox["for",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], 
    StyleBox[" ",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], 
    StyleBox["all",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], "   ", 
    RowBox[{"z", 
     StyleBox[".",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]]}]}]}]}]],
 "."
}], "Text"],

Cell[TextData[{
 "Hence the function ",
 Cell[BoxData[
  RowBox[{"g", 
   RowBox[{"(", "z", ")"}]}]]],
 " must be a constant function.  Thus, for all z,  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"g", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{"g", 
    RowBox[{"(", "0", ")"}]}]}]]],
 ".   Since  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"exp", 
    RowBox[{"(", "0", ")"}]}], "=", "1"}]]],
 "  (for the reader to verify!), we deduce \n\n\t\t\t ",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"g", 
     RowBox[{"(", "z", ")"}]}], "=", 
    RowBox[{"g", 
     RowBox[{"(", "0", ")"}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"          ", 
   RowBox[{
    RowBox[{"=", 
     RowBox[{"exp", 
      RowBox[{"(", "0", ")"}], "exp", 
      RowBox[{"(", "\[Zeta]", ")"}]}]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"          ", 
   RowBox[{"=", 
    RowBox[{"exp", 
     RowBox[{"(", "\[Zeta]", ")"}]}]}]}]}]],
 ". \n\nHence, for all ",
 StyleBox["z",
  FontFamily->"Courier New"],
 ", \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"g", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"exp", 
     RowBox[{"(", "z", ")"}], "exp", 
     RowBox[{"(", 
      RowBox[{"\[Zeta]", "-", "z"}], ")"}]}], "=", 
    RowBox[{"exp", 
     RowBox[{"(", "\[Zeta]", ")"}]}]}]}]]],
 "."
}], "Text"],

Cell[TextData[{
 "Setting  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   SubscriptBox["z", "1"]}]]],
 "  and letting  ",
 Cell[BoxData[
  RowBox[{"\[Zeta]", "=", 
   RowBox[{
    SubscriptBox["z", "1"], "+", 
    SubscriptBox["z", "2"]}]}]]],
 ",  we get\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"exp", 
    RowBox[{"(", 
     SubscriptBox["z", "1"], ")"}], "exp", 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["z", "1"], "+", 
      SubscriptBox["z", "2"], "-", 
      SubscriptBox["z", "1"]}], ")"}]}], "=", 
   RowBox[{"exp", 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["z", "1"], "+", 
      SubscriptBox["z", "2"]}], ")"}]}]}]]],
 ".\n\nwhich simplifies to be ",
 StyleBox["(ii)",
  FontColor->RGBColor[0, 0, 1]],
 " which is our desired result, i.e.  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"exp", 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["z", "1"], "+", 
      SubscriptBox["z", "2"]}], ")"}]}], "=", 
   RowBox[{"exp", 
    RowBox[{"(", 
     SubscriptBox["z", "1"], ")"}], "exp", 
    RowBox[{"(", 
     SubscriptBox["z", "2"], ")"}]}]}]]],
 "."
}], "Text"],

Cell[TextData[{
 "To prove part",
 StyleBox[" (iii)",
  FontColor->RGBColor[0, 0, 1]],
 ", we let  ",
 Cell[BoxData["\[Theta]"]],
 "  be a real number.  By Definition 5.1,  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]], " ", "=", "  ", 
      RowBox[{"exp", 
       RowBox[{"(", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]], ")"}]}]}], 
     "\[IndentingNewLine]"}], "\[IndentingNewLine]", "        ", 
    RowBox[{
     RowBox[{"=", "  ", 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"k", "=", "0"}], "\[Infinity]"], 
       RowBox[{
        FractionBox["1", 
         RowBox[{"k", "!"}]], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}], ")"}], "k"]}]}]}], " ", 
     "\[IndentingNewLine]"}], "\[IndentingNewLine]", "        ", 
    RowBox[{
     RowBox[{"=", " ", 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"n", "=", "0"}], "\[Infinity]"], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          FractionBox["1", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"2", "n"}], ")"}], "!"}]], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}], ")"}], 
           RowBox[{"2", "n"}]]}], " ", "+", " ", 
         RowBox[{
          FractionBox["1", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", "n"}], "+", "1"}], ")"}], "!"}]], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}], ")"}], 
           RowBox[{
            RowBox[{"2", "n"}], "+", "1"}]]}]}], " ", ")"}]}]}], 
     "\[IndentingNewLine]"}], "\[IndentingNewLine]", "        ", 
    RowBox[{
     RowBox[{"=", " ", 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"n", "=", "0"}], "\[Infinity]"], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          FractionBox["1", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"2", "n"}], ")"}], "!"}]], 
          SuperscriptBox[
           RowBox[{"(", 
            SuperscriptBox["\[ImaginaryI]", "2"], ")"}], "n"], " ", 
          SuperscriptBox["\[Theta]", 
           RowBox[{"2", "n"}]]}], " ", "+", " ", 
         RowBox[{
          FractionBox["1", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", "n"}], "+", "1"}], ")"}], "!"}]], "\[ImaginaryI]", 
          
          SuperscriptBox[
           RowBox[{"(", 
            SuperscriptBox["\[ImaginaryI]", "2"], ")"}], "n"], 
          SuperscriptBox["\[Theta]", 
           RowBox[{
            RowBox[{"2", "n"}], "+", "1"}]]}]}], " ", ")"}]}]}], 
     "\[IndentingNewLine]"}], "\[IndentingNewLine]", "        ", 
    RowBox[{
     RowBox[{"=", " ", 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"n", "=", "0"}], "\[Infinity]"], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          FractionBox["1", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"2", "n"}], ")"}], "!"}]], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], "n"], " ", 
          SuperscriptBox["\[Theta]", 
           RowBox[{"2", "n"}]]}], " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", 
          FractionBox["1", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", "n"}], "+", "1"}], ")"}], "!"}]], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], "n"], 
          SuperscriptBox["\[Theta]", 
           RowBox[{
            RowBox[{"2", "n"}], "+", "1"}]]}]}], " ", ")"}]}]}], 
     "\[IndentingNewLine]"}], "\[IndentingNewLine]", "        ", 
    RowBox[{
     RowBox[{"=", " ", 
      RowBox[{
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"n", "=", "0"}], "\[Infinity]"], 
        RowBox[{
         FractionBox[
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], "n"], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"2", "n"}], ")"}], "!"}]], 
         SuperscriptBox["\[Theta]", 
          RowBox[{"2", "n"}]]}]}], " ", "+", " ", 
       RowBox[{"\[ImaginaryI]", 
        RowBox[{
         UnderoverscriptBox["\[Sum]", 
          RowBox[{"n", "=", "0"}], "\[Infinity]"], 
         RowBox[{
          FractionBox[
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"-", "1"}], ")"}], "n"], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", "n"}], "+", "1"}], ")"}], "!"}]], " ", 
          SuperscriptBox["\[Theta]", 
           RowBox[{
            RowBox[{"2", "n"}], "+", "1"}]]}]}]}]}]}], "\[IndentingNewLine]", 
     " "}], "\[IndentingNewLine]", "        ", 
    RowBox[{"=", " ", 
     RowBox[{
      RowBox[{"cos", " ", "\[Theta]"}], " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", "sin", " ", "\[Theta]"}]}]}]}]}]]],
 "  "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Demonstration for Theorem 5.1 (i).",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 "Enter the D.E. with the given initial condition and solve it. \nThen enter \
the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], "=", 
   SuperscriptBox["\[ExponentialE]", "z"]}]]],
 ",  compute  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"f", "'"}], "[", "z", "]"}], "  ", "and", "  ", 
   RowBox[{"f", "[", "0", "]"}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", 
     RowBox[{"x", ",", "y", ",", "z"}], "]"}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "s", ",", "u", ",", "U", ",", "v", ",", "V"}], "]"}], 
    ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"de", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"f", "'"}], "[", "z", "]"}], "\[Equal]", 
      RowBox[{"f", "[", "z", "]"}]}]}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"solset", "=", 
     RowBox[{"DSolve", "[", 
      RowBox[{"de", ",", 
       RowBox[{"f", "[", "z", "]"}], ",", "z"}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "de", "]"}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     SubscriptBox["solset", 
      RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], "]"}], 
    ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ic", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"f", "'"}], "[", "0", "]"}], "\[Equal]", "1"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"solset", "=", 
     RowBox[{"DSolve", "[", 
      RowBox[{
       RowBox[{"Flatten", "[", 
        RowBox[{"{", 
         RowBox[{"de", ",", "ic"}], "}"}], "]"}], ",", 
       RowBox[{"f", "[", "z", "]"}], ",", "z"}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "de", "]"}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "ic", "]"}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     SubscriptBox["solset", 
      RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], "]"}], 
    ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", 
     SuperscriptBox["\[ExponentialE]", "z"]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f'[z] = \>\"", ",", 
      RowBox[{
       RowBox[{"f", "'"}], "[", "z", "]"}]}], "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f[0] = \>\"", ",", 
      RowBox[{"f", "[", "0", "]"}]}], "]"}], ";"}], "  ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39911915025*^9}],

Cell[TextData[{
 "\nConstruct the Maclaurin series for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], "=", 
   SuperscriptBox["\[ExponentialE]", "z"]}]]],
 ",  compute  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"f", "'"}], "[", "z", "]"}], "  ", "and", "  ", 
   RowBox[{"f", "[", "0", "]"}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"s", "[", "z_", "]"}], "=", 
     RowBox[{"Series", "[", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", "z"], ",", 
       RowBox[{"{", 
        RowBox[{"z", ",", "0", ",", "11"}], "}"}]}], "]"}]}], ";"}], "  ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f[z] = \>\"", ",", 
      RowBox[{"s", "[", "z", "]"}]}], "]"}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f'[z] = \>\"", ",", 
      RowBox[{
       RowBox[{"s", "'"}], "[", "z", "]"}]}], "]"}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f[0] = \>\"", ",", 
      RowBox[{"s", "[", "0", "]"}]}], "]"}], ";"}], "  ", 
   "\[IndentingNewLine]"}]}]], "Input"],

Cell[TextData[{
 "\nDetermine the real and imaginary parts of  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], "=", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", "z"], "=", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"x", " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", "y"}]}]]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"u", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"Re", "[", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"x", "+", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}]], "]"}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"v", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"Im", "[", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"x", "+", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}]], "]"}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<    f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f[x+\[ImaginaryI]y] = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"x", "+", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}]}], "]"}], ";"}], "  ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f[x+\[ImaginaryI]y] = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", "+", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<u[x,y] = Re[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(z\)]\)] = \
\>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<v[x,y] = Im[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(z\)]\)] = \
\>\"", ",", 
      RowBox[{"v", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<u[0,0] = \>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"0", ",", "0"}], "]"}]}], "]"}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<v[0,0] = \>\"", ",", 
      RowBox[{"v", "[", 
       RowBox[{"0", ",", "0"}], "]"}]}], "]"}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\< f[0+0\[ImaginaryI]] = u[0,0] + \[ImaginaryI] v[0,0]\>\"", "]"}], 
    ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f[0+0\[ImaginaryI]] = (\>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"0", ",", "0"}], "]"}], " ", ",", "\"\<) + \[ImaginaryI](\>\"",
       ",", " ", 
      RowBox[{"v", "[", 
       RowBox[{"0", ",", "0"}], "]"}], ",", "\"\<)\>\""}], "]"}], ";"}], "  ",
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f[0+0\[ImaginaryI]] = \>\"", ",", 
      RowBox[{
       RowBox[{"u", "[", 
        RowBox[{"0", ",", "0"}], "]"}], " ", "+", " ", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"v", "[", 
         RowBox[{"0", ",", "0"}], "]"}]}]}]}], "]"}], ";"}], "  ", 
   "\[IndentingNewLine]"}]}]], "Input",
 AspectRatioFixed->True],

Cell[TextData[{
 "\nDetermine the real and imaginary parts of the series ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], "=", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", "z"], "=", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", "0"}], "\[Infinity]"], 
     FractionBox[
      SuperscriptBox["z", "n"], 
      RowBox[{"n", "!"}]]}]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"s", "[", "z_", "]"}], "=", 
     RowBox[{"Series", "[", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", "z"], ",", 
       RowBox[{"{", 
        RowBox[{"z", ",", "0", ",", "5"}], "}"}]}], "]"}]}], ";"}], "  ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f[z] = \>\"", ",", 
      RowBox[{"s", "[", 
       RowBox[{"x", "+", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}]}], "]"}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<  Re[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(z\)]\)] = \>\"", 
      ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"Re", "[", 
        RowBox[{"Normal", "[", 
         RowBox[{"s", "[", 
          RowBox[{"x", "+", 
           RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], "]"}], 
       "]"}]}], "]"}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<  Im[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(z\)]\)] = \>\"", 
      ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"Im", "[", 
        RowBox[{"Normal", "[", 
         RowBox[{"s", "[", 
          RowBox[{"x", "+", 
           RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], "]"}], 
       "]"}]}], "]"}], ";"}], "  ", "\[IndentingNewLine]"}]}]], "Input"],

Cell[TextData[{
 "\nCompare the above results with the two variable Taylor series expansions \
for  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{" ", "x"}]], 
   RowBox[{"Cos", "[", "y", "]"}], "   ", "and", "   ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{" ", "x"}]], 
   RowBox[{"Sin", "[", "y", "]"}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"U", "=", 
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"x0", "+", 
           RowBox[{"t", " ", "x"}]}]], 
         RowBox[{"Cos", "[", 
          RowBox[{"y0", "+", 
           RowBox[{"t", " ", "y"}]}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"t", ",", "0", ",", "5"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"V", "=", 
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"x0", "+", 
           RowBox[{"t", " ", "x"}]}]], 
         RowBox[{"Sin", "[", 
          RowBox[{"y0", "+", 
           RowBox[{"t", " ", "y"}]}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"t", ",", "0", ",", "5"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"u", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], "=", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{"U", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"t", "\[Rule]", "1"}], ",", 
         RowBox[{"x0", "\[Rule]", "0"}], ",", 
         RowBox[{"y0", "\[Rule]", "0"}]}], "}"}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"v", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], "=", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{"V", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"t", "\[Rule]", "1"}], ",", 
         RowBox[{"x0", "\[Rule]", "0"}], ",", 
         RowBox[{"y0", "\[Rule]", "0"}]}], "}"}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<  Re[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(z\)]\)] = \>\"", 
      ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<  Im[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(z\)]\)] = \>\"", 
      ",", 
      RowBox[{"v", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<  Re[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(z\)]\)] = \>\"", 
      ",", 
      RowBox[{"Expand", "[", 
       RowBox[{"u", "[", 
        RowBox[{"x", ",", "y"}], "]"}], "]"}]}], "]"}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<  Im[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(z\)]\)] = \>\"", 
      ",", 
      RowBox[{"Expand", "[", 
       RowBox[{"v", "[", 
        RowBox[{"x", ",", "y"}], "]"}], "]"}]}], "]"}], ";"}], 
   "  "}]}]], "Input",
 CellChangeTimes->{{3.3991192196875*^9, 3.399119244546875*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Demonstration for Theorem 5.1 (ii).",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", 
     RowBox[{"w", ",", "x", ",", "y", ",", "z"}], "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["w", "1"], " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        SubscriptBox["x", "1"], "+", 
        RowBox[{"\[ImaginaryI]", " ", 
         SubscriptBox["y", "1"]}]}]], "]"}]}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["w", "2"], " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        SubscriptBox["x", "2"], "+", 
        RowBox[{"\[ImaginaryI]", " ", 
         SubscriptBox["y", "2"]}]}]], "]"}]}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SuperscriptBox[\(\[ExponentialE]\), SubscriptBox[\(z\), \
\(1\)]]\) = \>\"", ",", 
      SubscriptBox["w", "1"]}], "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SuperscriptBox[\(\[ExponentialE]\), SubscriptBox[\(z\), \
\(2\)]]\) = \>\"", ",", 
      SubscriptBox["w", "2"]}], "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["w", "3"], " ", "=", " ", 
     RowBox[{"Expand", "[", 
      RowBox[{
       SubscriptBox["w", "1"], " ", 
       SubscriptBox["w", "2"]}], "]"}]}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SuperscriptBox[\(\[ExponentialE]\), SubscriptBox[\(z\), \
\(1\)]]\)\!\(\*SuperscriptBox[\(\[ExponentialE]\), SubscriptBox[\(z\), \
\(2\)]]\) = \>\"", ",", 
      SubscriptBox["w", "3"]}], "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["w", "3"], " ", "=", " ", 
     RowBox[{"Simplify", "[", 
      RowBox[{
       SubscriptBox["w", "3"], ",", 
       RowBox[{"Trig", "\[Rule]", "False"}]}], "]"}]}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SuperscriptBox[\(\[ExponentialE]\), SubscriptBox[\(z\), \
\(1\)]]\)\!\(\*SuperscriptBox[\(\[ExponentialE]\), SubscriptBox[\(z\), \
\(2\)]]\) = \>\"", ",", 
      SubscriptBox["w", "3"]}], "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "4"], " ", "=", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["x", "1"], "+", 
        RowBox[{"\[ImaginaryI]", " ", 
         SubscriptBox["y", "1"]}]}], ")"}], "+", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["x", "2"], "+", 
        RowBox[{"\[ImaginaryI]", " ", 
         SubscriptBox["y", "2"]}]}], ")"}]}]}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["w", "4"], " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      SuperscriptBox["\[ExponentialE]", 
       SubscriptBox["z", "4"]], "]"}]}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\*SubscriptBox[\(z\), \
\(1\)] + \*SubscriptBox[\(z\), \(2\)]\)]\) = \>\"", ",", 
      SubscriptBox["w", "4"]}], "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["w", "4"], " ", "=", " ", 
     RowBox[{"Simplify", "[", 
      RowBox[{
       SubscriptBox["w", "4"], ",", 
       RowBox[{"Trig", "\[Rule]", "False"}]}], "]"}]}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\*SubscriptBox[\(z\), \
\(1\)] + \*SubscriptBox[\(z\), \(2\)]\)]\) = \>\"", ",", 
      SubscriptBox["w", "4"]}], "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<Does \!\(\*SuperscriptBox[\(\[ExponentialE]\), SubscriptBox[\(z\), \
\(1\)]]\)\!\(\*SuperscriptBox[\(\[ExponentialE]\), SubscriptBox[\(z\), \
\(2\)]]\)= \!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\*SubscriptBox[\(z\), \
\(1\)] + \*SubscriptBox[\(z\), \(2\)]\)]\) ?\>\"", "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      SubscriptBox["w", "3"], ",", "\"\< = \>\"", ",", 
      SubscriptBox["w", "4"]}], "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["w", "3"], " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      SubscriptBox["w", "3"], "]"}]}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["w", "4"], " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      SubscriptBox["w", "4"], "]"}]}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      SubscriptBox["w", "3"], ",", "\"\< = \>\"", ",", 
      SubscriptBox["w", "4"]}], "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["w", "3"], " ", "=", " ", 
     RowBox[{"Simplify", "[", 
      RowBox[{
       RowBox[{"ComplexExpand", "[", 
        SubscriptBox["w", "3"], "]"}], ",", 
       RowBox[{"Trig", "\[Rule]", "True"}]}], "]"}]}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["w", "4"], " ", "=", " ", 
     RowBox[{"Simplify", "[", 
      RowBox[{
       RowBox[{"ComplexExpand", "[", 
        SubscriptBox["w", "4"], "]"}], ",", 
       RowBox[{"Trig", "\[Rule]", "True"}]}], "]"}]}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      SubscriptBox["w", "3"], ",", "\"\< = \>\"", ",", 
      SubscriptBox["w", "4"]}], "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"TrigExpand", "[", 
       SubscriptBox["w", "3"], "]"}], "\[Equal]", 
      RowBox[{"TrigExpand", "[", 
       SubscriptBox["w", "4"], "]"}]}], "]"}], ";"}], "  ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399119253515625*^9, 3.3991192555*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Demonstration for Theorem 5.1 (iii).",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["This is DeMoivre's formula that was studied in Section 1.5. ", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    SuperscriptBox["\[ExponentialE]", "x"], "  ", "\[Equal]", "  ", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"k", "=", "0"}], "\[Infinity]"], 
     RowBox[{
      FractionBox["1", 
       RowBox[{"k", "!"}]], 
      SuperscriptBox["x", "k"]}]}]}], "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399119263359375*^9, 3.39911928325*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]], " ", "\[Equal]", " ", 
      RowBox[{
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"n", "=", "0"}], "\[Infinity]"], 
        RowBox[{
         FractionBox["1", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"2", "n"}], ")"}], "!"}]], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}], ")"}], 
          RowBox[{"2", "n"}]]}]}], " ", "+", " ", 
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"n", "=", "0"}], "\[Infinity]"], 
        RowBox[{
         FractionBox["1", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", "n"}], "+", "1"}], ")"}], "!"}]], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}], ")"}], 
          RowBox[{
           RowBox[{"2", "n"}], "+", "1"}]]}]}]}]}], "    ", "//", 
     "ComplexExpand"}], "//", "PowerExpand"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399119288875*^9, 3.39911929*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]], " ", "\[Equal]", " ", 
      RowBox[{
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"n", "=", "0"}], "\[Infinity]"], 
        RowBox[{
         FractionBox["1", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"2", "n"}], ")"}], "!"}]], 
         SuperscriptBox["\[ImaginaryI]", 
          RowBox[{"2", "n"}]], 
         SuperscriptBox["\[Theta]", 
          RowBox[{"2", "n"}]]}]}], " ", "+", " ", 
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"n", "=", "0"}], "\[Infinity]"], 
        RowBox[{
         FractionBox["1", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", "n"}], "+", "1"}], ")"}], "!"}]], 
         SuperscriptBox["\[ImaginaryI]", 
          RowBox[{
           RowBox[{"2", "n"}], "+", "1"}]], 
         SuperscriptBox["\[Theta]", 
          RowBox[{
           RowBox[{"2", "n"}], "+", "1"}]]}]}]}]}], "     ", "//", 
     "ComplexExpand"}], "//", "PowerExpand"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399119293671875*^9, 3.399119294921875*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]], " ", "\[Equal]", 
      RowBox[{
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"n", "=", "0"}], "\[Infinity]"], 
        RowBox[{
         FractionBox["1", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"2", "n"}], ")"}], "!"}]], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"-", "1"}], ")"}], "n"], 
         SuperscriptBox["\[Theta]", 
          RowBox[{"2", "n"}]]}]}], " ", "+", 
       RowBox[{"\[ImaginaryI]", 
        RowBox[{
         UnderoverscriptBox["\[Sum]", 
          RowBox[{"n", "=", "0"}], "\[Infinity]"], 
         RowBox[{
          FractionBox["1", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", "n"}], "+", "1"}], ")"}], "!"}]], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], "n"], " ", 
          SuperscriptBox["\[Theta]", 
           RowBox[{
            RowBox[{"2", "n"}], "+", "1"}]]}]}]}]}]}], "     ", "//", 
     "ComplexExpand"}], "//", "PowerExpand"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399119298484375*^9, 3.3991193038125*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Print", "[", 
    RowBox[{
    "\"\<\!\(\*UnderoverscriptBox[\(\[Sum]\), \(k = 0\), \(\[Infinity]\)]\)\!\
\(\*FractionBox[\(1\), \(k!\)]\)\!\(\*SuperscriptBox[\((\[ImaginaryI]\\\ \
\[Theta])\), \(k\)]\) = \>\"", ",", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"k", "=", "0"}], "\[Infinity]"], 
      RowBox[{
       FractionBox["1", 
        RowBox[{"k", "!"}]], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}], ")"}], "k"]}]}]}], "]"}],
    ";"}], "  "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Print", "[", 
    RowBox[{
    "\"\<\!\(\*UnderoverscriptBox[\(\[Sum]\), \(k = 0\), \(\[Infinity]\)]\)\!\
\(\*FractionBox[\(1\), \(k!\)]\)\!\(\*SuperscriptBox[\((\[ImaginaryI]\\\ \
\[Theta])\), \(k\)]\) = \>\"", ",", 
     RowBox[{"ComplexExpand", "[", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]], "]"}]}], "]"}], ";"}], 
  "  "}], "\[IndentingNewLine]"}], "Input"]
}, Closed]],

Cell[TextData[{
 "\tNote that parts ",
 StyleBox["(ii)",
  FontColor->RGBColor[0, 0, 1]],
 " and ",
 StyleBox["(iii)",
  FontColor->RGBColor[0, 0, 1]],
 " of the Theorem 5.1 combine to verify ",
 StyleBox[ButtonBox["De Moivre's",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/De_Moivre.\
html"], None}],
  FontVariations->{"Underline"->True}],
 " formula, which we introduced in Section 1.5. "
}], "Text"],

Cell[TextData[{
 "\tIf  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{"x", " ", "+", 
    RowBox[{"\[ImaginaryI]", " ", "y"}]}]}]]],
 ",  we also see from parts ",
 StyleBox["(ii)",
  FontColor->RGBColor[0, 0, 1]],
 " and ",
 StyleBox["(iii)",
  FontColor->RGBColor[0, 0, 1]],
 " that\n\t\n",
 StyleBox["(5-1)",
  FontColor->GrayLevel[1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"exp", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", "z"], " ", "=", " ", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"x", " ", "+", 
       RowBox[{"\[ImaginaryI]", " ", "y"}]}]], " ", "=", " ", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"x", " "}]], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", "y"}]], " "}]}]}]}]]],
 "   \n\t\t\t\n",
 StyleBox["(5-1)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"exp", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"x", " "}]], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"cos", " ", "y"}], "+", 
      RowBox[{"\[ImaginaryI]", " ", "sin", " ", "y"}]}], ")"}]}]}]]],
 "   \n\nSome texts start with this identity as their definition for ",
 Cell[BoxData[
  SuperscriptBox["\[ExponentialE]", "z"]]],
 ".  In the exercises, we show that this is a natural approach from the \
standpoint of differential equations.  "
}], "Text"],

Cell[TextData[{
 "\tThe notation  ",
 Cell[BoxData[
  RowBox[{"exp", 
   RowBox[{"(", "z", ")"}]}]]],
 "  is preferred over  ",
 Cell[BoxData[
  SuperscriptBox["\[ExponentialE]", "z"]]],
 "  in some situations.  For example,  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"exp", 
    RowBox[{"(", 
     FractionBox["1", "5"], ")"}]}], " ", "=", " ", 
   TagBox["\"\<1.22140275816016983392...\>\"",
    NumberForm[#, 70]& ]}]]],
 "  is the value of  ",
 Cell[BoxData[
  RowBox[{"exp", 
   RowBox[{"(", "z", ")"}]}]]],
 "  when  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   FractionBox["1", "5"]}]]],
 "  and equals the positive fifth root of  ",
 Cell[BoxData[
  RowBox[{"\[ExponentialE]", " ", "=", 
   RowBox[{"2.71828182845904523536", "..."}]}]]],
 ".  Thus the notation  ",
 Cell[BoxData[
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{"1", "/", "5"}]]]],
 "  is ambiguous and might be interpreted as any of the complex fifth roots \
of the number ",
 Cell[BoxData["\[ExponentialE]"]],
 " that we discussed in Section 1.5:\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"1", "/", "5"}]], " ", "=", " ", 
   RowBox[{"1.22140275816016983392", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"cos", 
       FractionBox[
        RowBox[{"2", " ", "\[Pi]", " ", "k"}], "5"]}], "+", 
      RowBox[{"\[ImaginaryI]", "  ", "sin", 
       FractionBox[
        RowBox[{"2", " ", "\[Pi]", " ", "k"}], "5"]}]}], ")"}]}]}]]],
 "   for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"k", "=", "0"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "1", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "2", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "3", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "4"}]]],
 ".  \n\nTo prevent this confusion, we often use  ",
 Cell[BoxData[
  RowBox[{"exp", 
   RowBox[{"(", "z", ")"}]}]]],
 "  to denote the single-valued exponential function."
}], "Text"],

Cell[TextData[{
 "\tWe now explore some additional properties of  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"exp", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   SuperscriptBox["\[ExponentialE]", "z"]}]]],
 ".  Using identity ",
 StyleBox["(5-1)",
  FontColor->RGBColor[0, 0, 1]],
 ", we can easily establish that  \n\n",
 StyleBox["(5-2)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"z", "+", 
     RowBox[{"\[ImaginaryI]2", " ", "n", " ", "\[Pi]"}]}]], "=", 
   SuperscriptBox["\[ExponentialE]", "z"]}]]],
 ",  for all  z,  provided n is an integer,  \n\n",
 StyleBox["(5-3)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[ExponentialE]", "z"], "=", "1"}]]],
 ",  if and only if  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{"\[ImaginaryI]", " ", "2", " ", "n", " ", "\[Pi]"}]}]]],
 ",  where n  is an integer, and\n\n",
 StyleBox["(5-4)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    SubscriptBox["z", "1"]], "=", 
   SuperscriptBox["\[ExponentialE]", 
    SubscriptBox["z", "2"]]}]]],
 ",  if and only if  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "2"], "=", 
   RowBox[{
    SubscriptBox["z", "1"], "+", 
    RowBox[{"\[ImaginaryI]", " ", "2", " ", "n", " ", "\[Pi]"}]}]}]]],
 ",  for some integer n.  "
}], "Text"],

Cell[TextData[{
 "    For example, because Identity ",
 StyleBox["(5-1)",
  FontColor->RGBColor[0, 0, 1]],
 " involves the periodic functions  cos y  and  sin y,  any two points in the \
",
 StyleBox["z",
  FontFamily->"Courier New"],
 " plane that lie on the same vertical line with their imaginary parts \
differing by an integral multiple of  ",
 Cell[BoxData[
  RowBox[{"2", " ", "\[Pi]"}]]],
 "  are mapped onto the same point in the ",
 StyleBox["w",
  FontFamily->"Courier New"],
 " plane.  Thus the complex exponential function is periodic with period  ",
 Cell[BoxData[
  RowBox[{"2", " ", "\[Pi]"}]]],
 ",  which establishes Equation ",
 StyleBox["(5-2)",
  FontColor->RGBColor[0, 0, 1]],
 ".  We leave the verification of Equations ",
 StyleBox["(5-3)",
  FontColor->RGBColor[0, 0, 1]],
 " and ",
 StyleBox["(5-4)",
  FontColor->RGBColor[0, 0, 1]],
 " as exercises for the reader."
}], "Text"],

Cell[TextData[{
 StyleBox["Example 5.1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  For any integer n, the points  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "n"], "=", 
   RowBox[{
    FractionBox["5", "4"], "+", 
    RowBox[{"\[ImaginaryI]", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{"11", " ", "\[Pi]"}], "6"], "+", 
       RowBox[{"2", " ", "n", " ", "\[Pi]"}]}], ")"}]}]}]}]]],
 "  are mapped onto a single point  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    SubscriptBox["w", "0"], "  ", "=", "  ", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      SubscriptBox["z", "n"]], "  ", "=", "  ", 
     RowBox[{"exp", 
      RowBox[{"(", 
       SubscriptBox["z", "n"], ")"}]}]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"      ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{"exp", "[", 
      RowBox[{
       FractionBox["5", "4"], "+", 
       RowBox[{"\[ImaginaryI]", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{"11", " ", "\[Pi]"}], "6"], "+", 
          RowBox[{"2", " ", "n", " ", "\[Pi]"}]}], ")"}]}]}], "]"}]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"      ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"5", "/", "4"}]], " ", "[", 
      RowBox[{
       RowBox[{"Cos", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{"11", " ", "\[Pi]"}], "6"], "+", 
          RowBox[{"2", " ", "n", " ", "\[Pi]"}]}], ")"}]}], "+", 
       RowBox[{"\[ImaginaryI]", " ", "Sin", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{"11", " ", "\[Pi]"}], "6"], "+", 
          RowBox[{"2", " ", "n", " ", "\[Pi]"}]}], ")"}]}]}], "]"}]}], 
    "\n"}]}], "\[IndentingNewLine]", 
  RowBox[{"      ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"5", "/", "4"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"cos", " ", 
         FractionBox[
          RowBox[{"11", " ", "\[Pi]"}], "6"]}], " ", "+", " ", 
        RowBox[{"\[ImaginaryI]", " ", "sin", " ", 
         FractionBox[
          RowBox[{"11", " ", "\[Pi]"}], "6"]}]}], ")"}]}]}], 
    "\[IndentingNewLine]"}]}], "\n", 
  RowBox[{"      ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{
      RowBox[{
       FractionBox[
        RowBox[{" ", 
         SqrtBox["3"]}], "2"], " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"5", "/", "4"}]]}], " ", "-", " ", 
      RowBox[{"\[ImaginaryI]", 
       FractionBox["1", "2"], "  ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"5", "/", "4"}]]}]}], "\[IndentingNewLine]", "\n", "      ", 
     RowBox[{"=", "  ", 
      RowBox[{"3.02272566908", "  ", "-", "  ", 
       RowBox[{"1.74517147873", "  ", "\[ImaginaryI]"}]}]}]}]}]}]}]],
 "  \n\nin the ",
 StyleBox["w",
  FontFamily->"Courier New"],
 " plane, as indicated in Figure 5.1."
}], "Text",
 AspectRatioFixed->True],

Cell[TextData[{
 "\t",
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8  scalefont  setfont
% Scaling calculations
0.468085 0.212766 0.0398732 0.0398732 [
[.04255 .02737 -6.96875 -10.9375 ]
[.04255 .02737 6.96875 0 ]
[.25532 .02737 -6.96875 -10.9375 ]
[.25532 .02737 6.96875 0 ]
[.68085 .02737 -4.21875 -10.9375 ]
[.68085 .02737 4.21875 0 ]
[.89362 .02737 -4.21875 -10.9375 ]
[.89362 .02737 4.21875 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04255 .03987 m
.04255 .04612 L
s
gsave
.04255 .02737 -67.9688 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.25532 .03987 m
.25532 .04612 L
s
gsave
.25532 .02737 -67.9688 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.68085 .03987 m
.68085 .04612 L
s
gsave
.68085 .02737 -65.2188 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.89362 .03987 m
.89362 .04612 L
s
gsave
.89362 .02737 -65.2188 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
0 .03987 m
1 .03987 L
s
.46809 0 m
.46809 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.5 Mabswid
0 .03987 m
.12121 .03987 L
.29703 .03987 L
.46608 .03987 L
.64609 .03987 L
.81933 .03987 L
s
.81933 .03987 m
1 .03987 L
s
0 1 1 r
.89362 .16514 m
.04255 .16514 L
.04255 .03987 L
.89362 .03987 L
.89362 .16514 L
F
.89362 .41567 m
.04255 .41567 L
.04255 .2904 L
.89362 .2904 L
.89362 .41567 L
F
.941 1 .941 r
.89362 .2904 m
.04255 .2904 L
.04255 .16514 L
.89362 .16514 L
.89362 .2904 L
F
.89362 .54093 m
.04255 .54093 L
.04255 .41567 L
.89362 .41567 L
.89362 .54093 L
F
0 g
.04255 .03987 m
.04255 .04495 L
.04255 .0505 L
.04255 .0557 L
.04255 .06071 L
.04255 .06604 L
.04255 .07116 L
.04255 .07662 L
.04255 .08187 L
.04255 .08692 L
.04255 .09229 L
.04255 .09747 L
.04255 .10245 L
.04255 .10775 L
.04255 .11285 L
.04255 .11827 L
.04255 .12349 L
.04255 .12851 L
.04255 .13386 L
.04255 .13901 L
.04255 .14448 L
.04255 .14975 L
.04255 .15482 L
.04255 .16021 L
.04255 .16514 L
s
.14894 .03987 m
.14894 .04495 L
.14894 .0505 L
.14894 .0557 L
.14894 .06071 L
.14894 .06604 L
.14894 .07116 L
.14894 .07662 L
.14894 .08187 L
.14894 .08692 L
.14894 .09229 L
.14894 .09747 L
.14894 .10245 L
.14894 .10775 L
.14894 .11285 L
.14894 .11827 L
.14894 .12349 L
.14894 .12851 L
.14894 .13386 L
.14894 .13901 L
.14894 .14448 L
.14894 .14975 L
.14894 .15482 L
.14894 .16021 L
.14894 .16514 L
s
.25532 .03987 m
.25532 .04495 L
.25532 .0505 L
.25532 .0557 L
.25532 .06071 L
.25532 .06604 L
.25532 .07116 L
.25532 .07662 L
.25532 .08187 L
.25532 .08692 L
.25532 .09229 L
.25532 .09747 L
.25532 .10245 L
.25532 .10775 L
.25532 .11285 L
.25532 .11827 L
.25532 .12349 L
.25532 .12851 L
.25532 .13386 L
.25532 .13901 L
.25532 .14448 L
.25532 .14975 L
.25532 .15482 L
.25532 .16021 L
.25532 .16514 L
s
.3617 .03987 m
.3617 .04495 L
.3617 .0505 L
.3617 .0557 L
.3617 .06071 L
.3617 .06604 L
.3617 .07116 L
.3617 .07662 L
.3617 .08187 L
.3617 .08692 L
.3617 .09229 L
.3617 .09747 L
.3617 .10245 L
.3617 .10775 L
.3617 .11285 L
.3617 .11827 L
.3617 .12349 L
.3617 .12851 L
.3617 .13386 L
.3617 .13901 L
.3617 .14448 L
.3617 .14975 L
.3617 .15482 L
.3617 .16021 L
.3617 .16514 L
s
.46809 .03987 m
.46809 .04495 L
.46809 .0505 L
.46809 .0557 L
.46809 .06071 L
.46809 .06604 L
.46809 .07116 L
.46809 .07662 L
.46809 .08187 L
.46809 .08692 L
.46809 .09229 L
.46809 .09747 L
.46809 .10245 L
.46809 .10775 L
.46809 .11285 L
.46809 .11827 L
.46809 .12349 L
.46809 .12851 L
.46809 .13386 L
.46809 .13901 L
.46809 .14448 L
.46809 .14975 L
.46809 .15482 L
.46809 .16021 L
.46809 .16514 L
s
.57447 .03987 m
.57447 .04495 L
.57447 .0505 L
.57447 .0557 L
.57447 .06071 L
.57447 .06604 L
.57447 .07116 L
.57447 .07662 L
.57447 .08187 L
.57447 .08692 L
.57447 .09229 L
.57447 .09747 L
.57447 .10245 L
.57447 .10775 L
.57447 .11285 L
.57447 .11827 L
.57447 .12349 L
.57447 .12851 L
.57447 .13386 L
.57447 .13901 L
.57447 .14448 L
.57447 .14975 L
.57447 .15482 L
.57447 .16021 L
.57447 .16514 L
s
.68085 .03987 m
.68085 .04495 L
.68085 .0505 L
.68085 .0557 L
.68085 .06071 L
.68085 .06604 L
.68085 .07116 L
.68085 .07662 L
.68085 .08187 L
.68085 .08692 L
.68085 .09229 L
.68085 .09747 L
.68085 .10245 L
.68085 .10775 L
.68085 .11285 L
.68085 .11827 L
.68085 .12349 L
.68085 .12851 L
.68085 .13386 L
.68085 .13901 L
.68085 .14448 L
.68085 .14975 L
.68085 .15482 L
.68085 .16021 L
.68085 .16514 L
s
.78723 .03987 m
.78723 .04495 L
.78723 .0505 L
.78723 .0557 L
.78723 .06071 L
.78723 .06604 L
.78723 .07116 L
.78723 .07662 L
.78723 .08187 L
.78723 .08692 L
.78723 .09229 L
.78723 .09747 L
.78723 .10245 L
.78723 .10775 L
.78723 .11285 L
.78723 .11827 L
.78723 .12349 L
.78723 .12851 L
.78723 .13386 L
.78723 .13901 L
.78723 .14448 L
.78723 .14975 L
.78723 .15482 L
.78723 .16021 L
.78723 .16514 L
s
.89362 .03987 m
.89362 .04495 L
.89362 .0505 L
.89362 .0557 L
.89362 .06071 L
.89362 .06604 L
.89362 .07116 L
.89362 .07662 L
.89362 .08187 L
.89362 .08692 L
.89362 .09229 L
.89362 .09747 L
.89362 .10245 L
.89362 .10775 L
.89362 .11285 L
.89362 .11827 L
.89362 .12349 L
.89362 .12851 L
.89362 .13386 L
.89362 .13901 L
.89362 .14448 L
.89362 .14975 L
.89362 .15482 L
.89362 .16021 L
.89362 .16514 L
s
.04255 .03987 m
.07708 .03987 L
.11473 .03987 L
.15009 .03987 L
.1841 .03987 L
.2203 .03987 L
.25514 .03987 L
.29218 .03987 L
.32786 .03987 L
.36219 .03987 L
.39871 .03987 L
.43387 .03987 L
.46768 .03987 L
.50369 .03987 L
.53833 .03987 L
.57517 .03987 L
.61066 .03987 L
.64479 .03987 L
.68111 .03987 L
.71607 .03987 L
.75323 .03987 L
.78904 .03987 L
.82349 .03987 L
.86013 .03987 L
.89362 .03987 L
s
.04255 .05553 m
.07708 .05553 L
.11473 .05553 L
.15009 .05553 L
.1841 .05553 L
.2203 .05553 L
.25514 .05553 L
.29218 .05553 L
.32786 .05553 L
.36219 .05553 L
.39871 .05553 L
.43387 .05553 L
.46768 .05553 L
.50369 .05553 L
.53833 .05553 L
.57517 .05553 L
.61066 .05553 L
.64479 .05553 L
.68111 .05553 L
.71607 .05553 L
.75323 .05553 L
.78904 .05553 L
.82349 .05553 L
.86013 .05553 L
.89362 .05553 L
s
.04255 .07119 m
.07708 .07119 L
.11473 .07119 L
.15009 .07119 L
.1841 .07119 L
.2203 .07119 L
.25514 .07119 L
.29218 .07119 L
.32786 .07119 L
.36219 .07119 L
.39871 .07119 L
.43387 .07119 L
.46768 .07119 L
.50369 .07119 L
.53833 .07119 L
.57517 .07119 L
.61066 .07119 L
.64479 .07119 L
.68111 .07119 L
.71607 .07119 L
.75323 .07119 L
.78904 .07119 L
.82349 .07119 L
.86013 .07119 L
.89362 .07119 L
s
.04255 .08685 m
.07708 .08685 L
.11473 .08685 L
.15009 .08685 L
.1841 .08685 L
.2203 .08685 L
.25514 .08685 L
.29218 .08685 L
.32786 .08685 L
.36219 .08685 L
.39871 .08685 L
.43387 .08685 L
.46768 .08685 L
.50369 .08685 L
.53833 .08685 L
.57517 .08685 L
.61066 .08685 L
.64479 .08685 L
.68111 .08685 L
.71607 .08685 L
.75323 .08685 L
.78904 .08685 L
.82349 .08685 L
.86013 .08685 L
.89362 .08685 L
s
.04255 .10251 m
.07708 .10251 L
.11473 .10251 L
.15009 .10251 L
.1841 .10251 L
.2203 .10251 L
.25514 .10251 L
.29218 .10251 L
.32786 .10251 L
.36219 .10251 L
.39871 .10251 L
.43387 .10251 L
.46768 .10251 L
.50369 .10251 L
.53833 .10251 L
.57517 .10251 L
.61066 .10251 L
.64479 .10251 L
.68111 .10251 L
.71607 .10251 L
.75323 .10251 L
.78904 .10251 L
.82349 .10251 L
.86013 .10251 L
.89362 .10251 L
s
.04255 .11816 m
.07708 .11816 L
.11473 .11816 L
.15009 .11816 L
.1841 .11816 L
.2203 .11816 L
.25514 .11816 L
.29218 .11816 L
.32786 .11816 L
.36219 .11816 L
.39871 .11816 L
.43387 .11816 L
.46768 .11816 L
.50369 .11816 L
.53833 .11816 L
.57517 .11816 L
.61066 .11816 L
.64479 .11816 L
.68111 .11816 L
.71607 .11816 L
.75323 .11816 L
.78904 .11816 L
.82349 .11816 L
.86013 .11816 L
.89362 .11816 L
s
.04255 .13382 m
.07708 .13382 L
.11473 .13382 L
.15009 .13382 L
.1841 .13382 L
.2203 .13382 L
.25514 .13382 L
.29218 .13382 L
.32786 .13382 L
.36219 .13382 L
.39871 .13382 L
.43387 .13382 L
.46768 .13382 L
.50369 .13382 L
.53833 .13382 L
.57517 .13382 L
.61066 .13382 L
.64479 .13382 L
.68111 .13382 L
.71607 .13382 L
.75323 .13382 L
.78904 .13382 L
.82349 .13382 L
.86013 .13382 L
.89362 .13382 L
s
.04255 .14948 m
.07708 .14948 L
.11473 .14948 L
.15009 .14948 L
.1841 .14948 L
.2203 .14948 L
.25514 .14948 L
.29218 .14948 L
.32786 .14948 L
.36219 .14948 L
.39871 .14948 L
.43387 .14948 L
.46768 .14948 L
.50369 .14948 L
.53833 .14948 L
.57517 .14948 L
.61066 .14948 L
.64479 .14948 L
.68111 .14948 L
.71607 .14948 L
.75323 .14948 L
.78904 .14948 L
.82349 .14948 L
.86013 .14948 L
.89362 .14948 L
s
.04255 .16514 m
.07708 .16514 L
.11473 .16514 L
.15009 .16514 L
.1841 .16514 L
.2203 .16514 L
.25514 .16514 L
.29218 .16514 L
.32786 .16514 L
.36219 .16514 L
.39871 .16514 L
.43387 .16514 L
.46768 .16514 L
.50369 .16514 L
.53833 .16514 L
.57517 .16514 L
.61066 .16514 L
.64479 .16514 L
.68111 .16514 L
.71607 .16514 L
.75323 .16514 L
.78904 .16514 L
.82349 .16514 L
.86013 .16514 L
.89362 .16514 L
s
.04255 .2904 m
.04255 .29549 L
.04255 .30103 L
.04255 .30623 L
.04255 .31124 L
.04255 .31657 L
.04255 .32169 L
.04255 .32715 L
.04255 .3324 L
.04255 .33745 L
.04255 .34283 L
.04255 .348 L
.04255 .35298 L
.04255 .35828 L
.04255 .36338 L
.04255 .3688 L
.04255 .37402 L
.04255 .37904 L
.04255 .38439 L
.04255 .38954 L
.04255 .39501 L
.04255 .40028 L
.04255 .40535 L
.04255 .41074 L
.04255 .41567 L
s
.14894 .2904 m
.14894 .29549 L
.14894 .30103 L
.14894 .30623 L
.14894 .31124 L
.14894 .31657 L
.14894 .32169 L
.14894 .32715 L
.14894 .3324 L
.14894 .33745 L
.14894 .34283 L
.14894 .348 L
.14894 .35298 L
.14894 .35828 L
.14894 .36338 L
.14894 .3688 L
.14894 .37402 L
.14894 .37904 L
.14894 .38439 L
.14894 .38954 L
.14894 .39501 L
.14894 .40028 L
.14894 .40535 L
.14894 .41074 L
.14894 .41567 L
s
.25532 .2904 m
.25532 .29549 L
.25532 .30103 L
.25532 .30623 L
.25532 .31124 L
.25532 .31657 L
.25532 .32169 L
.25532 .32715 L
.25532 .3324 L
.25532 .33745 L
.25532 .34283 L
.25532 .348 L
.25532 .35298 L
.25532 .35828 L
.25532 .36338 L
.25532 .3688 L
.25532 .37402 L
.25532 .37904 L
.25532 .38439 L
.25532 .38954 L
.25532 .39501 L
.25532 .40028 L
.25532 .40535 L
.25532 .41074 L
.25532 .41567 L
s
.3617 .2904 m
.3617 .29549 L
.3617 .30103 L
.3617 .30623 L
.3617 .31124 L
.3617 .31657 L
.3617 .32169 L
.3617 .32715 L
.3617 .3324 L
.3617 .33745 L
.3617 .34283 L
.3617 .348 L
.3617 .35298 L
.3617 .35828 L
.3617 .36338 L
.3617 .3688 L
.3617 .37402 L
.3617 .37904 L
.3617 .38439 L
.3617 .38954 L
.3617 .39501 L
.3617 .40028 L
.3617 .40535 L
.3617 .41074 L
.3617 .41567 L
s
.46809 .2904 m
.46809 .29549 L
.46809 .30103 L
.46809 .30623 L
.46809 .31124 L
.46809 .31657 L
.46809 .32169 L
.46809 .32715 L
.46809 .3324 L
.46809 .33745 L
.46809 .34283 L
.46809 .348 L
.46809 .35298 L
.46809 .35828 L
.46809 .36338 L
.46809 .3688 L
.46809 .37402 L
.46809 .37904 L
.46809 .38439 L
.46809 .38954 L
.46809 .39501 L
.46809 .40028 L
.46809 .40535 L
.46809 .41074 L
.46809 .41567 L
s
.57447 .2904 m
.57447 .29549 L
.57447 .30103 L
.57447 .30623 L
.57447 .31124 L
.57447 .31657 L
.57447 .32169 L
.57447 .32715 L
.57447 .3324 L
.57447 .33745 L
.57447 .34283 L
.57447 .348 L
.57447 .35298 L
.57447 .35828 L
.57447 .36338 L
.57447 .3688 L
.57447 .37402 L
.57447 .37904 L
.57447 .38439 L
.57447 .38954 L
.57447 .39501 L
.57447 .40028 L
.57447 .40535 L
.57447 .41074 L
.57447 .41567 L
s
.68085 .2904 m
.68085 .29549 L
.68085 .30103 L
.68085 .30623 L
.68085 .31124 L
.68085 .31657 L
.68085 .32169 L
.68085 .32715 L
.68085 .3324 L
.68085 .33745 L
.68085 .34283 L
.68085 .348 L
.68085 .35298 L
.68085 .35828 L
.68085 .36338 L
.68085 .3688 L
.68085 .37402 L
.68085 .37904 L
.68085 .38439 L
.68085 .38954 L
.68085 .39501 L
.68085 .40028 L
.68085 .40535 L
.68085 .41074 L
.68085 .41567 L
s
.78723 .2904 m
.78723 .29549 L
.78723 .30103 L
.78723 .30623 L
.78723 .31124 L
.78723 .31657 L
.78723 .32169 L
.78723 .32715 L
.78723 .3324 L
.78723 .33745 L
.78723 .34283 L
.78723 .348 L
.78723 .35298 L
.78723 .35828 L
.78723 .36338 L
.78723 .3688 L
.78723 .37402 L
.78723 .37904 L
.78723 .38439 L
.78723 .38954 L
.78723 .39501 L
.78723 .40028 L
.78723 .40535 L
.78723 .41074 L
.78723 .41567 L
s
.89362 .2904 m
.89362 .29549 L
.89362 .30103 L
.89362 .30623 L
.89362 .31124 L
.89362 .31657 L
.89362 .32169 L
.89362 .32715 L
.89362 .3324 L
.89362 .33745 L
.89362 .34283 L
.89362 .348 L
.89362 .35298 L
.89362 .35828 L
.89362 .36338 L
.89362 .3688 L
.89362 .37402 L
.89362 .37904 L
.89362 .38439 L
.89362 .38954 L
.89362 .39501 L
.89362 .40028 L
.89362 .40535 L
.89362 .41074 L
.89362 .41567 L
s
.04255 .2904 m
.07708 .2904 L
.11473 .2904 L
.15009 .2904 L
.1841 .2904 L
.2203 .2904 L
.25514 .2904 L
.29218 .2904 L
.32786 .2904 L
.36219 .2904 L
.39871 .2904 L
.43387 .2904 L
.46768 .2904 L
.50369 .2904 L
.53833 .2904 L
.57517 .2904 L
.61066 .2904 L
.64479 .2904 L
.68111 .2904 L
.71607 .2904 L
.75323 .2904 L
.78904 .2904 L
.82349 .2904 L
.86013 .2904 L
.89362 .2904 L
s
.04255 .30606 m
.07708 .30606 L
.11473 .30606 L
.15009 .30606 L
.1841 .30606 L
.2203 .30606 L
.25514 .30606 L
.29218 .30606 L
.32786 .30606 L
.36219 .30606 L
.39871 .30606 L
.43387 .30606 L
.46768 .30606 L
.50369 .30606 L
.53833 .30606 L
.57517 .30606 L
.61066 .30606 L
.64479 .30606 L
.68111 .30606 L
.71607 .30606 L
.75323 .30606 L
.78904 .30606 L
.82349 .30606 L
.86013 .30606 L
.89362 .30606 L
s
.04255 .32172 m
.07708 .32172 L
.11473 .32172 L
.15009 .32172 L
.1841 .32172 L
.2203 .32172 L
.25514 .32172 L
.29218 .32172 L
.32786 .32172 L
.36219 .32172 L
.39871 .32172 L
.43387 .32172 L
.46768 .32172 L
.50369 .32172 L
.53833 .32172 L
.57517 .32172 L
.61066 .32172 L
.64479 .32172 L
.68111 .32172 L
.71607 .32172 L
.75323 .32172 L
.78904 .32172 L
.82349 .32172 L
.86013 .32172 L
.89362 .32172 L
s
.04255 .33738 m
.07708 .33738 L
.11473 .33738 L
.15009 .33738 L
.1841 .33738 L
.2203 .33738 L
.25514 .33738 L
.29218 .33738 L
.32786 .33738 L
.36219 .33738 L
.39871 .33738 L
.43387 .33738 L
.46768 .33738 L
.50369 .33738 L
.53833 .33738 L
.57517 .33738 L
.61066 .33738 L
.64479 .33738 L
.68111 .33738 L
.71607 .33738 L
.75323 .33738 L
.78904 .33738 L
.82349 .33738 L
.86013 .33738 L
.89362 .33738 L
s
.04255 .35304 m
.07708 .35304 L
.11473 .35304 L
.15009 .35304 L
.1841 .35304 L
.2203 .35304 L
.25514 .35304 L
.29218 .35304 L
.32786 .35304 L
.36219 .35304 L
.39871 .35304 L
.43387 .35304 L
.46768 .35304 L
.50369 .35304 L
.53833 .35304 L
.57517 .35304 L
.61066 .35304 L
.64479 .35304 L
.68111 .35304 L
.71607 .35304 L
.75323 .35304 L
.78904 .35304 L
.82349 .35304 L
.86013 .35304 L
.89362 .35304 L
s
.04255 .36869 m
.07708 .36869 L
.11473 .36869 L
.15009 .36869 L
.1841 .36869 L
.2203 .36869 L
.25514 .36869 L
.29218 .36869 L
.32786 .36869 L
.36219 .36869 L
.39871 .36869 L
.43387 .36869 L
.46768 .36869 L
.50369 .36869 L
.53833 .36869 L
.57517 .36869 L
.61066 .36869 L
.64479 .36869 L
.68111 .36869 L
.71607 .36869 L
.75323 .36869 L
.78904 .36869 L
.82349 .36869 L
.86013 .36869 L
.89362 .36869 L
s
.04255 .38435 m
.07708 .38435 L
.11473 .38435 L
.15009 .38435 L
.1841 .38435 L
.2203 .38435 L
.25514 .38435 L
.29218 .38435 L
.32786 .38435 L
.36219 .38435 L
.39871 .38435 L
.43387 .38435 L
.46768 .38435 L
.50369 .38435 L
.53833 .38435 L
.57517 .38435 L
.61066 .38435 L
.64479 .38435 L
.68111 .38435 L
.71607 .38435 L
.75323 .38435 L
.78904 .38435 L
.82349 .38435 L
.86013 .38435 L
.89362 .38435 L
s
.04255 .40001 m
.07708 .40001 L
.11473 .40001 L
.15009 .40001 L
.1841 .40001 L
.2203 .40001 L
.25514 .40001 L
.29218 .40001 L
.32786 .40001 L
.36219 .40001 L
.39871 .40001 L
.43387 .40001 L
.46768 .40001 L
.50369 .40001 L
.53833 .40001 L
.57517 .40001 L
.61066 .40001 L
.64479 .40001 L
.68111 .40001 L
.71607 .40001 L
.75323 .40001 L
.78904 .40001 L
.82349 .40001 L
.86013 .40001 L
.89362 .40001 L
s
.04255 .41567 m
.07708 .41567 L
.11473 .41567 L
.15009 .41567 L
.1841 .41567 L
.2203 .41567 L
.25514 .41567 L
.29218 .41567 L
.32786 .41567 L
.36219 .41567 L
.39871 .41567 L
.43387 .41567 L
.46768 .41567 L
.50369 .41567 L
.53833 .41567 L
.57517 .41567 L
.61066 .41567 L
.64479 .41567 L
.68111 .41567 L
.71607 .41567 L
.75323 .41567 L
.78904 .41567 L
.82349 .41567 L
.86013 .41567 L
.89362 .41567 L
s
.04255 .16514 m
.04255 .17022 L
.04255 .17576 L
.04255 .18097 L
.04255 .18597 L
.04255 .1913 L
.04255 .19643 L
.04255 .20188 L
.04255 .20713 L
.04255 .21218 L
.04255 .21756 L
.04255 .22274 L
.04255 .22771 L
.04255 .23301 L
.04255 .23811 L
.04255 .24353 L
.04255 .24876 L
.04255 .25378 L
.04255 .25913 L
.04255 .26427 L
.04255 .26974 L
.04255 .27501 L
.04255 .28008 L
.04255 .28547 L
.04255 .2904 L
s
.14894 .16514 m
.14894 .17022 L
.14894 .17576 L
.14894 .18097 L
.14894 .18597 L
.14894 .1913 L
.14894 .19643 L
.14894 .20188 L
.14894 .20713 L
.14894 .21218 L
.14894 .21756 L
.14894 .22274 L
.14894 .22771 L
.14894 .23301 L
.14894 .23811 L
.14894 .24353 L
.14894 .24876 L
.14894 .25378 L
.14894 .25913 L
.14894 .26427 L
.14894 .26974 L
.14894 .27501 L
.14894 .28008 L
.14894 .28547 L
.14894 .2904 L
s
.25532 .16514 m
.25532 .17022 L
.25532 .17576 L
.25532 .18097 L
.25532 .18597 L
.25532 .1913 L
.25532 .19643 L
.25532 .20188 L
.25532 .20713 L
.25532 .21218 L
.25532 .21756 L
.25532 .22274 L
.25532 .22771 L
.25532 .23301 L
.25532 .23811 L
.25532 .24353 L
.25532 .24876 L
.25532 .25378 L
.25532 .25913 L
.25532 .26427 L
.25532 .26974 L
.25532 .27501 L
.25532 .28008 L
.25532 .28547 L
.25532 .2904 L
s
.3617 .16514 m
.3617 .17022 L
.3617 .17576 L
.3617 .18097 L
.3617 .18597 L
.3617 .1913 L
.3617 .19643 L
.3617 .20188 L
.3617 .20713 L
.3617 .21218 L
.3617 .21756 L
.3617 .22274 L
.3617 .22771 L
.3617 .23301 L
.3617 .23811 L
.3617 .24353 L
.3617 .24876 L
.3617 .25378 L
.3617 .25913 L
.3617 .26427 L
.3617 .26974 L
.3617 .27501 L
.3617 .28008 L
.3617 .28547 L
.3617 .2904 L
s
.46809 .16514 m
.46809 .17022 L
.46809 .17576 L
.46809 .18097 L
.46809 .18597 L
.46809 .1913 L
.46809 .19643 L
.46809 .20188 L
.46809 .20713 L
.46809 .21218 L
.46809 .21756 L
.46809 .22274 L
.46809 .22771 L
.46809 .23301 L
.46809 .23811 L
.46809 .24353 L
.46809 .24876 L
.46809 .25378 L
.46809 .25913 L
.46809 .26427 L
.46809 .26974 L
.46809 .27501 L
.46809 .28008 L
.46809 .28547 L
.46809 .2904 L
s
.57447 .16514 m
.57447 .17022 L
.57447 .17576 L
.57447 .18097 L
.57447 .18597 L
.57447 .1913 L
.57447 .19643 L
.57447 .20188 L
.57447 .20713 L
.57447 .21218 L
.57447 .21756 L
.57447 .22274 L
.57447 .22771 L
.57447 .23301 L
.57447 .23811 L
.57447 .24353 L
.57447 .24876 L
.57447 .25378 L
.57447 .25913 L
.57447 .26427 L
.57447 .26974 L
.57447 .27501 L
.57447 .28008 L
.57447 .28547 L
.57447 .2904 L
s
.68085 .16514 m
.68085 .17022 L
.68085 .17576 L
.68085 .18097 L
.68085 .18597 L
.68085 .1913 L
.68085 .19643 L
.68085 .20188 L
.68085 .20713 L
.68085 .21218 L
.68085 .21756 L
.68085 .22274 L
.68085 .22771 L
.68085 .23301 L
.68085 .23811 L
.68085 .24353 L
.68085 .24876 L
.68085 .25378 L
.68085 .25913 L
.68085 .26427 L
.68085 .26974 L
.68085 .27501 L
.68085 .28008 L
.68085 .28547 L
.68085 .2904 L
s
.78723 .16514 m
.78723 .17022 L
.78723 .17576 L
.78723 .18097 L
.78723 .18597 L
.78723 .1913 L
.78723 .19643 L
.78723 .20188 L
.78723 .20713 L
.78723 .21218 L
.78723 .21756 L
.78723 .22274 L
.78723 .22771 L
.78723 .23301 L
.78723 .23811 L
.78723 .24353 L
.78723 .24876 L
.78723 .25378 L
.78723 .25913 L
.78723 .26427 L
.78723 .26974 L
.78723 .27501 L
.78723 .28008 L
.78723 .28547 L
.78723 .2904 L
s
.89362 .16514 m
.89362 .17022 L
.89362 .17576 L
.89362 .18097 L
.89362 .18597 L
.89362 .1913 L
.89362 .19643 L
.89362 .20188 L
.89362 .20713 L
.89362 .21218 L
.89362 .21756 L
.89362 .22274 L
.89362 .22771 L
.89362 .23301 L
.89362 .23811 L
.89362 .24353 L
.89362 .24876 L
.89362 .25378 L
.89362 .25913 L
.89362 .26427 L
.89362 .26974 L
.89362 .27501 L
.89362 .28008 L
.89362 .28547 L
.89362 .2904 L
s
.04255 .16514 m
.07708 .16514 L
.11473 .16514 L
.15009 .16514 L
.1841 .16514 L
.2203 .16514 L
.25514 .16514 L
.29218 .16514 L
.32786 .16514 L
.36219 .16514 L
.39871 .16514 L
.43387 .16514 L
.46768 .16514 L
.50369 .16514 L
.53833 .16514 L
.57517 .16514 L
.61066 .16514 L
.64479 .16514 L
.68111 .16514 L
.71607 .16514 L
.75323 .16514 L
.78904 .16514 L
.82349 .16514 L
.86013 .16514 L
.89362 .16514 L
s
.04255 .1808 m
.07708 .1808 L
.11473 .1808 L
.15009 .1808 L
.1841 .1808 L
.2203 .1808 L
.25514 .1808 L
.29218 .1808 L
.32786 .1808 L
.36219 .1808 L
.39871 .1808 L
.43387 .1808 L
.46768 .1808 L
.50369 .1808 L
.53833 .1808 L
.57517 .1808 L
.61066 .1808 L
.64479 .1808 L
.68111 .1808 L
.71607 .1808 L
.75323 .1808 L
.78904 .1808 L
.82349 .1808 L
.86013 .1808 L
.89362 .1808 L
s
.04255 .19645 m
.07708 .19645 L
.11473 .19645 L
.15009 .19645 L
.1841 .19645 L
.2203 .19645 L
.25514 .19645 L
.29218 .19645 L
.32786 .19645 L
.36219 .19645 L
.39871 .19645 L
.43387 .19645 L
.46768 .19645 L
.50369 .19645 L
.53833 .19645 L
.57517 .19645 L
.61066 .19645 L
.64479 .19645 L
.68111 .19645 L
.71607 .19645 L
.75323 .19645 L
.78904 .19645 L
.82349 .19645 L
.86013 .19645 L
.89362 .19645 L
s
.04255 .21211 m
.07708 .21211 L
.11473 .21211 L
.15009 .21211 L
.1841 .21211 L
.2203 .21211 L
.25514 .21211 L
.29218 .21211 L
.32786 .21211 L
.36219 .21211 L
.39871 .21211 L
.43387 .21211 L
.46768 .21211 L
.50369 .21211 L
.53833 .21211 L
.57517 .21211 L
.61066 .21211 L
.64479 .21211 L
.68111 .21211 L
.71607 .21211 L
.75323 .21211 L
.78904 .21211 L
.82349 .21211 L
.86013 .21211 L
.89362 .21211 L
s
.04255 .22777 m
.07708 .22777 L
.11473 .22777 L
.15009 .22777 L
.1841 .22777 L
.2203 .22777 L
.25514 .22777 L
.29218 .22777 L
.32786 .22777 L
.36219 .22777 L
.39871 .22777 L
.43387 .22777 L
.46768 .22777 L
.50369 .22777 L
.53833 .22777 L
.57517 .22777 L
.61066 .22777 L
.64479 .22777 L
.68111 .22777 L
.71607 .22777 L
.75323 .22777 L
.78904 .22777 L
.82349 .22777 L
.86013 .22777 L
.89362 .22777 L
s
.04255 .24343 m
.07708 .24343 L
.11473 .24343 L
.15009 .24343 L
.1841 .24343 L
.2203 .24343 L
.25514 .24343 L
.29218 .24343 L
.32786 .24343 L
.36219 .24343 L
.39871 .24343 L
.43387 .24343 L
.46768 .24343 L
.50369 .24343 L
.53833 .24343 L
.57517 .24343 L
.61066 .24343 L
.64479 .24343 L
.68111 .24343 L
.71607 .24343 L
.75323 .24343 L
.78904 .24343 L
.82349 .24343 L
.86013 .24343 L
.89362 .24343 L
s
.04255 .25909 m
.07708 .25909 L
.11473 .25909 L
.15009 .25909 L
.1841 .25909 L
.2203 .25909 L
.25514 .25909 L
.29218 .25909 L
.32786 .25909 L
.36219 .25909 L
.39871 .25909 L
.43387 .25909 L
.46768 .25909 L
.50369 .25909 L
.53833 .25909 L
.57517 .25909 L
.61066 .25909 L
.64479 .25909 L
.68111 .25909 L
.71607 .25909 L
.75323 .25909 L
.78904 .25909 L
.82349 .25909 L
.86013 .25909 L
.89362 .25909 L
s
.04255 .27475 m
.07708 .27475 L
.11473 .27475 L
.15009 .27475 L
.1841 .27475 L
.2203 .27475 L
.25514 .27475 L
.29218 .27475 L
.32786 .27475 L
.36219 .27475 L
.39871 .27475 L
.43387 .27475 L
.46768 .27475 L
.50369 .27475 L
.53833 .27475 L
.57517 .27475 L
.61066 .27475 L
.64479 .27475 L
.68111 .27475 L
.71607 .27475 L
.75323 .27475 L
.78904 .27475 L
.82349 .27475 L
.86013 .27475 L
.89362 .27475 L
s
.04255 .2904 m
.07708 .2904 L
.11473 .2904 L
.15009 .2904 L
.1841 .2904 L
.2203 .2904 L
.25514 .2904 L
.29218 .2904 L
.32786 .2904 L
.36219 .2904 L
.39871 .2904 L
.43387 .2904 L
.46768 .2904 L
.50369 .2904 L
.53833 .2904 L
.57517 .2904 L
.61066 .2904 L
.64479 .2904 L
.68111 .2904 L
.71607 .2904 L
.75323 .2904 L
.78904 .2904 L
.82349 .2904 L
.86013 .2904 L
.89362 .2904 L
s
.04255 .41567 m
.04255 .42075 L
.04255 .42629 L
.04255 .4315 L
.04255 .4365 L
.04255 .44183 L
.04255 .44696 L
.04255 .45241 L
.04255 .45766 L
.04255 .46272 L
.04255 .46809 L
.04255 .47327 L
.04255 .47824 L
.04255 .48354 L
.04255 .48864 L
.04255 .49406 L
.04255 .49929 L
.04255 .50431 L
.04255 .50966 L
.04255 .5148 L
.04255 .52027 L
.04255 .52554 L
.04255 .53061 L
.04255 .536 L
.04255 .54093 L
s
.14894 .41567 m
.14894 .42075 L
.14894 .42629 L
.14894 .4315 L
.14894 .4365 L
.14894 .44183 L
.14894 .44696 L
.14894 .45241 L
.14894 .45766 L
.14894 .46272 L
.14894 .46809 L
.14894 .47327 L
.14894 .47824 L
.14894 .48354 L
.14894 .48864 L
.14894 .49406 L
.14894 .49929 L
.14894 .50431 L
.14894 .50966 L
.14894 .5148 L
.14894 .52027 L
.14894 .52554 L
.14894 .53061 L
.14894 .536 L
.14894 .54093 L
s
.25532 .41567 m
.25532 .42075 L
.25532 .42629 L
.25532 .4315 L
.25532 .4365 L
.25532 .44183 L
.25532 .44696 L
.25532 .45241 L
.25532 .45766 L
.25532 .46272 L
.25532 .46809 L
.25532 .47327 L
.25532 .47824 L
.25532 .48354 L
.25532 .48864 L
.25532 .49406 L
.25532 .49929 L
.25532 .50431 L
.25532 .50966 L
.25532 .5148 L
.25532 .52027 L
.25532 .52554 L
.25532 .53061 L
.25532 .536 L
.25532 .54093 L
s
.3617 .41567 m
.3617 .42075 L
.3617 .42629 L
.3617 .4315 L
.3617 .4365 L
.3617 .44183 L
.3617 .44696 L
.3617 .45241 L
.3617 .45766 L
.3617 .46272 L
.3617 .46809 L
.3617 .47327 L
.3617 .47824 L
.3617 .48354 L
.3617 .48864 L
.3617 .49406 L
.3617 .49929 L
.3617 .50431 L
.3617 .50966 L
.3617 .5148 L
.3617 .52027 L
.3617 .52554 L
.3617 .53061 L
.3617 .536 L
.3617 .54093 L
s
.46809 .41567 m
.46809 .42075 L
.46809 .42629 L
.46809 .4315 L
.46809 .4365 L
.46809 .44183 L
.46809 .44696 L
.46809 .45241 L
.46809 .45766 L
.46809 .46272 L
.46809 .46809 L
.46809 .47327 L
.46809 .47824 L
.46809 .48354 L
.46809 .48864 L
.46809 .49406 L
.46809 .49929 L
.46809 .50431 L
.46809 .50966 L
.46809 .5148 L
.46809 .52027 L
.46809 .52554 L
.46809 .53061 L
.46809 .536 L
.46809 .54093 L
s
.57447 .41567 m
.57447 .42075 L
.57447 .42629 L
.57447 .4315 L
.57447 .4365 L
.57447 .44183 L
.57447 .44696 L
.57447 .45241 L
.57447 .45766 L
.57447 .46272 L
.57447 .46809 L
.57447 .47327 L
.57447 .47824 L
.57447 .48354 L
.57447 .48864 L
.57447 .49406 L
.57447 .49929 L
.57447 .50431 L
.57447 .50966 L
.57447 .5148 L
.57447 .52027 L
.57447 .52554 L
.57447 .53061 L
.57447 .536 L
.57447 .54093 L
s
.68085 .41567 m
.68085 .42075 L
.68085 .42629 L
.68085 .4315 L
.68085 .4365 L
.68085 .44183 L
.68085 .44696 L
.68085 .45241 L
.68085 .45766 L
.68085 .46272 L
.68085 .46809 L
.68085 .47327 L
.68085 .47824 L
.68085 .48354 L
.68085 .48864 L
.68085 .49406 L
.68085 .49929 L
.68085 .50431 L
.68085 .50966 L
.68085 .5148 L
.68085 .52027 L
.68085 .52554 L
.68085 .53061 L
.68085 .536 L
.68085 .54093 L
s
.78723 .41567 m
.78723 .42075 L
.78723 .42629 L
.78723 .4315 L
.78723 .4365 L
.78723 .44183 L
.78723 .44696 L
.78723 .45241 L
.78723 .45766 L
.78723 .46272 L
.78723 .46809 L
.78723 .47327 L
.78723 .47824 L
.78723 .48354 L
.78723 .48864 L
.78723 .49406 L
.78723 .49929 L
.78723 .50431 L
.78723 .50966 L
.78723 .5148 L
.78723 .52027 L
.78723 .52554 L
.78723 .53061 L
.78723 .536 L
.78723 .54093 L
s
.89362 .41567 m
.89362 .42075 L
.89362 .42629 L
.89362 .4315 L
.89362 .4365 L
.89362 .44183 L
.89362 .44696 L
.89362 .45241 L
.89362 .45766 L
.89362 .46272 L
.89362 .46809 L
.89362 .47327 L
.89362 .47824 L
.89362 .48354 L
.89362 .48864 L
.89362 .49406 L
.89362 .49929 L
.89362 .50431 L
.89362 .50966 L
.89362 .5148 L
.89362 .52027 L
.89362 .52554 L
.89362 .53061 L
.89362 .536 L
.89362 .54093 L
s
.04255 .41567 m
.07708 .41567 L
.11473 .41567 L
.15009 .41567 L
.1841 .41567 L
.2203 .41567 L
.25514 .41567 L
.29218 .41567 L
.32786 .41567 L
.36219 .41567 L
.39871 .41567 L
.43387 .41567 L
.46768 .41567 L
.50369 .41567 L
.53833 .41567 L
.57517 .41567 L
.61066 .41567 L
.64479 .41567 L
.68111 .41567 L
.71607 .41567 L
.75323 .41567 L
.78904 .41567 L
.82349 .41567 L
.86013 .41567 L
.89362 .41567 L
s
.04255 .43133 m
.07708 .43133 L
.11473 .43133 L
.15009 .43133 L
.1841 .43133 L
.2203 .43133 L
.25514 .43133 L
.29218 .43133 L
.32786 .43133 L
.36219 .43133 L
.39871 .43133 L
.43387 .43133 L
.46768 .43133 L
.50369 .43133 L
.53833 .43133 L
.57517 .43133 L
.61066 .43133 L
.64479 .43133 L
.68111 .43133 L
.71607 .43133 L
.75323 .43133 L
.78904 .43133 L
.82349 .43133 L
.86013 .43133 L
.89362 .43133 L
s
.04255 .44699 m
.07708 .44699 L
.11473 .44699 L
.15009 .44699 L
.1841 .44699 L
.2203 .44699 L
.25514 .44699 L
.29218 .44699 L
.32786 .44699 L
.36219 .44699 L
.39871 .44699 L
.43387 .44699 L
.46768 .44699 L
.50369 .44699 L
.53833 .44699 L
.57517 .44699 L
.61066 .44699 L
.64479 .44699 L
.68111 .44699 L
.71607 .44699 L
.75323 .44699 L
.78904 .44699 L
.82349 .44699 L
.86013 .44699 L
.89362 .44699 L
s
.04255 .46264 m
.07708 .46264 L
.11473 .46264 L
.15009 .46264 L
.1841 .46264 L
.2203 .46264 L
.25514 .46264 L
.29218 .46264 L
.32786 .46264 L
.36219 .46264 L
.39871 .46264 L
.43387 .46264 L
.46768 .46264 L
.50369 .46264 L
.53833 .46264 L
.57517 .46264 L
.61066 .46264 L
.64479 .46264 L
.68111 .46264 L
.71607 .46264 L
.75323 .46264 L
.78904 .46264 L
.82349 .46264 L
.86013 .46264 L
.89362 .46264 L
s
.04255 .4783 m
.07708 .4783 L
.11473 .4783 L
.15009 .4783 L
.1841 .4783 L
.2203 .4783 L
.25514 .4783 L
.29218 .4783 L
.32786 .4783 L
.36219 .4783 L
.39871 .4783 L
.43387 .4783 L
.46768 .4783 L
.50369 .4783 L
.53833 .4783 L
.57517 .4783 L
.61066 .4783 L
.64479 .4783 L
.68111 .4783 L
.71607 .4783 L
.75323 .4783 L
.78904 .4783 L
.82349 .4783 L
.86013 .4783 L
.89362 .4783 L
s
.04255 .49396 m
.07708 .49396 L
.11473 .49396 L
.15009 .49396 L
.1841 .49396 L
.2203 .49396 L
.25514 .49396 L
.29218 .49396 L
.32786 .49396 L
.36219 .49396 L
.39871 .49396 L
.43387 .49396 L
.46768 .49396 L
.50369 .49396 L
.53833 .49396 L
.57517 .49396 L
.61066 .49396 L
.64479 .49396 L
.68111 .49396 L
.71607 .49396 L
.75323 .49396 L
.78904 .49396 L
.82349 .49396 L
.86013 .49396 L
.89362 .49396 L
s
.04255 .50962 m
.07708 .50962 L
.11473 .50962 L
.15009 .50962 L
.1841 .50962 L
.2203 .50962 L
.25514 .50962 L
.29218 .50962 L
.32786 .50962 L
.36219 .50962 L
.39871 .50962 L
.43387 .50962 L
.46768 .50962 L
.50369 .50962 L
.53833 .50962 L
.57517 .50962 L
.61066 .50962 L
.64479 .50962 L
.68111 .50962 L
.71607 .50962 L
.75323 .50962 L
.78904 .50962 L
.82349 .50962 L
.86013 .50962 L
.89362 .50962 L
s
.04255 .52528 m
.07708 .52528 L
.11473 .52528 L
.15009 .52528 L
.1841 .52528 L
.2203 .52528 L
.25514 .52528 L
.29218 .52528 L
.32786 .52528 L
.36219 .52528 L
.39871 .52528 L
.43387 .52528 L
.46768 .52528 L
.50369 .52528 L
.53833 .52528 L
.57517 .52528 L
.61066 .52528 L
.64479 .52528 L
.68111 .52528 L
.71607 .52528 L
.75323 .52528 L
.78904 .52528 L
.82349 .52528 L
.86013 .52528 L
.89362 .52528 L
s
.04255 .54093 m
.07708 .54093 L
.11473 .54093 L
.15009 .54093 L
.1841 .54093 L
.2203 .54093 L
.25514 .54093 L
.29218 .54093 L
.32786 .54093 L
.36219 .54093 L
.39871 .54093 L
.43387 .54093 L
.46768 .54093 L
.50369 .54093 L
.53833 .54093 L
.57517 .54093 L
.61066 .54093 L
.64479 .54093 L
.68111 .54093 L
.71607 .54093 L
.75323 .54093 L
.78904 .54093 L
.82349 .54093 L
.86013 .54093 L
.89362 .54093 L
s
gsave
.93617 .16514 -66.875 -11.0313 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22.0625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 14.938 moveto
%%IncludeResource: font Symbol
%%IncludeFont: Symbol
/Symbol findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
65.500 14.938 moveto
%%IncludeResource: font Symbol
%%IncludeFont: Symbol
/Symbol findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
70.750 14.938 moveto
%%IncludeResource: font Symbol
%%IncludeFont: Symbol
/Symbol findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.93617 .2904 -68.125 -11.0313 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22.0625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 14.938 moveto
%%IncludeResource: font Symbol
%%IncludeFont: Symbol
/Symbol findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.938 moveto
%%IncludeResource: font Symbol
%%IncludeFont: Symbol
/Symbol findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
68.000 14.938 moveto
(p) show
73.250 14.938 moveto
%%IncludeResource: font Symbol
%%IncludeFont: Symbol
/Symbol findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.93617 .41567 -68.125 -11.0313 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22.0625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 14.938 moveto
%%IncludeResource: font Symbol
%%IncludeFont: Symbol
/Symbol findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.938 moveto
%%IncludeResource: font Symbol
%%IncludeFont: Symbol
/Symbol findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
68.000 14.938 moveto
(p) show
73.250 14.938 moveto
%%IncludeResource: font Symbol
%%IncludeFont: Symbol
/Symbol findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.93617 .54093 -68.125 -11.0313 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22.0625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 14.938 moveto
%%IncludeResource: font Symbol
%%IncludeFont: Symbol
/Symbol findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.938 moveto
%%IncludeResource: font Symbol
%%IncludeFont: Symbol
/Symbol findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
68.000 14.938 moveto
(p) show
73.250 14.938 moveto
%%IncludeResource: font Symbol
%%IncludeFont: Symbol
/Symbol findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
1 0 0 r
.02 w
.73404 .019 Mdot
.73404 .26953 Mdot
.73404 .52006 Mdot
0 g
.5 Mabswid
.89362 .03987 m
1 .03987 L
s
% Start of user PostScript
2. 0 2.5 0 MAarrowhead1
% End of user PostScript
.46809 .57816 m
.46809 .61803 L
s
% Start of user PostScript
0 13.5 0 14.5 MAarrowhead1
% End of user PostScript
gsave
.96809 .07576 -66 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .59411 -69 -9.53125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.0625 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
75.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\
eJztXMFuEzEQdZLdhCYFlFZCQUViywUJrggoH9BeaP4hqpDSAwKVHoETcAnh
CnxBzv2E/kF+I7fyBWFnsna8Xnt3UQ6M47G63tV41n7P8+yos6s9HV2O37wd
XZ6fjZKTi9H78fnZh+T43UVqajWEaCRCiKtEwPUyvcyqZfq3PIQKLPbru3iK
xHA4FFp5heaWWPWDN4jnFtuR06/QZTZgD04RWlpiPp+L6XSKLc9UQ2vjwfM9
P1qN3M+aZrNZrS6qhnpp6S/JD7VYLBSKTYbCSWtBWJ9Yek6KoYRmONJypMGU
fb6ooCPtOG4M4z62d26oCGYdPOBIr6WKxuNxLcq6X7cwtNF5NvQ3S3/H6t7X
bqcTNaenbqef7qYJ1E2wdCuc2mBpr5yacMLl+WAtdXFHu1XgEl2KA6zp2SS1
fag7YIk9J4GmHX9JPNSg/4GGw+3gQhAmQ6dik9Dxpwe3YbmZZqVnroo9jZ10
3PWXeN+go36v/aRTK44E8dddVrwxM/RgobP4GToriKGzgoIPA0GYAUD3Xfy3
NMzShv8s7HnOyfYfj8ecdow4Qdk3ddircMqabpY3eBxgTc8mOXegbjsCRwlw
GQnLPkcJZgDQXVs0JdwBhIEgTFYQCZgBQGcFMfRgobP4GToriKEz9K0Sfw9q
fM/rtr8B6UKNb7TthkriGhrw7qestP+/9DFlia/rNo10HhyY1ux7zs5ms+Vr
dZ64C7Zdd2s2KB4nemNr0LeKohlFKLEZb4L4yzitVBjlbGkZ+MsoEnJV3tdI
+P68a0seOxKEWRc6K4ihBwudxc/QWUEMnRUUfBgIwgwAOoufobOCPIWOSRY0
2dKIrtQoJSZl7GzJzaqsKEE61RQ7OZukJs96YnOd9MWJiIwZMt2zJkp577Jc
+L/kQSnhr87v18mDUkJfxihSm87AVCbBR2WBPRsnCLMudFYQQw8WOoufobOC
GDpDZ/HTgxkAdKoK2opX/filUn6plIYtn2oqpGWaKrXmccppg7wpJTplFJFI
rCKmtUIpZExje7RL3pS1fWL1o9FLdm5rc2m77ZPS1MDt9Nliu+d2L/laLP2m
jpqQH24n23c4vq/cv6jgmx+BgGNiOpk9QdF7itZOBYVkfl/hhD101JWxmCam
568yA7L/vcnEisZf7jM42g==\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2, -1, 0, 0}}],
 StyleBox["     ",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8  scalefont  setfont
% Scaling calculations
0.49904 0.0959693 0.49904 0.0959693 [
[.11516 .48654 -6.96875 -10.9375 ]
[.11516 .48654 6.96875 0 ]
[.3071 .48654 -6.96875 -10.9375 ]
[.3071 .48654 6.96875 0 ]
[.69098 .48654 -4.21875 -10.9375 ]
[.69098 .48654 4.21875 0 ]
[.88292 .48654 -4.21875 -10.9375 ]
[.88292 .48654 4.21875 0 ]
[.48654 .11516 -13.9375 -5.46875 ]
[.48654 .11516 0 5.46875 ]
[.48654 .3071 -13.9375 -5.46875 ]
[.48654 .3071 0 5.46875 ]
[.48654 .69098 -8.4375 -5.46875 ]
[.48654 .69098 0 5.46875 ]
[.48654 .88292 -8.4375 -5.46875 ]
[.48654 .88292 0 5.46875 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11516 .49904 m
.11516 .50529 L
s
gsave
.11516 .48654 -67.9688 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.3071 .49904 m
.3071 .50529 L
s
gsave
.3071 .48654 -67.9688 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.69098 .49904 m
.69098 .50529 L
s
gsave
.69098 .48654 -65.2188 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.88292 .49904 m
.88292 .50529 L
s
gsave
.88292 .48654 -65.2188 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
0 .49904 m
1 .49904 L
s
.49904 .11516 m
.50529 .11516 L
s
gsave
.48654 .11516 -74.9375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.49904 .3071 m
.50529 .3071 L
s
gsave
.48654 .3071 -74.9375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.49904 .69098 m
.50529 .69098 L
s
gsave
.48654 .69098 -69.4375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.49904 .88292 m
.50529 .88292 L
s
gsave
.48654 .88292 -69.4375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.49904 0 m
.49904 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.5 Mabswid
0 .49904 m
.0188 .49904 L
.10233 .49904 L
.1828 .49904 L
.26022 .49904 L
.34258 .49904 L
.42189 .49904 L
.49814 .49904 L
.57933 .49904 L
.65747 .49904 L
.74055 .49904 L
.82058 .49904 L
.89755 .49904 L
.97947 .49904 L
s
.97947 .49904 m
1 .49904 L
s
0 1 1 r
1 1 m
-0.00192 1 L
-0.00192 .49904 L
1 .49904 L
1 1 L
F
.941 1 .941 r
-0.00192 -0.00192 m
1 -0.00192 L
1 .49904 L
-0.00192 .49904 L
-0.00192 -0.00192 L
F
0 g
.51203 .49904 m
.51203 .49909 L
.51203 .49914 L
.51203 .49919 L
.51203 .49924 L
.51203 .49933 L
.51202 .49942 L
.51202 .49953 L
.51201 .49964 L
.512 .49985 L
.51199 .50005 L
.51197 .50025 L
.51192 .50069 L
.51186 .50114 L
.51178 .50155 L
.51157 .50246 L
.51133 .50324 L
.51102 .50407 L
.51024 .50562 L
.5093 .50701 L
.50811 .50834 L
.50681 .50945 L
.50542 .51035 L
.50468 .51074 L
.50384 .51111 L
.50301 .51141 L
.50223 .51163 L
.50141 .51181 L
.50096 .51189 L
.50053 .51194 L
.50012 .51198 L
.49991 .512 L
.49968 .51201 L
.49948 .51202 L
.49937 .51202 L
.49932 .51203 L
.49927 .51203 L
.49923 .51203 L
.49918 .51203 L
.49914 .51203 L
.49909 .51203 L
.49904 .51203 L
.49899 .51203 L
.49894 .51203 L
.49889 .51203 L
.49884 .51203 L
.49879 .51203 L
.49869 .51202 L
.49859 .51202 L
.49847 .51202 L
Mistroke
.49827 .51201 L
.49809 .51199 L
.49766 .51195 L
.49721 .5119 L
.49677 .51183 L
.4963 .51174 L
.49546 .51153 L
.49465 .51126 L
.49381 .51093 L
.49237 .51018 L
.49094 .50919 L
.48971 .50807 L
.48856 .50672 L
.48765 .50528 L
.48695 .50379 L
.48667 .50299 L
.48642 .50212 L
.48633 .50173 L
.48625 .5013 L
.48619 .50093 L
.48614 .50053 L
.4861 .50015 L
.48607 .4998 L
.48606 .49961 L
.48606 .49943 L
.48606 .49934 L
.48605 .49929 L
.48605 .49923 L
.48605 .49918 L
.48605 .49913 L
.48605 .49908 L
.48605 .49904 L
Mfstroke
.52045 .49904 m
.52045 .49912 L
.52045 .4992 L
.52045 .49929 L
.52045 .49937 L
.52045 .49952 L
.52044 .49967 L
.52044 .49985 L
.52043 .50004 L
.52041 .50037 L
.52039 .50071 L
.52036 .50103 L
.52028 .50176 L
.52017 .5025 L
.52005 .50318 L
.5197 .50468 L
.51931 .50596 L
.51879 .50733 L
.5175 .50989 L
.51595 .51218 L
.51399 .51437 L
.51184 .5162 L
.50956 .51769 L
.50834 .51833 L
.50695 .51894 L
.50558 .51943 L
.5043 .5198 L
.50296 .52009 L
.50221 .52022 L
.50149 .52031 L
.50082 .52038 L
.50047 .52041 L
.50009 .52043 L
.49977 .52044 L
.49959 .52045 L
.4995 .52045 L
.49942 .52045 L
.49935 .52045 L
.49928 .52045 L
.4992 .52045 L
.49912 .52045 L
.49904 .52045 L
.49895 .52045 L
.49887 .52045 L
.49879 .52045 L
.4987 .52045 L
.49862 .52045 L
.49846 .52045 L
.49829 .52044 L
.49811 .52043 L
Mistroke
.49778 .52042 L
.49747 .5204 L
.49677 .52033 L
.49602 .52024 L
.4953 .52012 L
.49453 .51997 L
.49315 .51963 L
.4918 .51919 L
.49042 .51864 L
.48804 .51741 L
.48569 .51578 L
.48365 .51393 L
.48177 .5117 L
.48026 .50932 L
.47911 .50687 L
.47864 .50555 L
.47824 .50412 L
.47809 .50347 L
.47795 .50277 L
.47786 .50216 L
.47777 .50149 L
.47771 .50088 L
.47766 .5003 L
.47765 .49998 L
.47764 .49969 L
.47763 .49953 L
.47763 .49945 L
.47763 .49936 L
.47763 .49928 L
.47763 .49919 L
.47763 .49911 L
.47763 .49904 L
Mfstroke
.53435 .49904 m
.53435 .49918 L
.53434 .4993 L
.53434 .49945 L
.53434 .49958 L
.53434 .49982 L
.53433 .50009 L
.53432 .50037 L
.53431 .50068 L
.53428 .50123 L
.53424 .5018 L
.53419 .50232 L
.53406 .50353 L
.53388 .50475 L
.53368 .50586 L
.5331 .50834 L
.53245 .51045 L
.53159 .5127 L
.52948 .51693 L
.52692 .5207 L
.52369 .52431 L
.52015 .52734 L
.51639 .52979 L
.51437 .53084 L
.51209 .53185 L
.50982 .53266 L
.50771 .53326 L
.50549 .53375 L
.50426 .53396 L
.50309 .53411 L
.50197 .53422 L
.5014 .53427 L
.50078 .5343 L
.50024 .53432 L
.49995 .53433 L
.4998 .53434 L
.49967 .53434 L
.49954 .53434 L
.49943 .53434 L
.4993 .53434 L
.49916 .53435 L
.49903 .53435 L
.49889 .53435 L
.49876 .53434 L
.49863 .53434 L
.49849 .53434 L
.49835 .53434 L
.49809 .53433 L
.49781 .53432 L
.4975 .53431 L
Mistroke
.49696 .53428 L
.49645 .53425 L
.49529 .53415 L
.49406 .53399 L
.49287 .5338 L
.4916 .53355 L
.48932 .53298 L
.48711 .53227 L
.48483 .53136 L
.4809 .52933 L
.47703 .52664 L
.47367 .52359 L
.47056 .51991 L
.46807 .51599 L
.46618 .51194 L
.46541 .50977 L
.46474 .50741 L
.4645 .50635 L
.46428 .50519 L
.46411 .50419 L
.46397 .50308 L
.46387 .50207 L
.4638 .50112 L
.46377 .50059 L
.46375 .50011 L
.46374 .49985 L
.46374 .49971 L
.46374 .49956 L
.46374 .49943 L
.46374 .49929 L
.46374 .49916 L
.46374 .49904 L
Mfstroke
.55725 .49904 m
.55725 .49927 L
.55725 .49947 L
.55724 .49971 L
.55724 .49993 L
.55723 .50033 L
.55722 .50076 L
.55721 .50124 L
.55719 .50174 L
.55714 .50265 L
.55707 .50358 L
.557 .50446 L
.55678 .50644 L
.55648 .50845 L
.55615 .51029 L
.55519 .51437 L
.55413 .51785 L
.55271 .52157 L
.54922 .52854 L
.545 .53476 L
.53969 .5407 L
.53384 .5457 L
.52765 .54974 L
.52432 .55147 L
.52055 .55313 L
.51682 .55447 L
.51334 .55546 L
.50968 .55627 L
.50765 .55661 L
.50571 .55687 L
.50387 .55705 L
.50293 .55712 L
.5019 .55718 L
.50103 .55721 L
.50053 .55723 L
.5003 .55724 L
.50008 .55724 L
.49987 .55724 L
.49968 .55725 L
.49947 .55725 L
.49925 .55725 L
.49903 .55725 L
.49879 .55725 L
.49857 .55725 L
.49837 .55724 L
.49813 .55724 L
.4979 .55724 L
.49747 .55723 L
.49701 .55721 L
.49651 .55719 L
Mistroke
.4956 .55715 L
.49477 .55709 L
.49286 .55692 L
.49083 .55667 L
.48887 .55635 L
.48677 .55594 L
.48302 .555 L
.47937 .55382 L
.47561 .55232 L
.46913 .54897 L
.46275 .54455 L
.45721 .53952 L
.45209 .53345 L
.44798 .52699 L
.44486 .52032 L
.44359 .51673 L
.44249 .51285 L
.44209 .51109 L
.44172 .50918 L
.44145 .50753 L
.44122 .50571 L
.44105 .50403 L
.44093 .50246 L
.44089 .5016 L
.44086 .50081 L
.44085 .50037 L
.44084 .50014 L
.44084 .4999 L
.44084 .49969 L
.44083 .49945 L
.44083 .49924 L
.44083 .49904 L
Mfstroke
.59501 .49904 m
.59501 .49941 L
.59501 .49975 L
.595 .50014 L
.595 .50051 L
.59499 .50117 L
.59497 .50188 L
.59494 .50267 L
.59491 .5035 L
.59482 .50499 L
.59472 .50653 L
.59459 .50797 L
.59423 .51124 L
.59375 .51456 L
.5932 .51758 L
.59162 .52431 L
.58986 .53005 L
.58753 .53618 L
.58177 .54768 L
.57482 .55792 L
.56606 .56773 L
.55642 .57597 L
.5462 .58262 L
.54072 .58549 L
.5345 .58822 L
.52835 .59043 L
.52262 .59207 L
.51659 .59339 L
.51323 .59395 L
.51004 .59438 L
.507 .59468 L
.50546 .59479 L
.50376 .59489 L
.50231 .59495 L
.5015 .59498 L
.50111 .59499 L
.50075 .59499 L
.50041 .595 L
.5001 .595 L
.49975 .59501 L
.49938 .59501 L
.49902 .59501 L
.49863 .59501 L
.49827 .59501 L
.49793 .595 L
.49753 .595 L
.49716 .59499 L
.49645 .59497 L
.49569 .59495 L
.49486 .59492 L
Mistroke
.49337 .59484 L
.492 .59475 L
.48884 .59447 L
.4855 .59405 L
.48228 .59353 L
.47882 .59285 L
.47262 .5913 L
.4666 .58936 L
.46041 .58689 L
.44972 .58137 L
.4392 .57407 L
.43008 .56578 L
.42163 .55577 L
.41486 .54512 L
.40971 .53412 L
.40761 .52821 L
.40581 .5218 L
.40515 .51891 L
.40454 .51576 L
.4041 .51303 L
.4037 .51003 L
.40342 .50726 L
.40324 .50468 L
.40316 .50325 L
.40312 .50195 L
.4031 .50123 L
.40309 .50086 L
.40308 .50045 L
.40308 .5001 L
.40307 .49972 L
.40307 .49937 L
.40307 .49904 L
Mfstroke
.65727 .49904 m
.65727 .49965 L
.65726 .50021 L
.65726 .50086 L
.65725 .50147 L
.65723 .50255 L
.6572 .50372 L
.65715 .50502 L
.6571 .50639 L
.65696 .50885 L
.65678 .51139 L
.65658 .51376 L
.65598 .51915 L
.65518 .52463 L
.65429 .52961 L
.65168 .5407 L
.64878 .55017 L
.64494 .56028 L
.63544 .57923 L
.62398 .59612 L
.60953 .6123 L
.59365 .62587 L
.5768 .63684 L
.56776 .64157 L
.5575 .64607 L
.54736 .64971 L
.53791 .65242 L
.52797 .6546 L
.52244 .65553 L
.51718 .65622 L
.51216 .65672 L
.50962 .65691 L
.50682 .65708 L
.50444 .65717 L
.50309 .65721 L
.50246 .65723 L
.50186 .65724 L
.5013 .65725 L
.50078 .65726 L
.50021 .65726 L
.4996 .65727 L
.49901 .65727 L
.49837 .65727 L
.49777 .65726 L
.49721 .65726 L
.49656 .65725 L
.49594 .65724 L
.49477 .65721 L
.49352 .65717 L
.49215 .65712 L
Mistroke
.4897 .65699 L
.48743 .65684 L
.48223 .65637 L
.47672 .65568 L
.4714 .65483 L
.4657 .65371 L
.45548 .65115 L
.44556 .64795 L
.43534 .64388 L
.41773 .63477 L
.40038 .62274 L
.38534 .60908 L
.37141 .59257 L
.36024 .57501 L
.35176 .55687 L
.3483 .54713 L
.34533 .53657 L
.34424 .53179 L
.34323 .52661 L
.3425 .52211 L
.34186 .51716 L
.3414 .5126 L
.34109 .50834 L
.34097 .50599 L
.34089 .50384 L
.34086 .50266 L
.34084 .50203 L
.34083 .50137 L
.34082 .50079 L
.34082 .50016 L
.34081 .49958 L
.34081 .49904 L
Mfstroke
.75991 .49904 m
.75991 .50005 L
.7599 .50097 L
.75989 .50203 L
.75988 .50304 L
.75985 .50483 L
.7598 .50676 L
.75973 .5089 L
.75963 .51116 L
.75941 .51521 L
.75912 .5194 L
.75878 .52331 L
.7578 .5322 L
.75648 .54122 L
.755 .54944 L
.75071 .56773 L
.74592 .58334 L
.73958 .60001 L
.72392 .63126 L
.70504 .6591 L
.68121 .68577 L
.65502 .70815 L
.62724 .72624 L
.61233 .73403 L
.59543 .74145 L
.5787 .74745 L
.56313 .75192 L
.54673 .75552 L
.53762 .75704 L
.52894 .75819 L
.52067 .75901 L
.51649 .75933 L
.51187 .7596 L
.50794 .75976 L
.50573 .75983 L
.50467 .75985 L
.5037 .75987 L
.50276 .75989 L
.50191 .7599 L
.50097 .7599 L
.49996 .75991 L
.49899 .75991 L
.49793 .75991 L
.49694 .7599 L
.49602 .75989 L
.49494 .75988 L
.49392 .75986 L
.492 .75982 L
.48994 .75975 L
.48768 .75966 L
Mistroke
.48364 .75946 L
.47989 .75921 L
.47133 .75844 L
.46224 .7573 L
.45348 .7559 L
.44407 .75405 L
.42723 .74983 L
.41087 .74456 L
.39402 .73784 L
.36497 .72283 L
.33638 .70299 L
.31158 .68046 L
.28862 .65324 L
.2702 .62429 L
.25622 .59439 L
.25051 .57833 L
.24561 .56092 L
.24382 .55304 L
.24216 .54449 L
.24096 .53707 L
.23989 .52892 L
.23913 .52139 L
.23862 .51438 L
.23842 .51049 L
.23829 .50696 L
.23824 .505 L
.23822 .50397 L
.2382 .50288 L
.23818 .50193 L
.23818 .50088 L
.23817 .49993 L
.23817 .49904 L
Mfstroke
.92914 .49904 m
.92914 .50071 L
.92913 .50223 L
.92912 .50398 L
.92909 .50563 L
.92904 .50858 L
.92896 .51177 L
.92884 .51529 L
.92868 .51902 L
.92832 .52571 L
.92783 .5326 L
.92728 .53905 L
.92566 .55371 L
.92348 .56859 L
.92104 .58213 L
.91397 .61228 L
.90607 .63803 L
.89562 .66551 L
.86981 .71703 L
.83867 .76294 L
.79939 .8069 L
.7562 .8438 L
.7104 .87363 L
.68583 .88647 L
.65796 .89871 L
.63038 .9086 L
.6047 .91596 L
.57767 .9219 L
.56265 .92442 L
.54834 .92631 L
.53471 .92766 L
.52781 .92818 L
.52019 .92862 L
.51371 .92889 L
.51006 .929 L
.50833 .92904 L
.50672 .92908 L
.50518 .9291 L
.50377 .92912 L
.50222 .92913 L
.50055 .92914 L
.49895 .92914 L
.49722 .92914 L
.49558 .92913 L
.49406 .92912 L
.49229 .92909 L
.4906 .92906 L
.48743 .92899 L
.48403 .92888 L
.48032 .92874 L
Mistroke
.47365 .92839 L
.46747 .92798 L
.45335 .92671 L
.43836 .92484 L
.42392 .92253 L
.40841 .91949 L
.38064 .91253 L
.35367 .90383 L
.3259 .89275 L
.278 .868 L
.23085 .83529 L
.18997 .79815 L
.15211 .75327 L
.12175 .70554 L
.0987 .65625 L
.08928 .62977 L
.08121 .60106 L
.07825 .58807 L
.07551 .57398 L
.07353 .56174 L
.07177 .5483 L
.07052 .53589 L
.06968 .52433 L
.06935 .51792 L
.06913 .5121 L
.06905 .50887 L
.06901 .50717 L
.06898 .50538 L
.06896 .50381 L
.06895 .50208 L
.06894 .50051 L
.06894 .49904 L
Mfstroke
.51203 .49904 m
.51432 .49904 L
.51727 .49904 L
.52057 .49904 L
.5243 .49904 L
.52899 .49904 L
.53432 .49904 L
.54102 .49904 L
.54869 .49904 L
.55738 .49904 L
.56831 .49904 L
.58076 .49904 L
.59483 .49904 L
.61249 .49904 L
.63255 .49904 L
.65779 .49904 L
.6866 .49904 L
.71924 .49904 L
.76023 .49904 L
.80688 .49904 L
.86562 .49904 L
.93281 .49904 L
s
.93281 .49904 m
1 .49904 L
s
.51104 .50401 m
.51315 .50489 L
.51589 .50602 L
.51893 .50728 L
.52238 .50871 L
.52671 .5105 L
.53163 .51254 L
.53783 .51511 L
.54491 .51804 L
.55294 .52137 L
.56303 .52555 L
.57454 .53031 L
.58754 .5357 L
.60385 .54246 L
.62239 .55013 L
.64571 .55979 L
.67233 .57082 L
.70248 .58331 L
.74035 .59899 L
.78345 .61685 L
.83772 .63933 L
.89979 .66504 L
.97022 .69421 L
s
.97022 .69421 m
1 .70654 L
s
.50822 .50822 m
.50984 .50984 L
.51193 .51193 L
.51426 .51426 L
.5169 .5169 L
.52022 .52022 L
.52398 .52398 L
.52873 .52873 L
.53415 .53415 L
.54029 .54029 L
.54802 .54802 L
.55682 .55682 L
.56677 .56677 L
.57926 .57926 L
.59345 .59345 L
.61129 .61129 L
.63167 .63167 L
.65474 .65474 L
.68373 .68373 L
.71672 .71672 L
.75825 .75825 L
.80576 .80576 L
.85967 .85967 L
.92744 .92744 L
s
.92744 .92744 m
1 1 L
s
.50401 .51104 m
.50489 .51315 L
.50602 .51589 L
.50728 .51893 L
.50871 .52238 L
.5105 .52671 L
.51254 .53163 L
.51511 .53783 L
.51804 .54491 L
.52137 .55294 L
.52555 .56303 L
.53031 .57454 L
.5357 .58754 L
.54246 .60385 L
.55013 .62239 L
.55979 .64571 L
.57082 .67233 L
.58331 .70248 L
.59899 .74035 L
.61685 .78345 L
.63933 .83772 L
.66504 .89979 L
.69421 .97022 L
s
.69421 .97022 m
.70654 1 L
s
.49904 .51203 m
.49904 .51432 L
.49904 .51727 L
.49904 .52057 L
.49904 .5243 L
.49904 .52899 L
.49904 .53432 L
.49904 .54102 L
.49904 .54869 L
.49904 .55738 L
.49904 .56831 L
.49904 .58076 L
.49904 .59483 L
.49904 .61249 L
.49904 .63255 L
.49904 .65779 L
.49904 .6866 L
.49904 .71924 L
.49904 .76023 L
.49904 .80688 L
.49904 .86562 L
.49904 .93281 L
s
.49904 .93281 m
.49904 1 L
s
.49407 .51104 m
.49319 .51315 L
.49206 .51589 L
.4908 .51893 L
.48937 .52238 L
.48758 .52671 L
.48554 .53163 L
.48297 .53783 L
.48004 .54491 L
.47671 .55294 L
.47253 .56303 L
.46777 .57454 L
.46238 .58754 L
.45563 .60385 L
.44795 .62239 L
.43829 .64571 L
.42726 .67233 L
.41477 .70248 L
.39909 .74035 L
.38124 .78345 L
.35876 .83772 L
.33305 .89979 L
.30387 .97022 L
s
.30387 .97022 m
.29154 1 L
s
.48986 .50822 m
.48824 .50984 L
.48615 .51193 L
.48382 .51426 L
.48118 .5169 L
.47786 .52022 L
.4741 .52398 L
.46935 .52873 L
.46393 .53415 L
.45779 .54029 L
.45006 .54802 L
.44126 .55682 L
.43131 .56677 L
.41882 .57926 L
.40463 .59345 L
.38679 .61129 L
.36641 .63167 L
.34334 .65474 L
.31435 .68373 L
.28136 .71672 L
.23983 .75825 L
.19232 .80576 L
.13841 .85967 L
.07064 .92744 L
s
.07064 .92744 m
0 .99808 L
s
.48704 .50401 m
.48493 .50489 L
.48219 .50602 L
.47915 .50728 L
.4757 .50871 L
.47137 .5105 L
.46645 .51254 L
.46025 .51511 L
.45317 .51804 L
.44514 .52137 L
.43505 .52555 L
.42355 .53031 L
.41054 .5357 L
.39423 .54246 L
.37569 .55013 L
.35237 .55979 L
.32575 .57082 L
.2956 .58331 L
.25774 .59899 L
.21463 .61685 L
.16036 .63933 L
.09829 .66504 L
.02786 .69421 L
s
.02786 .69421 m
0 .70575 L
s
.48605 .49904 m
.48376 .49904 L
.48081 .49904 L
.47751 .49904 L
.47378 .49904 L
.46909 .49904 L
.46376 .49904 L
.45706 .49904 L
.44939 .49904 L
.4407 .49904 L
.42977 .49904 L
.41733 .49904 L
.40325 .49904 L
.38559 .49904 L
.36553 .49904 L
.34029 .49904 L
.31148 .49904 L
.27884 .49904 L
.23785 .49904 L
.1912 .49904 L
.13246 .49904 L
.06528 .49904 L
s
.06528 .49904 m
0 .49904 L
s
.48605 .49904 m
.48605 .49899 L
.48605 .49894 L
.48605 .49889 L
.48605 .49884 L
.48606 .49875 L
.48606 .49866 L
.48606 .49855 L
.48607 .49844 L
.48608 .49824 L
.48609 .49803 L
.48611 .49783 L
.48616 .49739 L
.48622 .49694 L
.4863 .49653 L
.48651 .49562 L
.48675 .49484 L
.48706 .49401 L
.48784 .49246 L
.48878 .49107 L
.48997 .48974 L
.49127 .48863 L
.49266 .48773 L
.4934 .48734 L
.49424 .48697 L
.49507 .48667 L
.49585 .48645 L
.49667 .48627 L
.49712 .4862 L
.49755 .48614 L
.49796 .4861 L
.49817 .48608 L
.4984 .48607 L
.4986 .48606 L
.49871 .48606 L
.49876 .48606 L
.49881 .48605 L
.49886 .48605 L
.4989 .48605 L
.49894 .48605 L
.49899 .48605 L
.49904 .48605 L
.4991 .48605 L
.49914 .48605 L
.49919 .48605 L
.49924 .48605 L
.4993 .48605 L
.49939 .48606 L
.49949 .48606 L
.49961 .48606 L
Mistroke
.49981 .48607 L
.49999 .48609 L
.50042 .48613 L
.50087 .48618 L
.50131 .48625 L
.50178 .48634 L
.50262 .48655 L
.50343 .48682 L
.50427 .48715 L
.50572 .4879 L
.50714 .48889 L
.50837 .49001 L
.50952 .49136 L
.51043 .4928 L
.51113 .49429 L
.51141 .49509 L
.51166 .49596 L
.51175 .49635 L
.51183 .49678 L
.51189 .49715 L
.51194 .49755 L
.51198 .49793 L
.51201 .49828 L
.51202 .49847 L
.51202 .49865 L
.51202 .49874 L
.51203 .49879 L
.51203 .49885 L
.51203 .4989 L
.51203 .49895 L
.51203 .499 L
.51203 .49904 L
Mfstroke
.47763 .49904 m
.47763 .49896 L
.47763 .49888 L
.47763 .49879 L
.47763 .49871 L
.47763 .49857 L
.47764 .49841 L
.47764 .49823 L
.47765 .49805 L
.47767 .49771 L
.47769 .49737 L
.47772 .49705 L
.4778 .49632 L
.47791 .49558 L
.47803 .4949 L
.47838 .4934 L
.47878 .49212 L
.4793 .49075 L
.48058 .48819 L
.48213 .4859 L
.48409 .48371 L
.48624 .48188 L
.48852 .48039 L
.48974 .47975 L
.49113 .47914 L
.4925 .47865 L
.49378 .47828 L
.49513 .47799 L
.49587 .47786 L
.49659 .47777 L
.49726 .4777 L
.49761 .47767 L
.49799 .47765 L
.49831 .47764 L
.49849 .47763 L
.49858 .47763 L
.49866 .47763 L
.49873 .47763 L
.4988 .47763 L
.49888 .47763 L
.49896 .47763 L
.49904 .47763 L
.49913 .47763 L
.49921 .47763 L
.49929 .47763 L
.49938 .47763 L
.49946 .47763 L
.49962 .47763 L
.49979 .47764 L
.49997 .47765 L
Mistroke
.5003 .47766 L
.50061 .47768 L
.50132 .47775 L
.50206 .47784 L
.50278 .47796 L
.50355 .47811 L
.50494 .47845 L
.50628 .47889 L
.50766 .47944 L
.51005 .48067 L
.51239 .4823 L
.51443 .48415 L
.51631 .48638 L
.51782 .48876 L
.51897 .49121 L
.51944 .49253 L
.51984 .49396 L
.51999 .49461 L
.52013 .49531 L
.52023 .49592 L
.52031 .49659 L
.52038 .49721 L
.52042 .49778 L
.52043 .4981 L
.52044 .49839 L
.52045 .49855 L
.52045 .49864 L
.52045 .49872 L
.52045 .4988 L
.52045 .49889 L
.52045 .49897 L
.52045 .49904 L
Mfstroke
.46374 .49904 m
.46374 .4989 L
.46374 .49878 L
.46374 .49864 L
.46374 .4985 L
.46374 .49826 L
.46375 .498 L
.46376 .49771 L
.46377 .4974 L
.4638 .49685 L
.46384 .49629 L
.46389 .49576 L
.46402 .49455 L
.4642 .49333 L
.4644 .49222 L
.46498 .48974 L
.46563 .48763 L
.46649 .48538 L
.46861 .48115 L
.47116 .47738 L
.47439 .47377 L
.47793 .47074 L
.48169 .46829 L
.48371 .46724 L
.486 .46623 L
.48826 .46542 L
.49037 .46482 L
.49259 .46433 L
.49382 .46412 L
.49499 .46397 L
.49611 .46386 L
.49668 .46381 L
.4973 .46378 L
.49784 .46376 L
.49814 .46375 L
.49828 .46374 L
.49841 .46374 L
.49854 .46374 L
.49865 .46374 L
.49878 .46374 L
.49892 .46374 L
.49905 .46374 L
.49919 .46374 L
.49932 .46374 L
.49945 .46374 L
.49959 .46374 L
.49973 .46374 L
.49999 .46375 L
.50027 .46376 L
.50058 .46377 L
Mistroke
.50112 .4638 L
.50163 .46383 L
.50279 .46393 L
.50402 .46409 L
.50521 .46428 L
.50648 .46453 L
.50876 .4651 L
.51097 .46581 L
.51325 .46672 L
.51718 .46875 L
.52105 .47144 L
.52441 .47449 L
.52752 .47817 L
.53001 .48209 L
.5319 .48614 L
.53268 .48831 L
.53334 .49067 L
.53358 .49173 L
.53381 .49289 L
.53397 .49389 L
.53411 .495 L
.53422 .49602 L
.53428 .49696 L
.53431 .49749 L
.53433 .49797 L
.53434 .49823 L
.53434 .49837 L
.53434 .49852 L
.53434 .49865 L
.53434 .49879 L
.53435 .49892 L
.53435 .49904 L
Mfstroke
.44083 .49904 m
.44083 .49881 L
.44083 .49861 L
.44084 .49837 L
.44084 .49815 L
.44085 .49775 L
.44086 .49732 L
.44087 .49684 L
.44089 .49634 L
.44094 .49543 L
.44101 .4945 L
.44108 .49363 L
.4413 .49164 L
.4416 .48963 L
.44193 .4878 L
.44289 .48371 L
.44396 .48023 L
.44537 .47651 L
.44886 .46954 L
.45308 .46333 L
.45839 .45738 L
.46424 .45238 L
.47044 .44835 L
.47376 .44661 L
.47753 .44495 L
.48126 .44361 L
.48474 .44262 L
.4884 .44181 L
.49043 .44147 L
.49237 .44122 L
.49421 .44103 L
.49515 .44096 L
.49618 .4409 L
.49706 .44087 L
.49755 .44085 L
.49778 .44085 L
.498 .44084 L
.49821 .44084 L
.4984 .44084 L
.49861 .44083 L
.49884 .44083 L
.49905 .44083 L
.49929 .44083 L
.49951 .44083 L
.49971 .44084 L
.49995 .44084 L
.50018 .44084 L
.50061 .44085 L
.50107 .44087 L
.50157 .44089 L
Mistroke
.50248 .44093 L
.50331 .44099 L
.50522 .44116 L
.50725 .44141 L
.50921 .44173 L
.51131 .44214 L
.51506 .44308 L
.51871 .44426 L
.52247 .44576 L
.52895 .44911 L
.53534 .45353 L
.54087 .45856 L
.54599 .46463 L
.5501 .47109 L
.55322 .47776 L
.55449 .48135 L
.55559 .48523 L
.55599 .48699 L
.55636 .4889 L
.55663 .49056 L
.55687 .49237 L
.55703 .49405 L
.55715 .49562 L
.55719 .49649 L
.55722 .49727 L
.55723 .49771 L
.55724 .49794 L
.55724 .49818 L
.55725 .4984 L
.55725 .49863 L
.55725 .49884 L
.55725 .49904 L
Mfstroke
.40307 .49904 m
.40307 .49867 L
.40307 .49833 L
.40308 .49794 L
.40308 .49757 L
.40309 .49691 L
.40311 .4962 L
.40314 .49541 L
.40317 .49458 L
.40326 .49309 L
.40336 .49155 L
.40349 .49011 L
.40385 .48684 L
.40433 .48352 L
.40488 .4805 L
.40646 .47377 L
.40822 .46803 L
.41055 .4619 L
.41631 .4504 L
.42326 .44016 L
.43202 .43035 L
.44166 .42211 L
.45188 .41546 L
.45736 .41259 L
.46358 .40986 L
.46973 .40766 L
.47546 .40601 L
.48149 .40469 L
.48485 .40413 L
.48804 .4037 L
.49108 .4034 L
.49262 .40329 L
.49432 .40319 L
.49577 .40313 L
.49658 .4031 L
.49697 .40309 L
.49733 .40309 L
.49767 .40308 L
.49798 .40308 L
.49833 .40307 L
.4987 .40307 L
.49906 .40307 L
.49945 .40307 L
.49981 .40307 L
.50015 .40308 L
.50055 .40308 L
.50092 .40309 L
.50163 .40311 L
.50239 .40313 L
.50322 .40316 L
Mistroke
.50471 .40324 L
.50608 .40333 L
.50924 .40361 L
.51258 .40403 L
.5158 .40455 L
.51926 .40523 L
.52546 .40678 L
.53148 .40872 L
.53767 .41119 L
.54836 .41671 L
.55888 .42401 L
.568 .4323 L
.57645 .44231 L
.58322 .45296 L
.58837 .46396 L
.59047 .46987 L
.59227 .47628 L
.59293 .47918 L
.59354 .48232 L
.59398 .48505 L
.59438 .48805 L
.59466 .49082 L
.59484 .4934 L
.59492 .49483 L
.59497 .49613 L
.59498 .49685 L
.59499 .49723 L
.595 .49763 L
.595 .49798 L
.59501 .49836 L
.59501 .49871 L
.59501 .49904 L
Mfstroke
.34081 .49904 m
.34081 .49843 L
.34082 .49787 L
.34082 .49722 L
.34083 .49661 L
.34085 .49553 L
.34088 .49436 L
.34093 .49306 L
.34098 .49169 L
.34112 .48923 L
.3413 .48669 L
.3415 .48432 L
.3421 .47893 L
.3429 .47346 L
.34379 .46847 L
.3464 .45738 L
.3493 .44791 L
.35315 .4378 L
.36264 .41885 L
.3741 .40196 L
.38855 .38579 L
.40443 .37221 L
.42128 .36124 L
.43032 .35651 L
.44058 .35201 L
.45072 .34837 L
.46017 .34566 L
.47011 .34348 L
.47564 .34255 L
.48091 .34186 L
.48592 .34136 L
.48846 .34117 L
.49126 .34101 L
.49364 .34091 L
.49499 .34087 L
.49562 .34085 L
.49622 .34084 L
.49678 .34083 L
.4973 .34082 L
.49787 .34082 L
.49848 .34081 L
.49907 .34081 L
.49971 .34082 L
.50031 .34082 L
.50087 .34082 L
.50152 .34083 L
.50215 .34084 L
.50331 .34087 L
.50456 .34091 L
.50593 .34096 L
Mistroke
.50838 .34109 L
.51065 .34124 L
.51585 .34171 L
.52136 .3424 L
.52668 .34325 L
.53238 .34437 L
.5426 .34693 L
.55252 .35013 L
.56274 .3542 L
.58036 .36331 L
.5977 .37534 L
.61274 .38901 L
.62667 .40551 L
.63784 .42307 L
.64632 .44121 L
.64978 .45095 L
.65275 .46151 L
.65384 .46629 L
.65485 .47147 L
.65558 .47598 L
.65623 .48092 L
.65669 .48548 L
.65699 .48974 L
.65711 .49209 L
.65719 .49424 L
.65723 .49542 L
.65724 .49605 L
.65725 .49671 L
.65726 .49729 L
.65726 .49792 L
.65727 .4985 L
.65727 .49904 L
Mfstroke
.23817 .49904 m
.23817 .49803 L
.23818 .49711 L
.23819 .49605 L
.2382 .49504 L
.23823 .49326 L
.23828 .49132 L
.23836 .48918 L
.23845 .48692 L
.23867 .48287 L
.23896 .47868 L
.2393 .47477 L
.24028 .46588 L
.2416 .45686 L
.24308 .44864 L
.24737 .43035 L
.25217 .41474 L
.2585 .39807 L
.27416 .36682 L
.29305 .33898 L
.31687 .31231 L
.34306 .28994 L
.37084 .27184 L
.38575 .26405 L
.40265 .25663 L
.41938 .25063 L
.43495 .24616 L
.45135 .24257 L
.46046 .24104 L
.46914 .23989 L
.47741 .23907 L
.48159 .23875 L
.48621 .23848 L
.49014 .23832 L
.49236 .23825 L
.49341 .23823 L
.49438 .23821 L
.49532 .2382 L
.49617 .23818 L
.49711 .23818 L
.49812 .23817 L
.49909 .23817 L
.50015 .23817 L
.50114 .23818 L
.50206 .23819 L
.50314 .2382 L
.50416 .23822 L
.50608 .23826 L
.50815 .23833 L
.5104 .23842 L
Mistroke
.51444 .23862 L
.51819 .23887 L
.52676 .23965 L
.53584 .24078 L
.5446 .24218 L
.55401 .24403 L
.57085 .24825 L
.58721 .25352 L
.60406 .26024 L
.63311 .27525 L
.6617 .29509 L
.6865 .31762 L
.70946 .34484 L
.72788 .37379 L
.74186 .40369 L
.74757 .41975 L
.75247 .43716 L
.75426 .44504 L
.75592 .45359 L
.75713 .46101 L
.7582 .46916 L
.75895 .47669 L
.75946 .4837 L
.75966 .48759 L
.75979 .49112 L
.75984 .49308 L
.75987 .49411 L
.75988 .4952 L
.7599 .49615 L
.75991 .4972 L
.75991 .49815 L
.75991 .49904 L
Mfstroke
.06894 .49904 m
.06894 .49737 L
.06895 .49585 L
.06896 .4941 L
.06899 .49245 L
.06904 .4895 L
.06912 .48631 L
.06924 .48279 L
.0694 .47906 L
.06976 .47237 L
.07025 .46548 L
.0708 .45903 L
.07242 .44437 L
.0746 .42949 L
.07704 .41595 L
.08411 .3858 L
.09201 .36005 L
.10246 .33257 L
.12827 .28105 L
.15941 .23514 L
.19869 .19118 L
.24188 .15428 L
.28768 .12445 L
.31225 .11161 L
.34012 .09937 L
.3677 .08948 L
.39338 .08212 L
.42041 .07618 L
.43543 .07366 L
.44974 .07177 L
.46337 .07042 L
.47027 .0699 L
.47789 .06946 L
.48437 .06919 L
.48802 .06908 L
.48975 .06904 L
.49136 .069 L
.4929 .06898 L
.49431 .06896 L
.49586 .06895 L
.49753 .06894 L
.49913 .06894 L
.50086 .06894 L
.5025 .06895 L
.50402 .06896 L
.50579 .06899 L
.50748 .06902 L
.51065 .06909 L
.51405 .0692 L
.51776 .06934 L
Mistroke
.52443 .06969 L
.53061 .0701 L
.54473 .07137 L
.55972 .07324 L
.57416 .07555 L
.58967 .07859 L
.61744 .08555 L
.64441 .09425 L
.67218 .10533 L
.72008 .13008 L
.76723 .16279 L
.80811 .19993 L
.84597 .24481 L
.87633 .29254 L
.89938 .34183 L
.9088 .36831 L
.91687 .39702 L
.91983 .41001 L
.92257 .4241 L
.92455 .43634 L
.92631 .44978 L
.92756 .46219 L
.9284 .47375 L
.92873 .48016 L
.92895 .48598 L
.92903 .48921 L
.92907 .49091 L
.9291 .4927 L
.92912 .49427 L
.92913 .496 L
.92914 .49757 L
.92914 .49904 L
Mfstroke
.48605 .49904 m
.48376 .49904 L
.48081 .49904 L
.47751 .49904 L
.47378 .49904 L
.46909 .49904 L
.46376 .49904 L
.45706 .49904 L
.44939 .49904 L
.4407 .49904 L
.42977 .49904 L
.41733 .49904 L
.40325 .49904 L
.38559 .49904 L
.36553 .49904 L
.34029 .49904 L
.31148 .49904 L
.27884 .49904 L
.23785 .49904 L
.1912 .49904 L
.13246 .49904 L
.06528 .49904 L
s
.06528 .49904 m
0 .49904 L
s
.48704 .49407 m
.48493 .49319 L
.48219 .49206 L
.47915 .4908 L
.4757 .48937 L
.47137 .48758 L
.46645 .48554 L
.46025 .48297 L
.45317 .48004 L
.44514 .47671 L
.43505 .47253 L
.42355 .46777 L
.41054 .46238 L
.39423 .45563 L
.37569 .44795 L
.35237 .43829 L
.32575 .42726 L
.2956 .41477 L
.25774 .39909 L
.21463 .38124 L
.16036 .35876 L
.09829 .33305 L
.02786 .30387 L
s
.02786 .30387 m
0 .29233 L
s
.48986 .48986 m
.48824 .48824 L
.48615 .48615 L
.48382 .48382 L
.48118 .48118 L
.47786 .47786 L
.4741 .4741 L
.46935 .46935 L
.46393 .46393 L
.45779 .45779 L
.45006 .45006 L
.44126 .44126 L
.43131 .43131 L
.41882 .41882 L
.40463 .40463 L
.38679 .38679 L
.36641 .36641 L
.34334 .34334 L
.31435 .31435 L
.28136 .28136 L
.23983 .23983 L
.19232 .19232 L
.13841 .13841 L
.07064 .07064 L
s
.07064 .07064 m
0 0 L
s
.49407 .48704 m
.49319 .48493 L
.49206 .48219 L
.4908 .47915 L
.48937 .4757 L
.48758 .47137 L
.48554 .46645 L
.48297 .46025 L
.48004 .45317 L
.47671 .44514 L
.47253 .43505 L
.46777 .42355 L
.46238 .41054 L
.45563 .39423 L
.44795 .37569 L
.43829 .35237 L
.42726 .32575 L
.41477 .2956 L
.39909 .25774 L
.38124 .21463 L
.35876 .16036 L
.33305 .09829 L
.30387 .02786 L
s
.30387 .02786 m
.29233 0 L
s
.49904 .48605 m
.49904 .48376 L
.49904 .48081 L
.49904 .47751 L
.49904 .47378 L
.49904 .46909 L
.49904 .46376 L
.49904 .45706 L
.49904 .44939 L
.49904 .4407 L
.49904 .42977 L
.49904 .41733 L
.49904 .40325 L
.49904 .38559 L
.49904 .36553 L
.49904 .34029 L
.49904 .31148 L
.49904 .27884 L
.49904 .23785 L
.49904 .1912 L
.49904 .13246 L
.49904 .06528 L
s
.49904 .06528 m
.49904 0 L
s
.50401 .48704 m
.50489 .48493 L
.50602 .48219 L
.50728 .47915 L
.50871 .4757 L
.5105 .47137 L
.51254 .46645 L
.51511 .46025 L
.51804 .45317 L
.52137 .44514 L
.52555 .43505 L
.53031 .42355 L
.5357 .41054 L
.54246 .39423 L
.55013 .37569 L
.55979 .35237 L
.57082 .32575 L
.58331 .2956 L
.59899 .25774 L
.61685 .21463 L
.63933 .16036 L
.66504 .09829 L
.69421 .02786 L
s
.69421 .02786 m
.70575 0 L
s
.50822 .48986 m
.50984 .48824 L
.51193 .48615 L
.51426 .48382 L
.5169 .48118 L
.52022 .47786 L
.52398 .4741 L
.52873 .46935 L
.53415 .46393 L
.54029 .45779 L
.54802 .45006 L
.55682 .44126 L
.56677 .43131 L
.57926 .41882 L
.59345 .40463 L
.61129 .38679 L
.63167 .36641 L
.65474 .34334 L
.68373 .31435 L
.71672 .28136 L
.75825 .23983 L
.80576 .19232 L
.85967 .13841 L
.92744 .07064 L
s
.92744 .07064 m
.99808 0 L
s
.51104 .49407 m
.51315 .49319 L
.51589 .49206 L
.51893 .4908 L
.52238 .48937 L
.52671 .48758 L
.53163 .48554 L
.53783 .48297 L
.54491 .48004 L
.55294 .47671 L
.56303 .47253 L
.57454 .46777 L
.58754 .46238 L
.60385 .45563 L
.62239 .44795 L
.64571 .43829 L
.67233 .42726 L
.70248 .41477 L
.74035 .39909 L
.78345 .38124 L
.83772 .35876 L
.89979 .33305 L
.97022 .30387 L
s
.97022 .30387 m
1 .29154 L
s
.51203 .49904 m
.51432 .49904 L
.51727 .49904 L
.52057 .49904 L
.5243 .49904 L
.52899 .49904 L
.53432 .49904 L
.54102 .49904 L
.54869 .49904 L
.55738 .49904 L
.56831 .49904 L
.58076 .49904 L
.59483 .49904 L
.61249 .49904 L
.63255 .49904 L
.65779 .49904 L
.6866 .49904 L
.71924 .49904 L
.76023 .49904 L
.80688 .49904 L
.86562 .49904 L
.93281 .49904 L
s
.93281 .49904 m
1 .49904 L
s
1 0 0 r
.02 w
.78913 .33156 Mdot
.78913 .33156 Mdot
0 g
.5 Mabswid
.97889 .49904 m
1 .49904 L
s
% Start of user PostScript
5. 0 5.22 0 MAarrowhead1
% End of user PostScript
.49904 .97889 m
.49904 1 L
s
% Start of user PostScript
0 5. 0 5.22 MAarrowhead1
% End of user PostScript
gsave
.97889 .53263 -66 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.51823 .97889 -69 -9.53125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.0625 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
75.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.47025 .88292 -66 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
69.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.47025 .69098 -66 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
69.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.47025 .3071 -69 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.188 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
75.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.47025 .11516 -69 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.188 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
75.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.11516 .47025 -69 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.188 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
75.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.3071 .47025 -69 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.188 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
75.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.69098 .47025 -66 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
69.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.88292 .47025 -66 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
69.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{239, 239},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
  ImageRangeCache->{{{0, 238}, {238, 0}} -> {-5, -5, 0, 0}}],
 StyleBox["  \nFigure 5.1",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  The points ",
 Cell[BoxData[
  RowBox[{"{", 
   SubscriptBox["z", "n"], "}"}]]],
 " in the ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " plane (i.e., the ",
 StyleBox["xy",
  FontFamily->"Courier New"],
 " plane) and their image  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["w", "0"], " ", "=", " ", 
   RowBox[{"exp", 
    RowBox[{"(", 
     SubscriptBox["z", "n"], ")"}]}]}]]],
 " in the w plane (i.e., the ",
 StyleBox["uv",
  FontFamily->"Courier New"],
 " plane)."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 5.1.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["Enter the formula for the points.", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"e", ",", "n", ",", "z", ",", "w"}], "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "0"], " ", "=", " ", 
     RowBox[{
      FractionBox["5", "4"], " ", "+", 
      FractionBox[
       RowBox[{" ", 
        RowBox[{"\[ImaginaryI]", " ", "11", " ", "\[Pi]"}]}], "6"]}]}], ";"}],
    "  ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "n_"], " ", "=", " ", 
     RowBox[{
      SubscriptBox["z", "0"], " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", "2", "\[Pi]", " ", "n"}]}]}], ";"}], 
   "   ", "\n", 
   RowBox[{
    RowBox[{"w", "=", 
     SuperscriptBox["\[ExponentialE]", 
      SubscriptBox["z", "n"]]}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(n\)]\) = \>\"", ",", 
      SubscriptBox["z", "n"]}], "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<w = \!\(\*SuperscriptBox[\(e\), SubscriptBox[\(z\), \(n\)]]\)\>\"", 
     "]"}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = \>\"", ",", "w"}], "]"}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"w", " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", "w", "]"}]}], " ", ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = \>\"", ",", "w"}], "]"}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"w", " ", "=", " ", 
     RowBox[{"Simplify", "[", 
      RowBox[{"w", ",", 
       RowBox[{"Element", "[", 
        RowBox[{"n", ",", "Integers"}], "]"}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = \>\"", ",", "w"}], "]"}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"w", " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", "w", "]"}]}], " ", ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = \>\"", ",", "w"}], "]"}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"w", " ", "=", " ", 
     RowBox[{"Simplify", "[", "w", "]"}]}], " ", ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = \>\"", ",", "w"}], "]"}], ";"}], "  ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399119320140625*^9}],

Cell["Here is another way to look at it.", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", "z", "]"}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"e", ",", "n"}], "]"}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "0"], " ", "=", " ", 
     RowBox[{
      FractionBox["5", "4"], " ", "+", 
      FractionBox[
       RowBox[{" ", 
        RowBox[{"\[ImaginaryI]", " ", "11", " ", "\[Pi]"}]}], "6"]}]}], ";"}],
    "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "n_"], " ", "=", " ", 
     RowBox[{
      SubscriptBox["z", "0"], " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", "2", "\[Pi]", " ", "n"}]}]}], " ", ";"}], 
   "  ", "\n", 
   RowBox[{"Print", "[", 
    RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(0\)]\) = \>\"", ",", 
     SubscriptBox["z", "0"]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Print", "[", 
    RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(n\)]\) = \>\"", ",", 
     SubscriptBox["z", "n"]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"n", "=", "0"}], ",", 
      RowBox[{"n", "\[LessEqual]", "5"}], ",", 
      RowBox[{"n", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Print", "[", 
        RowBox[{
         SuperscriptBox["e", 
          SubscriptBox["z", "n"]], ",", "\"\< = \>\"", ",", 
         RowBox[{"Factor", "[", 
          RowBox[{"ComplexExpand", "[", 
           SuperscriptBox["\[ExponentialE]", 
            SubscriptBox["z", "n"]], "]"}], "]"}]}], "]"}], ";"}]}], "   ", 
     "]"}], ";"}], "  ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399119324921875*^9, 3.4002615805*^9}]
}, Closed]],

Cell[TextData[{
 "\tLet's look at the range of the exponential function.  If ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{"x", " ", "+", 
    RowBox[{"\[ImaginaryI]", " ", "y"}]}]}]]],
 ", we see from identity ",
 StyleBox["(5-1)",
  FontColor->RGBColor[0, 0, 1]],
 " that  ",
 Cell[BoxData[
  SuperscriptBox["\[ExponentialE]", "z"]]],
 "  can never equal zero, as  ",
 Cell[BoxData[
  SuperscriptBox["\[ExponentialE]", "x"]]],
 "  is never zero, and the cosine and sine functions are never zero at the \
same point.  Suppose, then, that  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", "z"], "\[NotEqual]", "0"}]}]]],
 ".  If we write w in its exponential form as  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{"\[Rho]", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}]]}]}]]],
 ",  identity ",
 StyleBox["(5-1)",
  FontColor->RGBColor[0, 0, 1]],
 " gives \n\t\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Rho]", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}]]}], "=", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"x", " "}]], 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", "y"}]]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "Using identity ",
 StyleBox["(5-1)",
  FontColor->RGBColor[0, 0, 1]],
 ", and property ",
 StyleBox["(1-39)",
  FontColor->RGBColor[0, 0, 1]],
 " of Section 1.5 we get \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"\[Rho]", "=", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"x", " "}]]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{"\[Phi]", "=", 
   RowBox[{"y", "+", 
    RowBox[{"2", "n", " ", "\[Pi]"}]}]}]]],
 ", where n is an integer.\nTherefore,\n\t\t\t",
 Cell[BoxData[
  RowBox[{"\[Rho]", "=", 
   RowBox[{
    RowBox[{"|", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"z", " "}]], "|"}], "=", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"x", " "}]]}]}]]],
 ", \n\t\tand\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Phi]", "\[Element]", 
    RowBox[{"arg", 
     RowBox[{"(", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"z", " "}]], ")"}]}]}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Arg", 
      RowBox[{"(", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"z", " "}]], ")"}]}], "+", 
     RowBox[{"2", "n", " ", 
      RowBox[{"\[Pi]", ":", "  ", 
       RowBox[{"n", " ", 
        StyleBox["is",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], 
        StyleBox[" ",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], 
        StyleBox["an",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], 
        StyleBox[" ",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], 
        StyleBox["integer",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]]}]}]}]}], "}"}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "\n\tSolving these equations for x and y, yields\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"x", "=", 
   RowBox[{"ln", " ", "\[Rho]"}]}]]],
 " and  ",
 Cell[BoxData[
  RowBox[{"y", "=", 
   RowBox[{"\[Phi]", "+", 
    RowBox[{"2", "n", " ", "\[Pi]"}]}]}]]],
 ", \n\t\t\t\nwhere ",
 StyleBox["n",
  FontFamily->"Courier New"],
 " is an integer. Thus, for any complex number  ",
 Cell[BoxData[
  RowBox[{"w", "\[NotEqual]", "0"}]]],
 ",  there are infinitely many complex numbers ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{"x", " ", "+", 
    RowBox[{"\[ImaginaryI]", " ", "y"}]}]}]]],
 " such that  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   SuperscriptBox["\[ExponentialE]", "z"]}]]],
 ".  From the previous equations, we see that the numbers ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " are  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{
    RowBox[{"x", "+", 
     RowBox[{"\[ImaginaryI]", " ", "y"}]}], "=", 
    RowBox[{
     RowBox[{"ln", " ", "\[Rho]"}], "+", 
     RowBox[{"\[ImaginaryI]", 
      RowBox[{"(", 
       RowBox[{"\[Phi]", "+", 
        RowBox[{"2", "n", " ", "\[Pi]"}]}], ")"}]}]}]}]}]]],
 "  \n\t\tor\n\t\t\t",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{"ln", " ", "|", "w", "|", 
    RowBox[{
     RowBox[{"+", "\[ImaginaryI]"}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Arg", " ", "w"}], "+", 
       RowBox[{"2", "n", " ", "\[Pi]"}]}], ")"}]}]}]}]]],
 ",  \n\nwhere ",
 StyleBox["n",
  FontFamily->"Courier New"],
 " is an integer. Hence \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"exp", "[", 
     RowBox[{"ln", " ", "|", "w", "|", 
      RowBox[{
       RowBox[{"+", "\[ImaginaryI]"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Arg", " ", "w"}], "+", 
         RowBox[{"2", "n", " ", "\[Pi]"}]}], ")"}]}]}], "]"}], " ", "=", "  ",
     "w"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                           ", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"ln", " ", "|", "w", "|", 
      RowBox[{
       RowBox[{"+", "\[ImaginaryI]"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Arg", " ", "w"}], "+", 
         RowBox[{"2", "n", " ", "\[Pi]"}]}], ")"}]}]}]], "  ", "=", "  ", "w",
     " "}]}]}]],
 "  "
}], "Text"],

Cell[TextData[{
 "\n\tIn summary, the transformation ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   SuperscriptBox["\[ExponentialE]", "z"]}]]],
 " maps the complex plane (infinitely often) onto the set of nonzero complex \
numbers.\n\t\n\tIf we restrict the solutions in equation ",
 StyleBox["(5-9)",
  FontColor->RGBColor[0, 0, 1]],
 " so that only the principal value of the argument,  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"-", "\[Pi]"}], "<", 
   RowBox[{"Arg", " ", "w"}], "\[LessEqual]", "\[Pi]"}]]],
 ",  is used, the transformation  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", "z"], "=", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"x", " ", "+", 
      RowBox[{"\[ImaginaryI]", " ", "y", " "}]}]]}]}]]],
 " maps the horizontal strip  ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}], ":", " ", 
    RowBox[{
     RowBox[{"-", "\[Pi]"}], "<", " ", "y", "\[LessEqual]", "\[Pi]"}]}], 
   "}"}]]],
 ",  one-to-one and onto the range set  ",
 Cell[BoxData[
  RowBox[{"S", "=", 
   RowBox[{"{", 
    RowBox[{"w", ":", " ", 
     RowBox[{"w", "\[NotEqual]", "0"}]}], "}"}]}]]],
 ".  This strip is called the fundamental period strip and is shown in Figure \
5.2."
}], "Text"],

Cell[TextData[{
 "\t\t",
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10  scalefont  setfont
% Scaling calculations
0.489796 0.408163 0.302624 0.0852461 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30262 m
1 .30262 L
s
.4898 0 m
.4898 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.5 Mabswid
0 .30262 m
.16165 .30262 L
.48595 .30262 L
.83127 .30262 L
s
.83127 .30262 m
1 .30262 L
s
.941 1 .941 r
0 .03482 m
.97959 .03482 L
.97959 .57043 L
0 .57043 L
0 .03482 L
F
0 g
.97959 .30262 m
1 .30262 L
s
% Start of user PostScript
1.2 0 1.25 0 MAarrowhead1
% End of user PostScript
.4898 .60098 m
.4898 .60951 L
s
% Start of user PostScript
0 3.5 0 3.6 MAarrowhead1
% End of user PostScript
0 .30262 m
.97959 .30262 L
s
.4898 .03482 m
.4898 .57043 L
s
1 0 1 r
0 .50348 m
.97959 .50348 L
s
1 0 0 r
0 .36958 m
.97959 .36958 L
s
0 0 1 r
[ .025 .025 ] 0 setdash
0 .07945 m
.97959 .07945 L
s
.56 .37 .6 r
.2449 .03482 m
.2449 .57043 L
s
1 .5 0 r
[ ] 0 setdash
.79592 .03482 m
.79592 .57043 L
s
.5 .165 .165 r
.85714 .03482 m
.85714 .57043 L
s
0 1 0 r
0 .57043 m
.97959 .57043 L
s
[ .025 .025 ] 0 setdash
0 .03482 m
.97959 .03482 L
s
0 g
gsave
.97143 .33672 -66 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5102 .60951 -69 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
75.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.44898 .59601 -78 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.875 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344p) show
93.000 13.875 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.44898 .00924 -78 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.000 13.875 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344p) show
93.000 13.875 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{260, 160.625},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\
eJztm71OwzAQgN0mTbt0ByRQJbY+AxIbLPAKSFUFaqUWUOlEoR1g68DMxgvx
Ln0CTO7ODm1kpz9qhG2dozins/2d/86KnPi6M+7dDjvjfrfTuhx1Hnv97lPr
4mGUqqKKEJVYCPHVEiDLVFTRQEgpExBjkEQkUJ1KcNcMujeMxR08gJkmr2aC
UEUpXimYhoadNzRQTORyEYOsVdiCGkh1e/apPenekNTciVSQVIdhTEC2SjiE
DZD0AH/cfNLop3eymsUqISrfl3BvUAOTpOsiZ2KbutBQiHOxkAvVEpDgPlM6
CFp3pXRgReuaSjdrtzPdMcTMDo49ZU4hpw6Ol5DCItVAamwtYdnIUM0NTJqk
eKl1esFIMmtVQcsTtFOnRrb67bkPffUNZofDdm1dYU6Y84zZ4bBd8wnmhDnP
mB0O2zWfYE6Y84zZ4bBd84lQOb7OD5/YRxBXsSjtbeld8FqJ9pY+zqQGyDZu
4aswVzraGqPQVDraEKNwClGlxIrWVT1KM4BFHXU/FzgH+empwx7YhxjHWVn1
LNPRcmVLMrWu03xan5j9f+x9LQDf+P2CyoAkcTmX2XKudSf0ydSZxYffaZjN
bL/9LVSOr/OD2cz20d9C5fg6P5htYkuh/4aU6porHb1709VUOnr3pgvevWXi
d/td861QOb7OD2aHw3bNJ36yn8EL/25/gQf+gm9TFJ9ewL1o3LJ8p+ymAwKW
kwpY02hN2cig+yuIHwVwZ/F1V0RiaNVkqem5kwpJZtF0xOHZ3uH5cx4QlJ1N
zzHE5n6c2I1GWTNVL+hQUFE17qLyCyyfA14=\
\>"],
  ImageRangeCache->{{{0, 259}, {159.625, 0}} -> {-1, -3, 0, 0}}],
 "     ",
 StyleBox["      ",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10  scalefont  setfont
% Scaling calculations
0.493275 0.134504 0.493275 0.134504 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.941 1 .941 r
.49327 .49327 m
.49327 .49327 .44657 0 365.73 arc
F
1 1 1 r
.49327 .49327 m
.49327 .49327 .04051 0 365.73 arc
F
1 0 1 r
.5 Mabswid
[ ] 0 setdash
.49327 .49327 m
.1775 .80905 L
s
1 0 0 r
.49327 .49327 m
.80905 .80905 L
s
0 0 1 r
[ .025 .025 ] 0 setdash
.49327 .49327 m
.10653 .26999 L
s
0 0 0 r
[ ] 0 setdash
.49327 .49327 m
.49327 .96274 L
s
.49327 .49327 m
.96274 .49327 L
s
.49327 .49327 m
.49327 .02381 L
s
.56 .37 .6 r
.0012 w
[ .025 .025 ] 0 setdash
newpath
.49327 .49327 .07382 0 365.73 arc
s
1 .5 0 r
[ ] 0 setdash
newpath
.49327 .49327 .28475 0 365.73 arc
s
.5 .165 .165 r
newpath
.49327 .49327 .33083 0 365.73 arc
s
0 1 0 r
.5 Mabswid
.02381 .49731 m
.49327 .49731 L
s
[ .025 .025 ] 0 setdash
.02381 .48924 m
.49327 .48924 L
s
0 g
[ ] 0 setdash
.94929 .49327 m
.97619 .49327 L
s
% Start of user PostScript
3.39034 0 3.59034 0 MAarrowhead1
% End of user PostScript
.49327 .94929 m
.49327 .97619 L
s
% Start of user PostScript
0 3.39034 0 3.59034 MAarrowhead1
% End of user PostScript
gsave
.96274 .5269 -66 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(u) show
69.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.51345 .96274 -69 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(v) show
75.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{249, 249},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
  ImageRangeCache->{{{0, 248}, {248, 0}} -> {-3, -3, 0, 0}}],
 StyleBox["  \n\t\t\tFigure 5.2",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  The fundamental period strip for the mapping  ",
 Cell[BoxData[
  RowBox[{"w", " ", "=", " ", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", "z"], " ", "=", " ", 
    RowBox[{"exp", 
     RowBox[{"(", "z", ")"}]}]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "\tThe horizontal line  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{"t", "+", 
    RowBox[{"\[ImaginaryI]", " ", "b"}]}]}]]],
 ",  for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"-", "\[Infinity]"}], "<", "t", "<", "\[Infinity]"}]]],
 "   in the z plane, is mapped onto the ray   ",
 Cell[BoxData[
  RowBox[{"w", " ", "=", "  ", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"t", " "}]], 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "b"}]]}], " ", "=", "  ", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", "t"], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"cos", " ", "b"}], "+", 
       RowBox[{"\[ImaginaryI]", " ", "sin", " ", "b"}]}], ")"}]}]}]}]]],
 "  that is inclined at an angle  ",
 Cell[BoxData[
  RowBox[{"\[Phi]", "=", "b"}]]],
 "  in the ",
 StyleBox["w",
  FontFamily->"Courier New"],
 " plane. The vertical segment  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{"a", "+", 
    RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]}]}]]],
 ",  for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"-", "\[Pi]"}], "<", "\[Theta]", "\[LessEqual]", "\[Pi]"}]]],
 "  in the z plane, is mapped onto the circle centered at the origin with \
radius  ",
 Cell[BoxData[
  SuperscriptBox["\[ExponentialE]", "a"]]],
 "  in the w plane.  That is,   ",
 Cell[BoxData[
  RowBox[{"w", " ", "=", "  ", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"a", " "}]], 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]]}], " ", "=", "  ", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", "a"], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"cos", " ", "\[Theta]"}], "+", 
       RowBox[{"\[ImaginaryI]", " ", "sin", " ", "\[Theta]"}]}], 
      ")"}]}]}]}]]],
 ". "
}], "Text"],

Cell[TextData[{
 StyleBox["Example 5.2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Consider a rectangle  ",
 Cell[BoxData[
  RowBox[{"R", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"x", ",", "y"}], ")"}], ":", 
     RowBox[{"a", "\[LessEqual]", "x", "\[LessEqual]", 
      RowBox[{"b", "  ", "and", "  ", "c"}], "\[LessEqual]", "y", 
      "\[LessEqual]", "d"}]}], "}"}]}]]],
 ", where  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"-", "\[Pi]"}], "<", "c", "<", "d", "\[LessEqual]", "\[Pi]"}]]],
 ".  Show that the transformation  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", "z"], "=", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"x", " ", "+", 
      RowBox[{"\[ImaginaryI]", " ", "y"}]}]]}]}]]],
 "  maps the rectangle ",
 Cell[BoxData["R"]],
 " onto a portion of an annular region bounded by two rays. \n\nSolution.  \
The image points in the w plane satisfy the following relationships involving \
the modulus and argument of w:  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[ExponentialE]", "a"], " ", "=", " ", 
   RowBox[{
    RowBox[{"|", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"a", "+", 
       RowBox[{"\[ImaginaryI]", " ", "y"}]}]], "|", 
     RowBox[{"\[LessEqual]", 
      RowBox[{"|", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"x", " ", "+", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}]], "|", 
       RowBox[{"\[LessEqual]", 
        RowBox[{"|", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"b", "+", 
           RowBox[{"\[ImaginaryI]", " ", "y"}]}]], "|"}]}]}]}]}], "=", " ", 
    SuperscriptBox["\[ExponentialE]", "b"]}]}]]],
 ",   and \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"c", "=", 
   RowBox[{
    RowBox[{"Arg", 
     RowBox[{"(", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"x", "+", 
        RowBox[{"\[ImaginaryI]", " ", "c"}]}]], ")"}]}], "\[LessEqual]", 
    RowBox[{"Arg", 
     RowBox[{"(", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"x", "+", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}]], ")"}]}], "\[LessEqual]", 
    RowBox[{"Arg", 
     RowBox[{"(", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"x", "+", 
        RowBox[{"\[ImaginaryI]", " ", "d"}]}]], ")"}]}], "\[LessEqual]", 
    "d"}]}]]],
 ",  \n\nwhich is a portion of the annulus  ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{"\[Rho]", " ", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}]], ":", " ", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", "a"], "\[LessEqual]", "\[Rho]", 
      "\[LessEqual]", 
      SuperscriptBox["\[ExponentialE]", "b"]}]}]}], "}"}]]],
 "  in the w plane subtended by the rays  ",
 Cell[BoxData[
  RowBox[{"\[Phi]", "=", 
   RowBox[{
    RowBox[{"c", "  ", 
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", "\[Phi]"}], "=", "d"}]}]]],
 ".   In Figure 5.3, we show the image of the rectangle  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["R", "*"], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"x", ",", "y"}], ")"}], ":", " ", 
     RowBox[{
      RowBox[{"-", "1"}], "\[LessEqual]", "x", "\[LessEqual]", 
      RowBox[{"1", "  ", 
       StyleBox["and",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "  ", 
       FractionBox[
        RowBox[{"-", "\[Pi]"}], "4"]}], "\[LessEqual]", "y", "\[LessEqual]", 
      FractionBox["\[Pi]", "3"]}]}], "}"}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "\t",
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10  scalefont  setfont
% Scaling calculations
0.488889 0.444444 0.268203 0.23322 [
[1.025 .2682 0 -6.5 ]
[1.025 .2682 9 6.5 ]
[.48889 .64303 -4.34375 0 ]
[.48889 .64303 4.34375 13 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .2682 m
1 .2682 L
s
gsave
1.025 .2682 -61 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
68.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.48889 0 m
.48889 .61803 L
s
gsave
.48889 .64303 -65.3438 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
67.688 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.5 Mabswid
0 .2682 m
.13158 .2682 L
.4847 .2682 L
.86072 .2682 L
s
.86072 .2682 m
1 .2682 L
s
.941 1 .941 r
.04444 .08503 m
.93333 .08503 L
.93333 .51243 L
.04444 .51243 L
.04444 .08503 L
F
0 g
.04444 .08503 m
.04444 .10237 L
.04444 .12128 L
.04444 .13904 L
.04444 .15612 L
.04444 .1743 L
.04444 .19179 L
.04444 .21039 L
.04444 .22831 L
.04444 .24555 L
.04444 .26389 L
.04444 .28155 L
.04444 .29853 L
.04444 .31661 L
.04444 .33401 L
.04444 .35251 L
.04444 .37033 L
.04444 .38747 L
.04444 .40571 L
.04444 .42327 L
.04444 .44193 L
.04444 .45991 L
.04444 .47721 L
.04444 .49561 L
.04444 .51243 L
s
.26667 .08503 m
.26667 .10237 L
.26667 .12128 L
.26667 .13904 L
.26667 .15612 L
.26667 .1743 L
.26667 .19179 L
.26667 .21039 L
.26667 .22831 L
.26667 .24555 L
.26667 .26389 L
.26667 .28155 L
.26667 .29853 L
.26667 .31661 L
.26667 .33401 L
.26667 .35251 L
.26667 .37033 L
.26667 .38747 L
.26667 .40571 L
.26667 .42327 L
.26667 .44193 L
.26667 .45991 L
.26667 .47721 L
.26667 .49561 L
.26667 .51243 L
s
.48889 .08503 m
.48889 .10237 L
.48889 .12128 L
.48889 .13904 L
.48889 .15612 L
.48889 .1743 L
.48889 .19179 L
.48889 .21039 L
.48889 .22831 L
.48889 .24555 L
.48889 .26389 L
.48889 .28155 L
.48889 .29853 L
.48889 .31661 L
.48889 .33401 L
.48889 .35251 L
.48889 .37033 L
.48889 .38747 L
.48889 .40571 L
.48889 .42327 L
.48889 .44193 L
.48889 .45991 L
.48889 .47721 L
.48889 .49561 L
.48889 .51243 L
s
.71111 .08503 m
.71111 .10237 L
.71111 .12128 L
.71111 .13904 L
.71111 .15612 L
.71111 .1743 L
.71111 .19179 L
.71111 .21039 L
.71111 .22831 L
.71111 .24555 L
.71111 .26389 L
.71111 .28155 L
.71111 .29853 L
.71111 .31661 L
.71111 .33401 L
.71111 .35251 L
.71111 .37033 L
.71111 .38747 L
.71111 .40571 L
.71111 .42327 L
.71111 .44193 L
.71111 .45991 L
.71111 .47721 L
.71111 .49561 L
.71111 .51243 L
s
.93333 .08503 m
.93333 .10237 L
.93333 .12128 L
.93333 .13904 L
.93333 .15612 L
.93333 .1743 L
.93333 .19179 L
.93333 .21039 L
.93333 .22831 L
.93333 .24555 L
.93333 .26389 L
.93333 .28155 L
.93333 .29853 L
.93333 .31661 L
.93333 .33401 L
.93333 .35251 L
.93333 .37033 L
.93333 .38747 L
.93333 .40571 L
.93333 .42327 L
.93333 .44193 L
.93333 .45991 L
.93333 .47721 L
.93333 .49561 L
.93333 .51243 L
s
.04444 .08503 m
.0805 .08503 L
.11983 .08503 L
.15676 .08503 L
.19228 .08503 L
.23009 .08503 L
.26648 .08503 L
.30517 .08503 L
.34243 .08503 L
.37829 .08503 L
.41643 .08503 L
.45316 .08503 L
.48847 .08503 L
.52607 .08503 L
.56226 .08503 L
.60074 .08503 L
.6378 .08503 L
.67344 .08503 L
.71138 .08503 L
.7479 .08503 L
.78671 .08503 L
.82411 .08503 L
.86009 .08503 L
.89836 .08503 L
.93333 .08503 L
s
.04444 .14609 m
.0805 .14609 L
.11983 .14609 L
.15676 .14609 L
.19228 .14609 L
.23009 .14609 L
.26648 .14609 L
.30517 .14609 L
.34243 .14609 L
.37829 .14609 L
.41643 .14609 L
.45316 .14609 L
.48847 .14609 L
.52607 .14609 L
.56226 .14609 L
.60074 .14609 L
.6378 .14609 L
.67344 .14609 L
.71138 .14609 L
.7479 .14609 L
.78671 .14609 L
.82411 .14609 L
.86009 .14609 L
.89836 .14609 L
.93333 .14609 L
s
.04444 .20715 m
.0805 .20715 L
.11983 .20715 L
.15676 .20715 L
.19228 .20715 L
.23009 .20715 L
.26648 .20715 L
.30517 .20715 L
.34243 .20715 L
.37829 .20715 L
.41643 .20715 L
.45316 .20715 L
.48847 .20715 L
.52607 .20715 L
.56226 .20715 L
.60074 .20715 L
.6378 .20715 L
.67344 .20715 L
.71138 .20715 L
.7479 .20715 L
.78671 .20715 L
.82411 .20715 L
.86009 .20715 L
.89836 .20715 L
.93333 .20715 L
s
.04444 .2682 m
.0805 .2682 L
.11983 .2682 L
.15676 .2682 L
.19228 .2682 L
.23009 .2682 L
.26648 .2682 L
.30517 .2682 L
.34243 .2682 L
.37829 .2682 L
.41643 .2682 L
.45316 .2682 L
.48847 .2682 L
.52607 .2682 L
.56226 .2682 L
.60074 .2682 L
.6378 .2682 L
.67344 .2682 L
.71138 .2682 L
.7479 .2682 L
.78671 .2682 L
.82411 .2682 L
.86009 .2682 L
.89836 .2682 L
.93333 .2682 L
s
.04444 .32926 m
.0805 .32926 L
.11983 .32926 L
.15676 .32926 L
.19228 .32926 L
.23009 .32926 L
.26648 .32926 L
.30517 .32926 L
.34243 .32926 L
.37829 .32926 L
.41643 .32926 L
.45316 .32926 L
.48847 .32926 L
.52607 .32926 L
.56226 .32926 L
.60074 .32926 L
.6378 .32926 L
.67344 .32926 L
.71138 .32926 L
.7479 .32926 L
.78671 .32926 L
.82411 .32926 L
.86009 .32926 L
.89836 .32926 L
.93333 .32926 L
s
.04444 .39032 m
.0805 .39032 L
.11983 .39032 L
.15676 .39032 L
.19228 .39032 L
.23009 .39032 L
.26648 .39032 L
.30517 .39032 L
.34243 .39032 L
.37829 .39032 L
.41643 .39032 L
.45316 .39032 L
.48847 .39032 L
.52607 .39032 L
.56226 .39032 L
.60074 .39032 L
.6378 .39032 L
.67344 .39032 L
.71138 .39032 L
.7479 .39032 L
.78671 .39032 L
.82411 .39032 L
.86009 .39032 L
.89836 .39032 L
.93333 .39032 L
s
.04444 .45137 m
.0805 .45137 L
.11983 .45137 L
.15676 .45137 L
.19228 .45137 L
.23009 .45137 L
.26648 .45137 L
.30517 .45137 L
.34243 .45137 L
.37829 .45137 L
.41643 .45137 L
.45316 .45137 L
.48847 .45137 L
.52607 .45137 L
.56226 .45137 L
.60074 .45137 L
.6378 .45137 L
.67344 .45137 L
.71138 .45137 L
.7479 .45137 L
.78671 .45137 L
.82411 .45137 L
.86009 .45137 L
.89836 .45137 L
.93333 .45137 L
s
.04444 .51243 m
.0805 .51243 L
.11983 .51243 L
.15676 .51243 L
.19228 .51243 L
.23009 .51243 L
.26648 .51243 L
.30517 .51243 L
.34243 .51243 L
.37829 .51243 L
.41643 .51243 L
.45316 .51243 L
.48847 .51243 L
.52607 .51243 L
.56226 .51243 L
.60074 .51243 L
.6378 .51243 L
.67344 .51243 L
.71138 .51243 L
.7479 .51243 L
.78671 .51243 L
.82411 .51243 L
.86009 .51243 L
.89836 .51243 L
.93333 .51243 L
s
gsave
.42222 .55441 -73.8438 -14.5313 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 29.0625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 16.813 moveto
%%IncludeResource: font Symbol
%%IncludeFont: Symbol
/Symbol findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.063 16.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
%%BeginResource: font Times-Roman-MISO
%%BeginFont: Times-Roman-MISO
/Times-Roman /Times-Roman-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
67.875 16.813 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
76.875 9.563 moveto
%%IncludeResource: font Symbol
%%IncludeFont: Symbol
/Symbol findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.750 16.813 moveto
(\\200\\200) show
78.500 16.813 moveto
(\\200\\200) show
81.250 16.813 moveto
(\\200) show
81.625 16.813 moveto
(\\200) show
77.000 24.000 moveto
%%IncludeResource: font Symbol
%%IncludeFont: Symbol
/Symbol findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
84.688 16.813 moveto
%%IncludeResource: font Symbol
%%IncludeFont: Symbol
/Symbol findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.42222 .03606 -77.0313 -14.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 29 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 16.813 moveto
%%IncludeResource: font Symbol
%%IncludeFont: Symbol
/Symbol findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.063 16.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
%%BeginResource: font Times-Roman-MISO
%%BeginFont: Times-Roman-MISO
/Times-Roman /Times-Roman-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
67.875 16.813 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
74.313 16.813 moveto
(-) show
83.250 9.563 moveto
%%IncludeResource: font Symbol
%%IncludeFont: Symbol
/Symbol findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
82.125 16.813 moveto
(\\200\\200) show
84.875 16.813 moveto
(\\200\\200) show
87.625 16.813 moveto
(\\200) show
88.000 16.813 moveto
(\\200) show
83.375 24.000 moveto
%%IncludeResource: font Symbol
%%IncludeFont: Symbol
/Symbol findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
91.063 16.813 moveto
%%IncludeResource: font Symbol
%%IncludeFont: Symbol
/Symbol findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.02222 .23322 -68.9375 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.375 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
74.875 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.95556 .23322 -67.125 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
65.750 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
71.250 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.93333 .2682 m
1 .2682 L
s
% Start of user PostScript
1. 0 1.15 0 MAarrowhead1
% End of user PostScript
.48889 .59471 m
.48889 .61803 L
s
% Start of user PostScript
0 1.4 0 1.5 MAarrowhead1
% End of user PostScript
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{296, 182.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\
eJztm11OwkAQx5eWT/H7Ixp9wfCiXkC9gD55CEJMQCUa5EkEfVIvId7CQ/nE
DSozhS0s2y3loxDyb9LudGe2v+nslE277E2hVrqtFGrlYiF3XS08lcrF59zV
Y7VTZceEiJ0IIX5zgmSnI3YPX8JxHGELPulItH/zUbxrVImpmTeoSJAiGWAk
4gOqzpbyb9FUVAHmJSosUuxJyWB+p1HthLtv3SWOAszZLZukuHQ1yDwjzblh
mqS4f8OyPtLWKFAviJaUDv3NDSlnUKkdSzuTDLFuSnfcIIjeZmjzpkkgQ4aG
NOeETga4MF6Adqn4I8VZX0XXtu20eT/nY3DdRYBdj30CFFBAAQXUEqMwqgAF
FFBAAYVRZSFRW1wMvb9fTpmm+4JwvCgeeJ884nP3Zf7R2FBUtFkRJKSl4eZd
aZMKKypHbEnLL0qfLOdvz5KhUjJv1vk8MaDtpfRqxA7xR8Os5tlac6U0FVyT
cQ/DSRi1yymqWfF3OTJHbA86985czmcGKKCAAio8Cm+BQAEFFFBAYVQBCiig
gAJqEVEYVYACCiiggJrNqDLeX79fqGCNOkHUZ9TQqNJTM69TYU3XhXt5TXfu
ZmjmVp1b6mtb0aiyMkwhGx4EmCvrM7ZHMWcXeFWGYb3Jg/6+rVFQXvS8VRn7
Y6WXQVXXqJg0UqqIwVUZhjavioo23RSnwZzDzNN//U8NT6smVdWHDHDLrfiU
qROugm/zZ5II88np7ORPDbo1icPqBdWQhFZxZ/hM3I4ZJBH7BzZIWHk=\
\>"],
  ImageRangeCache->{{{0, 295}, {181.875, 0}} -> {-1, -1, 0, 0}}],
 StyleBox["     ",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.28571 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10  scalefont  setfont
% Scaling calculations
0.0571429 0.285714 0.571429 0.285714 [
[.91429 .55893 -7.5 -13 ]
[.91429 .55893 7.5 0 ]
[.04464 0 -16.375 -6.5 ]
[.04464 0 0 6.5 ]
[.04464 .28571 -16.375 -6.5 ]
[.04464 .28571 0 6.5 ]
[.04464 .85714 -9.5 -6.5 ]
[.04464 .85714 0 6.5 ]
[.04464 1.14286 -9.5 -6.5 ]
[.04464 1.14286 0 6.5 ]
[ 0 0 0 0 ]
[ 1 1.28571 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.91429 .57143 m
.91429 .57768 L
s
gsave
.91429 .55893 -68.5 -17 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
68.500 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
74.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .57143 m
1 .57143 L
s
.05714 0 m
.06339 0 L
s
gsave
.04464 0 -77.375 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.875 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.05714 .28571 m
.06339 .28571 L
s
gsave
.04464 .28571 -77.375 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.875 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.05714 .85714 m
.06339 .85714 L
s
gsave
.04464 .85714 -70.5 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.05714 1.14286 m
.06339 1.14286 L
s
gsave
.04464 1.14286 -70.5 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.05714 0 m
.05714 1.28571 L
s
0 0 m
1 0 L
1 1.28571 L
0 1.28571 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.5 Mabswid
.13147 .49711 m
.13678 .50283 L
.14207 .50951 L
.14654 .51615 L
.15034 .52284 L
.15385 .53024 L
.15666 .53761 L
.15904 .54564 L
.15999 .54973 L
.16072 .55354 L
.16129 .55727 L
.16153 .55918 L
.16176 .56124 L
.16194 .56329 L
.16207 .56517 L
.16212 .56608 L
.16216 .56707 L
.16219 .56794 L
.16222 .56887 L
.16223 .56943 L
.16224 .56995 L
.16224 .5702 L
.16225 .57044 L
.16225 .57069 L
.16225 .57082 L
.16225 .57096 L
.16225 .5712 L
.16225 .57147 L
.16225 .57172 L
.16225 .57195 L
.16225 .57216 L
.16225 .57239 L
.16224 .57285 L
.16224 .57312 L
.16223 .5734 L
.16222 .5739 L
.16219 .57504 L
.16215 .57602 L
.1621 .57709 L
.16197 .57916 L
.16181 .58105 L
.16134 .58526 L
.16076 .58909 L
.15997 .59322 L
.15793 .60124 L
.15539 .60879 L
.1524 .61585 L
.14867 .6231 L
.14456 .62979 L
.13965 .63654 L
Mistroke
.13444 .64266 L
.12899 .64815 L
.12277 .65353 L
.1164 .65824 L
.1097 .66246 L
Mfstroke
.17968 .44889 m
.18844 .45833 L
.19717 .46934 L
.20453 .48028 L
.21081 .49131 L
.21658 .50352 L
.22122 .51566 L
.22514 .52891 L
.2267 .53566 L
.22791 .54193 L
.22886 .54808 L
.22926 .55123 L
.22962 .55462 L
.22992 .55801 L
.23013 .56112 L
.23021 .56261 L
.23029 .56424 L
.23034 .56567 L
.23039 .56721 L
.23041 .56814 L
.23042 .56899 L
.23043 .56941 L
.23043 .5698 L
.23043 .57021 L
.23043 .57042 L
.23044 .57065 L
.23044 .57106 L
.23044 .57149 L
.23044 .5719 L
.23044 .57229 L
.23043 .57263 L
.23043 .57301 L
.23042 .57377 L
.23041 .57422 L
.23041 .57468 L
.23039 .57551 L
.23034 .57738 L
.23027 .579 L
.23019 .58076 L
.22997 .58418 L
.22971 .58728 L
.22893 .59423 L
.22797 .60055 L
.22667 .60736 L
.22332 .62059 L
.21912 .63303 L
.2142 .64467 L
.20805 .65662 L
.20127 .66765 L
.19318 .67878 L
Mistroke
.18458 .68887 L
.1756 .69792 L
.16534 .7068 L
.15483 .71456 L
.14379 .72151 L
Mfstroke
.25917 .3694 m
.27362 .38496 L
.28801 .40311 L
.30015 .42116 L
.31049 .43934 L
.32001 .45947 L
.32766 .47949 L
.33412 .50133 L
.3367 .51245 L
.33869 .5228 L
.34025 .53293 L
.34091 .53812 L
.34151 .54372 L
.342 .54931 L
.34235 .55443 L
.34249 .55689 L
.34261 .55958 L
.3427 .56193 L
.34277 .56448 L
.34281 .566 L
.34283 .5674 L
.34284 .56809 L
.34284 .56874 L
.34285 .56941 L
.34285 .56977 L
.34285 .57015 L
.34286 .57081 L
.34286 .57153 L
.34286 .57221 L
.34285 .57284 L
.34285 .57341 L
.34285 .57403 L
.34283 .5753 L
.34282 .57602 L
.34281 .57679 L
.34278 .57816 L
.34269 .58124 L
.34258 .58391 L
.34244 .58682 L
.34208 .59246 L
.34166 .59757 L
.34037 .60902 L
.33879 .61944 L
.33665 .63067 L
.33112 .65247 L
.32419 .673 L
.31609 .69218 L
.30594 .71189 L
.29477 .73007 L
.28143 .74843 L
Mistroke
.26725 .76505 L
.25244 .77997 L
.23553 .79461 L
.21821 .80742 L
.2 .81886 L
Mfstroke
.39023 .23834 m
.41406 .264 L
.43778 .29391 L
.45779 .32367 L
.47484 .35365 L
.49053 .38684 L
.50315 .41984 L
.51381 .45586 L
.51806 .47419 L
.52133 .49125 L
.52391 .50795 L
.52499 .51652 L
.52599 .52575 L
.52679 .53496 L
.52737 .5434 L
.5276 .54746 L
.5278 .55189 L
.52795 .55577 L
.52807 .55997 L
.52812 .56248 L
.52816 .56479 L
.52817 .56593 L
.52819 .56699 L
.52819 .56811 L
.5282 .56869 L
.5282 .56933 L
.5282 .57042 L
.52821 .5716 L
.5282 .57272 L
.5282 .57376 L
.52819 .57469 L
.52819 .57572 L
.52816 .5778 L
.52815 .579 L
.52812 .58027 L
.52808 .58252 L
.52793 .58761 L
.52776 .592 L
.52752 .5968 L
.52693 .6061 L
.52623 .61453 L
.52411 .6334 L
.52151 .65059 L
.51797 .66911 L
.50886 .70505 L
.49744 .73888 L
.48407 .77051 L
.46735 .80302 L
.44892 .83299 L
.42693 .86325 L
Mistroke
.40354 .89066 L
.37913 .91526 L
.35125 .9394 L
.3227 .96051 L
.29267 .97938 L
Mfstroke
.60632 .02225 m
.64559 .06456 L
.68471 .11388 L
.7177 .16295 L
.74581 .21237 L
.77168 .26709 L
.79248 .32151 L
.81006 .38088 L
.81707 .41111 L
.82246 .43924 L
.82671 .46678 L
.8285 .48089 L
.83013 .49612 L
.83146 .5113 L
.83242 .52522 L
.83279 .53191 L
.83313 .53922 L
.83337 .54562 L
.83357 .55254 L
.83365 .55668 L
.83372 .56048 L
.83374 .56236 L
.83376 .56412 L
.83378 .56595 L
.83378 .56692 L
.83379 .56796 L
.83379 .56976 L
.83379 .57172 L
.83379 .57356 L
.83379 .57527 L
.83378 .57681 L
.83376 .57851 L
.83372 .58194 L
.83369 .58392 L
.83366 .586 L
.83358 .58972 L
.83334 .5981 L
.83305 .60534 L
.83267 .61326 L
.83169 .62859 L
.83054 .64249 L
.82704 .6736 L
.82275 .70195 L
.81691 .73247 L
.80189 .79174 L
.78307 .84752 L
.76103 .89966 L
.73346 .95325 L
.70307 1.00267 L
.66682 1.05255 L
Mistroke
.62826 1.09775 L
.58802 1.13831 L
.54204 1.17811 L
.49497 1.21291 L
.44547 1.24403 L
Mfstroke
.13147 .49711 m
.13775 .49082 L
.1452 .48337 L
.15284 .47574 L
.1608 .46777 L
.17 .45857 L
.17963 .44894 L
.19077 .4378 L
.20246 .42611 L
.21467 .41391 L
.22878 .39979 L
.24357 .385 L
.25898 .36959 L
.2768 .35177 L
.29544 .33314 L
.31698 .31159 L
.33958 .28899 L
.36317 .2654 L
.39044 .23814 L
.41898 .20959 L
.452 .17657 L
.48666 .14191 L
.52288 .1057 L
.56476 .06382 L
.60632 .02225 L
s
.14817 .51887 m
.15586 .51443 L
.165 .50916 L
.17434 .50376 L
.18409 .49813 L
.19536 .49163 L
.20716 .48482 L
.2208 .47694 L
.23512 .46868 L
.25007 .46004 L
.26736 .45006 L
.28546 .43961 L
.30435 .42871 L
.32617 .41611 L
.34899 .40293 L
.37538 .38769 L
.40306 .37171 L
.43195 .35504 L
.46534 .33575 L
.5003 .31557 L
.54074 .29222 L
.58319 .26772 L
.62755 .24211 L
.67884 .21249 L
.72974 .1831 L
s
.15867 .54422 m
.16725 .54193 L
.17744 .5392 L
.18786 .5364 L
.19874 .53349 L
.21131 .53012 L
.22446 .5266 L
.23968 .52252 L
.25565 .51824 L
.27232 .51377 L
.2916 .5086 L
.3118 .50319 L
.33286 .49755 L
.3572 .49103 L
.38266 .48421 L
.41209 .47632 L
.44296 .46805 L
.47518 .45942 L
.51243 .44943 L
.55142 .43899 L
.59652 .4269 L
.64387 .41422 L
.69335 .40096 L
.75056 .38563 L
.80733 .37042 L
s
.16225 .57143 m
.17113 .57143 L
.18168 .57143 L
.19247 .57143 L
.20373 .57143 L
.21675 .57143 L
.23037 .57143 L
.24612 .57143 L
.26265 .57143 L
.27991 .57143 L
.29988 .57143 L
.32079 .57143 L
.34259 .57143 L
.36779 .57143 L
.39414 .57143 L
.42461 .57143 L
.45657 .57143 L
.48993 .57143 L
.52849 .57143 L
.56886 .57143 L
.61555 .57143 L
.66457 .57143 L
.71579 .57143 L
.77502 .57143 L
.83379 .57143 L
s
.15867 .59863 m
.16725 .60093 L
.17744 .60366 L
.18786 .60645 L
.19874 .60937 L
.21131 .61274 L
.22446 .61626 L
.23968 .62034 L
.25565 .62462 L
.27232 .62909 L
.2916 .63425 L
.3118 .63966 L
.33286 .64531 L
.3572 .65183 L
.38266 .65865 L
.41209 .66654 L
.44296 .67481 L
.47518 .68344 L
.51243 .69342 L
.55142 .70387 L
.59652 .71596 L
.64387 .72864 L
.69335 .7419 L
.75056 .75723 L
.80733 .77244 L
s
.14817 .62398 m
.15586 .62842 L
.165 .6337 L
.17434 .63909 L
.18409 .64472 L
.19536 .65123 L
.20716 .65804 L
.2208 .66592 L
.23512 .67418 L
.25007 .68281 L
.26736 .69279 L
.28546 .70325 L
.30435 .71415 L
.32617 .72675 L
.34899 .73993 L
.37538 .75516 L
.40306 .77114 L
.43195 .78782 L
.46534 .8071 L
.5003 .82729 L
.54074 .85063 L
.58319 .87514 L
.62755 .90075 L
.67884 .93037 L
.72974 .95975 L
s
.13147 .64575 m
.13775 .65203 L
.1452 .65949 L
.15284 .66712 L
.1608 .67508 L
.17 .68429 L
.17963 .69392 L
.19077 .70505 L
.20246 .71674 L
.21467 .72895 L
.22878 .74307 L
.24357 .75785 L
.25898 .77327 L
.2768 .79109 L
.29544 .80972 L
.31698 .83127 L
.33958 .85387 L
.36317 .87745 L
.39044 .90472 L
.41898 .93327 L
.452 .96628 L
.48666 1.00094 L
.52288 1.03716 L
.56476 1.07904 L
.60632 1.1206 L
s
.1097 .66246 m
.11414 .67015 L
.11941 .67928 L
.12481 .68863 L
.13044 .69838 L
.13694 .70965 L
.14375 .72144 L
.15163 .73509 L
.1599 .7494 L
.16853 .76435 L
.17851 .78164 L
.18896 .79975 L
.19987 .81863 L
.21247 .84046 L
.22564 .86328 L
.24088 .88967 L
.25686 .91734 L
.27354 .94623 L
.29282 .97963 L
.313 1.01459 L
.33635 1.05502 L
.36086 1.09747 L
.38647 1.14183 L
.41608 1.19313 L
.44547 1.24403 L
s
.941 1 .941 r
.13147 .49711 m
.60632 .02225 L
.72974 .1831 L
.80733 .37042 L
.83379 .57143 L
.80733 .77244 L
.72974 .95975 L
.60632 1.1206 L
.44547 1.24403 L
.1097 .66246 L
.13147 .64575 L
.14817 .62398 L
.15867 .59863 L
.16225 .57143 L
.15867 .54422 L
.14817 .51887 L
F
0 g
.13147 .49711 m
.13678 .50283 L
.14207 .50951 L
.14654 .51615 L
.15034 .52284 L
.15385 .53024 L
.15666 .53761 L
.15904 .54564 L
.15999 .54973 L
.16072 .55354 L
.16129 .55727 L
.16153 .55918 L
.16176 .56124 L
.16194 .56329 L
.16207 .56517 L
.16212 .56608 L
.16216 .56707 L
.16219 .56794 L
.16222 .56887 L
.16223 .56943 L
.16224 .56995 L
.16224 .5702 L
.16225 .57044 L
.16225 .57069 L
.16225 .57082 L
.16225 .57096 L
.16225 .5712 L
.16225 .57147 L
.16225 .57172 L
.16225 .57195 L
.16225 .57216 L
.16225 .57239 L
.16224 .57285 L
.16224 .57312 L
.16223 .5734 L
.16222 .5739 L
.16219 .57504 L
.16215 .57602 L
.1621 .57709 L
.16197 .57916 L
.16181 .58105 L
.16134 .58526 L
.16076 .58909 L
.15997 .59322 L
.15793 .60124 L
.15539 .60879 L
.1524 .61585 L
.14867 .6231 L
.14456 .62979 L
.13965 .63654 L
Mistroke
.13444 .64266 L
.12899 .64815 L
.12277 .65353 L
.1164 .65824 L
.1097 .66246 L
Mfstroke
.17968 .44889 m
.18844 .45833 L
.19717 .46934 L
.20453 .48028 L
.21081 .49131 L
.21658 .50352 L
.22122 .51566 L
.22514 .52891 L
.2267 .53566 L
.22791 .54193 L
.22886 .54808 L
.22926 .55123 L
.22962 .55462 L
.22992 .55801 L
.23013 .56112 L
.23021 .56261 L
.23029 .56424 L
.23034 .56567 L
.23039 .56721 L
.23041 .56814 L
.23042 .56899 L
.23043 .56941 L
.23043 .5698 L
.23043 .57021 L
.23043 .57042 L
.23044 .57065 L
.23044 .57106 L
.23044 .57149 L
.23044 .5719 L
.23044 .57229 L
.23043 .57263 L
.23043 .57301 L
.23042 .57377 L
.23041 .57422 L
.23041 .57468 L
.23039 .57551 L
.23034 .57738 L
.23027 .579 L
.23019 .58076 L
.22997 .58418 L
.22971 .58728 L
.22893 .59423 L
.22797 .60055 L
.22667 .60736 L
.22332 .62059 L
.21912 .63303 L
.2142 .64467 L
.20805 .65662 L
.20127 .66765 L
.19318 .67878 L
Mistroke
.18458 .68887 L
.1756 .69792 L
.16534 .7068 L
.15483 .71456 L
.14379 .72151 L
Mfstroke
.25917 .3694 m
.27362 .38496 L
.28801 .40311 L
.30015 .42116 L
.31049 .43934 L
.32001 .45947 L
.32766 .47949 L
.33412 .50133 L
.3367 .51245 L
.33869 .5228 L
.34025 .53293 L
.34091 .53812 L
.34151 .54372 L
.342 .54931 L
.34235 .55443 L
.34249 .55689 L
.34261 .55958 L
.3427 .56193 L
.34277 .56448 L
.34281 .566 L
.34283 .5674 L
.34284 .56809 L
.34284 .56874 L
.34285 .56941 L
.34285 .56977 L
.34285 .57015 L
.34286 .57081 L
.34286 .57153 L
.34286 .57221 L
.34285 .57284 L
.34285 .57341 L
.34285 .57403 L
.34283 .5753 L
.34282 .57602 L
.34281 .57679 L
.34278 .57816 L
.34269 .58124 L
.34258 .58391 L
.34244 .58682 L
.34208 .59246 L
.34166 .59757 L
.34037 .60902 L
.33879 .61944 L
.33665 .63067 L
.33112 .65247 L
.32419 .673 L
.31609 .69218 L
.30594 .71189 L
.29477 .73007 L
.28143 .74843 L
Mistroke
.26725 .76505 L
.25244 .77997 L
.23553 .79461 L
.21821 .80742 L
.2 .81886 L
Mfstroke
.39023 .23834 m
.41406 .264 L
.43778 .29391 L
.45779 .32367 L
.47484 .35365 L
.49053 .38684 L
.50315 .41984 L
.51381 .45586 L
.51806 .47419 L
.52133 .49125 L
.52391 .50795 L
.52499 .51652 L
.52599 .52575 L
.52679 .53496 L
.52737 .5434 L
.5276 .54746 L
.5278 .55189 L
.52795 .55577 L
.52807 .55997 L
.52812 .56248 L
.52816 .56479 L
.52817 .56593 L
.52819 .56699 L
.52819 .56811 L
.5282 .56869 L
.5282 .56933 L
.5282 .57042 L
.52821 .5716 L
.5282 .57272 L
.5282 .57376 L
.52819 .57469 L
.52819 .57572 L
.52816 .5778 L
.52815 .579 L
.52812 .58027 L
.52808 .58252 L
.52793 .58761 L
.52776 .592 L
.52752 .5968 L
.52693 .6061 L
.52623 .61453 L
.52411 .6334 L
.52151 .65059 L
.51797 .66911 L
.50886 .70505 L
.49744 .73888 L
.48407 .77051 L
.46735 .80302 L
.44892 .83299 L
.42693 .86325 L
Mistroke
.40354 .89066 L
.37913 .91526 L
.35125 .9394 L
.3227 .96051 L
.29267 .97938 L
Mfstroke
.60632 .02225 m
.64559 .06456 L
.68471 .11388 L
.7177 .16295 L
.74581 .21237 L
.77168 .26709 L
.79248 .32151 L
.81006 .38088 L
.81707 .41111 L
.82246 .43924 L
.82671 .46678 L
.8285 .48089 L
.83013 .49612 L
.83146 .5113 L
.83242 .52522 L
.83279 .53191 L
.83313 .53922 L
.83337 .54562 L
.83357 .55254 L
.83365 .55668 L
.83372 .56048 L
.83374 .56236 L
.83376 .56412 L
.83378 .56595 L
.83378 .56692 L
.83379 .56796 L
.83379 .56976 L
.83379 .57172 L
.83379 .57356 L
.83379 .57527 L
.83378 .57681 L
.83376 .57851 L
.83372 .58194 L
.83369 .58392 L
.83366 .586 L
.83358 .58972 L
.83334 .5981 L
.83305 .60534 L
.83267 .61326 L
.83169 .62859 L
.83054 .64249 L
.82704 .6736 L
.82275 .70195 L
.81691 .73247 L
.80189 .79174 L
.78307 .84752 L
.76103 .89966 L
.73346 .95325 L
.70307 1.00267 L
.66682 1.05255 L
Mistroke
.62826 1.09775 L
.58802 1.13831 L
.54204 1.17811 L
.49497 1.21291 L
.44547 1.24403 L
Mfstroke
.13147 .49711 m
.13775 .49082 L
.1452 .48337 L
.15284 .47574 L
.1608 .46777 L
.17 .45857 L
.17963 .44894 L
.19077 .4378 L
.20246 .42611 L
.21467 .41391 L
.22878 .39979 L
.24357 .385 L
.25898 .36959 L
.2768 .35177 L
.29544 .33314 L
.31698 .31159 L
.33958 .28899 L
.36317 .2654 L
.39044 .23814 L
.41898 .20959 L
.452 .17657 L
.48666 .14191 L
.52288 .1057 L
.56476 .06382 L
.60632 .02225 L
s
.14817 .51887 m
.15586 .51443 L
.165 .50916 L
.17434 .50376 L
.18409 .49813 L
.19536 .49163 L
.20716 .48482 L
.2208 .47694 L
.23512 .46868 L
.25007 .46004 L
.26736 .45006 L
.28546 .43961 L
.30435 .42871 L
.32617 .41611 L
.34899 .40293 L
.37538 .38769 L
.40306 .37171 L
.43195 .35504 L
.46534 .33575 L
.5003 .31557 L
.54074 .29222 L
.58319 .26772 L
.62755 .24211 L
.67884 .21249 L
.72974 .1831 L
s
.15867 .54422 m
.16725 .54193 L
.17744 .5392 L
.18786 .5364 L
.19874 .53349 L
.21131 .53012 L
.22446 .5266 L
.23968 .52252 L
.25565 .51824 L
.27232 .51377 L
.2916 .5086 L
.3118 .50319 L
.33286 .49755 L
.3572 .49103 L
.38266 .48421 L
.41209 .47632 L
.44296 .46805 L
.47518 .45942 L
.51243 .44943 L
.55142 .43899 L
.59652 .4269 L
.64387 .41422 L
.69335 .40096 L
.75056 .38563 L
.80733 .37042 L
s
.16225 .57143 m
.17113 .57143 L
.18168 .57143 L
.19247 .57143 L
.20373 .57143 L
.21675 .57143 L
.23037 .57143 L
.24612 .57143 L
.26265 .57143 L
.27991 .57143 L
.29988 .57143 L
.32079 .57143 L
.34259 .57143 L
.36779 .57143 L
.39414 .57143 L
.42461 .57143 L
.45657 .57143 L
.48993 .57143 L
.52849 .57143 L
.56886 .57143 L
.61555 .57143 L
.66457 .57143 L
.71579 .57143 L
.77502 .57143 L
.83379 .57143 L
s
.15867 .59863 m
.16725 .60093 L
.17744 .60366 L
.18786 .60645 L
.19874 .60937 L
.21131 .61274 L
.22446 .61626 L
.23968 .62034 L
.25565 .62462 L
.27232 .62909 L
.2916 .63425 L
.3118 .63966 L
.33286 .64531 L
.3572 .65183 L
.38266 .65865 L
.41209 .66654 L
.44296 .67481 L
.47518 .68344 L
.51243 .69342 L
.55142 .70387 L
.59652 .71596 L
.64387 .72864 L
.69335 .7419 L
.75056 .75723 L
.80733 .77244 L
s
.14817 .62398 m
.15586 .62842 L
.165 .6337 L
.17434 .63909 L
.18409 .64472 L
.19536 .65123 L
.20716 .65804 L
.2208 .66592 L
.23512 .67418 L
.25007 .68281 L
.26736 .69279 L
.28546 .70325 L
.30435 .71415 L
.32617 .72675 L
.34899 .73993 L
.37538 .75516 L
.40306 .77114 L
.43195 .78782 L
.46534 .8071 L
.5003 .82729 L
.54074 .85063 L
.58319 .87514 L
.62755 .90075 L
.67884 .93037 L
.72974 .95975 L
s
.13147 .64575 m
.13775 .65203 L
.1452 .65949 L
.15284 .66712 L
.1608 .67508 L
.17 .68429 L
.17963 .69392 L
.19077 .70505 L
.20246 .71674 L
.21467 .72895 L
.22878 .74307 L
.24357 .75785 L
.25898 .77327 L
.2768 .79109 L
.29544 .80972 L
.31698 .83127 L
.33958 .85387 L
.36317 .87745 L
.39044 .90472 L
.41898 .93327 L
.452 .96628 L
.48666 1.00094 L
.52288 1.03716 L
.56476 1.07904 L
.60632 1.1206 L
s
.1097 .66246 m
.11414 .67015 L
.11941 .67928 L
.12481 .68863 L
.13044 .69838 L
.13694 .70965 L
.14375 .72144 L
.15163 .73509 L
.1599 .7494 L
.16853 .76435 L
.17851 .78164 L
.18896 .79975 L
.19987 .81863 L
.21247 .84046 L
.22564 .86328 L
.24088 .88967 L
.25686 .91734 L
.27354 .94623 L
.29282 .97963 L
.313 1.01459 L
.33635 1.05502 L
.36086 1.09747 L
.38647 1.14183 L
.41608 1.19313 L
.44547 1.24403 L
s
gsave
.98286 .61429 -65.75 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(u) show
68.500 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.1 1.26571 -65.4375 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(v) show
67.875 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.86857 .51429 -66.5938 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\343) show
70.188 13.875 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.10571 .51429 -70.3438 -16.1563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.3125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 19.563 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
66.750 12.563 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
65.125 19.563 moveto
(\\200\\200) show
70.375 19.563 moveto
(\\200) show
72.688 19.563 moveto
(\\200) show
66.750 27.125 moveto
(\\343) show
77.688 19.563 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.91429 .57143 m
1 .57143 L
s
% Start of user PostScript
3. 0 3.3 0 MAarrowhead1
% End of user PostScript
.05714 1.25714 m
.05714 1.28571 L
s
% Start of user PostScript
0 2.4 0 2.5 MAarrowhead1
% End of user PostScript
gsave
.2 1.14286 -61 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 29.875 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.250 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
70.188 17.250 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
81.125 10.250 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
79.500 17.250 moveto
(\\200\\200) show
84.750 17.250 moveto
(\\200) show
87.063 17.250 moveto
(\\200) show
81.125 24.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
92.063 17.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.28571 .08571 -61 -14.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 29.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.250 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
70.188 17.250 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
77.375 17.250 moveto
(-) show
88.313 10.250 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
86.688 17.250 moveto
(\\200\\200) show
91.938 17.250 moveto
(\\200) show
94.250 17.250 moveto
(\\200) show
88.313 24.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
99.250 17.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{224, 287.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
  ImageRangeCache->{{{0, 223}, {286.938, 0}} -> {0, -2, 0, 0}}],
 StyleBox["  \n\t\tFigure 5.3",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  The image of  ",
 Cell[BoxData[
  SuperscriptBox["R", "*"]]],
 " under the transformation  ",
 Cell[BoxData[
  RowBox[{"w", " ", "=", " ", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", "z"], " ", "=", " ", 
    RowBox[{"exp", 
     RowBox[{"(", "z", ")"}]}]}]}]]],
 ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 5.2.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 "Enter the function  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{"f", "[", "z", "]"}], "=", 
    SuperscriptBox["\[ExponentialE]", "z"]}]}]]],
 ".  \n",
 StyleBox["For illustration.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  We graph the image of  the rectangle ",
 Cell[BoxData[
  RowBox[{"R", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"x", ",", "y"}], ")"}], ":", 
     RowBox[{
      RowBox[{"-", "1"}], "\[LessEqual]", "x", "\[LessEqual]", 
      RowBox[{"1", "  ", "and", "  ", 
       FractionBox[
        RowBox[{"-", "\[Pi]"}], "3"]}], "\[LessEqual]", "y", "\[LessEqual]", 
      FractionBox["\[Pi]", "4"]}]}], "}"}]}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", "z", "]"}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{"Clear", "[", "f", "]"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"Iden", "[", "z_", "]"}], " ", "=", " ", "z"}], ";"}], "  ", 
   "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     SuperscriptBox["\[ExponentialE]", "z"]}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g0", "=", 
     RowBox[{"CartesianMap", "[", 
      RowBox[{"Iden", ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "1", ",", "0.25"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         FractionBox[
          RowBox[{"-", "\[Pi]"}], "3"], ",", 
         FractionBox["\[Pi]", "4"], ",", 
         FractionBox["\[Pi]", "12"]}], "}"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.2"}], ",", "1.2"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.2"}], ",", "1.2"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{
            FractionBox[
             RowBox[{"-", "\[Pi]"}], "3"], ",", 
            FractionBox["\[Pi]", "4"]}], "}"}]}], "}"}]}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], ";"}], "   ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "g0", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The rectangle R = {(x,y): -1 \[LessEqual] x \[LessEqual] 1 and \!\(\
\*FractionBox[\(-\[Pi]\), \(3\)]\) \[LessEqual] y \[LessEqual] \
\!\(\*FractionBox[\(\[Pi]\), \(4\)]\)}.\>\"", "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"g1", "=", 
     RowBox[{"CartesianMap", "[", 
      RowBox[{"f", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "1", ",", "0.25"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         FractionBox[
          RowBox[{"-", "\[Pi]"}], "3"], ",", 
         FractionBox["\[Pi]", "4"], ",", 
         FractionBox["\[Pi]", "12"]}], "}"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.2"}], ",", "3"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2.5"}], ",", "2.3"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", 
        FractionBox["4.8", "3.2"]}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "3", ",", "1"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], ";"}], "   ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "g1", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The image sector \!\(\*FractionBox[\(1\), \(\[ExponentialE]\)]\) < \
\[Rho] < \[ExponentialE]  and  \!\(\*FractionBox[\(-\[Pi]\), \(3\)]\) \
\[LessEqual] \[Phi] \[LessEqual] \!\(\*FractionBox[\(\[Pi]\), \(4\)]\),\>\"", 
     "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<under the mapping  w = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], "   ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399119337890625*^9, 3.399119405890625*^9}, {
  3.399799643499752*^9, 3.399799643968502*^9}, {3.400261553203125*^9, 
  3.40026156178125*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "\nWe see that the transformation  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   SuperscriptBox["\[ExponentialE]", "z"]}]]],
 "  maps the rectangle  ",
 Cell[BoxData[
  RowBox[{"R", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"x", ",", "y"}], ")"}], ":", 
     RowBox[{
      RowBox[{"-", "1"}], "\[LessEqual]", "x", "\[LessEqual]", 
      RowBox[{"1", "  ", "and", "  ", 
       FractionBox[
        RowBox[{"-", "\[Pi]"}], "3"]}], "\[LessEqual]", "y", "\[LessEqual]", 
      FractionBox["\[Pi]", "4"]}]}], "}"}]}]]],
 "  onto a portion of an annular region  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", "1"}]], "<"}], "|", "w", "|", 
   RowBox[{"<", "\[ExponentialE]"}]}]]],
 "  bounded by two rays  ",
 Cell[BoxData[
  RowBox[{
   FractionBox[
    RowBox[{"-", "\[Pi]"}], "3"], "\[LessEqual]", 
   RowBox[{"arg", "[", "w", "]"}], "\[LessEqual]", 
   FractionBox["\[Pi]", "4"]}]]],
 ".  "
}], "Text"]
}, Closed]],

Cell["\<\
The \"legacy version\" being used to implement the commands \"CartesianMap \
and PolarMap.\"  The following Initialization Cell will load these \
subroutines. \
\>", "Text",
 CellChangeTimes->{{3.399722161203125*^9, 3.399722165296875*^9}, {
  3.39972222759375*^9, 3.3997223229375*^9}, {3.399722389046875*^9, 
  3.399722641234375*^9}, {3.399722683734375*^9, 3.3997227230625*^9}, {
  3.3997227559375*^9, 3.399722850765625*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Initialization Cell",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text",
 CellChangeTimes->{{3.399722161203125*^9, 3.399722165296875*^9}, {
  3.39972222759375*^9, 3.3997223229375*^9}, {3.399722389046875*^9, 
  3.399722641234375*^9}, {3.399722683734375*^9, 3.3997227230625*^9}, {
  3.3997227559375*^9, 3.399722850765625*^9}, {3.399742279828125*^9, 
  3.39974228209375*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}]], "Input",\

 InitializationCell->True]
}, Closed]],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["History of Complex Numbers",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/HistoryComplexBib.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Complex Numbers",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/ComplexNumbersBib.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/complex.html"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2008 John H. Mathews, Russel W. Howell",
 
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/"], None}],
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[0, 1, 0]]], "Text",
 CellChangeTimes->{{3.399119096359375*^9, 3.399119096484375*^9}}]
},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{963, 629},
WindowMargins->{{8, Automatic}, {Automatic, 3}},
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "CHAPTER 1"->{
  Cell[568, 21, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"],
  Cell[905, 32, 189, 5, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"CHAPTER 1", 239737, 10852}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"],
Cell[905, 32, 189, 5, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"],
Cell[1097, 39, 96, 2, 29, "Text"],
Cell[1196, 43, 1717, 48, 173, "Text"],
Cell[2916, 93, 124, 2, 29, "Text"],
Cell[3043, 97, 642, 21, 53, "Text"],
Cell[3688, 120, 1066, 40, 91, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[4779, 164, 177, 6, 29, "Text"],
Cell[4959, 172, 165, 7, 29, "Text",
 Evaluatable->False],
Cell[5127, 181, 315, 9, 52, "Input"],
Cell[5445, 192, 225, 6, 52, "Input"],
Cell[5673, 200, 165, 6, 47, "Text",
 Evaluatable->False],
Cell[5841, 208, 2368, 68, 453, "Input"]
}, Closed]],
Cell[8224, 279, 665, 16, 62, "Text"],
Cell[8892, 297, 2342, 90, 197, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[11259, 391, 109, 2, 29, "Text"],
Cell[11371, 395, 1378, 46, 109, "Text"],
Cell[12752, 443, 2501, 89, 195, "Text"],
Cell[15256, 534, 1370, 53, 214, "Text"],
Cell[16629, 589, 1095, 44, 101, "Text"],
Cell[17727, 635, 5195, 158, 339, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[22959, 798, 122, 2, 26, "Text"],
Cell[23084, 802, 441, 16, 47, "Text",
 Evaluatable->False],
Cell[23528, 820, 2677, 78, 392, "Input"],
Cell[26208, 900, 388, 15, 47, "Text",
 Evaluatable->False],
Cell[26599, 917, 993, 31, 172, "Input"],
Cell[27595, 950, 382, 13, 47, "Text",
 Evaluatable->False],
Cell[27980, 965, 3487, 103, 357, "Input"],
Cell[31470, 1070, 449, 16, 55, "Text",
 Evaluatable->False],
Cell[31922, 1088, 1508, 45, 152, "Input"],
Cell[33433, 1135, 417, 14, 47, "Text",
 Evaluatable->False],
Cell[33853, 1151, 3045, 93, 217, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[36935, 1249, 123, 2, 26, "Text"],
Cell[37061, 1253, 6219, 174, 657, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[43317, 1432, 124, 2, 26, "Text"],
Cell[43444, 1436, 76, 0, 29, "Text"],
Cell[43523, 1438, 438, 12, 96, "Input"],
Cell[43964, 1452, 1248, 37, 96, "Input"],
Cell[45215, 1491, 1289, 38, 96, "Input"],
Cell[46507, 1531, 1340, 40, 96, "Input"],
Cell[47850, 1573, 1049, 28, 118, "Input"]
}, Closed]],
Cell[48914, 1604, 469, 15, 26, "Text"],
Cell[49386, 1621, 1499, 51, 137, "Text"],
Cell[50888, 1674, 2608, 90, 155, "Text"],
Cell[53499, 1766, 1424, 49, 137, "Text"],
Cell[54926, 1817, 904, 28, 65, "Text"],
Cell[55833, 1847, 3077, 98, 332, "Text"],
Cell[58913, 1947, 89195, 4969, 274, "Text"],
Cell[CellGroupData[{
Cell[148133, 6920, 109, 2, 29, "Text"],
Cell[148245, 6924, 49, 0, 29, "Text"],
Cell[148297, 6926, 2540, 76, 388, "Input"],
Cell[150840, 7004, 50, 0, 29, "Text"],
Cell[150893, 7006, 1832, 49, 248, "Input"]
}, Closed]],
Cell[152740, 7058, 1296, 42, 80, "Text"],
Cell[154039, 7102, 2497, 84, 137, "Text"],
Cell[156539, 7188, 2289, 78, 321, "Text"],
Cell[158831, 7268, 1280, 39, 101, "Text"],
Cell[160114, 7309, 16155, 652, 284, "Text"],
Cell[176272, 7963, 1832, 61, 65, "Text"],
Cell[178107, 8026, 3918, 119, 242, "Text",
 Evaluatable->False],
Cell[182028, 8147, 48568, 2427, 323, "Text"],
Cell[CellGroupData[{
Cell[230621, 10578, 109, 2, 29, "Text"],
Cell[230733, 10582, 729, 25, 53, "Text"],
Cell[231465, 10609, 4474, 122, 403, "Input"],
Cell[235942, 10733, 993, 33, 77, "Text"]
}, Closed]],
Cell[236950, 10769, 435, 8, 26, "Text"],
Cell[CellGroupData[{
Cell[237410, 10781, 407, 7, 29, "Text"],
Cell[237820, 10790, 132, 4, 31, "Input",
 InitializationCell->True]
}, Closed]],
Cell[237967, 10797, 281, 7, 26, "Text"],
Cell[238251, 10806, 288, 7, 29, "Text"],
Cell[238542, 10815, 277, 7, 29, "Text"],
Cell[238822, 10824, 249, 5, 29, "Text"],
Cell[239074, 10831, 319, 7, 29, "Text"]
}
]
*)

(* End of internal cache information *)
