(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    234698,      12196]
NotebookOptionsPosition[    230959,      12075]
NotebookOutlinePosition[    231485,      12099]
CellTagsIndexPosition[    231410,      12094]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["5.2  The Complex Logarithm",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
 "\tIn Section 5.1, we showed that, if ",
 StyleBox["w",
  FontFamily->"Courier New"],
 " is a nonzero complex number, then the equation  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   SuperscriptBox["\[ExponentialE]", "z"]}]]],
 "  has infinitely many solutions.  Because the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   SuperscriptBox["\[ExponentialE]", "z"]}]]],
 "  is a many-to-one function, its inverse (the logarithm) is multivalued.  "
}], "Text"],

Cell[TextData[{
 StyleBox["Definition 5.2.  (Multivalued Logarithm)  ",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "For ",
 Cell[BoxData[
  RowBox[{"z", "\[NotEqual]", "0"}]]],
 ", we define the function  ",
 Cell[BoxData[
  RowBox[{"log", 
   RowBox[{"(", "z", ")"}]}]]],
 "  as the inverse of the exponential function;  that is,  \n\n ",
 StyleBox["(5-10)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"log", 
    RowBox[{"(", "z", ")"}]}], "=", "w"}]]],
 "   if and only if   ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   SuperscriptBox["\[ExponentialE]", "w"]}]]],
 ".  \n\n\tIf we go through the same steps as we did in equations (5-8) and \
(5-9), we find that, for any complex number  ",
 Cell[BoxData[
  RowBox[{"z", "\[NotEqual]", "0"}]]],
 ",  the solutions w to equation (5-10) take the form  \n\n",
 StyleBox["(5-11)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{"w", " ", "=", " ", 
   RowBox[{
    RowBox[{"log", 
     RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
    RowBox[{"ln", "|", "z", "|", " ", 
     RowBox[{
      RowBox[{"+", "  ", "\[ImaginaryI]"}], " ", "\[Theta]"}]}]}]}]]],
 ",   for   ",
 Cell[BoxData[
  RowBox[{"z", "\[NotEqual]", "0"}]]],
 ",  \n\nwhere  ",
 Cell[BoxData[
  RowBox[{"\[Theta]", "\[Element]", 
   RowBox[{"arg", 
    RowBox[{"(", "z", ")"}]}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{"ln", "|", "z", "|"}]]],
 "  denotes the natural logarithm of the positive number ",
 StyleBox["|z|",
  FontFamily->"Courier New"],
 ".  Because  ",
 Cell[BoxData[
  RowBox[{"arg", 
   RowBox[{"(", "z", ")"}]}]]],
 "  is the set  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"arg", 
    RowBox[{"(", "z", ")"}]}], " ", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Arg", 
      RowBox[{"(", "z", ")"}]}], "+", 
     RowBox[{"2", "n", " ", 
      RowBox[{"\[Pi]", ":", " ", 
       StyleBox[
        RowBox[{"where", " ", "n", " ", "is", " ", "an", " ", "integer"}],
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]]}]}]}], "}"}]}]]],
 ",  we can express the set of values comprising ",
 Cell[BoxData[
  RowBox[{"log", 
   RowBox[{"(", "z", ")"}]}]]],
 " as  \n\n",
 StyleBox["(5-12)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"log", 
    RowBox[{"(", "z", ")"}]}], " ", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ln", "|", "z", "|", 
      RowBox[{
       RowBox[{"+", " ", "\[ImaginaryI]"}], 
       RowBox[{"(", 
        RowBox[{"Arg", " ", "+", 
         RowBox[{"2", "n", " ", "\[Pi]"}]}], ")"}]}]}], ":", " ", 
     RowBox[{
      StyleBox["where",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], " ", "n", " ", 
      StyleBox["is",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox[" ",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox["an",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox[" ",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox["integer",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]]}]}], "}"}]}]]],
 ",  \n\t\tor\n",
 StyleBox["(5-13)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"log", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{"ln", "|", "z", "|", 
    RowBox[{
     RowBox[{"+", " ", "\[ImaginaryI]"}], " ", "arg", 
     RowBox[{"(", "z", ")"}]}]}]}]]],
 "   for   ",
 Cell[BoxData[
  RowBox[{"z", "\[NotEqual]", "0"}]]],
 ",   \n\nwhere it is understood that identity ",
 StyleBox["(5-13)",
  FontColor->RGBColor[0, 0, 1]],
 " refers to the same set of numbers given in identity ",
 StyleBox["(5-12)",
  FontColor->RGBColor[0, 0, 1]],
 "."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "\tRecall that Arg is defined so that for  ",
 Cell[BoxData[
  RowBox[{"z", "\[NotEqual]", "0"}]]],
 ",  we have  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"-", "\[Pi]"}], " ", "<", " ", 
   RowBox[{"Arg", 
    RowBox[{"(", "z", ")"}]}], " ", "\[LessEqual]", " ", "\[Pi]"}]]],
 ".  We call any one of the values given in Identities ",
 StyleBox["(5-12)",
  FontColor->RGBColor[0, 0, 1]],
 " or ",
 StyleBox["(5-13)",
  FontColor->RGBColor[0, 0, 1]],
 " a logarithm of ",
 StyleBox["z",
  FontFamily->"Courier New"],
 ".  Notice that the different values of  ",
 Cell[BoxData[
  RowBox[{"log", 
   RowBox[{"(", "z", ")"}]}]]],
 "  all have the same real part and that their imaginary parts differ by the \
amount  ",
 Cell[BoxData[
  RowBox[{"2", "\[Pi]", " ", "n"}]]],
 ",  where n is an integer.  When  ",
 Cell[BoxData[
  RowBox[{"n", "=", "0"}]]],
 ",  we have a special situation."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Definition 5.3.  (Principal Value of the ",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Logarithm",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/Logarithm.html"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 StyleBox[")  ",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "For  ",
 Cell[BoxData[
  RowBox[{"z", "\[NotEqual]", "0"}]]],
 ",  we define the principal value of the logarithm as follows:",
 StyleBox["\n\n",
  FontColor->RGBColor[1, 0, 1]],
 StyleBox["(5-14)",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["\t\t",
  FontColor->RGBColor[1, 0, 1]],
 Cell[BoxData[
  RowBox[{
   RowBox[{"Log", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{"ln", "|", "z", "|", 
    RowBox[{
     RowBox[{"+", " ", "\[ImaginaryI]"}], " ", "Arg", 
     RowBox[{"(", "z", ")"}], " "}]}]}]]],
 " where  ",
 Cell[BoxData[
  RowBox[{"|", "z", "|", 
   RowBox[{">", " ", "0"}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"-", "\[Pi]"}], " ", "<", " ", 
   RowBox[{"Arg", 
    RowBox[{"(", "z", ")"}]}], " ", "\[LessEqual]", " ", "\[Pi]", " "}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "\tThe domain for the function  ",
 Cell[BoxData[
  RowBox[{"w", " ", "=", " ", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "=", 
    RowBox[{"Log", 
     RowBox[{"(", "z", ")"}]}]}]}]]],
 "  is the set of all nonzero complex numbers in the  ",
 StyleBox["z",
  FontFamily->"Courier New"],
 "-plane, and its range is the horizontal strip  ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{"w", ":", " ", 
    RowBox[{
     RowBox[{"-", "\[Pi]"}], " ", "<", " ", 
     RowBox[{"Im", 
      RowBox[{"(", "w", ")"}]}], " ", "\[LessEqual]", " ", "\[Pi]"}]}], 
   "}"}]]],
 "  in the ",
 StyleBox["w",
  FontFamily->"Courier New"],
 "-plane, and is shown in Figure 5.A.  We stress again that  ",
 Cell[BoxData[
  RowBox[{"Log", 
   RowBox[{"(", "z", ")"}]}]]],
 "  is a single-valued function and corresponds to setting  ",
 Cell[BoxData[
  RowBox[{"n", "=", "0"}]]],
 "  in equation ",
 StyleBox["(5-12)",
  FontColor->RGBColor[0, 0, 1]],
 ".  As we demonstrated in Chapter 2, the function  ",
 Cell[BoxData[
  RowBox[{"Arg", 
   RowBox[{"(", "z", ")"}]}]]],
 "  is discontinuous at each point along the negative x-axis, hence so is the \
function  ",
 Cell[BoxData[
  RowBox[{"Log", 
   RowBox[{"(", "z", ")"}]}]]],
 ".  In fact, because any branch of the multi-valued function  ",
 Cell[BoxData[
  RowBox[{"Arg", 
   RowBox[{"(", "z", ")"}]}]]],
 "  is discontinuous along some ray, a corresponding branch of the logarithm \
will have a discontinuity along that same ray.  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "\t",
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10  scalefont  setfont
% Scaling calculations
0.493933 0.134321 0.493933 0.134321 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.941 1 .941 r
.02381 .02381 m
.96406 .02381 L
.96406 .96406 L
.02381 .96406 L
.02381 .02381 L
F
.49393 .49393 m
.49393 .49393 .44596 0 365.73 arc
F
.8 1 .8 r
.49393 .49393 m
.49393 .49393 .33038 0 365.73 arc
F
.941 1 .941 r
.49393 .49393 m
.49393 .49393 .07372 0 365.73 arc
F
1 1 1 r
.49393 .49393 m
.49393 .49393 .00672 0 365.73 arc
F
1 0 1 r
.5 Mabswid
[ ] 0 setdash
.48728 .50058 m
.17859 .80927 L
s
1 0 0 r
.49868 .49868 m
.80927 .80927 L
s
0 0 1 r
[ .025 .025 ] 0 setdash
.4823 .48722 m
.10772 .27095 L
s
0 0 0 r
[ ] 0 setdash
.49393 .50065 m
.49393 .96276 L
s
.50065 .49393 m
.96276 .49393 L
s
.49393 .48722 m
.49393 .02511 L
s
.56 .37 .6 r
.0012 w
[ .025 .025 ] 0 setdash
newpath
.49393 .49393 .07372 0 365.73 arc
s
1 .5 0 r
[ ] 0 setdash
newpath
.49393 .49393 .28436 0 365.73 arc
s
.5 .165 .165 r
newpath
.49393 .49393 .33038 0 365.73 arc
s
0 1 0 r
.5 Mabswid
.02511 .50065 m
.49393 .50065 L
s
[ .025 .025 ] 0 setdash
.02511 .48722 m
.49393 .48722 L
s
0 g
[ ] 0 setdash
.94933 .49393 m
.97619 .49393 L
s
% Start of user PostScript
3.39034 0 3.59034 0 MAarrowhead1
% End of user PostScript
.49393 .94933 m
.49393 .97619 L
s
% Start of user PostScript
0 3.39034 0 3.59034 MAarrowhead1
% End of user PostScript
gsave
.96276 .52751 -66 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.51408 .96276 -69 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
75.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 1 0 r
.0012 w
newpath
.49393 .49393 .00672 -90 90 arc
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{258, 258},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
  ImageRangeCache->{{{0, 257}, {257, 0}} -> {-3, -3, 0, 0}}],
 "       ",
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10  scalefont  setfont
% Scaling calculations
0.436364 0.363636 0.302624 0.0852461 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30262 m
1 .30262 L
s
.43636 0 m
.43636 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.5 Mabswid
0 .30262 m
.14402 .30262 L
.43294 .30262 L
.74059 .30262 L
s
.74059 .30262 m
1 .30262 L
s
.941 1 .941 r
0 .03482 m
.98182 .03482 L
.98182 .57043 L
0 .57043 L
0 .03482 L
F
.8 1 .8 r
.21818 .03482 m
.76364 .03482 L
.76364 .57043 L
.21818 .57043 L
.21818 .03482 L
F
0 g
.98182 .30262 m
1 .30262 L
s
% Start of user PostScript
1.5 0 1.55 0 MAarrowhead1
% End of user PostScript
.43636 .60098 m
.43636 .60951 L
s
% Start of user PostScript
0 3.5 0 3.6 MAarrowhead1
% End of user PostScript
0 .30262 m
.98182 .30262 L
s
.43636 .03482 m
.43636 .57043 L
s
1 0 1 r
0 .50348 m
.98182 .50348 L
s
1 0 0 r
0 .36958 m
.98182 .36958 L
s
0 0 1 r
[ .025 .025 ] 0 setdash
0 .07945 m
.98182 .07945 L
s
.56 .37 .6 r
.21818 .03482 m
.21818 .57043 L
s
1 .5 0 r
[ ] 0 setdash
.70909 .03482 m
.70909 .57043 L
s
.5 .165 .165 r
.76364 .03482 m
.76364 .57043 L
s
0 1 0 r
0 .57043 m
.98182 .57043 L
s
[ .025 .025 ] 0 setdash
0 .03482 m
.98182 .03482 L
s
0 g
gsave
.97455 .33672 -66 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(u) show
69.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.45455 .60951 -69 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(v) show
75.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.4 .59601 -78 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.875 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344p) show
93.000 13.875 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.4 .00924 -78 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.000 13.875 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344p) show
93.000 13.875 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\
eJztm0tOwzAQQJ0mTVqp4gJsuuYCgFRAYgELxBWQooLUFhCodIdQ992wpazg
CJyDHqY3MJ6xk9Bg90ej2NU4xB2N7effeKI4+DIedG7u40G3HTfP+/Fjp9t+
ap499IXK9xjzmoyxryYDmQtRRT3GOQ9BDEBiPkO1kOAONboPjNk1/ASQ4Ocy
QaigFMwUFKFu5t1qKDpysYhe2ivsQRWkmjn7iznpTpO0sxZpvaQazDDOXybV
NbplU1HyNdM6L3/0j1Rdm+RUsGM25VPRmNerMZvwCd4tjOVQJLoLpePDTNdQ
uuHeHlLgbkEcEZvYK7JPCLYKrAZuIwRFJtU1OiUJWD2VaibJx0qDmcbNyx+Z
UqF/XPVIPh65eAokJZJU6NtMqr7tf3smysJ4JG6zWtRkubqWiE1sZz0bwSy0
FGITu2y2vSuPYOT6iE1scn0E22IrJDax3V55BLPLUojNDiGuYFHzruam6/v1
lVJUIOuGCpIwUjq5fytDQ+nkrq0MpxB5BTY0Uu0orAIs6sZCJNhyU4rfL8Ji
bOYAY/mFJNHlDMjZ2vbznigJDnpVYpfM3pRL+Mbvg7IMSByfRDx9EiW6I4hD
G32SQzBXjY3YxHZ75RHMLkshNrHLZtu78ghml6UQe0vYHP+3EdhcXSOlk+8/
8moonXz/kRe8//CCNj3I6xHMQkshNrHLZlu58vBvNz3us+6xp2f4wWNbJsX8
E2+ow83rT5ldd6jMcLoNTyf5C8r6Gt3mCurOr+EA4xZ5mErv5oEM8pmWPcnm
60dlbK6qklaVSW8Lp5h5P0sm2EI=\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1, -3, 0, 0}}],
 "  \n\t\t\t\t",
 StyleBox["Figure 5.A",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  The principal branch of the logarithm ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{"Log", 
    RowBox[{"(", "z", ")"}]}]}]]],
 ". "
}], "Text"],

Cell[TextData[{
 StyleBox["Caution.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]],
 "  A phenomenon inherent in constructing an logarithm function:  It must \
have a discontinuity!  This is the case because as we saw in Chapter 2, any \
branch we choose for  ",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{"arg", 
    RowBox[{"(", "z", ")"}]}]}]]],
 "  is necessarily a discontinuous function.  The principal branch,  ",
 Cell[BoxData[
  RowBox[{"Log", 
   RowBox[{"(", "z", ")"}]}]]],
 ",  is discontinuous at each point along the negative x-axis.  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Extra Example 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Investigate the complex logarithm function."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution for Extra Example 1.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 "Enter the function  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{"f", "[", "z", "]"}], "=", 
    RowBox[{"Log", "[", 
     RowBox[{"x", "+", 
      RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}]}]}]]],
 "  and find its real and imaginary parts"
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", 
     RowBox[{"x", ",", "y", ",", "z"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "u", ",", "v"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"Log", "[", "z", "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"u", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{
       RowBox[{"Re", "[", 
        RowBox[{"f", "[", 
         RowBox[{"x", "+", 
          RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], ",", 
       RowBox[{"TargetFunctions", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Re", ",", "Im"}], "}"}]}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"v", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{
       RowBox[{"Im", "[", 
        RowBox[{"f", "[", 
         RowBox[{"x", "+", 
          RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], ",", 
       RowBox[{"TargetFunctions", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Re", ",", "Im"}], "}"}]}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<    Log[x+\[ImaginaryI]y] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<    Log[x+\[ImaginaryI]y] = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", "+", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<    Log[x+\[ImaginaryI]y] = \>\"", ",", 
      RowBox[{
       RowBox[{"u", "[", 
        RowBox[{"x", ",", "y"}], "]"}], "+", " ", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"v", "[", 
         RowBox[{"x", ",", "y"}], "]"}]}]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Re[Log[x+\[ImaginaryI]y]] = \>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Im[Log[x+\[ImaginaryI]y]] = \>\"", ",", 
      RowBox[{"v", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399280665796875*^9},
 AspectRatioFixed->True],

Cell["\<\
Find the polar form of the real and imaginary parts of the logarithm \
function.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "f", ",", "r", ",", "\[Theta]", ",", "u", ",", "U", ",", "v", ",", "V", 
      ",", "w", ",", "z"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"Log", "[", "z", "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"U", "[", 
      RowBox[{"r_", ",", "\[Theta]_"}], "]"}], " ", "=", " ", 
     RowBox[{"Log", "[", "r", "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"V", "[", 
      RowBox[{"r_", ",", "\[Theta]_"}], "]"}], " ", "=", " ", "\[Theta]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"W", " ", "=", " ", 
     RowBox[{
      RowBox[{"U", "[", 
       RowBox[{"r", ",", "\[Theta]"}], "]"}], " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"V", "[", 
        RowBox[{"r", ",", "\[Theta]"}], "]"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"u", "[", 
      RowBox[{"r_", ",", "\[Theta]_"}], "]"}], " ", "=", " ", 
     RowBox[{"PowerExpand", "[", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{
        RowBox[{"Re", "[", 
         RowBox[{"f", "[", 
          RowBox[{"r", " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]]}], "]"}], "]"}], ",", 
        
        RowBox[{"TargetFunctions", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"Re", ",", "Im"}], "}"}]}]}], "]"}], "]"}]}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"v", "[", 
      RowBox[{"r_", ",", "\[Theta]_"}], "]"}], " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{
       RowBox[{"Im", "[", 
        RowBox[{"f", "[", 
         RowBox[{"r", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]]}], "]"}], "]"}], ",", 
       RowBox[{"TargetFunctions", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Re", ",", "Im"}], "}"}]}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<    Log[r \!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\[ImaginaryI]\
\[Theta]\)]\)] = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"r", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]]}], "]"}]}], "]"}], ";"}],
    " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<    Log[r \!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\[ImaginaryI]\
\[Theta]\)]\)] = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"f", "[", 
        RowBox[{"r", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]]}], "]"}], "]"}]}], 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<    Log[r \!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\[ImaginaryI]\
\[Theta]\)]\)] = \>\"", ",", 
      RowBox[{
       RowBox[{"u", "[", 
        RowBox[{"r", ",", "\[Theta]"}], "]"}], "+", " ", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"v", "[", 
         RowBox[{"r", ",", "\[Theta]"}], "]"}]}]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<    Log[r \!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\[ImaginaryI]\
\[Theta]\)]\)] = \>\"", ",", 
      RowBox[{
       RowBox[{"U", "[", 
        RowBox[{"r", ",", "\[Theta]"}], "]"}], "+", " ", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"V", "[", 
         RowBox[{"r", ",", "\[Theta]"}], "]"}]}]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Re[Log[r \!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\[ImaginaryI]\
\[Theta]\)]\)]] = \>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"r", ",", "\[Theta]"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Im[Log[r \!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\[ImaginaryI]\
\[Theta]\)]\)]] = \>\"", ",", 
      RowBox[{"v", "[", 
       RowBox[{"r", ",", "\[Theta]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Im[Log[r \!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\[ImaginaryI]\
\[Theta]\)]\)]] = \>\"", ",", 
      RowBox[{"V", "[", 
       RowBox[{"r", ",", "\[Theta]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39928067171875*^9},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 5.3.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "   Find the values of  ",
 Cell[BoxData[
  RowBox[{"Log", 
   RowBox[{"(", 
    RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}], "   ", "and", "   ", "log", 
   RowBox[{"(", 
    RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}]}]]],
 ".  \n\nSolution.  By standard computations, we have  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"log", 
     RowBox[{"(", 
      RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}]}], " ", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"ln", "|", 
       RowBox[{"1", "+", "\[ImaginaryI]"}], "|", 
       RowBox[{
        RowBox[{"+", " ", "\[ImaginaryI]"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Arg", 
           RowBox[{"(", 
            RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}]}], "+", 
          RowBox[{"2", "n", " ", "\[Pi]"}]}], ")"}]}]}], ":", " ", 
      RowBox[{
       StyleBox["where",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], " ", "n", " ", 
       StyleBox["is",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], 
       StyleBox[" ",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], 
       StyleBox["an",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], 
       StyleBox[" ",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], 
       StyleBox["integer",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]]}]}], "}"}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                       ", 
   RowBox[{"=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"ln", 
        SqrtBox["2"]}], "+", " ", 
       RowBox[{"\[ImaginaryI]", 
        RowBox[{"(", 
         RowBox[{
          FractionBox["\[Pi]", "4"], "+", 
          RowBox[{"2", "n", " ", "\[Pi]"}]}], ")"}]}]}], ":", " ", 
      RowBox[{
       StyleBox["where",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], " ", "n", " ", 
       StyleBox["is",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], 
       StyleBox[" ",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], 
       StyleBox["an",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], 
       StyleBox[" ",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], 
       StyleBox["integer",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]]}]}], "}"}]}]}]}]],
 "  \n\t\t\tand\n\t\t\t",
 Cell[BoxData[
  RowBox[{"       ", 
   RowBox[{
    RowBox[{
     RowBox[{"log", 
      RowBox[{"(", "\[ImaginaryI]", ")"}]}], " ", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"ln", "|", "\[ImaginaryI]", "|", 
        RowBox[{
         RowBox[{"+", " ", "\[ImaginaryI]"}], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Arg", 
            RowBox[{"(", "\[ImaginaryI]", ")"}]}], "+", 
           RowBox[{"2", "n", " ", "\[Pi]"}]}], ")"}]}]}], ":", " ", 
       RowBox[{
        StyleBox["where",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], " ", "n", " ", 
        StyleBox["is",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], 
        StyleBox[" ",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], 
        StyleBox["an",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], 
        StyleBox[" ",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], 
        StyleBox["integer",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]]}]}], "}"}]}], "\[IndentingNewLine]", 
    "\[IndentingNewLine]", "                       ", 
    RowBox[{"=", 
     RowBox[{"{", " ", 
      RowBox[{
       RowBox[{"\[ImaginaryI]", 
        RowBox[{"(", 
         RowBox[{
          FractionBox["\[Pi]", "2"], "+", 
          RowBox[{"2", "n", " ", "\[Pi]"}]}], ")"}]}], ":", " ", 
       RowBox[{
        StyleBox["where",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], " ", "n", " ", 
        StyleBox["is",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], 
        StyleBox[" ",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], 
        StyleBox["an",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], 
        StyleBox[" ",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], 
        StyleBox["integer",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]]}]}], "}"}]}]}]}]]],
 "    \nThe principal values are\n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{"Log", 
    RowBox[{"(", 
     RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}]}], " ", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"ln", 
      SqrtBox["2"]}], "+", " ", 
     RowBox[{"\[ImaginaryI]", 
      FractionBox["\[Pi]", "4"]}]}], "=", 
    RowBox[{
     FractionBox[
      RowBox[{"ln", " ", "2"}], "2"], "+", " ", 
     RowBox[{"\[ImaginaryI]", 
      FractionBox["\[Pi]", "4"]}]}]}]}], "\[IndentingNewLine]", 
 "and", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Log", 
    RowBox[{"(", "\[ImaginaryI]", ")"}]}], " ", "=", " ", 
   RowBox[{"\[ImaginaryI]", 
    FractionBox["\[Pi]", "2"]}]}]}]],
 "  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 5.3.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 "Enter  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{"1", "+", "\[ImaginaryI]"}]}]]],
 "  and take its logarithm. "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", 
     RowBox[{"w", ",", "z"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"z", "=", 
     RowBox[{"1", "+", "\[ImaginaryI]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"w", " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"Log", "[", "z", "]"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Log[\>\"", ",", "z", ",", "\"\<] = \>\"", ",", "w"}], "]"}],
     ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399280681953125*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "The best we can do for the multivalued  ",
 Cell[BoxData[
  RowBox[{"log", 
   RowBox[{"(", 
    RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}]}]]],
 "  is to add  ",
 Cell[BoxData[
  RowBox[{
  "\[ImaginaryI]", " ", "2", "\[Pi]", " ", "n", "   ", "to", "   ", "Log", 
   RowBox[{"(", 
    RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}]}]]],
 ". "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", "w", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", "n", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["w", "1"], " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"Log", "[", "z", "]"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["w", "2"], " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{
       RowBox[{"Log", "[", "z", "]"}], " ", "+", " ", 
       RowBox[{"\[ImaginaryI]", " ", "2", " ", "\[Pi]", " ", "n"}]}], " ", 
      "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Log[\>\"", ",", "z", ",", "\"\<] = \>\"", ",", 
      RowBox[{"Log", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Log[\>\"", ",", "z", ",", "\"\<] = \>\"", ",", 
      SubscriptBox["w", "1"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<log[\>\"", ",", "z", ",", "\"\<] = \>\"", ",", 
      RowBox[{
       RowBox[{"Log", "[", "z", "]"}], " ", "+", " ", 
       RowBox[{"\[ImaginaryI]", " ", "2", " ", "\[Pi]", " ", "n"}]}]}], "]"}],
     ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<log[\>\"", ",", "z", ",", "\"\<] = \>\"", ",", 
      SubscriptBox["w", "2"]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399280686125*^9},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Extra Example 2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  The transformation  ",
 StyleBox["w = Log(z)",
  FontFamily->"Courier New"],
 "  maps the ",
 StyleBox["z",
  FontFamily->"Courier New"],
 "-plane punctured at the origin onto the horizontal strip in the ",
 StyleBox["w",
  FontFamily->"Courier New"],
 "-plane."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Explore Solution for Extra Example 2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 "  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", "z", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", "f", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"Iden", "[", "z_", "]"}], " ", "=", " ", "z"}], ";"}], " ", "\n",
    
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"Log", "[", "z", "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"PolarMap", "[", 
    RowBox[{"Iden", ",", " ", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1.0", "150"], ",", "150.1", ",", "15"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3.141"}], ",", "3.141", ",", 
       FractionBox["3.141", "6"]}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "150"}], ",", "150"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "150"}], ",", "150"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "150"}], ",", "150", ",", "150"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "150"}], ",", "150", ",", "150"}], "]"}]}], "}"}]}], 
     ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The z-plane punctured at the origin  {z: |z| > 0}.\>\"", "]"}], 
    ";"}], " ", "\n", 
   RowBox[{"PolarMap", "[", 
    RowBox[{"f", ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1.0", "150"], ",", "150.1", ",", "15"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3.141"}], ",", "3.141", ",", 
       FractionBox["3.141", "6"]}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "5.3"}], ",", "5.3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "3.3"}], ",", "3.3"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["3.3", "5.3"]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "5"}], ",", "5", ",", "5"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "\[Pi]"}], ",", "\[Pi]", ",", "\[Pi]"}], "]"}]}], 
       "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The image is the horizontal strip - \[Pi] < v \[LessEqual] \[Pi],\>\
\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<under the mapping  w = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399280698046875*^9, 3.3992807219375*^9}, {
  3.3997998235153775`*^9, 3.399799823718502*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 "\tWe now investigate some of the properties of ",
 StyleBox["log(z)",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["Log(z)",
  FontFamily->"Courier New"],
 ".  From Equations ",
 StyleBox["(5-10)",
  FontColor->RGBColor[0, 0, 1]],
 ", ",
 StyleBox["(5-12)",
  FontColor->RGBColor[0, 0, 1]],
 ", and ",
 StyleBox["(5-14)",
  FontColor->RGBColor[0, 0, 1]],
 ", it follows that\n\n",
 StyleBox["(5-15)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"exp", 
    RowBox[{"(", 
     RowBox[{"Log", " ", "z"}], ")"}]}], " ", "=", " ", "z"}]]],
 "   for all z\[NotEqual]0   \n\t\t\tand \n",
 StyleBox["(5-16)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Log", 
    RowBox[{"(", 
     RowBox[{"exp", " ", "z"}], ")"}]}], " ", "=", " ", "z"}]]],
 ",   provided   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"-", "\[Pi]"}], " ", "<", " ", 
   RowBox[{"Arg", 
    RowBox[{"(", "z", ")"}]}], " ", "\[LessEqual]", " ", "\[Pi]"}]]],
 ",    \n\nand that the mapping  ",
 StyleBox["w = Log(z)",
  FontFamily->"Courier New"],
 "  is one-to-one from domain  ",
 Cell[BoxData[
  RowBox[{"D", "=", 
   RowBox[{"{", 
    RowBox[{"z", ":", 
     RowBox[{"|", "z", "|", 
      RowBox[{">", "0"}]}]}], "}"}]}]]],
 "  in the ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " plane onto the horizontal strip  ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{"w", ":", 
    RowBox[{
     RowBox[{"-", "\[Pi]"}], " ", "<", " ", 
     RowBox[{"Im", 
      RowBox[{"(", "w", ")"}]}], "\[LessEqual]", " ", "\[Pi]"}]}], "}"}]]],
 "  in the ",
 StyleBox["w",
  FontFamily->"Courier New"],
 " plane.\n    The following example illustrates that, even though ",
 StyleBox["Log(z)",
  FontFamily->"Courier New"],
 " is not continuous along the negative real axis, it is still defined \
there."
}], "Text"],

Cell[TextData[{
 StyleBox["Example 5.4.  ",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "Identity  reveals that  \n\n\t",
 StyleBox["(a)",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Log", 
    RowBox[{"(", 
     RowBox[{"-", "\[ExponentialE]"}], ")"}]}], " ", "=", "  ", 
   RowBox[{
    RowBox[{"ln", "|", 
     RowBox[{"-", "\[ExponentialE]"}], "|", " ", 
     RowBox[{
      RowBox[{"+", " ", "\[ImaginaryI]"}], " ", "Arg", 
      RowBox[{"(", 
       RowBox[{"-", "\[ExponentialE]"}], ")"}]}]}], " ", "=", "  ", 
    RowBox[{"1", "+", " ", "\[ImaginaryI]", " "}]}]}]]],
 ",   and  \n\n\t",
 StyleBox["(b)",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Log", 
    RowBox[{"(", 
     RowBox[{"-", "1"}], ")"}]}], " ", "=", "  ", 
   RowBox[{
    RowBox[{"ln", "|", 
     RowBox[{"-", "1"}], "|", " ", 
     RowBox[{
      RowBox[{"+", "  ", "\[ImaginaryI]"}], "  ", "Arg", 
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}]}]}], "  ", "=", "  ", "\[ImaginaryI]", 
    "  "}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 5.4.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 StyleBox["(a)",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Enter  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{"-", "\[ExponentialE]"}]}]]],
 "  and take its logarithm. "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", 
     RowBox[{"z", ",", "w"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"z", "  ", "=", " ", 
     RowBox[{"-", " ", "\[ExponentialE]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["w", "1"], " ", "=", " ", 
     RowBox[{
      RowBox[{"Log", "[", 
       RowBox[{"Abs", "[", "z", "]"}], "]"}], " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"Arg", "[", "z", "]"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["w", "2"], " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"Log", "[", "z", "]"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<z = \>\"", ",", "z"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Log[Abs[\>\"", ",", "z", ",", "\"\<]] = \>\"", ",", "\"\<Log[\>\"", 
      ",", 
      RowBox[{"Abs", "[", "z", "]"}], ",", "\"\<] = \>\"", ",", " ", 
      RowBox[{"Log", "[", 
       RowBox[{"Abs", "[", "z", "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Arg[\>\"", ",", "z", ",", "\"\<]  = \>\"", ",", 
      RowBox[{"Arg", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Log[Abs[\>\"", ",", "z", ",", "\"\<]] + \[ImaginaryI] Arg[\>\"", 
      ",", "z", ",", "\"\<] = \>\"", ",", 
      SubscriptBox["w", "1"]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Log[\>\"", ",", "z", ",", "\"\<] = (\>\"", ",", 
      RowBox[{"Log", "[", 
       RowBox[{"Abs", "[", "z", "]"}], "]"}], ",", 
      "\"\<) + \[ImaginaryI] (\>\"", ",", " ", 
      RowBox[{"Arg", "[", "z", "]"}], ",", "\"\<)\>\""}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Log[\>\"", ",", "z", ",", "\"\<] = \>\"", ",", 
      SubscriptBox["w", "2"]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399280732171875*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["(b)",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Enter  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{"-", "1"}]}]]],
 "  and take its logarithm. "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", 
     RowBox[{"z", ",", "w"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"z", "  ", "=", " ", 
     RowBox[{"-", " ", "1"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["w", "1"], " ", "=", " ", 
     RowBox[{
      RowBox[{"Log", "[", 
       RowBox[{"Abs", "[", "z", "]"}], "]"}], " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"Arg", "[", "z", "]"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["w", "2"], " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"Log", "[", "z", "]"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<z = \>\"", ",", "z"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Log[Abs[\>\"", ",", "z", ",", "\"\<]] = \>\"", ",", "\"\<Log[\>\"", 
      ",", 
      RowBox[{"Abs", "[", "z", "]"}], ",", "\"\<] = \>\"", ",", " ", 
      RowBox[{"Log", "[", 
       RowBox[{"Abs", "[", "z", "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Arg[\>\"", ",", "z", ",", "\"\<]  = \>\"", ",", 
      RowBox[{"Arg", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Log[Abs[\>\"", ",", "z", ",", "\"\<]] + \[ImaginaryI] Arg[\>\"", 
      ",", "z", ",", "\"\<] = \>\"", ",", 
      SubscriptBox["w", "1"]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Log[\>\"", ",", "z", ",", "\"\<] = (\>\"", ",", 
      RowBox[{"Log", "[", 
       RowBox[{"Abs", "[", "z", "]"}], "]"}], ",", 
      "\"\<) + \[ImaginaryI] (\>\"", ",", " ", 
      RowBox[{"Arg", "[", "z", "]"}], ",", "\"\<)\>\""}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Log[\>\"", ",", "z", ",", "\"\<] = \>\"", ",", 
      SubscriptBox["w", "2"]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399280735828125*^9},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 "\tWhen  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{"x", "+", 
    RowBox[{"\[ImaginaryI]", " ", "y"}]}]}]]],
 ",  where ",
 StyleBox["x",
  FontFamily->"Courier New"],
 " is a positive real number, the principal value of the complex logarithm of \
",
 StyleBox["z",
  FontFamily->"Courier New"],
 " is  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Log", 
    RowBox[{"(", 
     RowBox[{"x", "+", 
      RowBox[{"\[ImaginaryI]", " ", "0"}]}], ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"ln", " ", "x"}], "+", 
     RowBox[{"\[ImaginaryI]", " ", "Arg", 
      RowBox[{"(", "x", ")"}]}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"ln", " ", "x"}], "+", 
      RowBox[{"\[ImaginaryI]", " ", "0"}]}], " ", "=", " ", 
     RowBox[{"ln", " ", "x"}]}]}]}]]],
 ",  \n\t\t\nwhere ",
 Cell[BoxData[
  RowBox[{"x", ">", "0"}]]],
 ".  Hence ",
 StyleBox["Log",
  FontFamily->"Courier New"],
 " is an extension of the real function ",
 StyleBox["ln(x)",
  FontFamily->"Courier New"],
 " to the complex case.  Are there other similarities?  Let's use complex \
function theory to find the derivative of ",
 StyleBox["Log(z)",
  FontFamily->"Courier New"],
 ".   \nWhen we use polar coordinates for  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{
    RowBox[{"r", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]]}], " ", "\[NotEqual]", " ", 
    "0"}]}]]],
 ",  equation ",
 StyleBox["(5-14)",
  FontColor->RGBColor[0, 0, 1]],
 " becomes  "
}], "Text"],

Cell[TextData[{
 "\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"Log", 
     RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
    RowBox[{"Log", 
     RowBox[{"(", 
      RowBox[{"r", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]]}], ")"}]}]}], " ", 
   "\n"}], "\[IndentingNewLine]", 
  RowBox[{"                 ", 
   RowBox[{"=", "  ", 
    RowBox[{"ln", " ", "|", 
     RowBox[{"r", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]]}], "|", "  ", 
     RowBox[{
      RowBox[{"+", "  ", "\[ImaginaryI]"}], " ", "Arg", 
      RowBox[{"(", 
       RowBox[{"r", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]]}], ")"}]}]}]}], "\n", 
   "                     "}], "\[IndentingNewLine]", 
  RowBox[{"                 ", 
   RowBox[{
    RowBox[{"=", " ", 
     RowBox[{
      RowBox[{"ln", " ", "r"}], "  ", "+", " ", 
      RowBox[{"\[ImaginaryI]", "  ", "\[Theta]"}]}]}], ",", "   ", 
    RowBox[{
     RowBox[{
      StyleBox["for",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "  ", "r"}], ">", 
     RowBox[{
      RowBox[{"0", "  ", 
       StyleBox["and",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]]}], "   ", "-", "\[Pi]"}], " ", "<", " ", 
     "\[Theta]", " ", "\[LessEqual]", " ", "\[Pi]"}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                 ", 
   RowBox[{"=", 
    RowBox[{
     RowBox[{"U", 
      RowBox[{"(", 
       RowBox[{"r", ",", "\[Theta]"}], ")"}]}], " ", "+", " ", 
     RowBox[{"\[ImaginaryI]", " ", "V", 
      RowBox[{"(", 
       RowBox[{"r", ",", "\[Theta]"}], ")"}]}]}]}]}]}]],
 "  "
}], "Text"],

Cell[TextData[{
 "where  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"U", 
    RowBox[{"(", 
     RowBox[{"r", ",", "\[Theta]"}], ")"}]}], " ", "=", 
   RowBox[{
    RowBox[{"ln", " ", "r", "   ", 
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "   ", "V", 
     RowBox[{"(", 
      RowBox[{"r", ",", "\[Theta]"}], ")"}]}], "=", "\[Theta]"}]}]]],
 ".  Because ",
 Cell[BoxData[
  RowBox[{"Arg", 
   RowBox[{"(", "z", ")"}]}]]],
 " is discontinuous only at points in its domain that lie on the negative \
real axis, U and V have continuous partials for any point ",
 Cell[BoxData[
  RowBox[{"(", 
   RowBox[{"r", ",", "\[Theta]"}], ")"}]]],
 " in their domain, provided ",
 Cell[BoxData[
  RowBox[{"r", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]]}]]],
 " is not on the negative real axis, that is, provided  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"-", "\[Pi]"}], " ", "<", " ", "\[Theta]", " ", "<", " ", 
   "\[Pi]"}]]],
 "  (Note the strict inequality for  here.).   In addition, the polar form of \
the Cauchy-Riemann equations holds in this region (see Equation ",
 StyleBox["(3-22)",
  FontColor->RGBColor[0, 0, 1]],
 " of Section 3.2), since  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["U", "r"], 
     RowBox[{"(", 
      RowBox[{"r", ",", "\[Theta]"}], ")"}]}], " ", "=", 
    FractionBox["1", "r"]}], ",", " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["U", "\[Theta]"], 
     RowBox[{"(", 
      RowBox[{"r", ",", "\[Theta]"}], ")"}]}], " ", "=", "0"}], ",", " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["V", "r"], 
     RowBox[{"(", 
      RowBox[{"r", ",", "\[Theta]"}], ")"}]}], "=", "0"}], ",", " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["V", "\[Theta]"], 
     RowBox[{"(", 
      RowBox[{"r", ",", "\[Theta]"}], ")"}]}], "=", "1"}]}]]],
 "  it follows that  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["U", "r"], 
    RowBox[{"(", 
     RowBox[{"r", ",", "\[Theta]"}], ")"}]}], " ", "=", " ", 
   RowBox[{
    FractionBox["1", "r"], " ", "=", " ", 
    RowBox[{
     FractionBox["1", "r"], 
     SubscriptBox["V", "\[Theta]"], 
     RowBox[{"(", 
      RowBox[{"r", ",", "\[Theta]"}], ")"}]}]}]}]]],
 "\n\t\tand\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["U", "\[Theta]"], 
    RowBox[{"(", 
     RowBox[{"r", ",", "\[Theta]"}], ")"}]}], " ", "=", " ", 
   RowBox[{"0", " ", "=", " ", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"-", "1"}], "r"], "0"}], "=", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"-", "1"}], "r"]}], 
      SubscriptBox["V", "r"], 
      RowBox[{"(", 
       RowBox[{"r", ",", "\[Theta]"}], ")"}]}]}]}]}]]]
}], "Text"],

Cell[TextData[{
 "Using Theorem 3.5 of Section 3,2, we see that  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     FractionBox["d", "dz"], "Log", 
     RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", " ", "\[ImaginaryI]"}], " ", "\[Theta]"}]], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubscriptBox["U", "r"], 
        RowBox[{"(", 
         RowBox[{"r", ",", "\[Theta]"}], ")"}]}], " ", "+", 
       RowBox[{"\[ImaginaryI]", "  ", 
        SubscriptBox["U", "\[Theta]"], 
        RowBox[{"(", 
         RowBox[{"r", ",", "\[Theta]"}], ")"}]}]}], ")"}]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                       ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", " ", "\[ImaginaryI]"}], " ", "\[Theta]"}]], 
       RowBox[{"(", 
        RowBox[{
         FractionBox["1", "r"], " ", "+", 
         RowBox[{"0", " ", "\[ImaginaryI]"}]}], ")"}]}], "  ", "=", "  ", 
      FractionBox["1", 
       RowBox[{"r", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]]}]]}]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                       ", 
   RowBox[{"=", " ", 
    FractionBox["1", "z"]}]}]}]],
 "  \n\nprovided   ",
 Cell[BoxData[
  RowBox[{"r", ">", 
   RowBox[{
    RowBox[{"0", "  ", 
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]]}], "  ", "-", "\[Pi]"}], " ", "<", " ", 
   "\[Theta]", " ", "<", " ", "\[Pi]"}]]],
 ".  Thus the principal branch of the complex logarithm has the derivative we \
would expect.  Other properties of the logarithm carry over, but only in \
specified regions of the complex plane.  "
}], "Text"],

Cell[TextData[{
 "\n",
 StyleBox["Example 5.5.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Show that the identity  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Log", 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["z", "1"], 
      SubscriptBox["z", "2"]}], ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"Log", 
     RowBox[{"(", 
      SubscriptBox["z", "1"], ")"}]}], " ", "+", " ", 
    RowBox[{"Log", 
     RowBox[{"(", 
      SubscriptBox["z", "2"], ")"}]}]}]}]]],
 "  is not always valid.  \n\nSolution.  Let  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SqrtBox["3"]}], "+", 
     RowBox[{"\[ImaginaryI]", "  ", 
      StyleBox["and",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "  ", 
      SubscriptBox["z", "2"]}]}], "=", 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     RowBox[{"\[ImaginaryI]", " ", 
      SqrtBox["3"]}]}]}]}]]],
 ".  Then  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{"Log", 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["z", "1"], " ", 
      SubscriptBox["z", "2"]}], ")"}]}], "  ", "=", "  ", 
   RowBox[{"Log", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        SqrtBox["3"]}], "+", "\[ImaginaryI]"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"\[ImaginaryI]", " ", 
        SqrtBox["3"]}]}], ")"}]}], "]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                        ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{"Log", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "4"}], " ", "\[ImaginaryI]"}], ")"}]}], "  ", "=", "   ",
      
     RowBox[{
      RowBox[{"ln", " ", "4"}], " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", 
       FractionBox[
        RowBox[{" ", 
         RowBox[{"-", "\[Pi]"}]}], "2"]}]}]}]}], 
   "  "}], "\[IndentingNewLine]", 
  RowBox[{"                        ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{"ln", " ", "4"}], " ", "-", " ", 
     RowBox[{"\[ImaginaryI]", 
      FractionBox["\[Pi]", "2"]}]}]}]}]}]],
 "  \n\t\tbut\n\t\t\t",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Log", 
       RowBox[{"(", 
        SubscriptBox["z", "1"], ")"}]}], "+", 
      RowBox[{"Log", 
       RowBox[{"(", 
        SubscriptBox["z", "2"], ")"}]}]}], "  ", "=", "  ", 
     RowBox[{
      RowBox[{"(", " ", 
       RowBox[{
        RowBox[{"Log", "[", "2", "]"}], "+", 
        RowBox[{"\[ImaginaryI]", 
         FractionBox[
          RowBox[{"5", " ", "\[Pi]"}], "6"]}]}], " ", ")"}], "+", 
      RowBox[{"(", " ", 
       RowBox[{
        RowBox[{"Log", "[", "2", "]"}], "+", 
        RowBox[{"\[ImaginaryI]", 
         FractionBox[
          RowBox[{"2", " ", "\[Pi]"}], "3"]}]}], ")"}]}]}], 
    "\[IndentingNewLine]", "                                         ", 
    RowBox[{"=", "  ", 
     RowBox[{
      RowBox[{"2", 
       RowBox[{"Log", "[", "2", "]"}]}], "+", 
      RowBox[{"\[ImaginaryI]", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{"5", " ", "\[Pi]"}], "6"], "+", 
         FractionBox[
          RowBox[{"2", " ", "\[Pi]"}], "3"]}], ")"}]}]}]}], 
    "\[IndentingNewLine]", "                                         ", 
    RowBox[{"=", "  ", 
     RowBox[{
      RowBox[{"ln", " ", "4"}], "  ", "+", " ", 
      RowBox[{"\[ImaginaryI]", 
       FractionBox[
        RowBox[{"3", " ", "\[Pi]"}], "2"]}]}]}]}]}]]],
 "   \n\nSince  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"ln", " ", "4"}], " ", "-", " ", 
    RowBox[{"\[ImaginaryI]", 
     FractionBox["\[Pi]", "2"]}]}], "\[NotEqual]", 
   RowBox[{
    RowBox[{"ln", " ", "4"}], "  ", "+", " ", 
    RowBox[{"\[ImaginaryI]", 
     FractionBox[
      RowBox[{"3", " ", "\[Pi]"}], "2"]}]}]}]]],
 ",  this is a counterexample for which   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Log", 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["z", "1"], 
      SubscriptBox["z", "2"]}], ")"}]}], " ", "\[NotEqual]", " ", 
   RowBox[{
    RowBox[{"Log", 
     RowBox[{"(", 
      SubscriptBox["z", "1"], ")"}]}], " ", "+", " ", 
    RowBox[{"Log", 
     RowBox[{"(", 
      SubscriptBox["z", "2"], ")"}]}]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 5.5.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 "Enter  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SqrtBox["3"]}], "+", 
     RowBox[{"\[ImaginaryI]", "  ", "and", "  ", 
      SubscriptBox["z", "2"]}]}], "=", 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     RowBox[{"\[ImaginaryI]", " ", 
      SqrtBox["3"]}]}]}]}]]],
 "  and take their logarithms. "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", 
     RowBox[{"z", ",", "w"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "1"], " ", "=", " ", 
     RowBox[{
      RowBox[{"-", " ", 
       SqrtBox["3"]}], " ", "+", " ", "\[ImaginaryI]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "2"], " ", "=", " ", 
     RowBox[{
      RowBox[{"-", " ", "1"}], " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", 
       SqrtBox["3"]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "3"], " ", "=", " ", 
     RowBox[{"Expand", "[", 
      RowBox[{
       SubscriptBox["z", "1"], " ", 
       SubscriptBox["z", "2"]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["w", "1"], " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"Log", "[", 
       SubscriptBox["z", "1"], "]"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["w", "2"], " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"Log", "[", 
       SubscriptBox["z", "2"], "]"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["w", "3"], " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"Log", "[", 
       SubscriptBox["z", "3"], "]"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<             \!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["z", "1"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<             \!\(\*SubscriptBox[\(z\), \(2\)]\) = \>\"", ",", 
      SubscriptBox["z", "2"]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<          \!\(\*SubscriptBox[\(z\), \(1\)]\) \!\(\*SubscriptBox[\(z\
\), \(2\)]\) = \>\"", ",", 
      SubscriptBox["z", "3"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<        Log[\!\(\*SubscriptBox[\(z\), \(1\)]\)] = \>\"", ",", 
      SubscriptBox["w", "1"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<        Log[\!\(\*SubscriptBox[\(z\), \(2\)]\)] = \>\"", ",", 
      SubscriptBox["w", "2"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<     Log[\!\(\*SubscriptBox[\(z\), \(1\)]\) \
\!\(\*SubscriptBox[\(z\), \(2\)]\)] = \>\"", ",", 
      SubscriptBox["w", "3"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Log[\!\(\*SubscriptBox[\(z\), \
\(1\)]\)]+Log[\!\(\*SubscriptBox[\(z\), \(2\)]\)] = \>\"", ",", 
      RowBox[{
       SubscriptBox["w", "1"], "+", 
       SubscriptBox["w", "2"]}]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{
       SubscriptBox["w", "1"], "+", 
       SubscriptBox["w", "2"]}], ",", "\"\< =? \>\"", ",", 
      SubscriptBox["w", "3"]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<  Is Log[\!\(\*SubscriptBox[\(z\), \(1\)]\) \
\!\(\*SubscriptBox[\(z\), \(2\)]\)] = Log[\!\(\*SubscriptBox[\(z\), \(1\)]\)] \
+ Log[\!\(\*SubscriptBox[\(z\), \(2\)]\)] = ?  \>\"", ",", 
      RowBox[{
       SubscriptBox["w", "3"], " ", "\[Equal]", 
       RowBox[{
        SubscriptBox["w", "1"], "+", 
        SubscriptBox["w", "2"]}]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399280744921875*^9}],

Cell[TextData[{
 "So we find in this counter example that it is possible for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Log", "[", 
    RowBox[{
     SubscriptBox["z", "1"], 
     SubscriptBox["z", "2"]}], "]"}], "\[NotEqual]", " ", 
   RowBox[{
    RowBox[{"Log", "[", 
     SubscriptBox["z", "1"], "]"}], "+", 
    RowBox[{"Log", "[", 
     SubscriptBox["z", "2"], "]"}]}]}]]],
 ",\nthis is in contrast to the multivalued logarithm for which  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"log", 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["z", "1"], " ", 
      SubscriptBox["z", "2"]}], ")"}]}], "=", 
   RowBox[{
    RowBox[{"log", 
     RowBox[{"(", 
      SubscriptBox["z", "1"], ")"}]}], "+", 
    RowBox[{"log", 
     RowBox[{"(", 
      SubscriptBox["z", "2"], ")"}]}]}]}]]],
 ".  "
}], "Text"]
}, Closed]],

Cell[TextData[{
 "\tOur next result explains why the identity  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Log", 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["z", "1"], 
      SubscriptBox["z", "2"]}], ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"Log", 
     RowBox[{"(", 
      SubscriptBox["z", "1"], ")"}]}], " ", "+", " ", 
    RowBox[{"Log", 
     RowBox[{"(", 
      SubscriptBox["z", "2"], ")"}]}]}]}]]],
 "  did not hold for the particular numbers we chose."
}], "Text"],

Cell[TextData[{
 StyleBox["\nTheorem 5.2.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  The identity  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Log", 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["z", "1"], 
      SubscriptBox["z", "2"]}], ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"Log", 
     RowBox[{"(", 
      SubscriptBox["z", "1"], ")"}]}], " ", "+", " ", 
    RowBox[{"Log", 
     RowBox[{"(", 
      SubscriptBox["z", "2"], ")"}]}]}]}]],
  Evaluatable->False,
  AspectRatioFixed->True],
 "  holds true if and only if  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"-", "\[Pi]"}], "<", 
   RowBox[{
    RowBox[{"Arg", 
     RowBox[{"(", 
      SubscriptBox["z", "1"], ")"}]}], "+", 
    RowBox[{"Arg", 
     RowBox[{"(", 
      SubscriptBox["z", "2"], ")"}]}]}], "\[LessEqual]", "\[Pi]"}]]],
 ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof of Theorem 5.2.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 "Suppose first that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"-", "\[Pi]"}], "<", 
   RowBox[{
    RowBox[{"Arg", 
     RowBox[{"(", 
      SubscriptBox["z", "1"], ")"}]}], "+", 
    RowBox[{"Arg", 
     RowBox[{"(", 
      SubscriptBox["z", "2"], ")"}]}]}], "\[LessEqual]", "\[Pi]"}]]],
 ".   By definition,  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Log", 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["z", "1"], 
      SubscriptBox["z", "2"]}], ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"ln", "|", 
     RowBox[{
      SubscriptBox["z", "1"], 
      SubscriptBox["z", "2"]}], "|", 
     RowBox[{
      RowBox[{"+", " ", "\[ImaginaryI]"}], " ", "Arg", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["z", "1"], 
        SubscriptBox["z", "2"]}], ")"}]}]}], " ", "=", "  ", 
    RowBox[{"ln", "|", 
     SubscriptBox["z", "1"], "|", 
     RowBox[{"+", "ln"}], "|", 
     SubscriptBox["z", "2"], "|", 
     RowBox[{
      RowBox[{"+", " ", "\[ImaginaryI]"}], " ", "Arg", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["z", "1"], 
        SubscriptBox["z", "2"]}], ")"}]}]}]}]}]]],
 ".   As  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"-", "\[Pi]"}], "<", 
   RowBox[{
    RowBox[{"Arg", 
     RowBox[{"(", 
      SubscriptBox["z", "1"], ")"}]}], "+", 
    RowBox[{"Arg", 
     RowBox[{"(", 
      SubscriptBox["z", "2"], ")"}]}]}], "\[LessEqual]", "\[Pi]"}]]],
 ",  it follows that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Arg", 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["z", "1"], 
      SubscriptBox["z", "2"]}], ")"}]}], "=", 
   RowBox[{
    RowBox[{"Arg", 
     RowBox[{"(", 
      SubscriptBox["z", "1"], ")"}]}], "+", 
    RowBox[{"Arg", 
     RowBox[{"(", 
      SubscriptBox["z", "2"], ")"}]}]}]}]]],
 "  (explain!),  and so  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Log", 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["z", "1"], 
      SubscriptBox["z", "2"]}], ")"}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"ln", "|", 
     SubscriptBox["z", "1"], "|", 
     RowBox[{"+", " ", "ln"}], "|", 
     SubscriptBox["z", "2"], "|", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"+", "  ", "\[ImaginaryI]"}], " ", "Arg", 
       RowBox[{"(", 
        SubscriptBox["z", "1"], ")"}]}], "+", "  ", 
      RowBox[{"\[ImaginaryI]", " ", "Arg", 
       RowBox[{"(", 
        SubscriptBox["z", "2"], ")"}]}]}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{"Log", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["z", "1"], 
        SubscriptBox["z", "2"]}], ")"}]}], " ", "=", " ", 
     RowBox[{
      RowBox[{"Log", 
       RowBox[{"(", 
        SubscriptBox["z", "1"], ")"}]}], " ", "+", " ", 
      RowBox[{"Log", 
       RowBox[{"(", 
        SubscriptBox["z", "2"], ")"}]}]}]}]}]}]]],
 ".  The \"only if\" part is left as an exercise."
}], "Text"]
}, Closed]],

Cell[TextData[{
 "\tAs Example 5.5 and Theorem 5.2 illustrate, properties of the complex \
logarithm don't carry over when arguments of products combine in such a way \
that they drop down to ",
 Cell[BoxData[
  RowBox[{"-", "\[Pi]"}]]],
 " or rise above ",
 Cell[BoxData[
  RowBox[{"-", "\[Pi]"}]]],
 ". This is because of the restrictions placed on the domain of the function \
",
 Cell[BoxData[
  RowBox[{"Arg", 
   RowBox[{"(", "z", ")"}]}]]],
 ".  From the set of numbers associated with the multivalued logarithm, \
however, we can formulate properties that look exactly the same as those \
corresponding with the real logarithm."
}], "Text"],

Cell[TextData[{
 StyleBox["Theorem 5.3.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Let ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], " ", "and", " ", 
   SubscriptBox["z", "2"]}]]],
 " be nonzero complex numbers. The multivalued function ",
 Cell[BoxData[
  RowBox[{"log", 
   RowBox[{"(", "z", ")"}]}]]],
 " obeys the familiar properties of logarithms: \n\n",
 StyleBox["(5-17)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"log", 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["z", "1"], " ", 
      SubscriptBox["z", "2"]}], ")"}]}], "=", 
   RowBox[{
    RowBox[{"log", 
     RowBox[{"(", 
      SubscriptBox["z", "1"], ")"}]}], "+", 
    RowBox[{"log", 
     RowBox[{"(", 
      SubscriptBox["z", "2"], ")"}]}]}]}]]],
 ",  \n\n",
 StyleBox["(5-18)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"log", 
    RowBox[{"(", 
     FractionBox[
      SubscriptBox["z", "1"], 
      RowBox[{" ", 
       SubscriptBox["z", "2"]}]], ")"}]}], "=", 
   RowBox[{
    RowBox[{"log", 
     RowBox[{"(", 
      SubscriptBox["z", "1"], ")"}]}], "-", 
    RowBox[{"log", 
     RowBox[{"(", 
      SubscriptBox["z", "2"], ")"}]}]}]}]]],
 ", and\n\n",
 StyleBox["(5-19)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"log", 
    RowBox[{"(", 
     FractionBox["1", 
      RowBox[{" ", "z"}]], ")"}]}], "=", 
   RowBox[{
    RowBox[{"-", "log"}], 
    RowBox[{"(", "z", ")"}]}]}]]],
 ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof of Theorem 5.3.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 "Identity ",
 StyleBox["(5-17)",
  FontColor->RGBColor[0, 0, 1]],
 " is easy to establish:  Using Identity  ",
 StyleBox["(1-38)",
  FontColor->RGBColor[0, 0, 1]],
 " in Section 1.4 concerning the argument of a product (and keeping in mind \
we are dealing with sets of numbers), we write  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"log", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["z", "1"], " ", 
       SubscriptBox["z", "2"]}], ")"}]}], " ", "=", " ", 
    RowBox[{"ln", "|", 
     RowBox[{
      SubscriptBox["z", "1"], "||", 
      SubscriptBox["z", "2"]}], "|", "  ", 
     RowBox[{
      RowBox[{"+", "  ", "\[ImaginaryI]"}], " ", "arg", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["z", "1"], " ", 
        SubscriptBox["z", "2"]}], ")"}]}]}]}], "\[IndentingNewLine]"}], "\n", 
 
  RowBox[{"\t              ", 
   RowBox[{"=", " ", 
    RowBox[{"ln", "|", 
     SubscriptBox["z", "1"], "|", 
     RowBox[{"+", "ln"}], "|", 
     SubscriptBox["z", "2"], "|", "  ", 
     RowBox[{
      RowBox[{
       RowBox[{"+", "  ", "\[ImaginaryI]"}], " ", "arg", 
       RowBox[{"(", 
        SubscriptBox["z", "1"], ")"}]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", "arg", 
       RowBox[{"(", 
        SubscriptBox["z", "2"], ")"}]}]}]}]}], "\n"}], "\[IndentingNewLine]", 
 
  RowBox[{"\t              ", 
   RowBox[{"=", " ", 
    RowBox[{
     RowBox[{
      StyleBox["(",
       FontSize->16], 
      RowBox[{"ln", "|", 
       SubscriptBox["z", "1"], "|", 
       RowBox[{
        RowBox[{"+", "\[ImaginaryI]"}], " ", "arg", 
        RowBox[{"(", 
         SubscriptBox["z", "1"], ")"}]}]}], 
      StyleBox[")",
       FontSize->16]}], "+", " ", 
     RowBox[{
      StyleBox["(",
       FontSize->16], 
      RowBox[{"ln", "|", 
       SubscriptBox["z", "2"], "|", 
       RowBox[{
        RowBox[{"+", "\[ImaginaryI]"}], " ", "arg", 
        RowBox[{"(", 
         SubscriptBox["z", "2"], ")"}]}]}], 
      StyleBox[")",
       FontSize->16]}]}]}], "\[IndentingNewLine]"}], "\n", 
  RowBox[{"                       ", 
   RowBox[{"=", " ", 
    RowBox[{
     RowBox[{"log", 
      RowBox[{"(", 
       SubscriptBox["z", "1"], ")"}]}], " ", "+", " ", 
     RowBox[{"log", 
      RowBox[{"(", 
       SubscriptBox["z", "2"], ")"}]}]}]}]}]}]],
 "   \n\nIdentities ",
 StyleBox["(5-18)",
  FontColor->RGBColor[0, 0, 1]],
 " and ",
 StyleBox["(5-19)",
  FontColor->RGBColor[0, 0, 1]],
 " are left as exercises."
}], "Text"]
}, Closed]],

Cell[TextData[{
 StyleBox["Property of  Log(z).",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  We know that ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"log", 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["z", "1"], " ", 
      SubscriptBox["z", "2"]}], ")"}]}], "=", 
   RowBox[{
    RowBox[{"log", 
     RowBox[{"(", 
      SubscriptBox["z", "1"], ")"}]}], "+", 
    RowBox[{"log", 
     RowBox[{"(", 
      SubscriptBox["z", "2"], ")"}]}]}]}]]],
 ", what about ",
 StyleBox["Log(z)",
  FontFamily->"Courier New"],
 "?"
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Demonstration of Property of  Log(z).",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 "Since the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " function  Log[z]  is the principal value of the logarithm, we will \
investigate the relationship for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"Log", "[", 
     RowBox[{
      SubscriptBox["z", "1"], " ", 
      SubscriptBox["z", "2"]}], "]"}], "  ", "and", "  ", 
    RowBox[{"Log", "[", 
     SubscriptBox["z", "1"], "]"}]}], "+", 
   RowBox[{"Log", "[", 
    SubscriptBox["z", "2"], "]"}]}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", 
     RowBox[{"v", ",", "x", ",", "y", ",", "z", ",", "Z"}], "]"}], ";"}], " ",
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "1"], "=", 
     RowBox[{
      SubscriptBox["x", "1"], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["y", "1"]}]}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "2"], "=", 
     RowBox[{
      SubscriptBox["x", "2"], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["y", "2"]}]}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "3"], "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["x", "1"], "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          SubscriptBox["y", "1"]}]}], ")"}], 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["x", "2"], "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          SubscriptBox["y", "2"]}]}], ")"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["v", "1"], " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{
       RowBox[{"Log", "[", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["x", "1"], "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["y", "1"]}]}], ")"}], "]"}], ",", "\n", "       ", 
       RowBox[{"TargetFunctions", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Im", ",", "Re"}], "}"}]}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["v", "2"], " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{
       RowBox[{"Log", "[", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["x", "2"], "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["y", "2"]}]}], ")"}], "]"}], ",", "\n", "       ", 
       RowBox[{"TargetFunctions", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Im", ",", "Re"}], "}"}]}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["v", "3"], " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{
       RowBox[{"Log", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["x", "1"], "+", 
           RowBox[{"\[ImaginaryI]", " ", 
            SubscriptBox["y", "1"]}]}], ")"}], 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["x", "2"], "+", 
           RowBox[{"\[ImaginaryI]", " ", 
            SubscriptBox["y", "2"]}]}], ")"}]}], "]"}], ",", "\n", "       ", 
       
       RowBox[{"TargetFunctions", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Im", ",", "Re"}], "}"}]}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"U", "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{
       RowBox[{"Log", "[", 
        RowBox[{"Abs", "[", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["x", "1"], "+", 
            RowBox[{"\[ImaginaryI]", " ", 
             SubscriptBox["y", "1"]}]}], ")"}], 
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["x", "2"], "+", 
            RowBox[{"\[ImaginaryI]", " ", 
             SubscriptBox["y", "2"]}]}], ")"}]}], "]"}], "]"}], ",", "\n", 
       "       ", 
       RowBox[{"TargetFunctions", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Im", ",", "Re"}], "}"}]}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"V", "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{
       RowBox[{"Arg", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["x", "1"], "+", 
           RowBox[{"\[ImaginaryI]", " ", 
            SubscriptBox["y", "1"]}]}], ")"}], 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["x", "2"], "+", 
           RowBox[{"\[ImaginaryI]", " ", 
            SubscriptBox["y", "2"]}]}], ")"}]}], "]"}], ",", "\n", "       ", 
       
       RowBox[{"TargetFunctions", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Im", ",", "Re"}], "}"}]}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["Z", "1"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(2\)]\) = \>\"", ",", 
      SubscriptBox["Z", "2"]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Log[\!\(\*SubscriptBox[\(z\), \(1\)]\)] = \>\"", ",", 
      SubscriptBox["v", "1"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Log[\!\(\*SubscriptBox[\(z\), \(2\)]\)] = \>\"", ",", 
      SubscriptBox["v", "2"]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\) \!\(\*SubscriptBox[\(z\), \(2\)]\
\) = \>\"", ",", 
      SubscriptBox["Z", "3"]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Log[Abs[\!\(\*SubscriptBox[\(z\), \(1\)]\) \
\!\(\*SubscriptBox[\(z\), \(2\)]\)]] = \>\"", ",", "U"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Arg[\!\(\*SubscriptBox[\(z\), \(1\)]\) \!\(\*SubscriptBox[\(z\), \
\(2\)]\)] = \>\"", ",", "V"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Log[\!\(\*SubscriptBox[\(z\), \(1\)]\) \!\(\*SubscriptBox[\(z\), \
\(2\)]\)] = \>\"", ",", 
      SubscriptBox["v", "3"]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39928076009375*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Remark.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 " The above formulas are for  Log[z]  and not  log(z).  What do you think \
about those pesky ArcTan's ? They are functions of two variables and evaluate \
properly throughout the complex plane to find  Arg[z].\n\n\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{"Arg", "[", 
    RowBox[{"-", "1"}], "]"}], "        ", "=", " ", 
   RowBox[{
    RowBox[{"ArcTan", "[", 
     RowBox[{
      RowBox[{"-", "1"}], ",", "0"}], "]"}], "    ", "=", " ", 
    "\[Pi]"}]}], "\n", 
  RowBox[{
   RowBox[{"Arg", "[", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "\[ImaginaryI]"}], "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{"ArcTan", "[", 
     RowBox[{
      RowBox[{"-", "1"}], ",", "1"}], "]"}], "    ", "=", " ", 
    FractionBox[
     RowBox[{"3", "\[Pi]"}], "4"]}]}], "\n", 
  RowBox[{
   RowBox[{"Arg", "[", "\[ImaginaryI]", "]"}], "          ", "=", " ", 
   RowBox[{
    RowBox[{"ArcTan", "[", 
     RowBox[{"0", ",", "1"}], "]"}], "       ", "=", " ", 
    FractionBox["\[Pi]", "2"]}]}], "\n", 
  RowBox[{
   RowBox[{"Arg", "[", 
    RowBox[{"1", "+", "\[ImaginaryI]"}], "]"}], "   ", "=", " ", 
   RowBox[{
    RowBox[{"ArcTan", "[", 
     RowBox[{"1", ",", "1"}], "]"}], "       ", "=", " ", 
    FractionBox["\[Pi]", "4"]}]}], "\n", 
  RowBox[{
   RowBox[{"Arg", "[", "1", "]"}], "          ", "=", " ", 
   RowBox[{
    RowBox[{"ArcTan", "[", 
     RowBox[{"1", ",", "0"}], "]"}], "       ", "=", " ", "0"}]}], "\n", 
  RowBox[{
   RowBox[{"Arg", "[", 
    RowBox[{"1", "-", "\[ImaginaryI]"}], "]"}], "   ", "=", " ", 
   RowBox[{
    RowBox[{"ArcTan", "[", 
     RowBox[{"1", ",", 
      RowBox[{"-", "1"}]}], "]"}], "    ", "=", " ", 
    FractionBox[
     RowBox[{"-", "\[Pi]"}], "4"]}]}], "\n", 
  RowBox[{
   RowBox[{"Arg", "[", 
    RowBox[{"-", "\[ImaginaryI]"}], "]"}], "       ", "=", " ", 
   RowBox[{
    RowBox[{"ArcTan", "[", 
     RowBox[{"0", ",", 
      RowBox[{"-", "1"}]}], "]"}], "    ", "=", " ", 
    FractionBox[
     RowBox[{"-", "\[Pi]"}], "2"]}]}], "\n", 
  RowBox[{
   RowBox[{"Arg", "[", 
    RowBox[{
     RowBox[{"-", "1"}], "-", "\[ImaginaryI]"}], "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{"ArcTan", "[", 
     RowBox[{
      RowBox[{"-", "1"}], ",", 
      RowBox[{"-", "1"}]}], "]"}], " ", "=", " ", 
    FractionBox[
     RowBox[{
      RowBox[{"-", "3"}], "\[Pi]"}], "4"]}]}]}]],
 "  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 "\tWe can construct many different branches of the multivalued logarithm \
function that are continuous and differentiable except at points along any \
preassigned ray  ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{"r", " ", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", "\[ImaginaryI]\[Alpha]"], ":", " ", 
     RowBox[{"r", ">", "0"}]}]}], "}"}]]],
 ".  If we let ",
 Cell[BoxData["\[Alpha]"]],
 " denote a real fixed number and choose the value of  ",
 Cell[BoxData[
  RowBox[{"\[Theta]", "\[Element]", 
   RowBox[{"arg", 
    RowBox[{"(", "z", ")"}]}]}]]],
 ",  that lies in the range  ",
 Cell[BoxData[
  RowBox[{"\[Alpha]", "<", "\[Theta]", "\[LessEqual]", 
   RowBox[{"\[Alpha]", "+", 
    RowBox[{"2", "\[Pi]"}]}]}]]],
 ",  then the function  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["log", "\[Alpha]"], 
   RowBox[{"(", "z", ")"}]}]]],
 "  defined by  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["log", "\[Alpha]"], 
    RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"ln", " ", "r"}], "  ", "+", " ", 
    RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]}]}]]],
 "\n\nwhere  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{
    RowBox[{"r", " ", 
     SuperscriptBox["\[ExponentialE]", "\[ImaginaryI]\[Theta]"]}], 
    "\[NotEqual]", "0"}]}]]],
 ",  and  ",
 Cell[BoxData[
  RowBox[{"\[Alpha]", "<", "\[Theta]", "\[LessEqual]", 
   RowBox[{"\[Alpha]", "+", 
    RowBox[{"2", "\[Pi]"}]}]}]]],
 ",  is a single-valued branch of the logarithm function. The branch cut for  \
",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["log", "\[Alpha]"], 
   RowBox[{"(", "z", ")"}]}]]],
 "  is the ray  ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{"r", " ", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", "\[ImaginaryI]\[Alpha]"], ":", " ", 
     RowBox[{"r", ">", "0"}]}]}], "}"}]]],
 ",  and each point along this ray is a point of discontinuity of ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["log", "\[Alpha]"], 
   RowBox[{"(", "z", ")"}]}]]],
 ".  Because  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"exp", 
    RowBox[{
     StyleBox["(",
      FontSize->16], 
     RowBox[{
      SubscriptBox["log", "\[Alpha]"], 
      RowBox[{"(", "z", ")"}]}], 
     StyleBox[")",
      FontSize->16]}]}], " ", "=", " ", "z"}]]],
 ",  we conclude that the mapping  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    SubscriptBox["log", "\[Alpha]"], 
    RowBox[{"(", "z", ")"}]}]}]]],
 "  is a one-to-one mapping of the domain ",
 Cell[BoxData[
  RowBox[{"|", "z", "|", 
   RowBox[{">", "0"}]}]]],
 " onto the horizontal strip  ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{"w", ":", "  ", 
    RowBox[{"\[Alpha]", "<", 
     RowBox[{"Im", 
      RowBox[{"(", "w", ")"}]}], "\[LessEqual]", 
     RowBox[{"\[Alpha]", "+", 
      RowBox[{"2", "\[Pi]"}]}]}]}], "}"}]]],
 ".  If  ",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{"\[Alpha]", "<", "c", "<", "d", "<", 
    RowBox[{"\[Alpha]", "+", 
     RowBox[{"2", "\[Pi]"}]}]}]}]]],
 ",  then the function  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    SubscriptBox["log", "\[Alpha]"], 
    RowBox[{"(", "z", ")"}]}]}]]],
 "  maps the set  ",
 Cell[BoxData[
  RowBox[{"D", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"r", " ", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", "\[ImaginaryI]\[Alpha]"], ":", " ", 
       RowBox[{"0", "<", "a", "<", "r", "<", "b"}]}]}], ",", "  ", 
     RowBox[{
      RowBox[{
       StyleBox["and",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "  ", "c"}], "<", "\[Theta]", "<", "d"}]}], 
    "}"}]}]]],
 "  one-to-one and onto the rectangle  ",
 Cell[BoxData[
  RowBox[{"R", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", " ", "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"v", ":", " ", 
        RowBox[{
         RowBox[{"ln", " ", "a"}], "<", "u", "<", 
         RowBox[{"ln", " ", "b"}]}]}]}]}], ",", "  ", 
     RowBox[{
      RowBox[{
       StyleBox["and",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "  ", "c"}], "<", "v", "<", "d"}]}], 
    "}"}]}]]],
 ".  Figure 5.4 shows the mapping ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    SubscriptBox["log", "\[Alpha]"], 
    RowBox[{"(", "z", ")"}]}]}]]],
 ", its branch cut ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{"r", " ", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", "\[ImaginaryI]\[Alpha]"], ":", " ", 
     RowBox[{"r", ">", "0"}]}]}], "}"}]]],
 ", the set ",
 StyleBox["D",
  FontFamily->"Courier New"],
 ", and its image ",
 StyleBox["R",
  FontFamily->"Courier New"],
 "."
}], "Text"],

Cell[TextData[{
 "\t",
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10  scalefont  setfont
% Scaling calculations
0.493933 0.134321 0.493933 0.134321 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.941 1 .941 r
.02381 .02381 m
.96406 .02381 L
.96406 .96406 L
.02381 .96406 L
.02381 .02381 L
F
.49393 .49393 m
.49393 .49393 .44596 0 365.73 arc
F
.8 1 .8 r
.49393 .49393 m
.49393 .49393 .33038 135 315 arc
F
.941 1 .941 r
.49393 .49393 m
.49393 .49393 .07372 0 365.73 arc
F
1 1 1 r
.49393 .49393 m
.49393 .49393 .00672 0 365.73 arc
F
1 0 0 r
.5 Mabswid
[ ] 0 setdash
.44181 .44181 m
.26032 .26032 L
s
0 0 0 r
.48722 .49393 m
.02511 .49393 L
s
.49393 .50468 m
.49393 .96276 L
s
.50468 .49393 m
.96276 .49393 L
s
.49393 .48722 m
.49393 .02511 L
s
0 0 1 r
.012 w
.54606 .44181 m
.72754 .26032 L
s
1 0 1 r
.44181 .54606 m
.26032 .72754 L
s
1 .5 0 r
.0012 w
newpath
.49393 .49393 .07372 0 365.73 arc
s
.5 .165 .165 r
newpath
.49393 .49393 .33038 0 365.73 arc
s
0 1 0 r
newpath
.49393 .49393 .41639 0 43.2811 arc
s
1 .5 0 r
.012 w
newpath
.49393 .49393 .07372 135 315 arc
s
.5 .165 .165 r
newpath
.49393 .49393 .33038 135 315 arc
s
0 1 0 r
.5 Mabswid
.50343 .49393 m
.96912 .95962 L
s
[ .025 .025 ] 0 setdash
.49393 .50343 m
.95962 .96912 L
s
0 g
[ ] 0 setdash
.94933 .49393 m
.97619 .49393 L
s
% Start of user PostScript
3.39034 0 3.59034 0 MAarrowhead1
% End of user PostScript
.49393 .94933 m
.49393 .97619 L
s
% Start of user PostScript
0 3.39034 0 3.59034 MAarrowhead1
% End of user PostScript
gsave
.88346 .70885 -66.5938 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
70.188 13.875 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.96276 .52751 -66 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.51408 .96276 -69 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
75.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 1 0 r
.0012 w
newpath
.49393 .49393 .00672 135 315 arc
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{280, 280},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
  ImageRangeCache->{{{0, 279}, {279, 0}} -> {-3, -3, 0, 0}}],
 StyleBox["       ",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10  scalefont  setfont
% Scaling calculations
0.436364 0.363636 0.0367877 0.0735755 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .03679 m
1 .03679 L
s
.43636 0 m
.43636 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.5 Mabswid
0 .03679 m
.14402 .03679 L
.43294 .03679 L
.74059 .03679 L
s
.74059 .03679 m
1 .03679 L
s
.941 1 .941 r
0 .09457 m
.98182 .09457 L
.98182 .55686 L
0 .55686 L
0 .09457 L
F
.8 1 .8 r
.21818 .21015 m
.76364 .21015 L
.76364 .44129 L
.21818 .44129 L
.21818 .21015 L
F
0 g
.98182 .03679 m
1 .03679 L
s
% Start of user PostScript
1.5 0 1.55 0 MAarrowhead1
% End of user PostScript
.43636 .61068 m
.43636 .61803 L
s
% Start of user PostScript
0 7.8 0 7.9 MAarrowhead1
% End of user PostScript
0 .03679 m
.98182 .03679 L
s
.43636 0 m
.43636 .61068 L
s
1 .5 0 r
.21818 .09457 m
.21818 .55686 L
s
.5 .165 .165 r
.76364 .09457 m
.76364 .55686 L
s
0 1 0 r
0 .55686 m
.98182 .55686 L
s
[ .025 .025 ] 0 setdash
0 .09457 m
.98182 .09457 L
s
1 0 1 r
[ ] 0 setdash
.21818 .21015 m
.76364 .21015 L
s
1 0 0 r
.21818 .32572 m
.76364 .32572 L
s
0 0 1 r
.21818 .44129 m
.76364 .44129 L
s
1 0 1 r
.012 w
.21818 .21015 m
.76364 .21015 L
s
0 0 1 r
.21818 .44129 m
.76364 .44129 L
s
.5 .165 .165 r
.76364 .21015 m
.76364 .44129 L
s
1 .5 0 r
.21818 .21015 m
.21818 .44129 L
s
0 g
gsave
.97455 .06622 -66 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(u) show
69.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.45455 .59596 -69 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(v) show
75.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.4 .57389 -93 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.875 moveto
(H) show
75.000 13.875 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
81.000 13.875 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
87.000 13.875 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.875 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
99.000 13.875 moveto
(L) show
123.000 13.875 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.4 .07358 -84 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 13.875 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344) show
87.000 13.875 moveto
(a) show
105.000 13.875 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{323, 199.625},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\
eJztWr1SwkAQ3vxJKNTWksKKd7ACsfIhMhEHRh0dpEAbevU9/MMOeQUbHoY3
iNlNuJBkkwDGMc5shrtbvt3vu73NZSAzd+oMe90rZ9h3ncbJwLnp9d3bRud6
4EOGBqC1AOCrAWh7vhl2T+B5HhhAX3wL25R6EBe1N+x1ROyCoB1EzCCIqosl
B62AVUPEKAgiqFaNgrxibxYk9EK9GcOiEo5wsJQEVXdZg5BgbCx6l2BEGaYY
FiP+zGVSnvy0TJWRugX2JvUrvt/3jGu/7E1Vx8eDFl2iZTBFTEfZJc8aWfVg
bR1YeAtMZgxkYWuFGF5L7DzExs1mPM4WHdERHdERHdERHdERnSroHKNNMhP/
z55Hge1f8bdh7s3D7NDC1sVeOMIRjnCEIxzhrM3B31uoQB7CEY5whCMc4fwX
zsSPzX+X3cZftXd70REd0REd0REd0REd0dlOhz5H6lgMwCUNgQha2A4YTGew
8KzQBeOqM9ge9VYMIwH/mgWWiwNFcPMRln2QKnWwyMwM5ZPIWeNZwhUJ50ml
MrKYjEwmFCALnv0kn/jSjDVvczLu77JbJ+Pi7Fy1N7i4jC2WcQBQT2zY3N3N
PWu7akLukcnZkV3GdZgdzp31s9TcH0HQg1pNjiujuJOVuKi4uioNWe9B0CMO
lMvnRoC+UsztzjWC9g1mFcq1\
\>"],
  ImageRangeCache->{{{0, 322}, {198.625, 0}} -> {-1, 0, 0, 0}}],
 StyleBox["  \n\t\t\t\t\tFigure 5.4",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  The branch ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    SubscriptBox["log", "\[Alpha]"], 
    RowBox[{"(", "z", ")"}]}]}]]],
 " of the logarithm. "
}], "Text"],

Cell[TextData[{
 "\tWe can easily compute the derivative of any branch of the multivalued \
logarithm. For a particular branch ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    SubscriptBox["log", "\[Alpha]"], 
    RowBox[{"(", "z", ")"}]}]}]]],
 " for ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{
    RowBox[{"r", " ", 
     SuperscriptBox["\[ExponentialE]", "\[ImaginaryI]\[Theta]"]}], 
    "\[NotEqual]", "0"}]}]]],
 ", and  ",
 Cell[BoxData[
  RowBox[{"\[Alpha]", "<", "\[Theta]", "\[LessEqual]", 
   RowBox[{"\[Alpha]", "+", 
    RowBox[{"2", "\[Pi]"}]}]}]]],
 " (note the strict inequality for ",
 Cell[BoxData["\[Theta]"]],
 "),  we start with ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{"exp", 
    RowBox[{"(", "w", ")"}]}]}]]],
 " in Equations ",
 StyleBox["(5-10)",
  FontColor->RGBColor[0, 0, 1]],
 " and differentiate both sides to get  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{"1", " ", "=", " ", 
   RowBox[{
    FractionBox["d", "dz"], "z", " "}]}], "\[IndentingNewLine]", 
  RowBox[{"   ", 
   RowBox[{"=", " ", 
    RowBox[{
     FractionBox["d", "dz"], "exp", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["log", "\[Alpha]"], 
       RowBox[{"(", "z", ")"}]}], ")"}]}]}]}], "\n", 
  RowBox[{"   ", 
   RowBox[{"=", "  ", 
    RowBox[{"exp", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["log", "\[Alpha]"], 
       RowBox[{"(", "z", ")"}]}], ")"}], 
     FractionBox["d", "dz"], 
     SubscriptBox["log", "\[Alpha]"], 
     RowBox[{"(", "z", ")"}]}]}]}], "\n", 
  RowBox[{"   ", 
   RowBox[{"=", " ", 
    RowBox[{"z", 
     FractionBox["d", "dz"], 
     SubscriptBox["log", "\[Alpha]"], 
     RowBox[{"(", "z", ")"}]}]}]}]}]],
 "  \n\nSolving for ",
 Cell[BoxData[
  RowBox[{
   FractionBox["d", "dz"], 
   SubscriptBox["log", "\[Alpha]"], 
   RowBox[{"(", "z", ")"}]}]]],
 " gives  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    FractionBox["d", "dz"], 
    SubscriptBox["log", "\[Alpha]"], 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   FractionBox["1", "z"]}]]],
 ",   for    for ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", "\[ImaginaryI]\[Theta]"], "\[NotEqual]",
     "0"}]}]]],
 ", and  ",
 Cell[BoxData[
  RowBox[{"\[Alpha]", "<", "\[Theta]", "\[LessEqual]", 
   RowBox[{"\[Alpha]", "+", 
    RowBox[{"2", "\[Pi]"}]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "\tThe Riemann surface for the multivalued function  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{"log", 
    RowBox[{"(", "z", ")"}]}]}]]],
 "  is similar to the one we presented for the square root function.  \
However, it requires infinitely many copies of the ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " plane cut along the negative x axis, which we label ",
 Cell[BoxData[
  SubscriptBox["S", "k"]]],
 " for ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"k", " ", "=", " ", 
    StyleBox["...",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{"-", "n"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   StyleBox["...",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{"-", "1"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "0", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "1", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   StyleBox["...",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "n", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   StyleBox["...",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]]}]]],
 ".  Now, we stack these cut planes directly on each other so that the \
corresponding points have the same position.  We join the sheet ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["S", "k"], " ", 
   StyleBox["to",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], " ", 
   SubscriptBox["S", 
    RowBox[{"k", "+", "1"}]]}]]],
 " as follows.  For each integer ",
 StyleBox["k",
  FontFamily->"Courier New"],
 ", the edge of the sheet ",
 Cell[BoxData[
  SubscriptBox["S", "k"]]],
 " in the upper half-plane is joined to the edge of the sheet ",
 Cell[BoxData[
  SubscriptBox["S", 
   RowBox[{"k", "+", "1"}]]]],
 " in the lower half-plane.  The Riemann surface for the domain of ",
 Cell[BoxData[
  RowBox[{"log", 
   RowBox[{"(", "z", ")"}]}]]],
 " looks like a spiral staircase that extends upward on the sheets ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["S", "1"], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   SubscriptBox["S", "2"], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   StyleBox["...",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]]}]]],
 "  and downward on the sheets ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["S", 
    RowBox[{"-", "1"}]], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   SubscriptBox["S", 
    RowBox[{"-", "2"}]], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   StyleBox["...",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]]}]]],
 ",  as shown in Figure 5-5.  We use polar coordinates for ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " on each sheet.  For ",
 Cell[BoxData[
  SubscriptBox["S", "k"]]],
 ", we use\n\n\t\t\t  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{
    RowBox[{"r", " ", 
     SuperscriptBox["\[ExponentialE]", "\[ImaginaryI]\[Theta]"]}], "=", 
    RowBox[{"r", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"cos", " ", "\[Theta]"}], "+", 
       RowBox[{"\[ImaginaryI]", " ", "sin", " ", "\[Theta]"}]}], 
      ")"}]}]}]}]]],
 ",    where  \n\t\t\t  \n\t\t\t  ",
 Cell[BoxData[
  RowBox[{"r", " ", "=", 
   RowBox[{"|", "z", "|"}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"2", "\[Pi]", " ", "k"}], "-", "\[Pi]"}], "<", "\[Theta]", 
   "\[LessEqual]", 
   RowBox[{"\[Pi]", "+", 
    RowBox[{"2", "\[Pi]", " ", "k"}]}]}]]],
 ".  \n\nAgain, for ",
 Cell[BoxData[
  SubscriptBox["S", "k"]]],
 ", the correct branch of ",
 Cell[BoxData[
  RowBox[{"log", 
   RowBox[{"(", "z", ")"}]}]]],
 " on each sheet is  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"log", 
    RowBox[{"(", " ", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"ln", " ", "r"}], " ", "+", " ", 
    RowBox[{"\[ImaginaryI]", "  ", "\[Theta]"}]}]}]]],
 ",    where\n\n\t\t\t  ",
 Cell[BoxData[
  RowBox[{"r", " ", "=", 
   RowBox[{"|", "z", "|"}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"2", "\[Pi]", " ", "k"}], "-", "\[Pi]"}], "<", "\[Theta]", 
   "\[LessEqual]", 
   RowBox[{"\[Pi]", "+", 
    RowBox[{"2", "\[Pi]", " ", "k"}]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "\t",
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 1.043 -0.416308 1.49011 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 g
.49134 .31897 m
.4745 .3438 L
.34625 .34063 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.49134 .31897 m
.4745 .3438 L
s
.4745 .3438 m
.34625 .34063 L
s
1 g
.59618 .30614 m
.4745 .3438 L
.49134 .31897 L
F
0 g
.4745 .3438 m
.49134 .31897 L
s
.49134 .31897 m
.59618 .30614 L
s
1 g
.59618 .30614 m
.61227 .33027 L
.4745 .3438 L
F
0 g
.59618 .30614 m
.61227 .33027 L
s
.61227 .33027 m
.4745 .3438 L
s
1 g
.69453 .28051 m
.61227 .33027 L
.59618 .30614 L
F
0 g
.61227 .33027 m
.59618 .30614 L
s
.59618 .30614 m
.69453 .28051 L
s
1 g
.69453 .28051 m
.74206 .30052 L
.61227 .33027 L
F
0 g
.69453 .28051 m
.74206 .30052 L
s
.74206 .30052 m
.61227 .33027 L
s
1 g
.39396 .31848 m
.34625 .34063 L
.2443 .32176 L
F
0 g
.39396 .31848 m
.34625 .34063 L
s
.34625 .34063 m
.2443 .32176 L
s
1 g
.49134 .31897 m
.34625 .34063 L
.39396 .31848 L
F
0 g
.34625 .34063 m
.39396 .31848 L
s
.39396 .31848 m
.49134 .31897 L
s
1 g
.77278 .24394 m
.74206 .30052 L
.69453 .28051 L
F
0 g
.74206 .30052 m
.69453 .28051 L
s
.69453 .28051 m
.77278 .24394 L
s
1 g
.77278 .24394 m
.84651 .25665 L
.74206 .30052 L
F
0 g
.77278 .24394 m
.84651 .25665 L
s
.84651 .25665 m
.74206 .30052 L
s
1 g
.50869 .29338 m
.49134 .31897 L
.39396 .31848 L
F
0 g
.50869 .29338 m
.49134 .31897 L
s
.49134 .31897 m
.39396 .31848 L
s
1 g
.57963 .28131 m
.49134 .31897 L
.50869 .29338 L
F
0 g
.49134 .31897 m
.50869 .29338 L
s
.50869 .29338 m
.57963 .28131 L
s
1 g
.57963 .28131 m
.59618 .30614 L
.49134 .31897 L
F
0 g
.57963 .28131 m
.59618 .30614 L
s
.59618 .30614 m
.49134 .31897 L
s
1 g
.64588 .26002 m
.59618 .30614 L
.57963 .28131 L
F
0 g
.59618 .30614 m
.57963 .28131 L
s
.57963 .28131 m
.64588 .26002 L
s
1 g
.64588 .26002 m
.69453 .28051 L
.59618 .30614 L
F
0 g
.64588 .26002 m
.69453 .28051 L
s
.69453 .28051 m
.59618 .30614 L
s
1 g
.39396 .31848 m
.2443 .32176 L
.3173 .30548 L
F
0 g
.2443 .32176 m
.3173 .30548 L
s
.3173 .30548 m
.39396 .31848 L
s
1 g
.44296 .29573 m
.39396 .31848 L
.3173 .30548 L
F
0 g
.44296 .29573 m
.39396 .31848 L
s
.39396 .31848 m
.3173 .30548 L
s
1 g
.50869 .29338 m
.39396 .31848 L
.44296 .29573 L
F
0 g
.39396 .31848 m
.44296 .29573 L
s
.44296 .29573 m
.50869 .29338 L
s
1 g
.3173 .30548 m
.2443 .32176 L
.1836 .28977 L
F
0 g
.3173 .30548 m
.2443 .32176 L
s
.2443 .32176 m
.1836 .28977 L
s
1 g
.69798 .23105 m
.69453 .28051 L
.64588 .26002 L
F
0 g
.69453 .28051 m
.64588 .26002 L
s
.64588 .26002 m
.69798 .23105 L
s
1 g
.69798 .23105 m
.77278 .24394 L
.69453 .28051 L
F
0 g
.69798 .23105 m
.77278 .24394 L
s
.77278 .24394 m
.69453 .28051 L
s
1 g
.52657 .26701 m
.50869 .29338 L
.44296 .29573 L
F
0 g
.52657 .26701 m
.50869 .29338 L
s
.50869 .29338 m
.44296 .29573 L
s
1 g
.56258 .25575 m
.50869 .29338 L
.52657 .26701 L
F
0 g
.50869 .29338 m
.52657 .26701 L
s
.52657 .26701 m
.56258 .25575 L
s
1 g
.56258 .25575 m
.57963 .28131 L
.50869 .29338 L
F
0 g
.56258 .25575 m
.57963 .28131 L
s
.57963 .28131 m
.50869 .29338 L
s
1 g
.59606 .23905 m
.57963 .28131 L
.56258 .25575 L
F
0 g
.57963 .28131 m
.56258 .25575 L
s
.56258 .25575 m
.59606 .23905 L
s
1 g
.59606 .23905 m
.64588 .26002 L
.57963 .28131 L
F
0 g
.59606 .23905 m
.64588 .26002 L
s
.64588 .26002 m
.57963 .28131 L
s
1 g
.81896 .19978 m
.84651 .25665 L
.77278 .24394 L
F
0 g
.84651 .25665 m
.77278 .24394 L
s
.77278 .24394 m
.81896 .19978 L
s
1 g
.81896 .19978 m
.90969 .20259 L
.84651 .25665 L
F
0 g
.81896 .19978 m
.90969 .20259 L
s
.90969 .20259 m
.84651 .25665 L
s
1 g
.3173 .30548 m
.1836 .28977 L
.27273 .28208 L
F
0 g
.1836 .28977 m
.27273 .28208 L
s
.27273 .28208 m
.3173 .30548 L
s
1 g
.39172 .28888 m
.3173 .30548 L
.27273 .28208 L
F
0 g
.39172 .28888 m
.3173 .30548 L
s
.3173 .30548 m
.27273 .28208 L
s
1 g
.44296 .29573 m
.3173 .30548 L
.39172 .28888 L
F
0 g
.3173 .30548 m
.39172 .28888 L
s
.39172 .28888 m
.44296 .29573 L
s
1 g
.49328 .27237 m
.44296 .29573 L
.39172 .28888 L
F
0 g
.49328 .27237 m
.44296 .29573 L
s
.44296 .29573 m
.39172 .28888 L
s
1 g
.52657 .26701 m
.44296 .29573 L
.49328 .27237 L
F
0 g
.44296 .29573 m
.49328 .27237 L
s
.49328 .27237 m
.52657 .26701 L
s
1 g
.62207 .21797 m
.64588 .26002 L
.59606 .23905 L
F
0 g
.64588 .26002 m
.59606 .23905 L
s
.59606 .23905 m
.62207 .21797 L
s
1 g
.62207 .21797 m
.69798 .23105 L
.64588 .26002 L
F
0 g
.62207 .21797 m
.69798 .23105 L
s
.69798 .23105 m
.64588 .26002 L
s
1 g
.72794 .19697 m
.77278 .24394 L
.69798 .23105 L
F
0 g
.77278 .24394 m
.69798 .23105 L
s
.69798 .23105 m
.72794 .19697 L
s
1 g
.72794 .19697 m
.81896 .19978 L
.77278 .24394 L
F
0 g
.72794 .19697 m
.81896 .19978 L
s
.81896 .19978 m
.77278 .24394 L
s
1 g
.39172 .28888 m
.27273 .28208 L
.36267 .27433 L
F
0 g
.27273 .28208 m
.36267 .27433 L
s
.36267 .27433 m
.39172 .28888 L
s
1 g
.4676 .27196 m
.39172 .28888 L
.36267 .27433 L
F
0 g
.4676 .27196 m
.39172 .28888 L
s
.39172 .28888 m
.36267 .27433 L
s
1 g
.49328 .27237 m
.39172 .28888 L
.4676 .27196 L
F
0 g
.39172 .28888 m
.4676 .27196 L
s
.4676 .27196 m
.49328 .27237 L
s
1 g
.27273 .28208 m
.1836 .28977 L
.17547 .24892 L
F
0 g
.27273 .28208 m
.1836 .28977 L
s
.1836 .28977 m
.17547 .24892 L
s
1 g
.54502 .22943 m
.56258 .25575 L
.52657 .26701 L
F
0 g
.56258 .25575 m
.52657 .26701 L
s
1 g
.54502 .22942 m
.54503 .22943 L
.54502 .22943 L
F
0 g
.54502 .22942 m
.54503 .22943 L
s
1 g
.54503 .22943 m
.56258 .25575 L
.54502 .22943 L
F
0 g
.54503 .22943 m
.56258 .25575 L
s
1 g
.54502 .22942 m
.54502 .22943 L
.54501 .23982 L
F
0 g
.54501 .23982 m
.54502 .22942 L
s
1 g
.54502 .22943 m
.52657 .26701 L
.54501 .23982 L
F
0 g
.52657 .26701 m
.54501 .23982 L
s
1 g
.54498 .23984 m
.52657 .26701 L
.49328 .27237 L
F
0 g
.52657 .26701 m
.49328 .27237 L
s
1 g
.54499 .23984 m
.52657 .26701 L
.54498 .23984 L
F
.54501 .23983 m
.52657 .26701 L
.545 .23983 L
F
0 g
.54501 .23983 m
.52657 .26701 L
s
1 g
.545 .23983 m
.54499 .23984 L
.54498 .23984 L
F
.54501 .23982 m
.54501 .23983 L
.545 .23983 L
F
0 g
.54501 .23982 m
.54501 .23983 L
s
1 g
.54501 .23982 m
.49463 .27152 L
.545 .24836 L
F
0 g
.545 .24836 m
.54501 .23982 L
s
1 g
.49463 .27152 m
.49403 .27202 L
.545 .24836 L
F
0 g
.49403 .27202 m
.545 .24836 L
s
1 g
.49463 .27152 m
.49328 .27237 L
.49403 .27202 L
F
0 g
.49328 .27237 m
.49403 .27202 L
s
1 g
.54497 .24836 m
.49328 .27237 L
.4676 .27196 L
F
0 g
.49328 .27237 m
.4676 .27196 L
s
1 g
.545 .24836 m
.54499 .24836 L
.54497 .24836 L
F
0 g
.545 .24836 m
.54499 .24836 L
s
1 g
.54499 .24836 m
.49328 .27237 L
.54497 .24836 L
F
0 g
.54499 .24836 m
.49328 .27237 L
s
1 g
.545 .24836 m
.54497 .24836 L
.54499 .2547 L
F
0 g
.54499 .2547 m
.545 .24836 L
s
1 g
.54497 .24836 m
.47487 .26974 L
.54499 .2547 L
F
.47487 .26974 m
.47195 .27099 L
.54499 .2547 L
F
0 g
.47195 .27099 m
.54499 .2547 L
s
1 g
.47487 .26974 m
.4676 .27196 L
.47195 .27099 L
F
0 g
.4676 .27196 m
.47195 .27099 L
s
1 g
.54499 .2547 m
.4676 .27196 L
.45341 .2665 L
F
0 g
.54499 .2547 m
.4676 .27196 L
s
.4676 .27196 m
.45341 .2665 L
s
1 g
.54499 .2547 m
.4706 .26428 L
.54498 .2586 L
F
0 g
.54498 .2586 m
.54499 .2547 L
s
1 g
.4706 .26428 m
.46337 .26521 L
.468 .26484 L
F
.4706 .26428 m
.468 .26484 L
.54498 .2586 L
F
.46337 .26521 m
.45341 .2665 L
.46148 .2658 L
F
0 g
.45341 .2665 m
.46148 .2658 L
s
1 g
.46337 .26521 m
.46148 .2658 L
.54498 .2586 L
F
0 g
.46148 .2658 m
.54498 .2586 L
s
1 g
.63664 .19415 m
.69798 .23105 L
.62207 .21797 L
F
0 g
.69798 .23105 m
.62207 .21797 L
s
.62207 .21797 m
.63664 .19415 L
s
1 g
.63664 .19415 m
.72794 .19697 L
.69798 .23105 L
F
0 g
.63664 .19415 m
.72794 .19697 L
s
.72794 .19697 m
.69798 .23105 L
s
1 g
.54504 .21756 m
.56258 .25575 L
.54502 .22942 L
F
0 g
.56258 .25575 m
.54502 .22942 L
s
.54502 .22942 m
.54504 .21756 L
s
1 g
.54504 .21756 m
.59606 .23905 L
.56258 .25575 L
F
0 g
.54504 .21756 m
.59606 .23905 L
s
.59606 .23905 m
.56258 .25575 L
s
1 g
.27273 .28208 m
.17547 .24892 L
.26828 .25168 L
F
0 g
.17547 .24892 m
.26828 .25168 L
s
.26828 .25168 m
.27273 .28208 L
s
1 g
.36267 .27433 m
.27273 .28208 L
.26828 .25168 L
F
0 g
.36267 .27433 m
.27273 .28208 L
s
.27273 .28208 m
.26828 .25168 L
s
1 g
.54505 .20469 m
.59606 .23905 L
.54504 .21756 L
F
0 g
.59606 .23905 m
.54504 .21756 L
s
.54504 .21756 m
.54505 .20469 L
s
1 g
.54505 .20469 m
.62207 .21797 L
.59606 .23905 L
F
0 g
.54505 .20469 m
.62207 .21797 L
s
.62207 .21797 m
.59606 .23905 L
s
1 g
.4676 .27196 m
.36267 .27433 L
.45341 .2665 L
F
0 g
.36267 .27433 m
.45341 .2665 L
s
.45341 .2665 m
.4676 .27196 L
s
1 g
.36267 .27433 m
.26828 .25168 L
.3608 .25444 L
F
0 g
.26828 .25168 m
.3608 .25444 L
s
.3608 .25444 m
.36267 .27433 L
s
1 g
.45341 .2665 m
.36267 .27433 L
.3608 .25444 L
F
0 g
.45341 .2665 m
.36267 .27433 L
s
.36267 .27433 m
.3608 .25444 L
s
1 g
.54505 .19131 m
.62207 .21797 L
.54505 .20469 L
F
0 g
.62207 .21797 m
.54505 .20469 L
s
.54505 .20469 m
.54505 .19131 L
s
1 g
.54505 .19131 m
.63664 .19415 L
.62207 .21797 L
F
0 g
.54505 .19131 m
.63664 .19415 L
s
.63664 .19415 m
.62207 .21797 L
s
1 g
.82452 .15273 m
.90969 .20259 L
.81896 .19978 L
F
0 g
.90969 .20259 m
.81896 .19978 L
s
.81896 .19978 m
.82452 .15273 L
s
1 g
.82452 .15273 m
.91939 .14417 L
.90969 .20259 L
F
0 g
.82452 .15273 m
.91939 .14417 L
s
.91939 .14417 m
.90969 .20259 L
s
1 g
.73052 .16121 m
.81896 .19978 L
.72794 .19697 L
F
0 g
.81896 .19978 m
.72794 .19697 L
s
.72794 .19697 m
.73052 .16121 L
s
1 g
.73052 .16121 m
.82452 .15273 L
.81896 .19978 L
F
0 g
.73052 .16121 m
.82452 .15273 L
s
.82452 .15273 m
.81896 .19978 L
s
1 g
.45341 .2665 m
.3608 .25444 L
.45303 .25718 L
F
0 g
.3608 .25444 m
.45303 .25718 L
s
.45303 .25718 m
.45341 .2665 L
s
1 g
.54498 .2586 m
.45341 .2665 L
.45303 .25718 L
F
0 g
.54498 .2586 m
.45341 .2665 L
s
.45341 .2665 m
.45303 .25718 L
s
1 g
.63736 .16961 m
.72794 .19697 L
.63664 .19415 L
F
0 g
.72794 .19697 m
.63664 .19415 L
s
.63664 .19415 m
.63736 .16961 L
s
1 g
.63736 .16961 m
.73052 .16121 L
.72794 .19697 L
F
0 g
.63736 .16961 m
.73052 .16121 L
s
.73052 .16121 m
.72794 .19697 L
s
1 g
.54505 .17794 m
.63664 .19415 L
.54505 .19131 L
F
0 g
.63664 .19415 m
.54505 .19131 L
s
.54505 .19131 m
.54505 .17794 L
s
1 g
.54505 .17794 m
.63736 .16961 L
.63664 .19415 L
F
0 g
.54505 .17794 m
.63736 .16961 L
s
.63736 .16961 m
.63664 .19415 L
s
1 g
.54498 .12282 m
.45318 .11988 L
.46689 .11007 L
F
0 g
.54498 .12282 m
.45318 .11988 L
s
.45318 .11988 m
.46689 .11007 L
s
1 g
.54498 .12282 m
.49227 .11421 L
.54499 .12413 L
F
0 g
.54499 .12413 m
.54498 .12282 L
s
1 g
.49227 .11421 m
.49187 .11415 L
.49232 .11423 L
F
.49227 .11421 m
.49232 .11423 L
.54499 .12413 L
F
.49187 .11415 m
.49704 .1155 L
.54499 .12413 L
F
0 g
.49704 .1155 m
.54499 .12413 L
s
1 g
.49187 .11415 m
.46689 .11007 L
.49704 .1155 L
F
0 g
.46689 .11007 m
.49704 .1155 L
s
1 g
.54499 .12413 m
.46689 .11007 L
.49278 .10494 L
F
0 g
.54499 .12413 m
.46689 .11007 L
s
.46689 .11007 m
.49278 .10494 L
s
1 g
.54499 .12413 m
.49278 .10494 L
.545 .12802 L
F
0 g
.49278 .10494 m
.545 .12802 L
s
.545 .12802 m
.54499 .12413 L
s
1 g
.54499 .12801 m
.49278 .10494 L
.52694 .1058 L
F
0 g
.49278 .10494 m
.52694 .1058 L
s
1 g
.545 .12802 m
.54496 .12801 L
.54499 .12801 L
F
0 g
.545 .12802 m
.54496 .12801 L
s
1 g
.54496 .12801 m
.49278 .10494 L
.54499 .12801 L
F
0 g
.54496 .12801 m
.49278 .10494 L
s
1 g
.545 .12802 m
.52694 .1058 L
.54501 .13435 L
F
0 g
.52694 .1058 m
.54501 .13435 L
s
.54501 .13435 m
.545 .12802 L
s
1 g
.54503 .13433 m
.52694 .1058 L
.56403 .11331 L
F
0 g
.52694 .1058 m
.56403 .11331 L
s
1 g
.54501 .13435 m
.54499 .13431 L
.54503 .13433 L
F
0 g
.54501 .13435 m
.54499 .13431 L
s
1 g
.54499 .13431 m
.52694 .1058 L
.54503 .13433 L
F
0 g
.54499 .13431 m
.52694 .1058 L
s
1 g
.54501 .13435 m
.56403 .11331 L
.54502 .14286 L
F
0 g
.56403 .11331 m
.54502 .14286 L
s
.54502 .14286 m
.54501 .13435 L
s
1 g
.54502 .14286 m
.59814 .12725 L
.54504 .15324 L
F
0 g
.59814 .12725 m
.54504 .15324 L
s
.54504 .15324 m
.54502 .14286 L
s
1 g
.54502 .14286 m
.56403 .11331 L
.59814 .12725 L
F
0 g
.54502 .14286 m
.56403 .11331 L
s
.56403 .11331 m
.59814 .12725 L
s
1 g
.54504 .15324 m
.6239 .1466 L
.54505 .16508 L
F
0 g
.6239 .1466 m
.54505 .16508 L
s
.54505 .16508 m
.54504 .15324 L
s
1 g
.54504 .15324 m
.59814 .12725 L
.6239 .1466 L
F
0 g
.54504 .15324 m
.59814 .12725 L
s
.59814 .12725 m
.6239 .1466 L
s
1 g
.54505 .16508 m
.63736 .16961 L
.54505 .17794 L
F
0 g
.63736 .16961 m
.54505 .17794 L
s
.54505 .17794 m
.54505 .16508 L
s
1 g
.54505 .16508 m
.6239 .1466 L
.63736 .16961 L
F
0 g
.54505 .16508 m
.6239 .1466 L
s
.6239 .1466 m
.63736 .16961 L
s
1 g
.45318 .11988 m
.38762 .0958 L
.46689 .11007 L
F
0 g
.38762 .0958 m
.46689 .11007 L
s
.46689 .11007 m
.45318 .11988 L
s
1 g
.45318 .11988 m
.3611 .11692 L
.38762 .0958 L
F
0 g
.45318 .11988 m
.3611 .11692 L
s
.3611 .11692 m
.38762 .0958 L
s
1 g
.54498 .2586 m
.45303 .25718 L
.54498 .25992 L
F
0 g
.45303 .25718 m
.54498 .25992 L
s
.54498 .25992 m
.54498 .2586 L
s
1 g
.3611 .11692 m
.30715 .08131 L
.38762 .0958 L
F
0 g
.30715 .08131 m
.38762 .0958 L
s
.38762 .0958 m
.3611 .11692 L
s
1 g
.3611 .11692 m
.26873 .11396 L
.30715 .08131 L
F
0 g
.3611 .11692 m
.26873 .11396 L
s
.26873 .11396 m
.30715 .08131 L
s
1 g
.26873 .11396 m
.22545 .0666 L
.30715 .08131 L
F
0 g
.22545 .0666 m
.30715 .08131 L
s
.30715 .08131 m
.26873 .11396 L
s
1 g
.26873 .11396 m
.17607 .11099 L
.22545 .0666 L
F
0 g
.26873 .11396 m
.17607 .11099 L
s
.17607 .11099 m
.22545 .0666 L
s
1 g
.6239 .1466 m
.73052 .16121 L
.63736 .16961 L
F
0 g
.73052 .16121 m
.63736 .16961 L
s
.63736 .16961 m
.6239 .1466 L
s
1 g
.46689 .11007 m
.43926 .08128 L
.49278 .10494 L
F
0 g
.43926 .08128 m
.49278 .10494 L
s
.49278 .10494 m
.46689 .11007 L
s
1 g
.46689 .11007 m
.38762 .0958 L
.43926 .08128 L
F
0 g
.46689 .11007 m
.38762 .0958 L
s
.38762 .0958 m
.43926 .08128 L
s
1 g
.70435 .12774 m
.82452 .15273 L
.73052 .16121 L
F
0 g
.82452 .15273 m
.73052 .16121 L
s
.73052 .16121 m
.70435 .12774 L
s
1 g
.6239 .1466 m
.70435 .12774 L
.73052 .16121 L
F
0 g
.6239 .1466 m
.70435 .12774 L
s
.70435 .12774 m
.73052 .16121 L
s
1 g
.59814 .12725 m
.70435 .12774 L
.6239 .1466 L
F
0 g
.70435 .12774 m
.6239 .1466 L
s
.6239 .1466 m
.59814 .12725 L
s
1 g
.49278 .10494 m
.50831 .07638 L
.52694 .1058 L
F
0 g
.50831 .07638 m
.52694 .1058 L
s
.52694 .1058 m
.49278 .10494 L
s
1 g
.49278 .10494 m
.43926 .08128 L
.50831 .07638 L
F
0 g
.49278 .10494 m
.43926 .08128 L
s
.43926 .08128 m
.50831 .07638 L
s
1 g
.59814 .12725 m
.65275 .10053 L
.70435 .12774 L
F
0 g
.59814 .12725 m
.65275 .10053 L
s
.65275 .10053 m
.70435 .12774 L
s
1 g
.56403 .11331 m
.65275 .10053 L
.59814 .12725 L
F
0 g
.65275 .10053 m
.59814 .12725 L
s
.59814 .12725 m
.56403 .11331 L
s
1 g
.78644 .1085 m
.91939 .14417 L
.82452 .15273 L
F
0 g
.91939 .14417 m
.82452 .15273 L
s
.82452 .15273 m
.78644 .1085 L
s
1 g
.70435 .12774 m
.78644 .1085 L
.82452 .15273 L
F
0 g
.70435 .12774 m
.78644 .1085 L
s
.78644 .1085 m
.82452 .15273 L
s
1 g
.38762 .0958 m
.3844 .05703 L
.43926 .08128 L
F
0 g
.3844 .05703 m
.43926 .08128 L
s
.43926 .08128 m
.38762 .0958 L
s
1 g
.38762 .0958 m
.30715 .08131 L
.3844 .05703 L
F
0 g
.38762 .0958 m
.30715 .08131 L
s
.30715 .08131 m
.3844 .05703 L
s
1 g
.52694 .1058 m
.58364 .0828 L
.56403 .11331 L
F
0 g
.58364 .0828 m
.56403 .11331 L
s
.56403 .11331 m
.52694 .1058 L
s
1 g
.52694 .1058 m
.50831 .07638 L
.58364 .0828 L
F
0 g
.52694 .1058 m
.50831 .07638 L
s
.50831 .07638 m
.58364 .0828 L
s
1 g
.56403 .11331 m
.58364 .0828 L
.65275 .10053 L
F
0 g
.56403 .11331 m
.58364 .0828 L
s
.58364 .0828 m
.65275 .10053 L
s
1 g
.78644 .1085 m
.87022 .08886 L
.91939 .14417 L
F
0 g
.78644 .1085 m
.87022 .08886 L
s
.87022 .08886 m
.91939 .14417 L
s
1 g
.65275 .10053 m
.78644 .1085 L
.70435 .12774 L
F
0 g
.78644 .1085 m
.70435 .12774 L
s
.70435 .12774 m
.65275 .10053 L
s
1 g
.30715 .08131 m
.32814 .03216 L
.3844 .05703 L
F
0 g
.32814 .03216 m
.3844 .05703 L
s
.3844 .05703 m
.30715 .08131 L
s
1 g
.30715 .08131 m
.22545 .0666 L
.32814 .03216 L
F
0 g
.30715 .08131 m
.22545 .0666 L
s
.22545 .0666 m
.32814 .03216 L
s
1 g
.43926 .08128 m
.4891 .04603 L
.50831 .07638 L
F
0 g
.4891 .04603 m
.50831 .07638 L
s
.50831 .07638 m
.43926 .08128 L
s
1 g
.43926 .08128 m
.3844 .05703 L
.4891 .04603 L
F
0 g
.43926 .08128 m
.3844 .05703 L
s
.3844 .05703 m
.4891 .04603 L
s
1 g
.65275 .10053 m
.70893 .07305 L
.78644 .1085 L
F
0 g
.65275 .10053 m
.70893 .07305 L
s
.70893 .07305 m
.78644 .1085 L
s
1 g
.58364 .0828 m
.70893 .07305 L
.65275 .10053 L
F
0 g
.70893 .07305 m
.65275 .10053 L
s
.65275 .10053 m
.58364 .0828 L
s
1 g
.50831 .07638 m
.60389 .05131 L
.58364 .0828 L
F
0 g
.60389 .05131 m
.58364 .0828 L
s
.58364 .0828 m
.50831 .07638 L
s
1 g
.50831 .07638 m
.4891 .04603 L
.60389 .05131 L
F
0 g
.50831 .07638 m
.4891 .04603 L
s
.4891 .04603 m
.60389 .05131 L
s
1 g
.70893 .07305 m
.87022 .08886 L
.78644 .1085 L
F
0 g
.87022 .08886 m
.78644 .1085 L
s
.78644 .1085 m
.70893 .07305 L
s
1 g
.58364 .0828 m
.60389 .05131 L
.70893 .07305 L
F
0 g
.58364 .0828 m
.60389 .05131 L
s
.60389 .05131 m
.70893 .07305 L
s
1 g
.3844 .05703 m
.46927 .01472 L
.4891 .04603 L
F
0 g
.46927 .01472 m
.4891 .04603 L
s
.4891 .04603 m
.3844 .05703 L
s
1 g
.3844 .05703 m
.32814 .03216 L
.46927 .01472 L
F
0 g
.3844 .05703 m
.32814 .03216 L
s
.32814 .03216 m
.46927 .01472 L
s
1 g
.70893 .07305 m
.76674 .04475 L
.87022 .08886 L
F
0 g
.70893 .07305 m
.76674 .04475 L
s
.76674 .04475 m
.87022 .08886 L
s
1 g
.60389 .05131 m
.76674 .04475 L
.70893 .07305 L
F
0 g
.76674 .04475 m
.70893 .07305 L
s
.70893 .07305 m
.60389 .05131 L
s
1 g
.4891 .04603 m
.62481 .01876 L
.60389 .05131 L
F
0 g
.62481 .01876 m
.60389 .05131 L
s
.60389 .05131 m
.4891 .04603 L
s
1 g
.4891 .04603 m
.46927 .01472 L
.62481 .01876 L
F
0 g
.4891 .04603 m
.46927 .01472 L
s
.46927 .01472 m
.62481 .01876 L
s
1 g
.60389 .05131 m
.62481 .01876 L
.76674 .04475 L
F
0 g
.60389 .05131 m
.62481 .01876 L
s
.62481 .01876 m
.76674 .04475 L
s
0 .67 .67 r
.49126 .45042 m
.47439 .47336 L
.34595 .47107 L
F
0 g
.49126 .45042 m
.47439 .47336 L
s
.47439 .47336 m
.34595 .47107 L
s
0 .706 .706 r
.59626 .43778 m
.47439 .47336 L
.49126 .45042 L
F
0 g
.47439 .47336 m
.49126 .45042 L
s
.49126 .45042 m
.59626 .43778 L
s
0 .706 .706 r
.59626 .43778 m
.61237 .46008 L
.47439 .47336 L
F
0 g
.59626 .43778 m
.61237 .46008 L
s
.61237 .46008 m
.47439 .47336 L
s
0 .742 .742 r
.69477 .41318 m
.61237 .46008 L
.59626 .43778 L
F
0 g
.61237 .46008 m
.59626 .43778 L
s
.59626 .43778 m
.69477 .41318 L
s
0 .742 .742 r
.69477 .41318 m
.74237 .43169 L
.61237 .46008 L
F
0 g
.69477 .41318 m
.74237 .43169 L
s
.74237 .43169 m
.61237 .46008 L
s
0 .647 .647 r
.39373 .45062 m
.34595 .47107 L
.24383 .45413 L
F
0 g
.39373 .45062 m
.34595 .47107 L
s
.34595 .47107 m
.24383 .45413 L
s
0 .67 .67 r
.49126 .45042 m
.34595 .47107 L
.39373 .45062 L
F
0 g
.34595 .47107 m
.39373 .45062 L
s
.39373 .45062 m
.49126 .45042 L
s
0 .768 .768 r
.77314 .37838 m
.74237 .43169 L
.69477 .41318 L
F
0 g
.74237 .43169 m
.69477 .41318 L
s
.69477 .41318 m
.77314 .37838 L
s
0 .768 .768 r
.77314 .37838 m
.84698 .39014 L
.74237 .43169 L
F
0 g
.77314 .37838 m
.84698 .39014 L
s
.84698 .39014 m
.74237 .43169 L
s
0 .667 .667 r
.50863 .42678 m
.49126 .45042 L
.39373 .45062 L
F
0 g
.50863 .42678 m
.49126 .45042 L
s
.49126 .45042 m
.39373 .45062 L
s
0 .714 .714 r
.57968 .41483 m
.49126 .45042 L
.50863 .42678 L
F
0 g
.49126 .45042 m
.50863 .42678 L
s
.50863 .42678 m
.57968 .41483 L
s
0 .714 .714 r
.57968 .41483 m
.59626 .43778 L
.49126 .45042 L
F
0 g
.57968 .41483 m
.59626 .43778 L
s
.59626 .43778 m
.49126 .45042 L
s
0 .759 .759 r
.64604 .39424 m
.59626 .43778 L
.57968 .41483 L
F
0 g
.59626 .43778 m
.57968 .41483 L
s
.57968 .41483 m
.64604 .39424 L
s
0 .759 .759 r
.64604 .39424 m
.69477 .41318 L
.59626 .43778 L
F
0 g
.64604 .39424 m
.69477 .41318 L
s
.69477 .41318 m
.59626 .43778 L
s
0 .647 .647 r
.39373 .45062 m
.24383 .45413 L
.31694 .4391 L
F
0 g
.24383 .45413 m
.31694 .4391 L
s
.31694 .4391 m
.39373 .45062 L
s
0 .637 .637 r
.44279 .42961 m
.39373 .45062 L
.31694 .4391 L
F
0 g
.44279 .42961 m
.39373 .45062 L
s
.39373 .45062 m
.31694 .4391 L
s
0 .667 .667 r
.50863 .42678 m
.39373 .45062 L
.44279 .42961 L
F
0 g
.39373 .45062 m
.44279 .42961 L
s
.44279 .42961 m
.50863 .42678 L
s
0 .646 .646 r
.31694 .4391 m
.24383 .45413 L
.18302 .42491 L
F
0 g
.31694 .4391 m
.24383 .45413 L
s
.24383 .45413 m
.18302 .42491 L
s
0 .789 .789 r
.69822 .36645 m
.69477 .41318 L
.64604 .39424 L
F
0 g
.69477 .41318 m
.64604 .39424 L
s
.64604 .39424 m
.69822 .36645 L
s
0 .789 .789 r
.69822 .36645 m
.77314 .37838 L
.69477 .41318 L
F
0 g
.69822 .36645 m
.77314 .37838 L
s
.77314 .37838 m
.69477 .41318 L
s
0 .66 .66 r
.52654 .40242 m
.50863 .42678 L
.44279 .42961 L
F
0 g
.52654 .40242 m
.50863 .42678 L
s
.50863 .42678 m
.44279 .42961 L
s
0 .729 .729 r
.56261 .3912 m
.50863 .42678 L
.52654 .40242 L
F
0 g
.50863 .42678 m
.52654 .40242 L
s
.52654 .40242 m
.56261 .3912 L
s
0 .729 .729 r
.56261 .3912 m
.57968 .41483 L
.50863 .42678 L
F
0 g
.56261 .3912 m
.57968 .41483 L
s
.57968 .41483 m
.50863 .42678 L
s
0 .788 .788 r
.59614 .37484 m
.57968 .41483 L
.56261 .3912 L
F
0 g
.57968 .41483 m
.56261 .3912 L
s
.56261 .3912 m
.59614 .37484 L
s
0 .788 .788 r
.59614 .37484 m
.64604 .39424 L
.57968 .41483 L
F
0 g
.59614 .37484 m
.64604 .39424 L
s
.64604 .39424 m
.57968 .41483 L
s
0 .78 .78 r
.8194 .33647 m
.84698 .39014 L
.77314 .37838 L
F
0 g
.84698 .39014 m
.77314 .37838 L
s
.77314 .37838 m
.8194 .33647 L
s
0 .78 .78 r
.8194 .33647 m
.91028 .33907 L
.84698 .39014 L
F
0 g
.8194 .33647 m
.91028 .33907 L
s
.91028 .33907 m
.84698 .39014 L
s
0 .646 .646 r
.31694 .4391 m
.18302 .42491 L
.27229 .41781 L
F
0 g
.18302 .42491 m
.27229 .41781 L
s
.27229 .41781 m
.31694 .4391 L
s
0 .635 .635 r
.39147 .42378 m
.31694 .4391 L
.27229 .41781 L
F
0 g
.39147 .42378 m
.31694 .4391 L
s
.31694 .4391 m
.27229 .41781 L
s
0 .637 .637 r
.44279 .42961 m
.31694 .4391 L
.39147 .42378 L
F
0 g
.31694 .4391 m
.39147 .42378 L
s
.39147 .42378 m
.44279 .42961 L
s
0 .613 .613 r
.4932 .40803 m
.44279 .42961 L
.39147 .42378 L
F
0 g
.4932 .40803 m
.44279 .42961 L
s
.44279 .42961 m
.39147 .42378 L
s
0 .66 .66 r
.52654 .40242 m
.44279 .42961 L
.4932 .40803 L
F
0 g
.44279 .42961 m
.4932 .40803 L
s
.4932 .40803 m
.52654 .40242 L
s
0 .824 .824 r
.6222 .35434 m
.64604 .39424 L
.59614 .37484 L
F
0 g
.64604 .39424 m
.59614 .37484 L
s
.59614 .37484 m
.6222 .35434 L
s
0 .824 .824 r
.6222 .35434 m
.69822 .36645 L
.64604 .39424 L
F
0 g
.6222 .35434 m
.69822 .36645 L
s
.69822 .36645 m
.64604 .39424 L
s
0 .802 .802 r
.72824 .33387 m
.77314 .37838 L
.69822 .36645 L
F
0 g
.77314 .37838 m
.69822 .36645 L
s
.69822 .36645 m
.72824 .33387 L
s
0 .802 .802 r
.72824 .33387 m
.8194 .33647 L
.77314 .37838 L
F
0 g
.72824 .33387 m
.8194 .33647 L
s
.8194 .33647 m
.77314 .37838 L
s
0 .635 .635 r
.39147 .42378 m
.27229 .41781 L
.36237 .41065 L
F
0 g
.27229 .41781 m
.36237 .41065 L
s
.36237 .41065 m
.39147 .42378 L
s
0 .613 .613 r
.46747 .40816 m
.39147 .42378 L
.36237 .41065 L
F
0 g
.46747 .40816 m
.39147 .42378 L
s
.39147 .42378 m
.36237 .41065 L
s
0 .613 .613 r
.4932 .40803 m
.39147 .42378 L
.46747 .40816 L
F
0 g
.39147 .42378 m
.46747 .40816 L
s
.46747 .40816 m
.4932 .40803 L
s
0 .663 .663 r
.27229 .41781 m
.18302 .42491 L
.17486 .38731 L
F
0 g
.27229 .41781 m
.18302 .42491 L
s
.18302 .42491 m
.17486 .38731 L
s
0 .768 .768 r
.54502 .36687 m
.56261 .3912 L
.52654 .40242 L
F
0 g
.56261 .3912 m
.52654 .40242 L
s
0 .768 .768 r
.54502 .36687 m
.54503 .36687 L
.54502 .36687 L
F
0 g
.54502 .36687 m
.54503 .36687 L
s
0 .768 .768 r
.54503 .36687 m
.56261 .3912 L
.54502 .36687 L
F
0 g
.54503 .36687 m
.56261 .3912 L
s
0 .768 .768 r
.54502 .36687 m
.54502 .36687 L
.54501 .3773 L
F
0 g
.54501 .3773 m
.54502 .36687 L
s
0 .768 .768 r
.54502 .36687 m
.52654 .40242 L
.54501 .3773 L
F
0 g
.52654 .40242 m
.54501 .3773 L
s
0 .635 .635 r
.54498 .37731 m
.52654 .40242 L
.4932 .40803 L
F
0 g
.52654 .40242 m
.4932 .40803 L
s
0 .635 .635 r
.54499 .37731 m
.52654 .40242 L
.54498 .37731 L
F
.54501 .3773 m
.52654 .40242 L
.545 .3773 L
F
0 g
.54501 .3773 m
.52654 .40242 L
s
0 .635 .635 r
.545 .3773 m
.54499 .37731 L
.54498 .37731 L
F
.54501 .3773 m
.54501 .3773 L
.545 .3773 L
F
0 g
.54501 .3773 m
.54501 .3773 L
s
0 .635 .635 r
.54501 .3773 m
.49455 .40723 L
.545 .38586 L
F
0 g
.545 .38586 m
.54501 .3773 L
s
0 .635 .635 r
.49455 .40723 m
.49395 .40771 L
.545 .38586 L
F
0 g
.49395 .40771 m
.545 .38586 L
s
0 .635 .635 r
.49455 .40723 m
.4932 .40803 L
.49395 .40771 L
F
0 g
.4932 .40803 m
.49395 .40771 L
s
0 .528 .528 r
.54497 .38587 m
.4932 .40803 L
.46747 .40816 L
F
0 g
.4932 .40803 m
.46747 .40816 L
s
0 .528 .528 r
.545 .38586 m
.54499 .38586 L
.54497 .38587 L
F
0 g
.545 .38586 m
.54499 .38586 L
s
0 .528 .528 r
.54499 .38586 m
.4932 .40803 L
.54497 .38587 L
F
0 g
.54499 .38586 m
.4932 .40803 L
s
0 .528 .528 r
.545 .38586 m
.54497 .38587 L
.54499 .39222 L
F
0 g
.54499 .39222 m
.545 .38586 L
s
0 .528 .528 r
.54497 .38587 m
.47476 .40606 L
.54499 .39222 L
F
.47476 .40606 m
.47183 .40726 L
.54499 .39222 L
F
0 g
.47183 .40726 m
.54499 .39222 L
s
0 .528 .528 r
.47476 .40606 m
.46747 .40816 L
.47183 .40726 L
F
0 g
.46747 .40816 m
.47183 .40726 L
s
0 .532 .532 r
.54499 .39222 m
.46747 .40816 L
.45326 .40343 L
F
0 g
.54499 .39222 m
.46747 .40816 L
s
.46747 .40816 m
.45326 .40343 L
s
0 .532 .532 r
.54499 .39222 m
.47048 .40133 L
.54498 .39614 L
F
0 g
.54498 .39614 m
.54499 .39222 L
s
0 .532 .532 r
.47048 .40133 m
.46324 .40221 L
.46787 .40187 L
F
.47048 .40133 m
.46787 .40187 L
.54498 .39614 L
F
.46324 .40221 m
.45326 .40343 L
.46135 .40279 L
F
0 g
.45326 .40343 m
.46135 .40279 L
s
0 .532 .532 r
.46324 .40221 m
.46135 .40279 L
.54498 .39614 L
F
0 g
.46135 .40279 m
.54498 .39614 L
s
0 .837 .837 r
.63679 .33125 m
.69822 .36645 L
.6222 .35434 L
F
0 g
.69822 .36645 m
.6222 .35434 L
s
.6222 .35434 m
.63679 .33125 L
s
0 .837 .837 r
.63679 .33125 m
.72824 .33387 L
.69822 .36645 L
F
0 g
.63679 .33125 m
.72824 .33387 L
s
.72824 .33387 m
.69822 .36645 L
s
0 .852 .852 r
.54504 .35497 m
.56261 .3912 L
.54502 .36687 L
F
0 g
.56261 .3912 m
.54502 .36687 L
s
.54502 .36687 m
.54504 .35497 L
s
0 .852 .852 r
.54504 .35497 m
.59614 .37484 L
.56261 .3912 L
F
0 g
.54504 .35497 m
.59614 .37484 L
s
.59614 .37484 m
.56261 .3912 L
s
0 .663 .663 r
.27229 .41781 m
.17486 .38731 L
.26782 .38986 L
F
0 g
.17486 .38731 m
.26782 .38986 L
s
.26782 .38986 m
.27229 .41781 L
s
0 .659 .659 r
.36237 .41065 m
.27229 .41781 L
.26782 .38986 L
F
0 g
.36237 .41065 m
.27229 .41781 L
s
.27229 .41781 m
.26782 .38986 L
s
0 .889 .889 r
.54505 .34206 m
.59614 .37484 L
.54504 .35497 L
F
0 g
.59614 .37484 m
.54504 .35497 L
s
.54504 .35497 m
.54505 .34206 L
s
0 .889 .889 r
.54505 .34206 m
.6222 .35434 L
.59614 .37484 L
F
0 g
.54505 .34206 m
.6222 .35434 L
s
.6222 .35434 m
.59614 .37484 L
s
0 .613 .613 r
.46747 .40816 m
.36237 .41065 L
.45326 .40343 L
F
0 g
.36237 .41065 m
.45326 .40343 L
s
.45326 .40343 m
.46747 .40816 L
s
0 .659 .659 r
.36237 .41065 m
.26782 .38986 L
.3605 .3924 L
F
0 g
.26782 .38986 m
.3605 .3924 L
s
.3605 .3924 m
.36237 .41065 L
s
0 .651 .651 r
.45326 .40343 m
.36237 .41065 L
.3605 .3924 L
F
0 g
.45326 .40343 m
.36237 .41065 L
s
.36237 .41065 m
.3605 .3924 L
s
0 .898 .898 r
.54505 .32863 m
.6222 .35434 L
.54505 .34206 L
F
0 g
.6222 .35434 m
.54505 .34206 L
s
.54505 .34206 m
.54505 .32863 L
s
0 .898 .898 r
.54505 .32863 m
.63679 .33125 L
.6222 .35434 L
F
0 g
.54505 .32863 m
.63679 .33125 L
s
.63679 .33125 m
.6222 .35434 L
s
0 .778 .778 r
.82499 .29185 m
.91028 .33907 L
.8194 .33647 L
F
0 g
.91028 .33907 m
.8194 .33647 L
s
.8194 .33647 m
.82499 .29185 L
s
0 .778 .778 r
.82499 .29185 m
.92002 .28392 L
.91028 .33907 L
F
0 g
.82499 .29185 m
.92002 .28392 L
s
.92002 .28392 m
.91028 .33907 L
s
0 .799 .799 r
.73082 .29971 m
.8194 .33647 L
.72824 .33387 L
F
0 g
.8194 .33647 m
.72824 .33387 L
s
.72824 .33387 m
.73082 .29971 L
s
0 .799 .799 r
.73082 .29971 m
.82499 .29185 L
.8194 .33647 L
F
0 g
.73082 .29971 m
.82499 .29185 L
s
.82499 .29185 m
.8194 .33647 L
s
0 .651 .651 r
.45326 .40343 m
.3605 .3924 L
.45288 .39493 L
F
0 g
.3605 .3924 m
.45288 .39493 L
s
.45288 .39493 m
.45326 .40343 L
s
0 .624 .624 r
.54498 .39614 m
.45326 .40343 L
.45288 .39493 L
F
0 g
.54498 .39614 m
.45326 .40343 L
s
.45326 .40343 m
.45288 .39493 L
s
0 .832 .832 r
.63752 .3075 m
.72824 .33387 L
.63679 .33125 L
F
0 g
.72824 .33387 m
.63679 .33125 L
s
.63679 .33125 m
.63752 .3075 L
s
0 .832 .832 r
.63752 .3075 m
.73082 .29971 L
.72824 .33387 L
F
0 g
.63752 .3075 m
.73082 .29971 L
s
.73082 .29971 m
.72824 .33387 L
s
0 .888 .888 r
.54505 .31521 m
.63679 .33125 L
.54505 .32863 L
F
0 g
.63679 .33125 m
.54505 .32863 L
s
.54505 .32863 m
.54505 .31521 L
s
0 .888 .888 r
.54505 .31521 m
.63752 .3075 L
.63679 .33125 L
F
0 g
.54505 .31521 m
.63752 .3075 L
s
.63752 .3075 m
.63679 .33125 L
s
0 .656 .656 r
.54498 .25992 m
.45303 .25718 L
.46676 .24817 L
F
0 g
.54498 .25992 m
.45303 .25718 L
s
.45303 .25718 m
.46676 .24817 L
s
0 .656 .656 r
.54498 .25992 m
.49218 .25199 L
.54499 .26123 L
F
0 g
.54499 .26123 m
.54498 .25992 L
s
0 .656 .656 r
.49218 .25199 m
.49178 .25193 L
.49223 .25201 L
F
.49218 .25199 m
.49223 .25201 L
.54499 .26123 L
F
.49178 .25193 m
.49696 .25321 L
.54499 .26123 L
F
0 g
.49696 .25321 m
.54499 .26123 L
s
0 .656 .656 r
.49178 .25193 m
.46676 .24817 L
.49696 .25321 L
F
0 g
.46676 .24817 m
.49696 .25321 L
s
0 .56 .56 r
.54499 .26123 m
.46676 .24817 L
.49269 .2437 L
F
0 g
.54499 .26123 m
.46676 .24817 L
s
.46676 .24817 m
.49269 .2437 L
s
0 .56 .56 r
.54499 .26123 m
.49269 .2437 L
.545 .26513 L
F
0 g
.49269 .2437 m
.545 .26513 L
s
.545 .26513 m
.54499 .26123 L
s
0 .531 .531 r
.54499 .26513 m
.49269 .2437 L
.52691 .24498 L
F
0 g
.49269 .2437 m
.52691 .24498 L
s
0 .531 .531 r
.545 .26513 m
.54496 .26512 L
.54499 .26513 L
F
0 g
.545 .26513 m
.54496 .26512 L
s
0 .531 .531 r
.54496 .26512 m
.49269 .2437 L
.54499 .26513 L
F
0 g
.54496 .26512 m
.49269 .2437 L
s
0 .531 .531 r
.545 .26513 m
.52691 .24498 L
.54501 .27148 L
F
0 g
.52691 .24498 m
.54501 .27148 L
s
.54501 .27148 m
.545 .26513 L
s
0 .606 .606 r
.54503 .27146 m
.52691 .24498 L
.56406 .25259 L
F
0 g
.52691 .24498 m
.56406 .25259 L
s
0 .606 .606 r
.54501 .27148 m
.54499 .27145 L
.54503 .27146 L
F
0 g
.54501 .27148 m
.54499 .27145 L
s
0 .606 .606 r
.54499 .27145 m
.52691 .24498 L
.54503 .27146 L
F
0 g
.54499 .27145 m
.52691 .24498 L
s
0 .606 .606 r
.54501 .27148 m
.56406 .25259 L
.54502 .28002 L
F
0 g
.56406 .25259 m
.54502 .28002 L
s
.54502 .28002 m
.54501 .27148 L
s
0 .721 .721 r
.54502 .28002 m
.59823 .26633 L
.54504 .29043 L
F
0 g
.59823 .26633 m
.54504 .29043 L
s
.54504 .29043 m
.54502 .28002 L
s
0 .721 .721 r
.54502 .28002 m
.56406 .25259 L
.59823 .26633 L
F
0 g
.54502 .28002 m
.56406 .25259 L
s
.56406 .25259 m
.59823 .26633 L
s
0 .809 .809 r
.54504 .29043 m
.62403 .28518 L
.54505 .30232 L
F
0 g
.62403 .28518 m
.54505 .30232 L
s
.54505 .30232 m
.54504 .29043 L
s
0 .809 .809 r
.54504 .29043 m
.59823 .26633 L
.62403 .28518 L
F
0 g
.54504 .29043 m
.59823 .26633 L
s
.59823 .26633 m
.62403 .28518 L
s
0 .861 .861 r
.54505 .30232 m
.63752 .3075 L
.54505 .31521 L
F
0 g
.63752 .3075 m
.54505 .31521 L
s
.54505 .31521 m
.54505 .30232 L
s
0 .861 .861 r
.54505 .30232 m
.62403 .28518 L
.63752 .3075 L
F
0 g
.54505 .30232 m
.62403 .28518 L
s
.62403 .28518 m
.63752 .3075 L
s
0 .681 .681 r
.45303 .25718 m
.38735 .23491 L
.46676 .24817 L
F
0 g
.38735 .23491 m
.46676 .24817 L
s
.46676 .24817 m
.45303 .25718 L
s
0 .681 .681 r
.45303 .25718 m
.3608 .25444 L
.38735 .23491 L
F
0 g
.45303 .25718 m
.3608 .25444 L
s
.3608 .25444 m
.38735 .23491 L
s
0 .624 .624 r
.54498 .39614 m
.45288 .39493 L
.54498 .39746 L
F
0 g
.45288 .39493 m
.54498 .39746 L
s
.54498 .39746 m
.54498 .39614 L
s
0 .689 .689 r
.3608 .25444 m
.30675 .22145 L
.38735 .23491 L
F
0 g
.30675 .22145 m
.38735 .23491 L
s
.38735 .23491 m
.3608 .25444 L
s
0 .689 .689 r
.3608 .25444 m
.26828 .25168 L
.30675 .22145 L
F
0 g
.3608 .25444 m
.26828 .25168 L
s
.26828 .25168 m
.30675 .22145 L
s
0 .692 .692 r
.26828 .25168 m
.22491 .20779 L
.30675 .22145 L
F
0 g
.22491 .20779 m
.30675 .22145 L
s
.30675 .22145 m
.26828 .25168 L
s
0 .692 .692 r
.26828 .25168 m
.17547 .24892 L
.22491 .20779 L
F
0 g
.26828 .25168 m
.17547 .24892 L
s
.17547 .24892 m
.22491 .20779 L
s
0 .809 .809 r
.62403 .28518 m
.73082 .29971 L
.63752 .3075 L
F
0 g
.73082 .29971 m
.63752 .3075 L
s
.63752 .3075 m
.62403 .28518 L
s
0 .64 .64 r
.46676 .24817 m
.43908 .22172 L
.49269 .2437 L
F
0 g
.43908 .22172 m
.49269 .2437 L
s
.49269 .2437 m
.46676 .24817 L
s
0 .64 .64 r
.46676 .24817 m
.38735 .23491 L
.43908 .22172 L
F
0 g
.46676 .24817 m
.38735 .23491 L
s
.38735 .23491 m
.43908 .22172 L
s
0 .781 .781 r
.70461 .26769 m
.82499 .29185 L
.73082 .29971 L
F
0 g
.82499 .29185 m
.73082 .29971 L
s
.73082 .29971 m
.70461 .26769 L
s
0 .809 .809 r
.62403 .28518 m
.70461 .26769 L
.73082 .29971 L
F
0 g
.62403 .28518 m
.70461 .26769 L
s
.70461 .26769 m
.73082 .29971 L
s
0 .768 .768 r
.59823 .26633 m
.70461 .26769 L
.62403 .28518 L
F
0 g
.70461 .26769 m
.62403 .28518 L
s
.62403 .28518 m
.59823 .26633 L
s
0 .627 .627 r
.49269 .2437 m
.50825 .21765 L
.52691 .24498 L
F
0 g
.50825 .21765 m
.52691 .24498 L
s
.52691 .24498 m
.49269 .2437 L
s
0 .627 .627 r
.49269 .2437 m
.43908 .22172 L
.50825 .21765 L
F
0 g
.49269 .2437 m
.43908 .22172 L
s
.43908 .22172 m
.50825 .21765 L
s
0 .768 .768 r
.59823 .26633 m
.65293 .24154 L
.70461 .26769 L
F
0 g
.59823 .26633 m
.65293 .24154 L
s
.65293 .24154 m
.70461 .26769 L
s
0 .713 .713 r
.56406 .25259 m
.65293 .24154 L
.59823 .26633 L
F
0 g
.65293 .24154 m
.59823 .26633 L
s
.59823 .26633 m
.56406 .25259 L
s
0 .763 .763 r
.78684 .24985 m
.92002 .28392 L
.82499 .29185 L
F
0 g
.92002 .28392 m
.82499 .29185 L
s
.82499 .29185 m
.78684 .24985 L
s
0 .781 .781 r
.70461 .26769 m
.78684 .24985 L
.82499 .29185 L
F
0 g
.70461 .26769 m
.78684 .24985 L
s
.78684 .24985 m
.82499 .29185 L
s
0 .662 .662 r
.38735 .23491 m
.38412 .1992 L
.43908 .22172 L
F
0 g
.38412 .1992 m
.43908 .22172 L
s
.43908 .22172 m
.38735 .23491 L
s
0 .662 .662 r
.38735 .23491 m
.30675 .22145 L
.38412 .1992 L
F
0 g
.38735 .23491 m
.30675 .22145 L
s
.30675 .22145 m
.38412 .1992 L
s
0 .657 .657 r
.52691 .24498 m
.5837 .22428 L
.56406 .25259 L
F
0 g
.5837 .22428 m
.56406 .25259 L
s
.56406 .25259 m
.52691 .24498 L
s
0 .657 .657 r
.52691 .24498 m
.50825 .21765 L
.5837 .22428 L
F
0 g
.52691 .24498 m
.50825 .21765 L
s
.50825 .21765 m
.5837 .22428 L
s
0 .713 .713 r
.56406 .25259 m
.5837 .22428 L
.65293 .24154 L
F
0 g
.56406 .25259 m
.5837 .22428 L
s
.5837 .22428 m
.65293 .24154 L
s
0 .763 .763 r
.78684 .24985 m
.87077 .23164 L
.92002 .28392 L
F
0 g
.78684 .24985 m
.87077 .23164 L
s
.87077 .23164 m
.92002 .28392 L
s
0 .749 .749 r
.65293 .24154 m
.78684 .24985 L
.70461 .26769 L
F
0 g
.78684 .24985 m
.70461 .26769 L
s
.70461 .26769 m
.65293 .24154 L
s
0 .673 .673 r
.30675 .22145 m
.32777 .1761 L
.38412 .1992 L
F
0 g
.32777 .1761 m
.38412 .1992 L
s
.38412 .1992 m
.30675 .22145 L
s
0 .673 .673 r
.30675 .22145 m
.22491 .20779 L
.32777 .1761 L
F
0 g
.30675 .22145 m
.22491 .20779 L
s
.22491 .20779 m
.32777 .1761 L
s
0 .654 .654 r
.43908 .22172 m
.489 .18947 L
.50825 .21765 L
F
0 g
.489 .18947 m
.50825 .21765 L
s
.50825 .21765 m
.43908 .22172 L
s
0 .654 .654 r
.43908 .22172 m
.38412 .1992 L
.489 .18947 L
F
0 g
.43908 .22172 m
.38412 .1992 L
s
.38412 .1992 m
.489 .18947 L
s
0 .749 .749 r
.65293 .24154 m
.70921 .21603 L
.78684 .24985 L
F
0 g
.65293 .24154 m
.70921 .21603 L
s
.70921 .21603 m
.78684 .24985 L
s
0 .709 .709 r
.5837 .22428 m
.70921 .21603 L
.65293 .24154 L
F
0 g
.70921 .21603 m
.65293 .24154 L
s
.65293 .24154 m
.5837 .22428 L
s
0 .672 .672 r
.50825 .21765 m
.60399 .19504 L
.5837 .22428 L
F
0 g
.60399 .19504 m
.5837 .22428 L
s
.5837 .22428 m
.50825 .21765 L
s
0 .672 .672 r
.50825 .21765 m
.489 .18947 L
.60399 .19504 L
F
0 g
.50825 .21765 m
.489 .18947 L
s
.489 .18947 m
.60399 .19504 L
s
0 .738 .738 r
.70921 .21603 m
.87077 .23164 L
.78684 .24985 L
F
0 g
.87077 .23164 m
.78684 .24985 L
s
.78684 .24985 m
.70921 .21603 L
s
0 .709 .709 r
.5837 .22428 m
.60399 .19504 L
.70921 .21603 L
F
0 g
.5837 .22428 m
.60399 .19504 L
s
.60399 .19504 m
.70921 .21603 L
s
0 .667 .667 r
.38412 .1992 m
.46914 .16039 L
.489 .18947 L
F
0 g
.46914 .16039 m
.489 .18947 L
s
.489 .18947 m
.38412 .1992 L
s
0 .667 .667 r
.38412 .1992 m
.32777 .1761 L
.46914 .16039 L
F
0 g
.38412 .1992 m
.32777 .1761 L
s
.32777 .1761 m
.46914 .16039 L
s
0 .738 .738 r
.70921 .21603 m
.76713 .18978 L
.87077 .23164 L
F
0 g
.70921 .21603 m
.76713 .18978 L
s
.76713 .18978 m
.87077 .23164 L
s
0 .707 .707 r
.60399 .19504 m
.76713 .18978 L
.70921 .21603 L
F
0 g
.76713 .18978 m
.70921 .21603 L
s
.70921 .21603 m
.60399 .19504 L
s
0 .68 .68 r
.489 .18947 m
.62495 .16483 L
.60399 .19504 L
F
0 g
.62495 .16483 m
.60399 .19504 L
s
.60399 .19504 m
.489 .18947 L
s
0 .68 .68 r
.489 .18947 m
.46914 .16039 L
.62495 .16483 L
F
0 g
.489 .18947 m
.46914 .16039 L
s
.46914 .16039 m
.62495 .16483 L
s
0 .707 .707 r
.60399 .19504 m
.62495 .16483 L
.76713 .18978 L
F
0 g
.60399 .19504 m
.62495 .16483 L
s
.62495 .16483 m
.76713 .18978 L
s
1 g
.49117 .58228 m
.47428 .60332 L
.34564 .60192 L
F
0 g
.49117 .58228 m
.47428 .60332 L
s
.47428 .60332 m
.34564 .60192 L
s
1 g
.59634 .56983 m
.47428 .60332 L
.49117 .58228 L
F
0 g
.47428 .60332 m
.49117 .58228 L
s
.49117 .58228 m
.59634 .56983 L
s
1 g
.59634 .56983 m
.61248 .59029 L
.47428 .60332 L
F
0 g
.59634 .56983 m
.61248 .59029 L
s
.61248 .59029 m
.47428 .60332 L
s
1 g
.695 .54628 m
.61248 .59029 L
.59634 .56983 L
F
0 g
.61248 .59029 m
.59634 .56983 L
s
.59634 .56983 m
.695 .54628 L
s
1 g
.695 .54628 m
.74268 .56327 L
.61248 .59029 L
F
0 g
.695 .54628 m
.74268 .56327 L
s
.74268 .56327 m
.61248 .59029 L
s
1 g
.39349 .58317 m
.34564 .60192 L
.24335 .58692 L
F
0 g
.39349 .58317 m
.34564 .60192 L
s
.34564 .60192 m
.24335 .58692 L
s
1 g
.49117 .58228 m
.34564 .60192 L
.39349 .58317 L
F
0 g
.34564 .60192 m
.39349 .58317 L
s
.39349 .58317 m
.49117 .58228 L
s
1 g
.77351 .51325 m
.74268 .56327 L
.695 .54628 L
F
0 g
.74268 .56327 m
.695 .54628 L
s
.695 .54628 m
.77351 .51325 L
s
1 g
.77351 .51325 m
.84746 .52405 L
.74268 .56327 L
F
0 g
.77351 .51325 m
.84746 .52405 L
s
.84746 .52405 m
.74268 .56327 L
s
1 g
.50857 .56061 m
.49117 .58228 L
.39349 .58317 L
F
0 g
.50857 .56061 m
.49117 .58228 L
s
.49117 .58228 m
.39349 .58317 L
s
1 g
.57974 .54877 m
.49117 .58228 L
.50857 .56061 L
F
0 g
.49117 .58228 m
.50857 .56061 L
s
.50857 .56061 m
.57974 .54877 L
s
1 g
.57974 .54877 m
.59634 .56983 L
.49117 .58228 L
F
0 g
.57974 .54877 m
.59634 .56983 L
s
.59634 .56983 m
.49117 .58228 L
s
1 g
.6462 .52888 m
.59634 .56983 L
.57974 .54877 L
F
0 g
.59634 .56983 m
.57974 .54877 L
s
.57974 .54877 m
.6462 .52888 L
s
1 g
.6462 .52888 m
.695 .54628 L
.59634 .56983 L
F
0 g
.6462 .52888 m
.695 .54628 L
s
.695 .54628 m
.59634 .56983 L
s
1 g
.39349 .58317 m
.24335 .58692 L
.31657 .57315 L
F
0 g
.24335 .58692 m
.31657 .57315 L
s
.31657 .57315 m
.39349 .58317 L
s
1 g
.44263 .56392 m
.39349 .58317 L
.31657 .57315 L
F
0 g
.44263 .56392 m
.39349 .58317 L
s
.39349 .58317 m
.31657 .57315 L
s
1 g
.50857 .56061 m
.39349 .58317 L
.44263 .56392 L
F
0 g
.39349 .58317 m
.44263 .56392 L
s
.44263 .56392 m
.50857 .56061 L
s
1 g
.31657 .57315 m
.24335 .58692 L
.18243 .56048 L
F
0 g
.31657 .57315 m
.24335 .58692 L
s
.24335 .58692 m
.18243 .56048 L
s
1 g
.69847 .50228 m
.695 .54628 L
.6462 .52888 L
F
0 g
.695 .54628 m
.6462 .52888 L
s
.6462 .52888 m
.69847 .50228 L
s
1 g
.69847 .50228 m
.77351 .51325 L
.695 .54628 L
F
0 g
.69847 .50228 m
.77351 .51325 L
s
.77351 .51325 m
.695 .54628 L
s
1 g
.52651 .53826 m
.50857 .56061 L
.44263 .56392 L
F
0 g
.52651 .53826 m
.50857 .56061 L
s
.50857 .56061 m
.44263 .56392 L
s
1 g
.56264 .52709 m
.50857 .56061 L
.52651 .53826 L
F
0 g
.50857 .56061 m
.52651 .53826 L
s
.52651 .53826 m
.56264 .52709 L
s
1 g
.56264 .52709 m
.57974 .54877 L
.50857 .56061 L
F
0 g
.56264 .52709 m
.57974 .54877 L
s
.57974 .54877 m
.50857 .56061 L
s
1 g
.59623 .51107 m
.57974 .54877 L
.56264 .52709 L
F
0 g
.57974 .54877 m
.56264 .52709 L
s
.56264 .52709 m
.59623 .51107 L
s
1 g
.59623 .51107 m
.6462 .52888 L
.57974 .54877 L
F
0 g
.59623 .51107 m
.6462 .52888 L
s
.6462 .52888 m
.57974 .54877 L
s
1 g
.81985 .47361 m
.84746 .52405 L
.77351 .51325 L
F
0 g
.84746 .52405 m
.77351 .51325 L
s
.77351 .51325 m
.81985 .47361 L
s
1 g
.81985 .47361 m
.91088 .476 L
.84746 .52405 L
F
0 g
.81985 .47361 m
.91088 .476 L
s
.91088 .476 m
.84746 .52405 L
s
1 g
.31657 .57315 m
.18243 .56048 L
.27185 .55398 L
F
0 g
.18243 .56048 m
.27185 .55398 L
s
.27185 .55398 m
.31657 .57315 L
s
1 g
.39123 .55911 m
.31657 .57315 L
.27185 .55398 L
F
0 g
.39123 .55911 m
.31657 .57315 L
s
.31657 .57315 m
.27185 .55398 L
s
1 g
.44263 .56392 m
.31657 .57315 L
.39123 .55911 L
F
0 g
.31657 .57315 m
.39123 .55911 L
s
.39123 .55911 m
.44263 .56392 L
s
1 g
.49311 .54414 m
.44263 .56392 L
.39123 .55911 L
F
0 g
.49311 .54414 m
.44263 .56392 L
s
.44263 .56392 m
.39123 .55911 L
s
1 g
.52651 .53826 m
.44263 .56392 L
.49311 .54414 L
F
0 g
.44263 .56392 m
.49311 .54414 L
s
.49311 .54414 m
.52651 .53826 L
s
1 g
.62232 .49116 m
.6462 .52888 L
.59623 .51107 L
F
0 g
.6462 .52888 m
.59623 .51107 L
s
.59623 .51107 m
.62232 .49116 L
s
1 g
.62232 .49116 m
.69847 .50228 L
.6462 .52888 L
F
0 g
.62232 .49116 m
.69847 .50228 L
s
.69847 .50228 m
.6462 .52888 L
s
1 g
.72854 .47121 m
.77351 .51325 L
.69847 .50228 L
F
0 g
.77351 .51325 m
.69847 .50228 L
s
.69847 .50228 m
.72854 .47121 L
s
1 g
.72854 .47121 m
.81985 .47361 L
.77351 .51325 L
F
0 g
.72854 .47121 m
.81985 .47361 L
s
.81985 .47361 m
.77351 .51325 L
s
1 g
.39123 .55911 m
.27185 .55398 L
.36208 .54742 L
F
0 g
.27185 .55398 m
.36208 .54742 L
s
.36208 .54742 m
.39123 .55911 L
s
1 g
.46735 .5448 m
.39123 .55911 L
.36208 .54742 L
F
0 g
.46735 .5448 m
.39123 .55911 L
s
.39123 .55911 m
.36208 .54742 L
s
1 g
.49311 .54414 m
.39123 .55911 L
.46735 .5448 L
F
0 g
.39123 .55911 m
.46735 .5448 L
s
.46735 .5448 m
.49311 .54414 L
s
1 g
.27185 .55398 m
.18243 .56048 L
.17425 .52616 L
F
0 g
.27185 .55398 m
.18243 .56048 L
s
.18243 .56048 m
.17425 .52616 L
s
1 g
.54502 .50476 m
.56264 .52709 L
.52651 .53826 L
F
0 g
.56264 .52709 m
.52651 .53826 L
s
1 g
.54502 .50476 m
.54502 .50476 L
.54502 .50476 L
F
0 g
.54502 .50476 m
.54502 .50476 L
s
1 g
.54502 .50476 m
.56264 .52709 L
.54502 .50476 L
F
0 g
.54502 .50476 m
.56264 .52709 L
s
1 g
.54502 .50476 m
.54502 .50476 L
.54501 .51522 L
F
0 g
.54501 .51522 m
.54502 .50476 L
s
1 g
.54502 .50476 m
.52651 .53826 L
.54501 .51522 L
F
0 g
.52651 .53826 m
.54501 .51522 L
s
1 g
.54498 .51524 m
.52651 .53826 L
.49311 .54414 L
F
0 g
.52651 .53826 m
.49311 .54414 L
s
1 g
.54499 .51524 m
.52651 .53826 L
.54498 .51524 L
F
.54501 .51523 m
.52651 .53826 L
.545 .51523 L
F
0 g
.54501 .51523 m
.52651 .53826 L
s
1 g
.545 .51523 m
.54499 .51524 L
.54498 .51524 L
F
.54501 .51522 m
.54501 .51523 L
.545 .51523 L
F
0 g
.54501 .51522 m
.54501 .51523 L
s
1 g
.54501 .51522 m
.49446 .54339 L
.54499 .52381 L
F
0 g
.54499 .52381 m
.54501 .51522 L
s
1 g
.49446 .54339 m
.49386 .54385 L
.54499 .52381 L
F
0 g
.49386 .54385 m
.54499 .52381 L
s
1 g
.49446 .54339 m
.49311 .54414 L
.49386 .54385 L
F
0 g
.49311 .54414 m
.49386 .54385 L
s
1 g
.54497 .52382 m
.49311 .54414 L
.46735 .5448 L
F
0 g
.49311 .54414 m
.46735 .5448 L
s
1 g
.54499 .52381 m
.54499 .52382 L
.54497 .52382 L
F
0 g
.54499 .52381 m
.54499 .52382 L
s
1 g
.54499 .52382 m
.49311 .54414 L
.54497 .52382 L
F
0 g
.54499 .52382 m
.49311 .54414 L
s
1 g
.54499 .52381 m
.54497 .52382 L
.54498 .5302 L
F
0 g
.54498 .5302 m
.54499 .52381 L
s
1 g
.54497 .52382 m
.47464 .54283 L
.54498 .5302 L
F
.47464 .54283 m
.47171 .54398 L
.54498 .5302 L
F
0 g
.47171 .54398 m
.54498 .5302 L
s
1 g
.47464 .54283 m
.46735 .5448 L
.47171 .54398 L
F
0 g
.46735 .5448 m
.47171 .54398 L
s
1 g
.54498 .5302 m
.46735 .5448 L
.45311 .54081 L
F
0 g
.54498 .5302 m
.46735 .5448 L
s
.46735 .5448 m
.45311 .54081 L
s
1 g
.54498 .5302 m
.47035 .53881 L
.54498 .53413 L
F
0 g
.54498 .53413 m
.54498 .5302 L
s
1 g
.47035 .53881 m
.46311 .53965 L
.46775 .53934 L
F
.47035 .53881 m
.46775 .53934 L
.54498 .53413 L
F
.46311 .53965 m
.45311 .54081 L
.46121 .54022 L
F
0 g
.45311 .54081 m
.46121 .54022 L
s
1 g
.46311 .53965 m
.46121 .54022 L
.54498 .53413 L
F
0 g
.46121 .54022 m
.54498 .53413 L
s
1 g
.63694 .46881 m
.69847 .50228 L
.62232 .49116 L
F
0 g
.69847 .50228 m
.62232 .49116 L
s
.62232 .49116 m
.63694 .46881 L
s
1 g
.63694 .46881 m
.72854 .47121 L
.69847 .50228 L
F
0 g
.63694 .46881 m
.72854 .47121 L
s
.72854 .47121 m
.69847 .50228 L
s
1 g
.54504 .49282 m
.56264 .52709 L
.54502 .50476 L
F
0 g
.56264 .52709 m
.54502 .50476 L
s
.54502 .50476 m
.54504 .49282 L
s
1 g
.54504 .49282 m
.59623 .51107 L
.56264 .52709 L
F
0 g
.54504 .49282 m
.59623 .51107 L
s
.59623 .51107 m
.56264 .52709 L
s
1 g
.27185 .55398 m
.17425 .52616 L
.26737 .52849 L
F
0 g
.17425 .52616 m
.26737 .52849 L
s
.26737 .52849 m
.27185 .55398 L
s
1 g
.36208 .54742 m
.27185 .55398 L
.26737 .52849 L
F
0 g
.36208 .54742 m
.27185 .55398 L
s
.27185 .55398 m
.26737 .52849 L
s
1 g
.54505 .47987 m
.59623 .51107 L
.54504 .49282 L
F
0 g
.59623 .51107 m
.54504 .49282 L
s
.54504 .49282 m
.54505 .47987 L
s
1 g
.54505 .47987 m
.62232 .49116 L
.59623 .51107 L
F
0 g
.54505 .47987 m
.62232 .49116 L
s
.62232 .49116 m
.59623 .51107 L
s
1 g
.46735 .5448 m
.36208 .54742 L
.45311 .54081 L
F
0 g
.36208 .54742 m
.45311 .54081 L
s
.45311 .54081 m
.46735 .5448 L
s
1 g
.36208 .54742 m
.26737 .52849 L
.36019 .53082 L
F
0 g
.26737 .52849 m
.36019 .53082 L
s
.36019 .53082 m
.36208 .54742 L
s
1 g
.45311 .54081 m
.36208 .54742 L
.36019 .53082 L
F
0 g
.45311 .54081 m
.36208 .54742 L
s
.36208 .54742 m
.36019 .53082 L
s
1 g
.54505 .4664 m
.62232 .49116 L
.54505 .47987 L
F
0 g
.62232 .49116 m
.54505 .47987 L
s
.54505 .47987 m
.54505 .4664 L
s
1 g
.54505 .4664 m
.63694 .46881 L
.62232 .49116 L
F
0 g
.54505 .4664 m
.63694 .46881 L
s
.63694 .46881 m
.62232 .49116 L
s
1 g
.82545 .43143 m
.91088 .476 L
.81985 .47361 L
F
0 g
.91088 .476 m
.81985 .47361 L
s
.81985 .47361 m
.82545 .43143 L
s
1 g
.82545 .43143 m
.92064 .42413 L
.91088 .476 L
F
0 g
.82545 .43143 m
.92064 .42413 L
s
.92064 .42413 m
.91088 .476 L
s
1 g
.73113 .43867 m
.81985 .47361 L
.72854 .47121 L
F
0 g
.81985 .47361 m
.72854 .47121 L
s
.72854 .47121 m
.73113 .43867 L
s
1 g
.73113 .43867 m
.82545 .43143 L
.81985 .47361 L
F
0 g
.73113 .43867 m
.82545 .43143 L
s
.82545 .43143 m
.81985 .47361 L
s
1 g
.45311 .54081 m
.36019 .53082 L
.45273 .53314 L
F
0 g
.36019 .53082 m
.45273 .53314 L
s
.45273 .53314 m
.45311 .54081 L
s
1 g
.54498 .53413 m
.45311 .54081 L
.45273 .53314 L
F
0 g
.54498 .53413 m
.45311 .54081 L
s
.45311 .54081 m
.45273 .53314 L
s
1 g
.63767 .44583 m
.72854 .47121 L
.63694 .46881 L
F
0 g
.72854 .47121 m
.63694 .46881 L
s
.63694 .46881 m
.63767 .44583 L
s
1 g
.63767 .44583 m
.73113 .43867 L
.72854 .47121 L
F
0 g
.63767 .44583 m
.73113 .43867 L
s
.73113 .43867 m
.72854 .47121 L
s
1 g
.54505 .45294 m
.63694 .46881 L
.54505 .4664 L
F
0 g
.63694 .46881 m
.54505 .4664 L
s
.54505 .4664 m
.54505 .45294 L
s
1 g
.54505 .45294 m
.63767 .44583 L
.63694 .46881 L
F
0 g
.54505 .45294 m
.63767 .44583 L
s
.63767 .44583 m
.63694 .46881 L
s
1 g
.54498 .39746 m
.45288 .39493 L
.46663 .38672 L
F
0 g
.54498 .39746 m
.45288 .39493 L
s
.45288 .39493 m
.46663 .38672 L
s
1 g
.54498 .39746 m
.49209 .39021 L
.54499 .39878 L
F
0 g
.54499 .39878 m
.54498 .39746 L
s
1 g
.49209 .39021 m
.49169 .39016 L
.49214 .39023 L
F
.49209 .39021 m
.49214 .39023 L
.54499 .39878 L
F
.49169 .39016 m
.49688 .39138 L
.54499 .39878 L
F
0 g
.49688 .39138 m
.54499 .39878 L
s
1 g
.49169 .39016 m
.46663 .38672 L
.49688 .39138 L
F
0 g
.46663 .38672 m
.49688 .39138 L
s
1 g
.54499 .39878 m
.46663 .38672 L
.4926 .38291 L
F
0 g
.54499 .39878 m
.46663 .38672 L
s
.46663 .38672 m
.4926 .38291 L
s
1 g
.54499 .39878 m
.4926 .38291 L
.545 .40269 L
F
0 g
.4926 .38291 m
.545 .40269 L
s
.545 .40269 m
.54499 .39878 L
s
1 g
.54499 .40269 m
.4926 .38291 L
.52688 .38461 L
F
0 g
.4926 .38291 m
.52688 .38461 L
s
1 g
.545 .40269 m
.54496 .40268 L
.54499 .40269 L
F
0 g
.545 .40269 m
.54496 .40268 L
s
1 g
.54496 .40268 m
.4926 .38291 L
.54499 .40269 L
F
0 g
.54496 .40268 m
.4926 .38291 L
s
1 g
.545 .40269 m
.52688 .38461 L
.54501 .40906 L
F
0 g
.52688 .38461 m
.54501 .40906 L
s
.54501 .40906 m
.545 .40269 L
s
1 g
.54503 .40904 m
.52688 .38461 L
.56409 .39234 L
F
0 g
.52688 .38461 m
.56409 .39234 L
s
1 g
.54501 .40906 m
.54499 .40903 L
.54503 .40904 L
F
0 g
.54501 .40906 m
.54499 .40903 L
s
1 g
.54499 .40903 m
.52688 .38461 L
.54503 .40904 L
F
0 g
.54499 .40903 m
.52688 .38461 L
s
1 g
.54501 .40906 m
.56409 .39234 L
.54502 .41763 L
F
0 g
.56409 .39234 m
.54502 .41763 L
s
.54502 .41763 m
.54501 .40906 L
s
1 g
.54502 .41763 m
.59832 .40586 L
.54504 .42808 L
F
0 g
.59832 .40586 m
.54504 .42808 L
s
.54504 .42808 m
.54502 .41763 L
s
1 g
.54502 .41763 m
.56409 .39234 L
.59832 .40586 L
F
0 g
.54502 .41763 m
.56409 .39234 L
s
.56409 .39234 m
.59832 .40586 L
s
1 g
.54504 .42808 m
.62416 .42421 L
.54505 .44 L
F
0 g
.62416 .42421 m
.54505 .44 L
s
.54505 .44 m
.54504 .42808 L
s
1 g
.54504 .42808 m
.59832 .40586 L
.62416 .42421 L
F
0 g
.54504 .42808 m
.59832 .40586 L
s
.59832 .40586 m
.62416 .42421 L
s
1 g
.54505 .44 m
.63767 .44583 L
.54505 .45294 L
F
0 g
.63767 .44583 m
.54505 .45294 L
s
.54505 .45294 m
.54505 .44 L
s
1 g
.54505 .44 m
.62416 .42421 L
.63767 .44583 L
F
0 g
.54505 .44 m
.62416 .42421 L
s
.62416 .42421 m
.63767 .44583 L
s
1 g
.45288 .39493 m
.38709 .37449 L
.46663 .38672 L
F
0 g
.38709 .37449 m
.46663 .38672 L
s
.46663 .38672 m
.45288 .39493 L
s
1 g
.45288 .39493 m
.3605 .3924 L
.38709 .37449 L
F
0 g
.45288 .39493 m
.3605 .3924 L
s
.3605 .3924 m
.38709 .37449 L
s
1 g
.54498 .53413 m
.45273 .53314 L
.54498 .53545 L
F
0 g
.45273 .53314 m
.54498 .53545 L
s
.54498 .53545 m
.54498 .53413 L
s
1 g
.3605 .3924 m
.30635 .36206 L
.38709 .37449 L
F
0 g
.30635 .36206 m
.38709 .37449 L
s
.38709 .37449 m
.3605 .3924 L
s
1 g
.3605 .3924 m
.26782 .38986 L
.30635 .36206 L
F
0 g
.3605 .3924 m
.26782 .38986 L
s
.26782 .38986 m
.30635 .36206 L
s
1 g
.26782 .38986 m
.22437 .34945 L
.30635 .36206 L
F
0 g
.22437 .34945 m
.30635 .36206 L
s
.30635 .36206 m
.26782 .38986 L
s
1 g
.26782 .38986 m
.17486 .38731 L
.22437 .34945 L
F
0 g
.26782 .38986 m
.17486 .38731 L
s
.17486 .38731 m
.22437 .34945 L
s
1 g
.62416 .42421 m
.73113 .43867 L
.63767 .44583 L
F
0 g
.73113 .43867 m
.63767 .44583 L
s
.63767 .44583 m
.62416 .42421 L
s
1 g
.46663 .38672 m
.4389 .36263 L
.4926 .38291 L
F
0 g
.4389 .36263 m
.4926 .38291 L
s
.4926 .38291 m
.46663 .38672 L
s
1 g
.46663 .38672 m
.38709 .37449 L
.4389 .36263 L
F
0 g
.46663 .38672 m
.38709 .37449 L
s
.38709 .37449 m
.4389 .36263 L
s
1 g
.70488 .40811 m
.82545 .43143 L
.73113 .43867 L
F
0 g
.82545 .43143 m
.73113 .43867 L
s
.73113 .43867 m
.70488 .40811 L
s
1 g
.62416 .42421 m
.70488 .40811 L
.73113 .43867 L
F
0 g
.62416 .42421 m
.70488 .40811 L
s
.70488 .40811 m
.73113 .43867 L
s
1 g
.59832 .40586 m
.70488 .40811 L
.62416 .42421 L
F
0 g
.70488 .40811 m
.62416 .42421 L
s
.62416 .42421 m
.59832 .40586 L
s
1 g
.4926 .38291 m
.50819 .3594 L
.52688 .38461 L
F
0 g
.50819 .3594 m
.52688 .38461 L
s
.52688 .38461 m
.4926 .38291 L
s
1 g
.4926 .38291 m
.4389 .36263 L
.50819 .3594 L
F
0 g
.4926 .38291 m
.4389 .36263 L
s
.4389 .36263 m
.50819 .3594 L
s
1 g
.59832 .40586 m
.65311 .38301 L
.70488 .40811 L
F
0 g
.59832 .40586 m
.65311 .38301 L
s
.65311 .38301 m
.70488 .40811 L
s
1 g
.56409 .39234 m
.65311 .38301 L
.59832 .40586 L
F
0 g
.65311 .38301 m
.59832 .40586 L
s
.59832 .40586 m
.56409 .39234 L
s
1 g
.78725 .39168 m
.92064 .42413 L
.82545 .43143 L
F
0 g
.92064 .42413 m
.82545 .43143 L
s
.82545 .43143 m
.78725 .39168 L
s
1 g
.70488 .40811 m
.78725 .39168 L
.82545 .43143 L
F
0 g
.70488 .40811 m
.78725 .39168 L
s
.78725 .39168 m
.82545 .43143 L
s
1 g
.38709 .37449 m
.38385 .34185 L
.4389 .36263 L
F
0 g
.38385 .34185 m
.4389 .36263 L
s
.4389 .36263 m
.38709 .37449 L
s
1 g
.38709 .37449 m
.30635 .36206 L
.38385 .34185 L
F
0 g
.38709 .37449 m
.30635 .36206 L
s
.30635 .36206 m
.38385 .34185 L
s
1 g
.52688 .38461 m
.58377 .36623 L
.56409 .39234 L
F
0 g
.58377 .36623 m
.56409 .39234 L
s
.56409 .39234 m
.52688 .38461 L
s
1 g
.52688 .38461 m
.50819 .3594 L
.58377 .36623 L
F
0 g
.52688 .38461 m
.50819 .3594 L
s
.50819 .3594 m
.58377 .36623 L
s
1 g
.56409 .39234 m
.58377 .36623 L
.65311 .38301 L
F
0 g
.56409 .39234 m
.58377 .36623 L
s
.58377 .36623 m
.65311 .38301 L
s
1 g
.78725 .39168 m
.87133 .3749 L
.92064 .42413 L
F
0 g
.78725 .39168 m
.87133 .3749 L
s
.87133 .3749 m
.92064 .42413 L
s
1 g
.65311 .38301 m
.78725 .39168 L
.70488 .40811 L
F
0 g
.78725 .39168 m
.70488 .40811 L
s
.70488 .40811 m
.65311 .38301 L
s
1 g
.30635 .36206 m
.32739 .32053 L
.38385 .34185 L
F
0 g
.32739 .32053 m
.38385 .34185 L
s
.38385 .34185 m
.30635 .36206 L
s
1 g
.30635 .36206 m
.22437 .34945 L
.32739 .32053 L
F
0 g
.30635 .36206 m
.22437 .34945 L
s
.22437 .34945 m
.32739 .32053 L
s
1 g
.4389 .36263 m
.48891 .33341 L
.50819 .3594 L
F
0 g
.48891 .33341 m
.50819 .3594 L
s
.50819 .3594 m
.4389 .36263 L
s
1 g
.4389 .36263 m
.38385 .34185 L
.48891 .33341 L
F
0 g
.4389 .36263 m
.38385 .34185 L
s
.38385 .34185 m
.48891 .33341 L
s
1 g
.65311 .38301 m
.70949 .35951 L
.78725 .39168 L
F
0 g
.65311 .38301 m
.70949 .35951 L
s
.70949 .35951 m
.78725 .39168 L
s
1 g
.58377 .36623 m
.70949 .35951 L
.65311 .38301 L
F
0 g
.70949 .35951 m
.65311 .38301 L
s
.65311 .38301 m
.58377 .36623 L
s
1 g
.50819 .3594 m
.60409 .33926 L
.58377 .36623 L
F
0 g
.60409 .33926 m
.58377 .36623 L
s
.58377 .36623 m
.50819 .3594 L
s
1 g
.50819 .3594 m
.48891 .33341 L
.60409 .33926 L
F
0 g
.50819 .3594 m
.48891 .33341 L
s
.48891 .33341 m
.60409 .33926 L
s
1 g
.70949 .35951 m
.87133 .3749 L
.78725 .39168 L
F
0 g
.87133 .3749 m
.78725 .39168 L
s
.78725 .39168 m
.70949 .35951 L
s
1 g
.58377 .36623 m
.60409 .33926 L
.70949 .35951 L
F
0 g
.58377 .36623 m
.60409 .33926 L
s
.60409 .33926 m
.70949 .35951 L
s
1 g
.38385 .34185 m
.46901 .30657 L
.48891 .33341 L
F
0 g
.46901 .30657 m
.48891 .33341 L
s
.48891 .33341 m
.38385 .34185 L
s
1 g
.38385 .34185 m
.32739 .32053 L
.46901 .30657 L
F
0 g
.38385 .34185 m
.32739 .32053 L
s
.32739 .32053 m
.46901 .30657 L
s
1 g
.70949 .35951 m
.76751 .33531 L
.87133 .3749 L
F
0 g
.70949 .35951 m
.76751 .33531 L
s
.76751 .33531 m
.87133 .3749 L
s
1 g
.60409 .33926 m
.76751 .33531 L
.70949 .35951 L
F
0 g
.76751 .33531 m
.70949 .35951 L
s
.70949 .35951 m
.60409 .33926 L
s
1 g
.48891 .33341 m
.62509 .3114 L
.60409 .33926 L
F
0 g
.62509 .3114 m
.60409 .33926 L
s
.60409 .33926 m
.48891 .33341 L
s
1 g
.48891 .33341 m
.46901 .30657 L
.62509 .3114 L
F
0 g
.48891 .33341 m
.46901 .30657 L
s
.46901 .30657 m
.62509 .3114 L
s
1 g
.60409 .33926 m
.62509 .3114 L
.76751 .33531 L
F
0 g
.60409 .33926 m
.62509 .3114 L
s
.62509 .3114 m
.76751 .33531 L
s
gsave
.93901 .32888 -66.2813 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
69.563 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.96182 .30748 -65.75 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
68.500 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.93984 .46164 -66.2813 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
69.563 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.9627 .44008 -65.75 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
68.500 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.93817 .19668 -66.2813 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
69.563 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .17593 -68.9375 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.375 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
74.875 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {0, 0, 0, 0}}],
 StyleBox["     ",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10  scalefont  setfont
% Scaling calculations
0.468085 0.212766 0.290201 0.0289483 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .2902 m
1 .2902 L
s
.46809 0 m
.46809 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.5 Mabswid
0 .2902 m
.12121 .2902 L
.29703 .2902 L
.46608 .2902 L
.64609 .2902 L
.81933 .2902 L
s
.81933 .2902 m
1 .2902 L
s
0 1 1 r
.89362 .38114 m
.04255 .38114 L
.04255 .19926 L
.89362 .19926 L
.89362 .38114 L
F
0 g
.04255 .19926 m
.04255 .20664 L
.04255 .21468 L
.04255 .22224 L
.04255 .22951 L
.04255 .23724 L
.04255 .24469 L
.04255 .25261 L
.04255 .26023 L
.04255 .26757 L
.04255 .27537 L
.04255 .28289 L
.04255 .29011 L
.04255 .29781 L
.04255 .30521 L
.04255 .31309 L
.04255 .32067 L
.04255 .32796 L
.04255 .33573 L
.04255 .3432 L
.04255 .35114 L
.04255 .35879 L
.04255 .36616 L
.04255 .37399 L
.04255 .38114 L
s
.14894 .19926 m
.14894 .20664 L
.14894 .21468 L
.14894 .22224 L
.14894 .22951 L
.14894 .23724 L
.14894 .24469 L
.14894 .25261 L
.14894 .26023 L
.14894 .26757 L
.14894 .27537 L
.14894 .28289 L
.14894 .29011 L
.14894 .29781 L
.14894 .30521 L
.14894 .31309 L
.14894 .32067 L
.14894 .32796 L
.14894 .33573 L
.14894 .3432 L
.14894 .35114 L
.14894 .35879 L
.14894 .36616 L
.14894 .37399 L
.14894 .38114 L
s
.25532 .19926 m
.25532 .20664 L
.25532 .21468 L
.25532 .22224 L
.25532 .22951 L
.25532 .23724 L
.25532 .24469 L
.25532 .25261 L
.25532 .26023 L
.25532 .26757 L
.25532 .27537 L
.25532 .28289 L
.25532 .29011 L
.25532 .29781 L
.25532 .30521 L
.25532 .31309 L
.25532 .32067 L
.25532 .32796 L
.25532 .33573 L
.25532 .3432 L
.25532 .35114 L
.25532 .35879 L
.25532 .36616 L
.25532 .37399 L
.25532 .38114 L
s
.3617 .19926 m
.3617 .20664 L
.3617 .21468 L
.3617 .22224 L
.3617 .22951 L
.3617 .23724 L
.3617 .24469 L
.3617 .25261 L
.3617 .26023 L
.3617 .26757 L
.3617 .27537 L
.3617 .28289 L
.3617 .29011 L
.3617 .29781 L
.3617 .30521 L
.3617 .31309 L
.3617 .32067 L
.3617 .32796 L
.3617 .33573 L
.3617 .3432 L
.3617 .35114 L
.3617 .35879 L
.3617 .36616 L
.3617 .37399 L
.3617 .38114 L
s
.46809 .19926 m
.46809 .20664 L
.46809 .21468 L
.46809 .22224 L
.46809 .22951 L
.46809 .23724 L
.46809 .24469 L
.46809 .25261 L
.46809 .26023 L
.46809 .26757 L
.46809 .27537 L
.46809 .28289 L
.46809 .29011 L
.46809 .29781 L
.46809 .30521 L
.46809 .31309 L
.46809 .32067 L
.46809 .32796 L
.46809 .33573 L
.46809 .3432 L
.46809 .35114 L
.46809 .35879 L
.46809 .36616 L
.46809 .37399 L
.46809 .38114 L
s
.57447 .19926 m
.57447 .20664 L
.57447 .21468 L
.57447 .22224 L
.57447 .22951 L
.57447 .23724 L
.57447 .24469 L
.57447 .25261 L
.57447 .26023 L
.57447 .26757 L
.57447 .27537 L
.57447 .28289 L
.57447 .29011 L
.57447 .29781 L
.57447 .30521 L
.57447 .31309 L
.57447 .32067 L
.57447 .32796 L
.57447 .33573 L
.57447 .3432 L
.57447 .35114 L
.57447 .35879 L
.57447 .36616 L
.57447 .37399 L
.57447 .38114 L
s
.68085 .19926 m
.68085 .20664 L
.68085 .21468 L
.68085 .22224 L
.68085 .22951 L
.68085 .23724 L
.68085 .24469 L
.68085 .25261 L
.68085 .26023 L
.68085 .26757 L
.68085 .27537 L
.68085 .28289 L
.68085 .29011 L
.68085 .29781 L
.68085 .30521 L
.68085 .31309 L
.68085 .32067 L
.68085 .32796 L
.68085 .33573 L
.68085 .3432 L
.68085 .35114 L
.68085 .35879 L
.68085 .36616 L
.68085 .37399 L
.68085 .38114 L
s
.78723 .19926 m
.78723 .20664 L
.78723 .21468 L
.78723 .22224 L
.78723 .22951 L
.78723 .23724 L
.78723 .24469 L
.78723 .25261 L
.78723 .26023 L
.78723 .26757 L
.78723 .27537 L
.78723 .28289 L
.78723 .29011 L
.78723 .29781 L
.78723 .30521 L
.78723 .31309 L
.78723 .32067 L
.78723 .32796 L
.78723 .33573 L
.78723 .3432 L
.78723 .35114 L
.78723 .35879 L
.78723 .36616 L
.78723 .37399 L
.78723 .38114 L
s
.89362 .19926 m
.89362 .20664 L
.89362 .21468 L
.89362 .22224 L
.89362 .22951 L
.89362 .23724 L
.89362 .24469 L
.89362 .25261 L
.89362 .26023 L
.89362 .26757 L
.89362 .27537 L
.89362 .28289 L
.89362 .29011 L
.89362 .29781 L
.89362 .30521 L
.89362 .31309 L
.89362 .32067 L
.89362 .32796 L
.89362 .33573 L
.89362 .3432 L
.89362 .35114 L
.89362 .35879 L
.89362 .36616 L
.89362 .37399 L
.89362 .38114 L
s
.04255 .19926 m
.07708 .19926 L
.11473 .19926 L
.15009 .19926 L
.1841 .19926 L
.2203 .19926 L
.25514 .19926 L
.29218 .19926 L
.32786 .19926 L
.36219 .19926 L
.39871 .19926 L
.43387 .19926 L
.46768 .19926 L
.50369 .19926 L
.53833 .19926 L
.57517 .19926 L
.61066 .19926 L
.64479 .19926 L
.68111 .19926 L
.71607 .19926 L
.75323 .19926 L
.78904 .19926 L
.82349 .19926 L
.86013 .19926 L
.89362 .19926 L
s
.04255 .22199 m
.07708 .22199 L
.11473 .22199 L
.15009 .22199 L
.1841 .22199 L
.2203 .22199 L
.25514 .22199 L
.29218 .22199 L
.32786 .22199 L
.36219 .22199 L
.39871 .22199 L
.43387 .22199 L
.46768 .22199 L
.50369 .22199 L
.53833 .22199 L
.57517 .22199 L
.61066 .22199 L
.64479 .22199 L
.68111 .22199 L
.71607 .22199 L
.75323 .22199 L
.78904 .22199 L
.82349 .22199 L
.86013 .22199 L
.89362 .22199 L
s
.04255 .24473 m
.07708 .24473 L
.11473 .24473 L
.15009 .24473 L
.1841 .24473 L
.2203 .24473 L
.25514 .24473 L
.29218 .24473 L
.32786 .24473 L
.36219 .24473 L
.39871 .24473 L
.43387 .24473 L
.46768 .24473 L
.50369 .24473 L
.53833 .24473 L
.57517 .24473 L
.61066 .24473 L
.64479 .24473 L
.68111 .24473 L
.71607 .24473 L
.75323 .24473 L
.78904 .24473 L
.82349 .24473 L
.86013 .24473 L
.89362 .24473 L
s
.04255 .26746 m
.07708 .26746 L
.11473 .26746 L
.15009 .26746 L
.1841 .26746 L
.2203 .26746 L
.25514 .26746 L
.29218 .26746 L
.32786 .26746 L
.36219 .26746 L
.39871 .26746 L
.43387 .26746 L
.46768 .26746 L
.50369 .26746 L
.53833 .26746 L
.57517 .26746 L
.61066 .26746 L
.64479 .26746 L
.68111 .26746 L
.71607 .26746 L
.75323 .26746 L
.78904 .26746 L
.82349 .26746 L
.86013 .26746 L
.89362 .26746 L
s
.04255 .2902 m
.07708 .2902 L
.11473 .2902 L
.15009 .2902 L
.1841 .2902 L
.2203 .2902 L
.25514 .2902 L
.29218 .2902 L
.32786 .2902 L
.36219 .2902 L
.39871 .2902 L
.43387 .2902 L
.46768 .2902 L
.50369 .2902 L
.53833 .2902 L
.57517 .2902 L
.61066 .2902 L
.64479 .2902 L
.68111 .2902 L
.71607 .2902 L
.75323 .2902 L
.78904 .2902 L
.82349 .2902 L
.86013 .2902 L
.89362 .2902 L
s
.04255 .31294 m
.07708 .31294 L
.11473 .31294 L
.15009 .31294 L
.1841 .31294 L
.2203 .31294 L
.25514 .31294 L
.29218 .31294 L
.32786 .31294 L
.36219 .31294 L
.39871 .31294 L
.43387 .31294 L
.46768 .31294 L
.50369 .31294 L
.53833 .31294 L
.57517 .31294 L
.61066 .31294 L
.64479 .31294 L
.68111 .31294 L
.71607 .31294 L
.75323 .31294 L
.78904 .31294 L
.82349 .31294 L
.86013 .31294 L
.89362 .31294 L
s
.04255 .33567 m
.07708 .33567 L
.11473 .33567 L
.15009 .33567 L
.1841 .33567 L
.2203 .33567 L
.25514 .33567 L
.29218 .33567 L
.32786 .33567 L
.36219 .33567 L
.39871 .33567 L
.43387 .33567 L
.46768 .33567 L
.50369 .33567 L
.53833 .33567 L
.57517 .33567 L
.61066 .33567 L
.64479 .33567 L
.68111 .33567 L
.71607 .33567 L
.75323 .33567 L
.78904 .33567 L
.82349 .33567 L
.86013 .33567 L
.89362 .33567 L
s
.04255 .35841 m
.07708 .35841 L
.11473 .35841 L
.15009 .35841 L
.1841 .35841 L
.2203 .35841 L
.25514 .35841 L
.29218 .35841 L
.32786 .35841 L
.36219 .35841 L
.39871 .35841 L
.43387 .35841 L
.46768 .35841 L
.50369 .35841 L
.53833 .35841 L
.57517 .35841 L
.61066 .35841 L
.64479 .35841 L
.68111 .35841 L
.71607 .35841 L
.75323 .35841 L
.78904 .35841 L
.82349 .35841 L
.86013 .35841 L
.89362 .35841 L
s
.04255 .38114 m
.07708 .38114 L
.11473 .38114 L
.15009 .38114 L
.1841 .38114 L
.2203 .38114 L
.25514 .38114 L
.29218 .38114 L
.32786 .38114 L
.36219 .38114 L
.39871 .38114 L
.43387 .38114 L
.46768 .38114 L
.50369 .38114 L
.53833 .38114 L
.57517 .38114 L
.61066 .38114 L
.64479 .38114 L
.68111 .38114 L
.71607 .38114 L
.75323 .38114 L
.78904 .38114 L
.82349 .38114 L
.86013 .38114 L
.89362 .38114 L
s
.04255 .38114 m
.04255 .38852 L
.04255 .39657 L
.04255 .40413 L
.04255 .4114 L
.04255 .41913 L
.04255 .42658 L
.04255 .43449 L
.04255 .44212 L
.04255 .44946 L
.04255 .45726 L
.04255 .46478 L
.04255 .472 L
.04255 .4797 L
.04255 .4871 L
.04255 .49497 L
.04255 .50256 L
.04255 .50985 L
.04255 .51762 L
.04255 .52509 L
.04255 .53303 L
.04255 .54068 L
.04255 .54804 L
.04255 .55587 L
.04255 .56303 L
s
.14894 .38114 m
.14894 .38852 L
.14894 .39657 L
.14894 .40413 L
.14894 .4114 L
.14894 .41913 L
.14894 .42658 L
.14894 .43449 L
.14894 .44212 L
.14894 .44946 L
.14894 .45726 L
.14894 .46478 L
.14894 .472 L
.14894 .4797 L
.14894 .4871 L
.14894 .49497 L
.14894 .50256 L
.14894 .50985 L
.14894 .51762 L
.14894 .52509 L
.14894 .53303 L
.14894 .54068 L
.14894 .54804 L
.14894 .55587 L
.14894 .56303 L
s
.25532 .38114 m
.25532 .38852 L
.25532 .39657 L
.25532 .40413 L
.25532 .4114 L
.25532 .41913 L
.25532 .42658 L
.25532 .43449 L
.25532 .44212 L
.25532 .44946 L
.25532 .45726 L
.25532 .46478 L
.25532 .472 L
.25532 .4797 L
.25532 .4871 L
.25532 .49497 L
.25532 .50256 L
.25532 .50985 L
.25532 .51762 L
.25532 .52509 L
.25532 .53303 L
.25532 .54068 L
.25532 .54804 L
.25532 .55587 L
.25532 .56303 L
s
.3617 .38114 m
.3617 .38852 L
.3617 .39657 L
.3617 .40413 L
.3617 .4114 L
.3617 .41913 L
.3617 .42658 L
.3617 .43449 L
.3617 .44212 L
.3617 .44946 L
.3617 .45726 L
.3617 .46478 L
.3617 .472 L
.3617 .4797 L
.3617 .4871 L
.3617 .49497 L
.3617 .50256 L
.3617 .50985 L
.3617 .51762 L
.3617 .52509 L
.3617 .53303 L
.3617 .54068 L
.3617 .54804 L
.3617 .55587 L
.3617 .56303 L
s
.46809 .38114 m
.46809 .38852 L
.46809 .39657 L
.46809 .40413 L
.46809 .4114 L
.46809 .41913 L
.46809 .42658 L
.46809 .43449 L
.46809 .44212 L
.46809 .44946 L
.46809 .45726 L
.46809 .46478 L
.46809 .472 L
.46809 .4797 L
.46809 .4871 L
.46809 .49497 L
.46809 .50256 L
.46809 .50985 L
.46809 .51762 L
.46809 .52509 L
.46809 .53303 L
.46809 .54068 L
.46809 .54804 L
.46809 .55587 L
.46809 .56303 L
s
.57447 .38114 m
.57447 .38852 L
.57447 .39657 L
.57447 .40413 L
.57447 .4114 L
.57447 .41913 L
.57447 .42658 L
.57447 .43449 L
.57447 .44212 L
.57447 .44946 L
.57447 .45726 L
.57447 .46478 L
.57447 .472 L
.57447 .4797 L
.57447 .4871 L
.57447 .49497 L
.57447 .50256 L
.57447 .50985 L
.57447 .51762 L
.57447 .52509 L
.57447 .53303 L
.57447 .54068 L
.57447 .54804 L
.57447 .55587 L
.57447 .56303 L
s
.68085 .38114 m
.68085 .38852 L
.68085 .39657 L
.68085 .40413 L
.68085 .4114 L
.68085 .41913 L
.68085 .42658 L
.68085 .43449 L
.68085 .44212 L
.68085 .44946 L
.68085 .45726 L
.68085 .46478 L
.68085 .472 L
.68085 .4797 L
.68085 .4871 L
.68085 .49497 L
.68085 .50256 L
.68085 .50985 L
.68085 .51762 L
.68085 .52509 L
.68085 .53303 L
.68085 .54068 L
.68085 .54804 L
.68085 .55587 L
.68085 .56303 L
s
.78723 .38114 m
.78723 .38852 L
.78723 .39657 L
.78723 .40413 L
.78723 .4114 L
.78723 .41913 L
.78723 .42658 L
.78723 .43449 L
.78723 .44212 L
.78723 .44946 L
.78723 .45726 L
.78723 .46478 L
.78723 .472 L
.78723 .4797 L
.78723 .4871 L
.78723 .49497 L
.78723 .50256 L
.78723 .50985 L
.78723 .51762 L
.78723 .52509 L
.78723 .53303 L
.78723 .54068 L
.78723 .54804 L
.78723 .55587 L
.78723 .56303 L
s
.89362 .38114 m
.89362 .38852 L
.89362 .39657 L
.89362 .40413 L
.89362 .4114 L
.89362 .41913 L
.89362 .42658 L
.89362 .43449 L
.89362 .44212 L
.89362 .44946 L
.89362 .45726 L
.89362 .46478 L
.89362 .472 L
.89362 .4797 L
.89362 .4871 L
.89362 .49497 L
.89362 .50256 L
.89362 .50985 L
.89362 .51762 L
.89362 .52509 L
.89362 .53303 L
.89362 .54068 L
.89362 .54804 L
.89362 .55587 L
.89362 .56303 L
s
.04255 .38114 m
.07708 .38114 L
.11473 .38114 L
.15009 .38114 L
.1841 .38114 L
.2203 .38114 L
.25514 .38114 L
.29218 .38114 L
.32786 .38114 L
.36219 .38114 L
.39871 .38114 L
.43387 .38114 L
.46768 .38114 L
.50369 .38114 L
.53833 .38114 L
.57517 .38114 L
.61066 .38114 L
.64479 .38114 L
.68111 .38114 L
.71607 .38114 L
.75323 .38114 L
.78904 .38114 L
.82349 .38114 L
.86013 .38114 L
.89362 .38114 L
s
.04255 .40388 m
.07708 .40388 L
.11473 .40388 L
.15009 .40388 L
.1841 .40388 L
.2203 .40388 L
.25514 .40388 L
.29218 .40388 L
.32786 .40388 L
.36219 .40388 L
.39871 .40388 L
.43387 .40388 L
.46768 .40388 L
.50369 .40388 L
.53833 .40388 L
.57517 .40388 L
.61066 .40388 L
.64479 .40388 L
.68111 .40388 L
.71607 .40388 L
.75323 .40388 L
.78904 .40388 L
.82349 .40388 L
.86013 .40388 L
.89362 .40388 L
s
.04255 .42662 m
.07708 .42662 L
.11473 .42662 L
.15009 .42662 L
.1841 .42662 L
.2203 .42662 L
.25514 .42662 L
.29218 .42662 L
.32786 .42662 L
.36219 .42662 L
.39871 .42662 L
.43387 .42662 L
.46768 .42662 L
.50369 .42662 L
.53833 .42662 L
.57517 .42662 L
.61066 .42662 L
.64479 .42662 L
.68111 .42662 L
.71607 .42662 L
.75323 .42662 L
.78904 .42662 L
.82349 .42662 L
.86013 .42662 L
.89362 .42662 L
s
.04255 .44935 m
.07708 .44935 L
.11473 .44935 L
.15009 .44935 L
.1841 .44935 L
.2203 .44935 L
.25514 .44935 L
.29218 .44935 L
.32786 .44935 L
.36219 .44935 L
.39871 .44935 L
.43387 .44935 L
.46768 .44935 L
.50369 .44935 L
.53833 .44935 L
.57517 .44935 L
.61066 .44935 L
.64479 .44935 L
.68111 .44935 L
.71607 .44935 L
.75323 .44935 L
.78904 .44935 L
.82349 .44935 L
.86013 .44935 L
.89362 .44935 L
s
.04255 .47209 m
.07708 .47209 L
.11473 .47209 L
.15009 .47209 L
.1841 .47209 L
.2203 .47209 L
.25514 .47209 L
.29218 .47209 L
.32786 .47209 L
.36219 .47209 L
.39871 .47209 L
.43387 .47209 L
.46768 .47209 L
.50369 .47209 L
.53833 .47209 L
.57517 .47209 L
.61066 .47209 L
.64479 .47209 L
.68111 .47209 L
.71607 .47209 L
.75323 .47209 L
.78904 .47209 L
.82349 .47209 L
.86013 .47209 L
.89362 .47209 L
s
.04255 .49482 m
.07708 .49482 L
.11473 .49482 L
.15009 .49482 L
.1841 .49482 L
.2203 .49482 L
.25514 .49482 L
.29218 .49482 L
.32786 .49482 L
.36219 .49482 L
.39871 .49482 L
.43387 .49482 L
.46768 .49482 L
.50369 .49482 L
.53833 .49482 L
.57517 .49482 L
.61066 .49482 L
.64479 .49482 L
.68111 .49482 L
.71607 .49482 L
.75323 .49482 L
.78904 .49482 L
.82349 .49482 L
.86013 .49482 L
.89362 .49482 L
s
.04255 .51756 m
.07708 .51756 L
.11473 .51756 L
.15009 .51756 L
.1841 .51756 L
.2203 .51756 L
.25514 .51756 L
.29218 .51756 L
.32786 .51756 L
.36219 .51756 L
.39871 .51756 L
.43387 .51756 L
.46768 .51756 L
.50369 .51756 L
.53833 .51756 L
.57517 .51756 L
.61066 .51756 L
.64479 .51756 L
.68111 .51756 L
.71607 .51756 L
.75323 .51756 L
.78904 .51756 L
.82349 .51756 L
.86013 .51756 L
.89362 .51756 L
s
.04255 .5403 m
.07708 .5403 L
.11473 .5403 L
.15009 .5403 L
.1841 .5403 L
.2203 .5403 L
.25514 .5403 L
.29218 .5403 L
.32786 .5403 L
.36219 .5403 L
.39871 .5403 L
.43387 .5403 L
.46768 .5403 L
.50369 .5403 L
.53833 .5403 L
.57517 .5403 L
.61066 .5403 L
.64479 .5403 L
.68111 .5403 L
.71607 .5403 L
.75323 .5403 L
.78904 .5403 L
.82349 .5403 L
.86013 .5403 L
.89362 .5403 L
s
.04255 .56303 m
.07708 .56303 L
.11473 .56303 L
.15009 .56303 L
.1841 .56303 L
.2203 .56303 L
.25514 .56303 L
.29218 .56303 L
.32786 .56303 L
.36219 .56303 L
.39871 .56303 L
.43387 .56303 L
.46768 .56303 L
.50369 .56303 L
.53833 .56303 L
.57517 .56303 L
.61066 .56303 L
.64479 .56303 L
.68111 .56303 L
.71607 .56303 L
.75323 .56303 L
.78904 .56303 L
.82349 .56303 L
.86013 .56303 L
.89362 .56303 L
s
.04255 .01737 m
.04255 .02475 L
.04255 .03279 L
.04255 .04035 L
.04255 .04762 L
.04255 .05536 L
.04255 .0628 L
.04255 .07072 L
.04255 .07834 L
.04255 .08568 L
.04255 .09349 L
.04255 .101 L
.04255 .10823 L
.04255 .11592 L
.04255 .12333 L
.04255 .1312 L
.04255 .13878 L
.04255 .14608 L
.04255 .15384 L
.04255 .16131 L
.04255 .16925 L
.04255 .17691 L
.04255 .18427 L
.04255 .1921 L
.04255 .19926 L
s
.14894 .01737 m
.14894 .02475 L
.14894 .03279 L
.14894 .04035 L
.14894 .04762 L
.14894 .05536 L
.14894 .0628 L
.14894 .07072 L
.14894 .07834 L
.14894 .08568 L
.14894 .09349 L
.14894 .101 L
.14894 .10823 L
.14894 .11592 L
.14894 .12333 L
.14894 .1312 L
.14894 .13878 L
.14894 .14608 L
.14894 .15384 L
.14894 .16131 L
.14894 .16925 L
.14894 .17691 L
.14894 .18427 L
.14894 .1921 L
.14894 .19926 L
s
.25532 .01737 m
.25532 .02475 L
.25532 .03279 L
.25532 .04035 L
.25532 .04762 L
.25532 .05536 L
.25532 .0628 L
.25532 .07072 L
.25532 .07834 L
.25532 .08568 L
.25532 .09349 L
.25532 .101 L
.25532 .10823 L
.25532 .11592 L
.25532 .12333 L
.25532 .1312 L
.25532 .13878 L
.25532 .14608 L
.25532 .15384 L
.25532 .16131 L
.25532 .16925 L
.25532 .17691 L
.25532 .18427 L
.25532 .1921 L
.25532 .19926 L
s
.3617 .01737 m
.3617 .02475 L
.3617 .03279 L
.3617 .04035 L
.3617 .04762 L
.3617 .05536 L
.3617 .0628 L
.3617 .07072 L
.3617 .07834 L
.3617 .08568 L
.3617 .09349 L
.3617 .101 L
.3617 .10823 L
.3617 .11592 L
.3617 .12333 L
.3617 .1312 L
.3617 .13878 L
.3617 .14608 L
.3617 .15384 L
.3617 .16131 L
.3617 .16925 L
.3617 .17691 L
.3617 .18427 L
.3617 .1921 L
.3617 .19926 L
s
.46809 .01737 m
.46809 .02475 L
.46809 .03279 L
.46809 .04035 L
.46809 .04762 L
.46809 .05536 L
.46809 .0628 L
.46809 .07072 L
.46809 .07834 L
.46809 .08568 L
.46809 .09349 L
.46809 .101 L
.46809 .10823 L
.46809 .11592 L
.46809 .12333 L
.46809 .1312 L
.46809 .13878 L
.46809 .14608 L
.46809 .15384 L
.46809 .16131 L
.46809 .16925 L
.46809 .17691 L
.46809 .18427 L
.46809 .1921 L
.46809 .19926 L
s
.57447 .01737 m
.57447 .02475 L
.57447 .03279 L
.57447 .04035 L
.57447 .04762 L
.57447 .05536 L
.57447 .0628 L
.57447 .07072 L
.57447 .07834 L
.57447 .08568 L
.57447 .09349 L
.57447 .101 L
.57447 .10823 L
.57447 .11592 L
.57447 .12333 L
.57447 .1312 L
.57447 .13878 L
.57447 .14608 L
.57447 .15384 L
.57447 .16131 L
.57447 .16925 L
.57447 .17691 L
.57447 .18427 L
.57447 .1921 L
.57447 .19926 L
s
.68085 .01737 m
.68085 .02475 L
.68085 .03279 L
.68085 .04035 L
.68085 .04762 L
.68085 .05536 L
.68085 .0628 L
.68085 .07072 L
.68085 .07834 L
.68085 .08568 L
.68085 .09349 L
.68085 .101 L
.68085 .10823 L
.68085 .11592 L
.68085 .12333 L
.68085 .1312 L
.68085 .13878 L
.68085 .14608 L
.68085 .15384 L
.68085 .16131 L
.68085 .16925 L
.68085 .17691 L
.68085 .18427 L
.68085 .1921 L
.68085 .19926 L
s
.78723 .01737 m
.78723 .02475 L
.78723 .03279 L
.78723 .04035 L
.78723 .04762 L
.78723 .05536 L
.78723 .0628 L
.78723 .07072 L
.78723 .07834 L
.78723 .08568 L
.78723 .09349 L
.78723 .101 L
.78723 .10823 L
.78723 .11592 L
.78723 .12333 L
.78723 .1312 L
.78723 .13878 L
.78723 .14608 L
.78723 .15384 L
.78723 .16131 L
.78723 .16925 L
.78723 .17691 L
.78723 .18427 L
.78723 .1921 L
.78723 .19926 L
s
.89362 .01737 m
.89362 .02475 L
.89362 .03279 L
.89362 .04035 L
.89362 .04762 L
.89362 .05536 L
.89362 .0628 L
.89362 .07072 L
.89362 .07834 L
.89362 .08568 L
.89362 .09349 L
.89362 .101 L
.89362 .10823 L
.89362 .11592 L
.89362 .12333 L
.89362 .1312 L
.89362 .13878 L
.89362 .14608 L
.89362 .15384 L
.89362 .16131 L
.89362 .16925 L
.89362 .17691 L
.89362 .18427 L
.89362 .1921 L
.89362 .19926 L
s
.04255 .01737 m
.07708 .01737 L
.11473 .01737 L
.15009 .01737 L
.1841 .01737 L
.2203 .01737 L
.25514 .01737 L
.29218 .01737 L
.32786 .01737 L
.36219 .01737 L
.39871 .01737 L
.43387 .01737 L
.46768 .01737 L
.50369 .01737 L
.53833 .01737 L
.57517 .01737 L
.61066 .01737 L
.64479 .01737 L
.68111 .01737 L
.71607 .01737 L
.75323 .01737 L
.78904 .01737 L
.82349 .01737 L
.86013 .01737 L
.89362 .01737 L
s
.04255 .0401 m
.07708 .0401 L
.11473 .0401 L
.15009 .0401 L
.1841 .0401 L
.2203 .0401 L
.25514 .0401 L
.29218 .0401 L
.32786 .0401 L
.36219 .0401 L
.39871 .0401 L
.43387 .0401 L
.46768 .0401 L
.50369 .0401 L
.53833 .0401 L
.57517 .0401 L
.61066 .0401 L
.64479 .0401 L
.68111 .0401 L
.71607 .0401 L
.75323 .0401 L
.78904 .0401 L
.82349 .0401 L
.86013 .0401 L
.89362 .0401 L
s
.04255 .06284 m
.07708 .06284 L
.11473 .06284 L
.15009 .06284 L
.1841 .06284 L
.2203 .06284 L
.25514 .06284 L
.29218 .06284 L
.32786 .06284 L
.36219 .06284 L
.39871 .06284 L
.43387 .06284 L
.46768 .06284 L
.50369 .06284 L
.53833 .06284 L
.57517 .06284 L
.61066 .06284 L
.64479 .06284 L
.68111 .06284 L
.71607 .06284 L
.75323 .06284 L
.78904 .06284 L
.82349 .06284 L
.86013 .06284 L
.89362 .06284 L
s
.04255 .08558 m
.07708 .08558 L
.11473 .08558 L
.15009 .08558 L
.1841 .08558 L
.2203 .08558 L
.25514 .08558 L
.29218 .08558 L
.32786 .08558 L
.36219 .08558 L
.39871 .08558 L
.43387 .08558 L
.46768 .08558 L
.50369 .08558 L
.53833 .08558 L
.57517 .08558 L
.61066 .08558 L
.64479 .08558 L
.68111 .08558 L
.71607 .08558 L
.75323 .08558 L
.78904 .08558 L
.82349 .08558 L
.86013 .08558 L
.89362 .08558 L
s
.04255 .10831 m
.07708 .10831 L
.11473 .10831 L
.15009 .10831 L
.1841 .10831 L
.2203 .10831 L
.25514 .10831 L
.29218 .10831 L
.32786 .10831 L
.36219 .10831 L
.39871 .10831 L
.43387 .10831 L
.46768 .10831 L
.50369 .10831 L
.53833 .10831 L
.57517 .10831 L
.61066 .10831 L
.64479 .10831 L
.68111 .10831 L
.71607 .10831 L
.75323 .10831 L
.78904 .10831 L
.82349 .10831 L
.86013 .10831 L
.89362 .10831 L
s
.04255 .13105 m
.07708 .13105 L
.11473 .13105 L
.15009 .13105 L
.1841 .13105 L
.2203 .13105 L
.25514 .13105 L
.29218 .13105 L
.32786 .13105 L
.36219 .13105 L
.39871 .13105 L
.43387 .13105 L
.46768 .13105 L
.50369 .13105 L
.53833 .13105 L
.57517 .13105 L
.61066 .13105 L
.64479 .13105 L
.68111 .13105 L
.71607 .13105 L
.75323 .13105 L
.78904 .13105 L
.82349 .13105 L
.86013 .13105 L
.89362 .13105 L
s
.04255 .15378 m
.07708 .15378 L
.11473 .15378 L
.15009 .15378 L
.1841 .15378 L
.2203 .15378 L
.25514 .15378 L
.29218 .15378 L
.32786 .15378 L
.36219 .15378 L
.39871 .15378 L
.43387 .15378 L
.46768 .15378 L
.50369 .15378 L
.53833 .15378 L
.57517 .15378 L
.61066 .15378 L
.64479 .15378 L
.68111 .15378 L
.71607 .15378 L
.75323 .15378 L
.78904 .15378 L
.82349 .15378 L
.86013 .15378 L
.89362 .15378 L
s
.04255 .17652 m
.07708 .17652 L
.11473 .17652 L
.15009 .17652 L
.1841 .17652 L
.2203 .17652 L
.25514 .17652 L
.29218 .17652 L
.32786 .17652 L
.36219 .17652 L
.39871 .17652 L
.43387 .17652 L
.46768 .17652 L
.50369 .17652 L
.53833 .17652 L
.57517 .17652 L
.61066 .17652 L
.64479 .17652 L
.68111 .17652 L
.71607 .17652 L
.75323 .17652 L
.78904 .17652 L
.82349 .17652 L
.86013 .17652 L
.89362 .17652 L
s
.04255 .19926 m
.07708 .19926 L
.11473 .19926 L
.15009 .19926 L
.1841 .19926 L
.2203 .19926 L
.25514 .19926 L
.29218 .19926 L
.32786 .19926 L
.36219 .19926 L
.39871 .19926 L
.43387 .19926 L
.46768 .19926 L
.50369 .19926 L
.53833 .19926 L
.57517 .19926 L
.61066 .19926 L
.64479 .19926 L
.68111 .19926 L
.71607 .19926 L
.75323 .19926 L
.78904 .19926 L
.82349 .19926 L
.86013 .19926 L
.89362 .19926 L
s
.89362 .2902 m
1 .2902 L
s
% Start of user PostScript
2. 0 2.5 0 MAarrowhead1
% End of user PostScript
.46809 .59777 m
.46809 .61224 L
s
% Start of user PostScript
0 10.6248 0 11.1248 MAarrowhead1
% End of user PostScript
gsave
.93617 .38114 -66.875 -11.0313 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22.0625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 14.938 moveto
%%IncludeResource: font Symbol
%%IncludeFont: Symbol
/Symbol findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
65.500 14.938 moveto
%%IncludeResource: font Symbol
%%IncludeFont: Symbol
/Symbol findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
70.750 14.938 moveto
%%IncludeResource: font Symbol
%%IncludeFont: Symbol
/Symbol findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.93617 .47209 -68.125 -11.0313 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22.0625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 14.938 moveto
%%IncludeResource: font Symbol
%%IncludeFont: Symbol
/Symbol findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.938 moveto
%%IncludeResource: font Symbol
%%IncludeFont: Symbol
/Symbol findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
68.000 14.938 moveto
(p) show
73.250 14.938 moveto
%%IncludeResource: font Symbol
%%IncludeFont: Symbol
/Symbol findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.93617 .56303 -68.125 -11.0313 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22.0625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 14.938 moveto
%%IncludeResource: font Symbol
%%IncludeFont: Symbol
/Symbol findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.938 moveto
%%IncludeResource: font Symbol
%%IncludeFont: Symbol
/Symbol findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
68.000 14.938 moveto
(p) show
73.250 14.938 moveto
%%IncludeResource: font Symbol
%%IncludeFont: Symbol
/Symbol findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.93617 .19926 -70.0625 -11.0313 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22.0625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 14.938 moveto
%%IncludeResource: font Symbol
%%IncludeFont: Symbol
/Symbol findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
65.500 14.938 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.875 14.938 moveto
%%IncludeResource: font Symbol
%%IncludeFont: Symbol
/Symbol findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
77.125 14.938 moveto
%%IncludeResource: font Symbol
%%IncludeFont: Symbol
/Symbol findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.93617 .10831 -71.3125 -11.0313 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22.0625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 14.938 moveto
%%IncludeResource: font Symbol
%%IncludeFont: Symbol
/Symbol findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.938 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.375 14.938 moveto
%%IncludeResource: font Symbol
%%IncludeFont: Symbol
/Symbol findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
74.375 14.938 moveto
(p) show
79.625 14.938 moveto
%%IncludeResource: font Symbol
%%IncludeFont: Symbol
/Symbol findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.93617 .01737 -71.3125 -11.0313 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22.0625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 14.938 moveto
%%IncludeResource: font Symbol
%%IncludeFont: Symbol
/Symbol findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.938 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.375 14.938 moveto
%%IncludeResource: font Symbol
%%IncludeFont: Symbol
/Symbol findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
74.375 14.938 moveto
(p) show
79.625 14.938 moveto
%%IncludeResource: font Symbol
%%IncludeFont: Symbol
/Symbol findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.98936 .31915 -66 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(u) show
69.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .60066 -69 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(v) show
75.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\
eJztnd9u0zAYxd2kXbsNNv5okxBD5GnG1R6imiZtFwg0dolASMANcI14DB6O
6yw+TVLPtT0mJOaTHEtznM929jt17Npf8+dkeXV+9np5dXG6rF5dLt+eX5y+
q47fXDamcmLMpDLG/K6MTddNso2+mrquTWmw06Ts30/E5o5Zn2wMUxnILezO
brz251id9mhdSBzivY2n1jLF/vxGbneQbvtglcLmjzXs2FSxrl5Gi3v/93nA
dpRRuZ2AnJnzWTJqmiOe3rA14QmvokXffYhFvBgGOsaDl8PQkgmS0IUudA05
Qhf6kNDVb4U+KnSsvLDwKgK57jKfVp1ngwMi4Ytg1FkkW9F34Niw4S/ZjR02
UTET9fKcDM5zgv75lFcE8TeCpkNZlBO60MeIriFH6ELnQ1e/Ffqo0EPMWLYQ
r5DBHPKNEGua2di5jmSda8NDRxiGsP1bCrVZxhpAYTZsRwHb/y7XqYdrYyvS
hCwiAqOE0IX+d+ixiQmjFqELXejZo2vIEbrQ+dDVb4UudA50/DgMV8WCXARW
5yvfxOounspGE3JVuF2nJBcB05xXBHH/Hgg6phTPbMq5PItS1SHijSuNiLv4
8BQdmDrsvyfWNJCBgBhdyyKhC50PXf1W6KNCXzjMnQ2zoUfkmkJTOmJN2147
2fDYkRO8IcUv5B0z98tQ4EXYijTcfcON4HItod83uq4QFbrQha4hZ2zNkAmS
0FnQ1W+FPip0/PyffgzHHrk6zxZ9DAexzllMp2OzYd+RiKEu7LhKV8xE8538
H56cGXl7T9vYtTXhgFcRzmD0ykNeEcTfA5oEZVFO6EIfI7qGHKELnQ9d/Vbo
o0LHygum6NtJiNeVoceWDsxVMm9j19ZJ67YbbhJUir7TpS0efZmNV9x1PoTq
fGhPNNdm+sV9qMbH/qRMFLr9bTx4dw7okgaQbfefyI9V1peeIZG1CEv77pdb
f95Fn/rmFILh179oTWSZyTX01NGj\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2, -10, 0, 0}}],
 StyleBox["  \n\t\t\t\tFigure 5.5",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  The Riemann surface for the mapping  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{"log", 
    RowBox[{"(", "z", ")"}]}]}]]],
 "."
}], "Text"],

Cell["\<\
The \"legacy version\" being used to implement the commands \"CartesianMap \
and PolarMap.\"  The following Initialization Cell will load these \
subroutines. \
\>", "Text",
 CellChangeTimes->{{3.399722161203125*^9, 3.399722165296875*^9}, {
  3.39972222759375*^9, 3.3997223229375*^9}, {3.399722389046875*^9, 
  3.399722641234375*^9}, {3.399722683734375*^9, 3.3997227230625*^9}, {
  3.3997227559375*^9, 3.399722850765625*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Initialization Cell",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text",
 CellChangeTimes->{{3.399722161203125*^9, 3.399722165296875*^9}, {
  3.39972222759375*^9, 3.3997223229375*^9}, {3.399722389046875*^9, 
  3.399722641234375*^9}, {3.399722683734375*^9, 3.3997227230625*^9}, {
  3.3997227559375*^9, 3.399722850765625*^9}, {3.399742279828125*^9, 
  3.39974228209375*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}]], "Input",\

 InitializationCell->True]
}, Closed]],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Complex Logarithms",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/LogarithmFunBib.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Riemann Surfaces",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/RiemannSurfaceBib.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/complex.html"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2008 John H. Mathews, Russell W. \
Howell",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/"], None}],
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[0, 1, 0]]], "Text",
 CellChangeTimes->{{3.399280633703125*^9, 3.399280633828125*^9}}]
},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{985, 603},
WindowMargins->{{10, Automatic}, {Automatic, 5}},
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "CHAPTER 1"->{
  Cell[568, 21, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"CHAPTER 1", 231300, 12087}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"],
Cell[905, 32, 114, 2, 29, "Text"],
Cell[1022, 36, 517, 15, 47, "Text"],
Cell[1542, 53, 4905, 170, 299, "Text",
 Evaluatable->False],
Cell[6450, 225, 958, 33, 47, "Text",
 Evaluatable->False],
Cell[7411, 260, 1233, 44, 65, "Text",
 Evaluatable->False],
Cell[8647, 306, 1561, 51, 83, "Text",
 Evaluatable->False],
Cell[10211, 359, 15671, 663, 293, "Text"],
Cell[25885, 1024, 617, 18, 47, "Text",
 Evaluatable->False],
Cell[26505, 1044, 207, 7, 29, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[26737, 1055, 125, 2, 29, "Text"],
Cell[26865, 1059, 290, 10, 29, "Text"],
Cell[27158, 1071, 2695, 77, 272, "Input"],
Cell[29856, 1150, 104, 3, 29, "Text"],
Cell[29963, 1155, 4700, 132, 372, "Input"]
}, Closed]],
Cell[34678, 1290, 9267, 291, 331, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[43970, 1585, 109, 2, 29, "Text"],
Cell[44082, 1589, 149, 6, 29, "Text"],
Cell[44234, 1597, 654, 18, 132, "Input"],
Cell[44891, 1617, 415, 15, 29, "Text",
 Evaluatable->False],
Cell[45309, 1634, 1621, 43, 232, "Input"]
}, Closed]],
Cell[46945, 1680, 425, 16, 26, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[47395, 1700, 139, 5, 29, "Text"],
Cell[47537, 1707, 3671, 108, 334, "Input"]
}, Closed]],
Cell[51223, 1818, 1858, 69, 152, "Text"],
Cell[53084, 1889, 1173, 43, 101, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[54282, 1936, 109, 2, 29, "Text"],
Cell[54394, 1940, 220, 9, 29, "Text"],
Cell[54617, 1951, 2371, 65, 292, "Input"],
Cell[56991, 2018, 206, 9, 29, "Text"],
Cell[57200, 2029, 2357, 65, 292, "Input"]
}, Closed]],
Cell[59572, 2097, 1555, 55, 134, "Text"],
Cell[61130, 2154, 2086, 64, 148, "Text"],
Cell[63219, 2220, 2923, 99, 173, "Text"],
Cell[66145, 2321, 2050, 60, 216, "Text"],
Cell[68198, 2383, 4470, 156, 312, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[72693, 2543, 109, 2, 29, "Text"],
Cell[72805, 2547, 403, 16, 31, "Text"],
Cell[73211, 2565, 3858, 110, 438, "Input"],
Cell[77072, 2677, 805, 29, 47, "Text"]
}, Closed]],
Cell[77892, 2709, 487, 17, 26, "Text"],
Cell[78382, 2728, 839, 33, 47, "Text"],
Cell[CellGroupData[{
Cell[79246, 2765, 109, 2, 29, "Text"],
Cell[79358, 2769, 2830, 102, 65, "Text"]
}, Closed]],
Cell[82203, 2874, 648, 17, 62, "Text"],
Cell[82854, 2893, 1528, 64, 160, "Text"],
Cell[CellGroupData[{
Cell[84407, 2961, 109, 2, 29, "Text"],
Cell[84519, 2965, 2489, 84, 216, "Text"]
}, Closed]],
Cell[87023, 3052, 595, 25, 26, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[87643, 3081, 125, 2, 29, "Text"],
Cell[87771, 3085, 511, 18, 29, "Text"],
Cell[88285, 3105, 6139, 178, 552, "Input"],
Cell[94427, 3285, 2475, 77, 253, "Text",
 Evaluatable->False]
}, Closed]],
Cell[96917, 3365, 4920, 171, 200, "Text"],
Cell[101840, 3538, 18468, 777, 315, "Text"],
Cell[120311, 4317, 2358, 85, 248, "Text"],
Cell[122672, 4404, 7353, 262, 281, "Text"],
Cell[130028, 4668, 98489, 7334, 213, "Text"],
Cell[228520, 12004, 435, 8, 29, "Text"],
Cell[CellGroupData[{
Cell[228980, 12016, 407, 7, 29, "Text"],
Cell[229390, 12025, 132, 4, 31, "Input",
 InitializationCell->True]
}, Closed]],
Cell[229537, 12032, 281, 7, 26, "Text"],
Cell[229821, 12041, 278, 7, 29, "Text"],
Cell[230102, 12050, 278, 7, 29, "Text"],
Cell[230383, 12059, 249, 5, 29, "Text"],
Cell[230635, 12066, 320, 7, 29, "Text"]
}
]
*)

(* End of internal cache information *)
