(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    294109,      11652]
NotebookOptionsPosition[    285939,      11399]
NotebookOutlinePosition[    286464,      11423]
CellTagsIndexPosition[    286389,      11418]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["5.4  Trigonometric and Hyperbolic Functions",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
 "\tBased on the success we had in using power series to define the complex \
exponential, we have reason to believe this approach will be fruitful for \
other elementary functions as well. The power series expansions for the \
real-valued sine and cosine functions are \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"sin", 
    RowBox[{"(", "x", ")"}]}], " ", "=", " ", 
   StyleBox[
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", "0"}], "\[Infinity]"], 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], "n"], " ", 
       SuperscriptBox["x", 
        RowBox[{
         RowBox[{"2", "n"}], "+", "1"}]]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", "n"}], "+", "1"}], ")"}], "!"}]]}],
    FontSize->12]}]]],
 ",    and  \n\t\t   \n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"cos", 
    RowBox[{"(", "x", ")"}]}], "=", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", "0"}], "\[Infinity]"], 
    FractionBox[
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], "n"], " ", 
      SuperscriptBox["x", 
       RowBox[{"2", " ", "n"}]]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2", " ", "n"}], ")"}], "!"}]]}]}]]],
 "\n\nThus, it is natural to make the following definitions."
}], "Text"],

Cell[TextData[{
 " ",
 StyleBox["Definition 5.5.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "   The series for  ",
 StyleBox[ButtonBox["Sine",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/Sine.html"], None}],
  FontVariations->{"Underline"->True}],
 " and ",
 StyleBox[ButtonBox["Cosine",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/Cosine.html"], None}],
  FontVariations->{"Underline"->True}],
 " are ",
 StyleBox["\n",
  FontColor->RGBColor[1, 0, 1]],
 "\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"sin", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   StyleBox[
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", "0"}], "\[Infinity]"], 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], "n"], " ", 
       SuperscriptBox["z", 
        RowBox[{
         RowBox[{"2", "n"}], "+", "1"}]]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", "n"}], " ", "+", " ", "1"}], ")"}], "!"}]]}],
    FontSize->12]}]]],
 ",    and  \n\t\t   \n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"cos", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", "0"}], "\[Infinity]"], 
    FractionBox[
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], "n"], " ", 
      SuperscriptBox["z", 
       RowBox[{"2", " ", "n"}]]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2", " ", "n"}], ")"}], "!"}]]}]}]]],
 "\n\n\tClearly, these definitions agree with their real counterparts when z \
is real.  Additionally, it is easy to show that ",
 Cell[BoxData[
  RowBox[{"cos", 
   RowBox[{"(", "z", ")"}], " ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], " ", "sin", 
   RowBox[{"(", "z", ")"}]}]]],
 " are entire functions.  (We leave the proof as an exercise.)"
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Exploration (i).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Investigate the series ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"sin", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   StyleBox[
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", "0"}], "\[Infinity]"], 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], "n"], " ", 
       SuperscriptBox["z", 
        RowBox[{
         RowBox[{"2", "n"}], "+", "1"}]]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", "n"}], "+", "1"}], ")"}], "!"}]]}],
    FontSize->12]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration (i).",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "Consider  sin(z) and use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to find a Taylor polynomial expanded about z = 0, the remainder is \
expressed in the Big \"O\" notation."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", 
     RowBox[{"b", ",", "z"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"k", ",", "n", ",", "sin", ",", "S", ",", "S13"}], "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"sin", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"Series", "[", 
      RowBox[{
       RowBox[{"Sin", "[", "z", "]"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"z", ",", "0", ",", "11"}], "}"}]}], "]"}]}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Sin[z] = \>\"", ",", 
      RowBox[{"sin", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Sin[z] = \>\"", ",", 
      RowBox[{"Normal", "[", 
       RowBox[{"sin", "[", "z", "]"}], "]"}], ",", "\"\< + ...\>\""}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39928633840625*^9},
 AspectRatioFixed->True],

Cell["\<\
Use the general term in the series for  sin(z)  and sum the infinite series.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["b", "n_"], " ", "=", " ", 
     FractionBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], "n"], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", "n"}], "+", "1"}], ")"}], "!"}]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"S13", " ", "=", " ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "0"}], "6"], 
      FractionBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"-", "1"}], ")"}], "n"], " ", 
        SuperscriptBox["z", 
         RowBox[{
          RowBox[{"2", "n"}], "+", "1"}]]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", "n"}], "+", "1"}], ")"}], "!"}]]}]}], ";"}], " ", "\n",
    
   RowBox[{
    RowBox[{"S", " ", "=", " ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "0"}], "\[Infinity]"], 
      FractionBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"-", "1"}], ")"}], "n"], " ", 
        SuperscriptBox["z", 
         RowBox[{
          RowBox[{"2", "n"}], "+", "1"}]]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", "n"}], "+", "1"}], ")"}], "!"}]]}]}], ";"}], " ", "\n",
    
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<    \!\(\*SubscriptBox[\(b\), \(n\)]\) = \>\"", ",", 
      SubscriptBox["b", "n"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(S\), \(13\)]\)[z] = \>\"", ",", 
      "\"\< \!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 0\), \
\(6\)]\)\!\(\*FractionBox[\(\*SuperscriptBox[\((\(-1\))\), \(n\)]\\\ \
\*SuperscriptBox[\(z\), \(2  n + 1\)]\), \(\((2  n + 1)\)!\)]\)\>\""}], "]"}],
     ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(S\), \(13\)]\)[z] = \>\"", ",", "S13"}], "]"}],
     ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(S\), \(\[Infinity]\)]\)[z] = \>\"", ",", "S13",
       ",", "\"\< + ...\>\""}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< \!\(\*SubscriptBox[\(S\), \(\[Infinity]\)]\)[z] = \>\"", ",", 
      "\"\< \!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 0\), \
\(\[Infinity]\)]\)\!\(\*FractionBox[\(\*SuperscriptBox[\((\(-1\))\), \(n\)]\\\
\ \*SuperscriptBox[\(z\), \(2  n + 1\)]\), \(\((2  n + 1)\)!\)]\)\>\""}], 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< \!\(\*SubscriptBox[\(S\), \(\[Infinity]\)]\)[z] = \>\"", ",", 
      "S"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< \!\(\*SubscriptBox[\(S\), \(\[Infinity]\)]\)[z] = \>\"", ",", 
      RowBox[{"PowerExpand", "[", "S", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39928634309375*^9, 3.399286344765625*^9}, {
  3.3998262755153775`*^9, 3.3998262835778775`*^9}, {3.3998263186403775`*^9, 
  3.399826346468502*^9}, {3.3998264433278775`*^9, 3.399826455843502*^9}}],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to plot some partial sums for sin(z)."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "m", ",", "n", ",", "s", ",", "z"}], "]"}], ";"}], " ",
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", 
     RowBox[{"Sin", "[", "z", "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"For", " ", "[", 
     RowBox[{
      RowBox[{"m", "=", "1"}], ",", 
      RowBox[{"m", "\[LessEqual]", "3"}], ",", 
      RowBox[{"m", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"s", "[", "z_", "]"}], "=", 
        RowBox[{
         UnderoverscriptBox["\[Sum]", 
          RowBox[{"n", "=", "0"}], "m"], 
         FractionBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"-", "1"}], ")"}], "n"], " ", 
           SuperscriptBox["z", 
            RowBox[{
             RowBox[{"2", "n"}], "+", "1"}]]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", "n"}], "+", "1"}], ")"}], "!"}]]}]}], ";", " ", 
       "\[IndentingNewLine]", 
       RowBox[{"g0", "=", 
        RowBox[{"CartesianMap", "[", 
         RowBox[{"s", ",", 
          RowBox[{"{", 
           RowBox[{
            FractionBox[
             RowBox[{"-", "\[Pi]"}], "2"], ",", 
            FractionBox["\[Pi]", "2"], ",", 
            FractionBox["\[Pi]", "16"]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "1", ",", "0.25"}], "}"}], ",", 
          RowBox[{"PlotRange", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "1.7"}], ",", "1.7"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "1.2"}], ",", "1.2"}], "}"}]}], "}"}]}], ",", 
          RowBox[{"AspectRatio", "\[Rule]", 
           FractionBox["1.2", "1.7"]}], ",", 
          RowBox[{"Ticks", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Range", "[", 
              RowBox[{
               RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}], ",", 
             RowBox[{"Range", "[", 
              RowBox[{
               RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}], 
          ",", 
          RowBox[{"AxesLabel", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
          RowBox[{"PlotStyle", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Print", "[", "g0", "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{"\"\<w = s[z,\>\"", ",", 
         RowBox[{
          RowBox[{"2", "m"}], "+", "1"}], ",", "\"\<] = \>\"", ",", 
         RowBox[{"s", "[", "z", "]"}]}], "]"}], ";"}]}], " ", "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g1", "=", 
     RowBox[{"CartesianMap", "[", 
      RowBox[{"f", ",", 
       RowBox[{"{", 
        RowBox[{
         FractionBox[
          RowBox[{"-", "\[Pi]"}], "2"], ",", 
         FractionBox["\[Pi]", "2"], ",", 
         FractionBox["\[Pi]", "16"]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "1", ",", "0.25"}], "}"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.7"}], ",", "1.7"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.2"}], ",", "1.2"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", 
        FractionBox["1.2", "1.7"]}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", "g1", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  The mapping  w = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39928635290625*^9, 3.399286404453125*^9}, {
  3.3998261604216275`*^9, 3.399826160593502*^9}}]
}, Closed]],

Cell[TextData[{
 StyleBox["Exploration (ii).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Investigate the series ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"cos", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", "0"}], "\[Infinity]"], 
    FractionBox[
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], "n"], " ", 
      SuperscriptBox["z", 
       RowBox[{"2", " ", "n"}]]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2", " ", "n"}], ")"}], "!"}]]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration (ii).",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "Consider  cos(z) and use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to find a Taylor polynomial expanded about z = 0, the remainder is \
expressed in the Big \"O\" notation."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", 
     RowBox[{"a", ",", "z"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"cos", ",", "k", ",", "n", ",", "S", ",", "S12"}], "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"cos", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"Series", "[", 
      RowBox[{
       RowBox[{"Cos", "[", "z", "]"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"z", ",", "0", ",", "12"}], "}"}]}], "]"}]}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Cos[z] = \>\"", ",", 
      RowBox[{"cos", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Cos[z] = \>\"", ",", 
      RowBox[{"Normal", "[", 
       RowBox[{"cos", "[", "z", "]"}], "]"}], ",", "\"\< + ...\>\""}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399286414875*^9},
 AspectRatioFixed->True],

Cell["\<\
Use the general term in the series for  cos(z)  and sum the infinite series.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["a", "n_"], " ", "=", " ", 
     FractionBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], "n"], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"2", "n"}], ")"}], "!"}]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"S12", "=", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "0"}], "6"], " ", 
      FractionBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"-", "1"}], ")"}], "n"], " ", 
        SuperscriptBox["z", 
         RowBox[{"2", " ", "n"}]]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"2", " ", "n"}], ")"}], "!"}]]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"S", "=", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "0"}], "\[Infinity]"], 
      FractionBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"-", "1"}], ")"}], "n"], " ", 
        SuperscriptBox["z", 
         RowBox[{"2", " ", "n"}]]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"2", " ", "n"}], ")"}], "!"}]]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<    \!\(\*SubscriptBox[\(a\), \(n\)]\) = \>\"", ",", 
      SubscriptBox["a", "n"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(S\), \(12\)]\)[z] = \>\"", ",", 
      "\"\<\!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 0\), \(6\)]\) \
\!\(\*FractionBox[\(\*SuperscriptBox[\((\(-1\))\), \(n\)]\\\ \
\*SuperscriptBox[\(z\), \(2\\\ n\)]\), \(\((2\\\ n)\)!\)]\)\>\""}], "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(S\), \(12\)]\)[z] = \>\"", ",", "S12"}], "]"}],
     ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(S\), \(\[Infinity]\)]\)[z] = \>\"", ",", "S12",
       ",", "\"\< + ...\>\""}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< \!\(\*SubscriptBox[\(S\), \(\[Infinity]\)]\)[z] = \>\"", ",", 
      "\"\<\!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 0\), \(\[Infinity]\)]\)\
\!\(\*FractionBox[\(\*SuperscriptBox[\((\(-1\))\), \(n\)]\\\ \
\*SuperscriptBox[\(z\), \(2\\\ n\)]\), \(\((2\\\ n)\)!\)]\)\>\""}], "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< \!\(\*SubscriptBox[\(S\), \(\[Infinity]\)]\)[z] = \>\"", ",", 
      "S"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< \!\(\*SubscriptBox[\(S\), \(\[Infinity]\)]\)[z] = \>\"", ",", 
      RowBox[{"PowerExpand", "[", "S", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39928641884375*^9, 3.3992864220625*^9}, {
  3.3998265194841275`*^9, 3.3998265462028775`*^9}}],

Cell[TextData[{
 "\nUse ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to plot some partial sums for cos(z)."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "m", ",", "n", ",", "s", ",", "z"}], "]"}], ";"}], " ",
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", 
     RowBox[{"Cos", "[", "z", "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"For", " ", "[", 
     RowBox[{
      RowBox[{"m", "=", "2"}], ",", 
      RowBox[{"m", "\[LessEqual]", "5"}], ",", 
      RowBox[{"m", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"s", "[", "z_", "]"}], "=", 
        RowBox[{
         UnderoverscriptBox["\[Sum]", 
          RowBox[{"n", "=", "0"}], "m"], " ", 
         FractionBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"-", "1"}], ")"}], "n"], " ", 
           SuperscriptBox["z", 
            RowBox[{"2", " ", "n"}]]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"2", " ", "n"}], ")"}], "!"}]]}]}], ";", " ", 
       "\[IndentingNewLine]", 
       RowBox[{"g0", "=", 
        RowBox[{"CartesianMap", "[", 
         RowBox[{"s", ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "\[Pi]", ",", 
            FractionBox["\[Pi]", "16"]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "1", ",", "0.25"}], "}"}], ",", 
          RowBox[{"PlotRange", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "1.7"}], ",", "1.7"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "1.2"}], ",", "1.2"}], "}"}]}], "}"}]}], ",", 
          RowBox[{"AspectRatio", "\[Rule]", 
           FractionBox["1.2", "1.7"]}], ",", 
          RowBox[{"Ticks", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Range", "[", 
              RowBox[{
               RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}], ",", 
             RowBox[{"Range", "[", 
              RowBox[{
               RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}], 
          ",", 
          RowBox[{"AxesLabel", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
          RowBox[{"PlotStyle", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], ";", "  ", 
       "\[IndentingNewLine]", 
       RowBox[{"Print", "[", "g0", "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{"\"\<w = s[z,\>\"", ",", 
         RowBox[{"2", "m"}], ",", "\"\<] = \>\"", ",", 
         RowBox[{"s", "[", "z", "]"}]}], "]"}], ";"}]}], " ", "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g1", "=", 
     RowBox[{"CartesianMap", "[", 
      RowBox[{"f", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "\[Pi]", ",", 
         FractionBox["\[Pi]", "16"]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "1", ",", "0.25"}], "}"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.7"}], ",", "1.7"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.2"}], ",", "1.2"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", 
        FractionBox["1.2", "1.7"]}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "g1", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  The mapping  w = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3992864255*^9, 3.399286457828125*^9}, {
  3.3998261664216275`*^9, 3.399826166593502*^9}}]
}, Closed]],

Cell["\<\
\tWith these definitions in place, it is now easy to create the other complex \
trigonometric functions, provided the denominators in the following \
expressions do not equal zero.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Definition 5.6.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"tan", " ", "z"}], " ", "=", " ", 
   FractionBox[
    RowBox[{"sin", " ", "z"}], 
    RowBox[{"cos", " ", "z"}]]}]]],
 ",  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"cot", " ", "z"}], " ", "=", " ", 
   FractionBox[
    RowBox[{"cos", " ", "z"}], 
    RowBox[{"sin", " ", "z"}]]}]]],
 ",  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"sec", " ", "z"}], " ", "=", " ", 
   FractionBox["1", 
    RowBox[{"cos", " ", "z"}]]}]]],
 ",  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"csc", " ", "z"}], " ", "=", " ", 
   FractionBox["1", 
    RowBox[{"sin", " ", "z"}]]}]]],
 ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration for Definition 5.6.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Tan", "[", "z", "]"}], "\[Equal]", 
   FractionBox[
    RowBox[{"Sin", "[", "z", "]"}], 
    RowBox[{"Cos", "[", "z", "]"}]]}]}]], "Input",
 CellChangeTimes->{3.3998265998591275`*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Cot", "[", "z", "]"}], "\[Equal]", 
   FractionBox[
    RowBox[{"Cos", "[", "z", "]"}], 
    RowBox[{"Sin", "[", "z", "]"}]]}]}]], "Input",
 CellChangeTimes->{3.399826600749752*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Sec", "[", "z", "]"}], "\[Equal]", 
   FractionBox["1", 
    RowBox[{"Cos", "[", "z", "]"}]]}]}]], "Input",
 CellChangeTimes->{3.3998266014841275`*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Csc", "[", "z", "]"}], "\[Equal]", 
   FractionBox["1", 
    RowBox[{"Sin", "[", "z", "]"}]]}]}]], "Input",
 CellChangeTimes->{3.399826602499752*^9}]
}, Closed]],

Cell[TextData[{
 "\tSince the series for the complex sine and cosine agree with the real sine \
and cosine when ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " is real, the remaining complex trigonometric functions likewise agree with \
their real counterparts.  What additional properties are common?  For \
starters, we have  "
}], "Text",
 CellChangeTimes->{{3.399286093859375*^9, 3.399286095125*^9}}],

Cell[TextData[{
 StyleBox["Theorem 5.4.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  ",
 Cell[BoxData[
  RowBox[{"sin", 
   RowBox[{"(", "z", ")"}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{"cos", 
   RowBox[{"(", "z", ")"}]}]]],
 " are entire functions, with  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    FractionBox["d", "dz"], "sin", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{"cos", 
    RowBox[{"(", "z", ")"}]}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    FractionBox["d", "dz"], "cos", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"-", " ", "sin"}], 
    RowBox[{"(", "z", ")"}]}]}]]],
 ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof of Theorem 5.4.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 "\tThe ratio test shows that the radius of convergence for both functions is \
infinity, so they are entire by 4.17, part (i). Part (iii) of that theorem \
gives  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     FractionBox["d", "dz"], "sin", 
     RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
    RowBox[{
     FractionBox["d", "dz"], 
     StyleBox[
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"n", "=", "0"}], "\[Infinity]"], 
       FractionBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"-", "1"}], ")"}], "n"], " ", 
         SuperscriptBox["z", 
          RowBox[{
           RowBox[{"2", "n"}], "+", "1"}]]}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", "n"}], "+", "1"}], ")"}], "!"}]]}],
      FontSize->12]}]}], " ", "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 
  RowBox[{"                       ", 
   RowBox[{"=", " ", 
    StyleBox[
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "0"}], "\[Infinity]"], 
      RowBox[{"(", 
       RowBox[{
        FractionBox["d", "dz"], 
        FractionBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], "n"], " "}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", "n"}], "+", "1"}], ")"}], "!"}]], 
        SuperscriptBox["z", 
         RowBox[{
          RowBox[{"2", "n"}], "+", "1"}]]}], ")"}]}],
     FontSize->12]}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                       ", 
   RowBox[{"=", " ", 
    StyleBox[
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "0"}], "\[Infinity]"], 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], "n"], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", "n"}], "+", "1"}], ")"}]}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", "n"}], "+", "1"}], ")"}], "!"}]], 
        SuperscriptBox["z", 
         RowBox[{"2", "n"}]]}], ")"}]}],
     FontSize->12]}], " ", "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                       ", 
   RowBox[{"=", " ", 
    StyleBox[
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "0"}], "\[Infinity]"], 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"-", "1"}], ")"}], "n"], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"2", "n"}], ")"}], "!"}]], 
        SuperscriptBox["z", 
         RowBox[{"2", "n"}]]}], ")"}]}],
     FontSize->12]}], 
   StyleBox[" ",
    FontSize->12], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                       ", 
   RowBox[{
    StyleBox["=",
     FontSize->12], 
    StyleBox[" ",
     FontSize->12], 
    RowBox[{"cos", 
     RowBox[{"(", "z", ")"}]}]}]}]}]],
 "  "
}], "Text"],

Cell[TextData[{
 "We leave the proof that ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    FractionBox["d", "dz"], "cos", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"-", " ", "sin"}], 
    RowBox[{"(", "z", ")"}]}]}]]],
 " as an exercise. "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration for Theorem 5.4.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    SubscriptBox["\[PartialD]", "z"], " ", 
    RowBox[{"Sin", "[", "z", "]"}]}], "\[Equal]", 
   RowBox[{"Cos", "[", "z", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.3998266213591275`*^9, 3.3998266232341275`*^9}, 
   3.399826722374752*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    SubscriptBox["\[PartialD]", "z"], " ", 
    RowBox[{"Cos", "[", "z", "]"}]}], "\[Equal]", 
   RowBox[{"-", 
    RowBox[{"Sin", "[", "z", "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.399826608281002*^9, 3.399826635937252*^9}, 
   3.3998267238278775`*^9}]
}, Closed]],

Cell[TextData[{
 "\tWe now list several additional properties, providing proofs for some and \
leaving others as exercises.  For all complex numbers ",
 StyleBox["z",
  FontFamily->"Courier New"],
 ", \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"sin", 
     RowBox[{"(", 
      RowBox[{"-", "z"}], ")"}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{"-", " ", "sin"}], 
     RowBox[{"(", "z", ")"}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{" ", 
   RowBox[{
    RowBox[{"cos", 
     RowBox[{"(", 
      RowBox[{"-", "z"}], ")"}]}], " ", "=", " ", 
    RowBox[{"cos", 
     RowBox[{"(", "z", ")"}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    SuperscriptBox[
     RowBox[{
      StyleBox["(",
       FontSize->16], 
      RowBox[{"cos", " ", "z"}], 
      StyleBox[")",
       FontSize->16]}], "2"], " ", "+", 
    SuperscriptBox[
     RowBox[{
      StyleBox["(",
       FontSize->16], 
      RowBox[{"sin", " ", "z"}], 
      StyleBox[")",
       FontSize->16]}], "2"]}], " ", "=", " ", "1"}]}]],
 "  "
}], "Text"],

Cell[TextData[{
 "\tThe verification that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"sin", 
    RowBox[{"(", 
     RowBox[{"-", "z"}], ")"}]}], "=", 
   RowBox[{
    RowBox[{"-", "sin"}], 
    RowBox[{"(", "z", ")"}]}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"cos", 
    RowBox[{"(", 
     RowBox[{"-", "z"}], ")"}]}], "=", 
   RowBox[{"cos", 
    RowBox[{"(", "z", ")"}]}]}]]],
 "  comes from substituting ",
 StyleBox["-z",
  FontFamily->"Courier New"],
 " for ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " in Definition 5.5.  We leave verification of the identity ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox[
     RowBox[{
      StyleBox["(",
       FontSize->16], 
      RowBox[{"cos", " ", "z"}], 
      StyleBox[")",
       FontSize->16]}], "2"], "+", 
    SuperscriptBox[
     RowBox[{
      StyleBox["(",
       FontSize->16], 
      RowBox[{"sin", " ", "z"}], 
      StyleBox[")",
       FontSize->16]}], "2"]}], "=", "1"}]]],
 "  as an exercise (with hints)."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration for identities.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Sin", "[", 
    RowBox[{"-", "z"}], "]"}], "\[Equal]", 
   RowBox[{"-", 
    RowBox[{"Sin", "[", "z", "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.399826641593502*^9, 3.3998266429528775`*^9}, {
  3.3998266760153775`*^9, 3.399826717999752*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Cos", "[", 
    RowBox[{"-", "z"}], "]"}], "\[Equal]", 
   RowBox[{"Cos", "[", "z", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.3998266439216275`*^9, 3.3998266447028775`*^9}, {
  3.3998266770466275`*^9, 3.399826719906002*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"eqn", "=", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"Cos", "[", "z", "]"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"Sin", "[", "z", "]"}], "2"]}], "\[Equal]", "1"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", "eqn", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.399826645499752*^9, 3.399826646249752*^9}, 
   3.399826678468502*^9}]
}, Closed]],

Cell[TextData[{
 StyleBox["A series exploration (i)",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 StyleBox[" The derivative of  sin(z)  is  cos(z).",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["A series exploration (i).",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "Construct the Maclaurin series for cos(z) and sin(z) using ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s \"Series\" procedure."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", "z", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"cos", ",", "sin"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"cos", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"Series", "[", 
      RowBox[{
       RowBox[{"Cos", "[", "z", "]"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"z", ",", "0", ",", "14"}], "}"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"sin", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"Series", "[", 
      RowBox[{
       RowBox[{"Sin", "[", "z", "]"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"z", ",", "0", ",", "15"}], "}"}]}], "]"}]}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Sin[z] = \>\"", ",", 
      RowBox[{"sin", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*FractionBox[\(d\), \(dz\)]\)Sin[z] = \>\"", ",", 
      RowBox[{
       RowBox[{"sin", "'"}], "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<   Cos[z] = \>\"", ",", 
      RowBox[{"cos", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Does  \!\(\*FractionBox[\(d\), \(dz\)]\)Sin[z] = Cos[z] ?  \>\"", 
      ",", 
      RowBox[{
       RowBox[{
        RowBox[{"sin", "'"}], "[", "z", "]"}], " ", "\[Equal]", " ", 
       RowBox[{"cos", "[", "z", "]"}]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399286650328125*^9},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["A series exploration (ii)",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 StyleBox[" ",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["The derivative of  cos(z)  is  -sin(z).",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["A series exploration (ii).",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "Construct the Maclaurin series for cos(z) and sin(z) using ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s \"Series\" procedure."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", "z", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"cos", ",", "sin"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"cos", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"Series", "[", 
      RowBox[{
       RowBox[{"Cos", "[", "z", "]"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"z", ",", "0", ",", "16"}], "}"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"sin", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"Series", "[", 
      RowBox[{
       RowBox[{"Sin", "[", "z", "]"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"z", ",", "0", ",", "15"}], "}"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Cos[z] = \>\"", ",", 
      RowBox[{"cos", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Sin[z] = \>\"", ",", 
      RowBox[{"sin", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< \!\(\*FractionBox[\(d\), \(dz\)]\)Cos[z] = \>\"", ",", 
      RowBox[{
       RowBox[{"cos", "'"}], "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  - Sin[z] = \>\"", ",", 
      RowBox[{"-", 
       RowBox[{"sin", "[", "z", "]"}]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Does  \!\(\*FractionBox[\(d\), \(dz\)]\)Cos[z] = - Sin[z] ?  \>\"", 
      ",", 
      RowBox[{
       RowBox[{
        RowBox[{"cos", "'"}], "[", "z", "]"}], " ", "\[Equal]", " ", 
       RowBox[{"-", " ", 
        RowBox[{"sin", "[", "z", "]"}]}]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39928666828125*^9},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 "\tFor all complex numbers ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " for which the expressions are defined,  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     FractionBox["d", "dz"], "tan", " ", "z"}], "  ", "=", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"sec", " ", "z"}], ")"}], "2"]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     FractionBox["d", "dz"], " ", "cot", " ", "z"}], "  ", "=", " ", 
    RowBox[{"-", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"csc", " ", "z"}], ")"}], "2"]}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     FractionBox["d", "dz"], " ", "sec", " ", "z"}], "  ", "=", " ", 
    RowBox[{"sec", " ", "z", "  ", "tan", " ", "z"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     FractionBox["d", "dz"], " ", "csc", " ", "z"}], "  ", "=", " ", 
    RowBox[{
     RowBox[{"-", " ", "cot"}], " ", "z", "  ", "Csc", " ", 
     RowBox[{"z", 
      StyleBox[" ",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox[".",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox[" ",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]]}]}]}]}]]],
 "  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "\tThe proof that ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    FractionBox["d", "dz"], "tan", " ", "z"}], " ", "=", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"sec", " ", "z"}], ")"}], "2"]}]]],
 " uses the identity ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox[
     RowBox[{
      StyleBox["(",
       FontSize->16], 
      RowBox[{"cos", " ", "z"}], 
      StyleBox[")",
       FontSize->16]}], "2"], "+", 
    SuperscriptBox[
     RowBox[{
      StyleBox["(",
       FontSize->16], 
      RowBox[{"sin", " ", "z"}], 
      StyleBox[")",
       FontSize->16]}], "2"]}], "=", "1"}]]],
 ":  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     FractionBox["d", "dz"], "tan", " ", "z"}], " ", "=", 
    RowBox[{
     RowBox[{
      FractionBox["d", 
       RowBox[{" ", "dz"}]], 
      FractionBox[
       RowBox[{"sin", " ", "z"}], 
       RowBox[{"cos", " ", "z"}]]}], " ", "=", " ", 
     FractionBox[
      RowBox[{
       RowBox[{"cos", " ", "z", 
        FractionBox["d", "dz"], "sin", " ", "z"}], " ", "-", " ", 
       RowBox[{"sin", " ", "z", 
        FractionBox["d", "dz"], "cos", " ", "z"}]}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"cos", " ", "z"}], ")"}], "2"]]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                  ", 
   RowBox[{"=", " ", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{
         StyleBox["(",
          FontSize->16], 
         RowBox[{"cos", " ", "z"}], 
         StyleBox[")",
          FontSize->16]}], "2"], "+", 
       SuperscriptBox[
        RowBox[{
         StyleBox["(",
          FontSize->16], 
         RowBox[{"sin", " ", "z"}], 
         StyleBox[")",
          FontSize->16]}], "2"]}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"cos", " ", "z"}], ")"}], "2"]], " ", "=", " ", 
     FractionBox["1", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"cos", " ", "z"}], ")"}], "2"]]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                  ", 
   RowBox[{"=", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"sec", " ", "z"}], ")"}], "2"]}]}]}]]
}], "Text"],

Cell["\<\
We leave the proofs of the other derivative formulas as exercises.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration for the identities.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    SubscriptBox["\[PartialD]", "z"], " ", 
    RowBox[{"Tan", "[", "z", "]"}]}], "\[Equal]", 
   SuperscriptBox[
    RowBox[{"Sec", "[", "z", "]"}], "2"]}]}]], "Input",
 CellChangeTimes->{{3.3998266588903775`*^9, 3.3998266705153775`*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    SubscriptBox["\[PartialD]", "z"], " ", 
    RowBox[{"Cot", "[", "z", "]"}]}], "\[Equal]", 
   RowBox[{"-", 
    SuperscriptBox[
     RowBox[{"Csc", "[", "z", "]"}], "2"]}]}]}]], "Input",
 CellChangeTimes->{{3.3998266608278775`*^9, 3.3998266688903775`*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    SubscriptBox["\[PartialD]", "z"], " ", 
    RowBox[{"Sec", "[", "z", "]"}]}], "\[Equal]", 
   RowBox[{
    RowBox[{"Sec", "[", "z", "]"}], " ", 
    RowBox[{"Tan", "[", "z", "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.3998266628903775`*^9, 3.399826667999752*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    SubscriptBox["\[PartialD]", "z"], " ", 
    RowBox[{"Csc", "[", "z", "]"}]}], "\[Equal]", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"Cot", "[", "z", "]"}]}], " ", 
    RowBox[{"Csc", "[", "z", "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.399826664593502*^9, 3.3998266671403775`*^9}}]
}, Closed]],

Cell[TextData[{
 "\tTo establish additional properties, it will be useful to express ",
 Cell[BoxData[
  RowBox[{"cos", " ", "z", "  ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "  ", "sin", " ", "z"}]]],
 " in the Cartesian form ",
 Cell[BoxData[
  RowBox[{"u", "+", 
   RowBox[{"\[ImaginaryI]", " ", "v"}]}]]],
 ".  (Additionally, the applications in Chapters 9 and 10 will use these \
formulas.)  We begin by observing that the argument given to prove part (iii) \
in Theorem 5.1 easily generalizes to the complex case with the aid of \
Definition 5.5.  That is,  \n\n",
 StyleBox["(5-30)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[ImaginaryI]", " ", "z"}]], " ", "=", " ", 
   RowBox[{
    RowBox[{"cos", " ", "z"}], " ", "+", " ", 
    RowBox[{"\[ImaginaryI]", " ", "sin", " ", "z"}]}]}]]],
 ",\n\nfor all ",
 StyleBox["z",
  FontFamily->"Courier New"],
 ", whether ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " is real or complex.  Hence,  \n\n",
 StyleBox["(5-31)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "\[ImaginaryI]"}], " ", "z"}]], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"cos", 
      RowBox[{"(", 
       RowBox[{"-", "z"}], ")"}]}], " ", "+", " ", 
     RowBox[{"\[ImaginaryI]", " ", "sin", 
      RowBox[{"(", 
       RowBox[{"-", "z"}], ")"}]}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{"cos", " ", "z"}], " ", "-", " ", 
     RowBox[{"\[ImaginaryI]", " ", "sin", " ", "z"}]}]}]}]]],
 "  "
}], "Text",
 CellChangeTimes->{{3.399286311859375*^9, 3.399286312703125*^9}}],

Cell[TextData[{
 "\tAdding the above two expressions and solving for ",
 Cell[BoxData[
  RowBox[{"cos", " ", "z"}]]],
 " gives\n\n",
 StyleBox["(5-32)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"cos", " ", "z"}], " ", "=", " ", 
   FractionBox[
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "z"}]], "  ", "+", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "z"}]]}], "2"]}]]],
 " ,\n\nand subtracting ",
 StyleBox["(5-32)",
  FontColor->RGBColor[0, 0, 1]],
 " from ",
 StyleBox["(5-31) ",
  FontColor->RGBColor[0, 0, 1]],
 "and solving for ",
 Cell[BoxData[
  RowBox[{"sin", " ", "z"}]]],
 " gives\n\n",
 StyleBox["(5-33)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"sin", " ", "z"}], " ", "=", " ", 
   FractionBox[
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "z"}]], "  ", "-", "  ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "z"}]]}], 
    RowBox[{"2", "\[ImaginaryI]"}]]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "\t",
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .64706 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.294118 0.323529 0.294118 [
[.038 .31103 -17.4375 -20.875 ]
[.038 .31103 17.4375 0 ]
[.962 .31103 -12.8125 -20.875 ]
[.962 .31103 12.8125 0 ]
[1.025 .32353 0 -6.5 ]
[1.025 .32353 9 6.5 ]
[.4875 .02941 -16.375 -6.5 ]
[.4875 .02941 0 6.5 ]
[.4875 .61765 -9.5 -6.5 ]
[.4875 .61765 0 6.5 ]
[.5 .67206 -4.34375 0 ]
[.5 .67206 4.34375 13 ]
[ 0 0 0 0 ]
[ 1 .64706 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.038 .32353 m
.038 .32978 L
s
gsave
.038 .31103 -78.4375 -24.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.875 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 16.688 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
%%BeginResource: font Helvetica-MISO
%%BeginFont: Helvetica-MISO
/Helvetica /Helvetica-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
65.563 9.438 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.438 9.438 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
64.438 16.688 moveto
(\\200\\200\\200\\200) show
69.938 16.688 moveto
(\\200\\200\\200\\200) show
75.438 16.688 moveto
(\\200) show
77.063 16.688 moveto
(\\200) show
68.813 23.875 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.875 16.688 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.962 .32353 m
.962 .32978 L
s
gsave
.962 .31103 -73.8125 -24.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.875 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 16.688 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
%%BeginResource: font Helvetica-MISO
%%BeginFont: Helvetica-MISO
/Helvetica /Helvetica-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
76.750 9.438 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
75.438 16.688 moveto
(\\200\\200\\200\\200) show
80.938 16.688 moveto
(\\200) show
81.563 16.688 moveto
(\\200) show
76.563 23.875 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
84.625 16.688 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .32353 m
1 .32353 L
s
gsave
1.025 .32353 -61 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
68.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .02941 m
.50625 .02941 L
s
gsave
.4875 .02941 -77.375 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.875 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .61765 m
.50625 .61765 L
s
gsave
.4875 .61765 -70.5 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 0 m
.5 .64706 L
s
gsave
.5 .67206 -65.3438 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
67.688 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .64706 L
0 .64706 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.038 .02941 m
.038 .05327 L
.038 .0793 L
.038 .10374 L
.038 .12725 L
.038 .15227 L
.038 .17635 L
.038 .20195 L
.038 .22661 L
.038 .25034 L
.038 .27558 L
.038 .29988 L
.038 .32325 L
.038 .34814 L
.038 .37208 L
.038 .39755 L
.038 .42207 L
.038 .44566 L
.038 .47077 L
.038 .49493 L
.038 .52062 L
.038 .54536 L
.038 .56917 L
.038 .5945 L
.038 .61765 L
s
1 0 0 r
.09575 .02941 m
.09575 .05327 L
.09575 .0793 L
.09575 .10374 L
.09575 .12725 L
.09575 .15227 L
.09575 .17635 L
.09575 .20195 L
.09575 .22661 L
.09575 .25034 L
.09575 .27558 L
.09575 .29988 L
.09575 .32325 L
.09575 .34814 L
.09575 .37208 L
.09575 .39755 L
.09575 .42207 L
.09575 .44566 L
.09575 .47077 L
.09575 .49493 L
.09575 .52062 L
.09575 .54536 L
.09575 .56917 L
.09575 .5945 L
.09575 .61765 L
s
0 0 1 r
.1535 .02941 m
.1535 .05327 L
.1535 .0793 L
.1535 .10374 L
.1535 .12725 L
.1535 .15227 L
.1535 .17635 L
.1535 .20195 L
.1535 .22661 L
.1535 .25034 L
.1535 .27558 L
.1535 .29988 L
.1535 .32325 L
.1535 .34814 L
.1535 .37208 L
.1535 .39755 L
.1535 .42207 L
.1535 .44566 L
.1535 .47077 L
.1535 .49493 L
.1535 .52062 L
.1535 .54536 L
.1535 .56917 L
.1535 .5945 L
.1535 .61765 L
s
1 0 0 r
.21125 .02941 m
.21125 .05327 L
.21125 .0793 L
.21125 .10374 L
.21125 .12725 L
.21125 .15227 L
.21125 .17635 L
.21125 .20195 L
.21125 .22661 L
.21125 .25034 L
.21125 .27558 L
.21125 .29988 L
.21125 .32325 L
.21125 .34814 L
.21125 .37208 L
.21125 .39755 L
.21125 .42207 L
.21125 .44566 L
.21125 .47077 L
.21125 .49493 L
.21125 .52062 L
.21125 .54536 L
.21125 .56917 L
.21125 .5945 L
.21125 .61765 L
s
0 0 1 r
.269 .02941 m
.269 .05327 L
.269 .0793 L
.269 .10374 L
.269 .12725 L
.269 .15227 L
.269 .17635 L
.269 .20195 L
.269 .22661 L
.269 .25034 L
.269 .27558 L
.269 .29988 L
.269 .32325 L
.269 .34814 L
.269 .37208 L
.269 .39755 L
.269 .42207 L
.269 .44566 L
.269 .47077 L
.269 .49493 L
.269 .52062 L
.269 .54536 L
.269 .56917 L
.269 .5945 L
.269 .61765 L
s
1 0 0 r
.32675 .02941 m
.32675 .05327 L
.32675 .0793 L
.32675 .10374 L
.32675 .12725 L
.32675 .15227 L
.32675 .17635 L
.32675 .20195 L
.32675 .22661 L
.32675 .25034 L
.32675 .27558 L
.32675 .29988 L
.32675 .32325 L
.32675 .34814 L
.32675 .37208 L
.32675 .39755 L
.32675 .42207 L
.32675 .44566 L
.32675 .47077 L
.32675 .49493 L
.32675 .52062 L
.32675 .54536 L
.32675 .56917 L
.32675 .5945 L
.32675 .61765 L
s
0 0 1 r
.3845 .02941 m
.3845 .05327 L
.3845 .0793 L
.3845 .10374 L
.3845 .12725 L
.3845 .15227 L
.3845 .17635 L
.3845 .20195 L
.3845 .22661 L
.3845 .25034 L
.3845 .27558 L
.3845 .29988 L
.3845 .32325 L
.3845 .34814 L
.3845 .37208 L
.3845 .39755 L
.3845 .42207 L
.3845 .44566 L
.3845 .47077 L
.3845 .49493 L
.3845 .52062 L
.3845 .54536 L
.3845 .56917 L
.3845 .5945 L
.3845 .61765 L
s
1 0 0 r
.44225 .02941 m
.44225 .05327 L
.44225 .0793 L
.44225 .10374 L
.44225 .12725 L
.44225 .15227 L
.44225 .17635 L
.44225 .20195 L
.44225 .22661 L
.44225 .25034 L
.44225 .27558 L
.44225 .29988 L
.44225 .32325 L
.44225 .34814 L
.44225 .37208 L
.44225 .39755 L
.44225 .42207 L
.44225 .44566 L
.44225 .47077 L
.44225 .49493 L
.44225 .52062 L
.44225 .54536 L
.44225 .56917 L
.44225 .5945 L
.44225 .61765 L
s
0 0 1 r
.5 .02941 m
.5 .05327 L
.5 .0793 L
.5 .10374 L
.5 .12725 L
.5 .15227 L
.5 .17635 L
.5 .20195 L
.5 .22661 L
.5 .25034 L
.5 .27558 L
.5 .29988 L
.5 .32325 L
.5 .34814 L
.5 .37208 L
.5 .39755 L
.5 .42207 L
.5 .44566 L
.5 .47077 L
.5 .49493 L
.5 .52062 L
.5 .54536 L
.5 .56917 L
.5 .5945 L
.5 .61765 L
s
1 0 0 r
.55775 .02941 m
.55775 .05327 L
.55775 .0793 L
.55775 .10374 L
.55775 .12725 L
.55775 .15227 L
.55775 .17635 L
.55775 .20195 L
.55775 .22661 L
.55775 .25034 L
.55775 .27558 L
.55775 .29988 L
.55775 .32325 L
.55775 .34814 L
.55775 .37208 L
.55775 .39755 L
.55775 .42207 L
.55775 .44566 L
.55775 .47077 L
.55775 .49493 L
.55775 .52062 L
.55775 .54536 L
.55775 .56917 L
.55775 .5945 L
.55775 .61765 L
s
0 0 1 r
.6155 .02941 m
.6155 .05327 L
.6155 .0793 L
.6155 .10374 L
.6155 .12725 L
.6155 .15227 L
.6155 .17635 L
.6155 .20195 L
.6155 .22661 L
.6155 .25034 L
.6155 .27558 L
.6155 .29988 L
.6155 .32325 L
.6155 .34814 L
.6155 .37208 L
.6155 .39755 L
.6155 .42207 L
.6155 .44566 L
.6155 .47077 L
.6155 .49493 L
.6155 .52062 L
.6155 .54536 L
.6155 .56917 L
.6155 .5945 L
.6155 .61765 L
s
1 0 0 r
.67325 .02941 m
.67325 .05327 L
.67325 .0793 L
.67325 .10374 L
.67325 .12725 L
.67325 .15227 L
.67325 .17635 L
.67325 .20195 L
.67325 .22661 L
.67325 .25034 L
.67325 .27558 L
.67325 .29988 L
.67325 .32325 L
.67325 .34814 L
.67325 .37208 L
.67325 .39755 L
.67325 .42207 L
.67325 .44566 L
.67325 .47077 L
.67325 .49493 L
.67325 .52062 L
.67325 .54536 L
.67325 .56917 L
.67325 .5945 L
.67325 .61765 L
s
0 0 1 r
.731 .02941 m
.731 .05327 L
.731 .0793 L
.731 .10374 L
.731 .12725 L
.731 .15227 L
.731 .17635 L
.731 .20195 L
.731 .22661 L
.731 .25034 L
.731 .27558 L
.731 .29988 L
.731 .32325 L
.731 .34814 L
.731 .37208 L
.731 .39755 L
.731 .42207 L
.731 .44566 L
.731 .47077 L
.731 .49493 L
.731 .52062 L
.731 .54536 L
.731 .56917 L
.731 .5945 L
.731 .61765 L
s
1 0 0 r
.78875 .02941 m
.78875 .05327 L
.78875 .0793 L
.78875 .10374 L
.78875 .12725 L
.78875 .15227 L
.78875 .17635 L
.78875 .20195 L
.78875 .22661 L
.78875 .25034 L
.78875 .27558 L
.78875 .29988 L
.78875 .32325 L
.78875 .34814 L
.78875 .37208 L
.78875 .39755 L
.78875 .42207 L
.78875 .44566 L
.78875 .47077 L
.78875 .49493 L
.78875 .52062 L
.78875 .54536 L
.78875 .56917 L
.78875 .5945 L
.78875 .61765 L
s
0 0 1 r
.8465 .02941 m
.8465 .05327 L
.8465 .0793 L
.8465 .10374 L
.8465 .12725 L
.8465 .15227 L
.8465 .17635 L
.8465 .20195 L
.8465 .22661 L
.8465 .25034 L
.8465 .27558 L
.8465 .29988 L
.8465 .32325 L
.8465 .34814 L
.8465 .37208 L
.8465 .39755 L
.8465 .42207 L
.8465 .44566 L
.8465 .47077 L
.8465 .49493 L
.8465 .52062 L
.8465 .54536 L
.8465 .56917 L
.8465 .5945 L
.8465 .61765 L
s
1 0 0 r
.90425 .02941 m
.90425 .05327 L
.90425 .0793 L
.90425 .10374 L
.90425 .12725 L
.90425 .15227 L
.90425 .17635 L
.90425 .20195 L
.90425 .22661 L
.90425 .25034 L
.90425 .27558 L
.90425 .29988 L
.90425 .32325 L
.90425 .34814 L
.90425 .37208 L
.90425 .39755 L
.90425 .42207 L
.90425 .44566 L
.90425 .47077 L
.90425 .49493 L
.90425 .52062 L
.90425 .54536 L
.90425 .56917 L
.90425 .5945 L
.90425 .61765 L
s
0 0 1 r
.962 .02941 m
.962 .05327 L
.962 .0793 L
.962 .10374 L
.962 .12725 L
.962 .15227 L
.962 .17635 L
.962 .20195 L
.962 .22661 L
.962 .25034 L
.962 .27558 L
.962 .29988 L
.962 .32325 L
.962 .34814 L
.962 .37208 L
.962 .39755 L
.962 .42207 L
.962 .44566 L
.962 .47077 L
.962 .49493 L
.962 .52062 L
.962 .54536 L
.962 .56917 L
.962 .5945 L
.962 .61765 L
s
.038 .02941 m
.07548 .02941 L
.11636 .02941 L
.15476 .02941 L
.19168 .02941 L
.23098 .02941 L
.26881 .02941 L
.30902 .02941 L
.34776 .02941 L
.38503 .02941 L
.42468 .02941 L
.46286 .02941 L
.49956 .02941 L
.53865 .02941 L
.57627 .02941 L
.61626 .02941 L
.65479 .02941 L
.69184 .02941 L
.73128 .02941 L
.76924 .02941 L
.80958 .02941 L
.84846 .02941 L
.88586 .02941 L
.92564 .02941 L
.962 .02941 L
s
1 0 0 r
.038 .10294 m
.07548 .10294 L
.11636 .10294 L
.15476 .10294 L
.19168 .10294 L
.23098 .10294 L
.26881 .10294 L
.30902 .10294 L
.34776 .10294 L
.38503 .10294 L
.42468 .10294 L
.46286 .10294 L
.49956 .10294 L
.53865 .10294 L
.57627 .10294 L
.61626 .10294 L
.65479 .10294 L
.69184 .10294 L
.73128 .10294 L
.76924 .10294 L
.80958 .10294 L
.84846 .10294 L
.88586 .10294 L
.92564 .10294 L
.962 .10294 L
s
0 0 1 r
.038 .17647 m
.07548 .17647 L
.11636 .17647 L
.15476 .17647 L
.19168 .17647 L
.23098 .17647 L
.26881 .17647 L
.30902 .17647 L
.34776 .17647 L
.38503 .17647 L
.42468 .17647 L
.46286 .17647 L
.49956 .17647 L
.53865 .17647 L
.57627 .17647 L
.61626 .17647 L
.65479 .17647 L
.69184 .17647 L
.73128 .17647 L
.76924 .17647 L
.80958 .17647 L
.84846 .17647 L
.88586 .17647 L
.92564 .17647 L
.962 .17647 L
s
1 0 0 r
.038 .25 m
.07548 .25 L
.11636 .25 L
.15476 .25 L
.19168 .25 L
.23098 .25 L
.26881 .25 L
.30902 .25 L
.34776 .25 L
.38503 .25 L
.42468 .25 L
.46286 .25 L
.49956 .25 L
.53865 .25 L
.57627 .25 L
.61626 .25 L
.65479 .25 L
.69184 .25 L
.73128 .25 L
.76924 .25 L
.80958 .25 L
.84846 .25 L
.88586 .25 L
.92564 .25 L
.962 .25 L
s
0 0 1 r
.038 .32353 m
.07548 .32353 L
.11636 .32353 L
.15476 .32353 L
.19168 .32353 L
.23098 .32353 L
.26881 .32353 L
.30902 .32353 L
.34776 .32353 L
.38503 .32353 L
.42468 .32353 L
.46286 .32353 L
.49956 .32353 L
.53865 .32353 L
.57627 .32353 L
.61626 .32353 L
.65479 .32353 L
.69184 .32353 L
.73128 .32353 L
.76924 .32353 L
.80958 .32353 L
.84846 .32353 L
.88586 .32353 L
.92564 .32353 L
.962 .32353 L
s
1 0 0 r
.038 .39706 m
.07548 .39706 L
.11636 .39706 L
.15476 .39706 L
.19168 .39706 L
.23098 .39706 L
.26881 .39706 L
.30902 .39706 L
.34776 .39706 L
.38503 .39706 L
.42468 .39706 L
.46286 .39706 L
.49956 .39706 L
.53865 .39706 L
.57627 .39706 L
.61626 .39706 L
.65479 .39706 L
.69184 .39706 L
.73128 .39706 L
.76924 .39706 L
.80958 .39706 L
.84846 .39706 L
.88586 .39706 L
.92564 .39706 L
.962 .39706 L
s
0 0 1 r
.038 .47059 m
.07548 .47059 L
.11636 .47059 L
.15476 .47059 L
.19168 .47059 L
.23098 .47059 L
.26881 .47059 L
.30902 .47059 L
.34776 .47059 L
.38503 .47059 L
.42468 .47059 L
.46286 .47059 L
.49956 .47059 L
.53865 .47059 L
.57627 .47059 L
.61626 .47059 L
.65479 .47059 L
.69184 .47059 L
.73128 .47059 L
.76924 .47059 L
.80958 .47059 L
.84846 .47059 L
.88586 .47059 L
.92564 .47059 L
.962 .47059 L
s
1 0 0 r
.038 .54412 m
.07548 .54412 L
.11636 .54412 L
.15476 .54412 L
.19168 .54412 L
.23098 .54412 L
.26881 .54412 L
.30902 .54412 L
.34776 .54412 L
.38503 .54412 L
.42468 .54412 L
.46286 .54412 L
.49956 .54412 L
.53865 .54412 L
.57627 .54412 L
.61626 .54412 L
.65479 .54412 L
.69184 .54412 L
.73128 .54412 L
.76924 .54412 L
.80958 .54412 L
.84846 .54412 L
.88586 .54412 L
.92564 .54412 L
.962 .54412 L
s
0 0 1 r
.038 .61765 m
.07548 .61765 L
.11636 .61765 L
.15476 .61765 L
.19168 .61765 L
.23098 .61765 L
.26881 .61765 L
.30902 .61765 L
.34776 .61765 L
.38503 .61765 L
.42468 .61765 L
.46286 .61765 L
.49956 .61765 L
.53865 .61765 L
.57627 .61765 L
.61626 .61765 L
.65479 .61765 L
.69184 .61765 L
.73128 .61765 L
.76924 .61765 L
.80958 .61765 L
.84846 .61765 L
.88586 .61765 L
.92564 .61765 L
.962 .61765 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 186.313},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\
eJzt3Utu00AYAGDn1fRFy6Y8hRQuAysOEVVI7QKBSnesoCvorr0Nh+oVTGZs
5+GOCjR22kSfpdgTz+9O5pvJ2HET+8P4/OTjp/H56fF49P5s/OXk9Pjr6N3n
s8mqXifLOqMsy36PspDOJ8lydpnleZ71svhkkgqPqzjPVpl1kcgaNBb+LSz6
IaP/fxsehcVNWP9mbkWMzaexe+W6fG77/UTcfsNxqXK7tbqEadjwa9lbQd1e
rwd3L8y7kFtFvvs9i7th7qbLRYsWLVq0aNGiRYsWLVq0aNGiRYsWbRO0NyF6
Tf5Rse7WaNGiRYsWLVq0aNGiRYsWLVq0aNGiRYv2cdCu05f4190aLVq0aNGi
RYsWLVq0aNGiRYsWLdqNo41FDSY5yWsTQL5/uWGKF295Xjyd5c+22WLeQD36
C3GT6VWReJIQ18ubqMdgIa7q7S+L1EGCPV4MJX7RP3VZlGfFhoeJrJ72arwe
M9NZXLGLLYsfLGRVzeut0/wO4o6miOExx16ijffAZHpRSDu8dOS+frTx0m0H
5SjCd/lyq2krzI7035b7L1q0aNFOaVMf/7rl/i0GZO0Uv/nct06QxOvtRtvy
o/fTmv00SFdfstzhQlxlWy3Lc4M7YdGfdXUN8UANcTgNzW6FFMt8eloR/b/G
bdfHn/pyfhQalEO+3t7ckF+x+lTTWj0cH7ZWj2JQTp+UHmJvqx6pY8LtIhWL
3w0r4g9UdkJqtxYeHlrnIVoHtzFoQ9jtVdGiRYsWLVq0aNGiRYsWLVq0aNGi
RXtvWjef0I3RokWLFi1atGjRokWLFi1atGjRokWLFi3ahmjd10M3RosWLVq0
aNGiRYsWLVq0aNGiRYsWLVq0aBui9WsH3RgtWrRo0aJFixYtWrRo0aJFixYt
2o2lTd19OHVfW9y4cT8G7vlfSnyv1S9Mw0Sdr4rcH2HR/UvQxZ1mt8IvV5gV
n7xtL/0rUfT1Mi+4/gfDdL1M1s+yOebLqkLuiZR1/gDx2bAZ\
\>"],
  ImageRangeCache->{{{0, 287}, {185.313, 0}} -> {-1, -1, 0, 0}}],
 StyleBox["     ",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .75 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.3125 0.375 0.3125 [
[.1875 .3625 -8.1875 -13 ]
[.1875 .3625 8.1875 0 ]
[.8125 .3625 -4.75 -13 ]
[.8125 .3625 4.75 0 ]
[1.025 .375 0 -6.5 ]
[1.025 .375 9.5 6.5 ]
[.4875 .0625 -16.375 -6.5 ]
[.4875 .0625 0 6.5 ]
[.4875 .6875 -9.5 -6.5 ]
[.4875 .6875 0 6.5 ]
[.5 .775 -4.4375 0 ]
[.5 .775 4.4375 13 ]
[ 0 0 0 0 ]
[ 1 .75 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1875 .375 m
.1875 .38125 L
s
gsave
.1875 .3625 -69.1875 -17 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.875 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.8125 .375 m
.8125 .38125 L
s
gsave
.8125 .3625 -65.75 -17 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .375 m
1 .375 L
s
gsave
1.025 .375 -61 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(u) show
68.500 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .0625 m
.50625 .0625 L
s
gsave
.4875 .0625 -77.375 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.875 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .6875 m
.50625 .6875 L
s
gsave
.4875 .6875 -70.5 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 0 m
.5 .75 L
s
gsave
.5 .775 -65.4375 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(v) show
67.875 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .75 L
0 .75 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.01779 .375 m
.04603 .375 L
.07343 .375 L
.09611 .375 L
.11529 .375 L
.13301 .375 L
.14755 .375 L
.16042 .375 L
.17038 .375 L
.17777 .375 L
.18334 .375 L
.18649 .375 L
.1875 .375 L
.18641 .375 L
.18323 .375 L
.17755 .375 L
.1698 .375 L
.16017 .375 L
.14752 .375 L
.13291 .375 L
.11467 .375 L
.09432 .375 L
.07202 .375 L
.04523 .375 L
.01779 .375 L
s
1 0 0 r
.02705 .30335 m
.05475 .31076 L
.08162 .31835 L
.10387 .32508 L
.12268 .33123 L
.14006 .33746 L
.15432 .3432 L
.16694 .34907 L
.17671 .35454 L
.18397 .35967 L
.18685 .36223 L
.18942 .36502 L
.19128 .36764 L
.19193 .36882 L
.19251 .37009 L
.19277 .37078 L
.19298 .37143 L
.19316 .37209 L
.19328 .37269 L
.19338 .37328 L
.19342 .37355 L
.19345 .37384 L
.19347 .37414 L
.19348 .37428 L
.19349 .37443 L
.1935 .37458 L
.1935 .37473 L
.1935 .37482 L
.1935 .3749 L
.1935 .37506 L
.1935 .37521 L
.1935 .37537 L
.19349 .37551 L
.19349 .37565 L
.19347 .37597 L
.19344 .3763 L
.1934 .37662 L
.19335 .37693 L
.19322 .37761 L
.19292 .37875 L
.19249 .37998 L
.19188 .38129 L
.19106 .38272 L
.18913 .38533 L
.1867 .38792 L
.18352 .39069 L
.17623 .39575 L
.16622 .40129 L
.15432 .4068 L
.13915 .41288 L
Mistroke
.12197 .41902 L
.10296 .4252 L
.07991 .43215 L
.05482 .43922 L
.02705 .44665 L
Mfstroke
0 0 1 r
.05449 .23446 m
.08059 .24899 L
.1059 .26388 L
.12685 .27708 L
.14457 .28913 L
.16094 .30136 L
.17438 .31263 L
.18627 .32415 L
.19547 .33488 L
.2023 .34493 L
.20502 .34994 L
.20744 .35542 L
.20919 .36057 L
.20981 .36287 L
.21035 .36538 L
.2106 .36673 L
.21079 .36799 L
.21096 .36929 L
.21108 .37047 L
.21117 .37163 L
.21121 .37216 L
.21124 .37272 L
.21126 .37332 L
.21127 .37359 L
.21127 .37388 L
.21128 .37418 L
.21128 .37447 L
.21129 .37465 L
.21129 .37481 L
.21129 .37512 L
.21129 .37541 L
.21128 .37572 L
.21128 .37601 L
.21127 .37628 L
.21125 .37689 L
.21122 .37755 L
.21119 .37818 L
.21114 .37878 L
.21102 .38012 L
.21074 .38236 L
.21033 .38476 L
.20975 .38734 L
.20898 .39015 L
.20717 .39527 L
.20487 .40035 L
.20188 .40578 L
.19502 .41571 L
.18559 .42657 L
.17438 .43737 L
.16009 .44931 L
Mistroke
.1439 .46134 L
.126 .47348 L
.10429 .48709 L
.08065 .50098 L
.05449 .51554 L
Mfstroke
1 0 0 r
.09905 .17097 m
.12254 .19205 L
.14532 .21368 L
.16418 .23284 L
.18012 .25034 L
.19486 .26809 L
.20695 .28445 L
.21765 .30117 L
.22593 .31675 L
.23208 .33135 L
.23452 .33862 L
.2367 .34657 L
.23828 .35405 L
.23883 .35739 L
.23933 .36103 L
.23955 .363 L
.23972 .36482 L
.23987 .36671 L
.23998 .36842 L
.24006 .37011 L
.24009 .37088 L
.24012 .37169 L
.24014 .37256 L
.24015 .37295 L
.24015 .37337 L
.24016 .37381 L
.24016 .37423 L
.24016 .37448 L
.24017 .37473 L
.24017 .37518 L
.24016 .37559 L
.24016 .37604 L
.24016 .37646 L
.24015 .37685 L
.24013 .37775 L
.24011 .3787 L
.24007 .37962 L
.24004 .38048 L
.23993 .38244 L
.23967 .38569 L
.2393 .38917 L
.23879 .39292 L
.23809 .39699 L
.23646 .40442 L
.23439 .4118 L
.2317 .41968 L
.22552 .4341 L
.21704 .44987 L
.20695 .46555 L
.19409 .48288 L
Mistroke
.17952 .50035 L
.16341 .51797 L
.14387 .53774 L
.1226 .55789 L
.09905 .57903 L
Mfstroke
0 0 1 r
.15902 .11531 m
.17899 .14215 L
.19837 .16968 L
.21441 .19407 L
.22797 .21634 L
.2405 .23893 L
.25078 .25975 L
.25988 .28103 L
.26692 .30086 L
.27215 .31944 L
.27423 .3287 L
.27609 .33881 L
.27743 .34834 L
.2779 .35259 L
.27831 .35722 L
.2785 .35972 L
.27865 .36204 L
.27878 .36445 L
.27887 .36663 L
.27894 .36877 L
.27897 .36975 L
.27899 .37079 L
.27901 .3719 L
.27901 .37239 L
.27902 .37292 L
.27902 .37349 L
.27903 .37402 L
.27903 .37434 L
.27903 .37465 L
.27903 .37523 L
.27903 .37576 L
.27903 .37632 L
.27902 .37686 L
.27902 .37736 L
.279 .3785 L
.27898 .37971 L
.27895 .38088 L
.27892 .38198 L
.27883 .38447 L
.27861 .38861 L
.27829 .39303 L
.27786 .39781 L
.27726 .40299 L
.27588 .41245 L
.27412 .42184 L
.27183 .43187 L
.26658 .45022 L
.25936 .47029 L
.25078 .49025 L
.23984 .51231 L
Mistroke
.22746 .53454 L
.21375 .55696 L
.19713 .58212 L
.17905 .60777 L
.15902 .63469 L
Mfstroke
1 0 0 r
.2321 .06964 m
.24779 .1012 L
.26301 .13357 L
.27561 .16225 L
.28627 .18843 L
.29611 .215 L
.30419 .23948 L
.31134 .26451 L
.31687 .28782 L
.32098 .30967 L
.32261 .32056 L
.32407 .33245 L
.32513 .34365 L
.32549 .34865 L
.32582 .35409 L
.32597 .35703 L
.32609 .35977 L
.32619 .36259 L
.32626 .36516 L
.32632 .36768 L
.32634 .36883 L
.32635 .37005 L
.32637 .37136 L
.32637 .37194 L
.32638 .37256 L
.32638 .37322 L
.32638 .37385 L
.32638 .37423 L
.32638 .37459 L
.32638 .37527 L
.32638 .37589 L
.32638 .37656 L
.32638 .37719 L
.32637 .37777 L
.32636 .37912 L
.32634 .38053 L
.32632 .38192 L
.3263 .38321 L
.32622 .38613 L
.32606 .391 L
.32581 .3962 L
.32546 .40182 L
.325 .40792 L
.32391 .41903 L
.32253 .43007 L
.32073 .44187 L
.3166 .46345 L
.31093 .48705 L
.30419 .51052 L
.2956 .53646 L
Mistroke
.28586 .56259 L
.2751 .58897 L
.26204 .61855 L
.24783 .64871 L
.2321 .68036 L
Mfstroke
0 0 1 r
.31547 .0357 m
.32627 .07077 L
.33676 .10674 L
.34544 .1386 L
.35278 .1677 L
.35956 .19722 L
.36512 .22442 L
.37005 .25223 L
.37386 .27813 L
.37669 .30241 L
.37781 .31451 L
.37882 .32772 L
.37954 .34016 L
.3798 .34572 L
.38002 .35176 L
.38013 .35504 L
.38021 .35807 L
.38028 .36121 L
.38033 .36406 L
.38036 .36686 L
.38038 .36815 L
.38039 .3695 L
.3804 .37095 L
.3804 .37159 L
.38041 .37228 L
.38041 .37303 L
.38041 .37372 L
.38041 .37414 L
.38041 .37454 L
.38041 .3753 L
.38041 .37599 L
.38041 .37673 L
.38041 .37743 L
.3804 .37808 L
.3804 .37957 L
.38038 .38115 L
.38037 .38269 L
.38035 .38412 L
.3803 .38737 L
.38018 .39278 L
.38001 .39856 L
.37978 .4048 L
.37946 .41157 L
.37871 .42393 L
.37775 .43619 L
.37651 .4493 L
.37367 .47328 L
.36977 .4995 L
.36512 .52558 L
.3592 .5544 L
Mistroke
.3525 .58344 L
.34508 .61275 L
.33609 .64562 L
.3263 .67913 L
.31547 .7143 L
Mfstroke
1 0 0 r
.40592 .01481 m
.41143 .05203 L
.41678 .09022 L
.4212 .12404 L
.42495 .15493 L
.4284 .18627 L
.43124 .21515 L
.43375 .24466 L
.43569 .27217 L
.43714 .29794 L
.43771 .31078 L
.43822 .32481 L
.43859 .33802 L
.43872 .34391 L
.43884 .35033 L
.43889 .35381 L
.43893 .35703 L
.43896 .36037 L
.43899 .36339 L
.43901 .36636 L
.43902 .36772 L
.43902 .36916 L
.43903 .3707 L
.43903 .37138 L
.43903 .37212 L
.43903 .37291 L
.43903 .37364 L
.43903 .37409 L
.43903 .37452 L
.43903 .37531 L
.43903 .37605 L
.43903 .37684 L
.43903 .37758 L
.43903 .37827 L
.43903 .37986 L
.43902 .38153 L
.43901 .38316 L
.439 .38468 L
.43898 .38813 L
.43892 .39387 L
.43883 .40001 L
.43871 .40663 L
.43855 .41383 L
.43817 .42694 L
.43768 .43996 L
.43705 .45388 L
.4356 .47933 L
.43361 .50717 L
.43124 .53485 L
.42822 .56545 L
Mistroke
.42481 .59628 L
.42102 .62739 L
.41644 .66229 L
.41145 .69787 L
.40592 .73519 L
Mfstroke
0 0 1 r
.5 .00775 m
.5 .04571 L
.5 .08464 L
.5 .11913 L
.5 .15062 L
.5 .18257 L
.5 .21201 L
.5 .24211 L
.5 .27015 L
.5 .29643 L
.5 .32383 L
.5 .34985 L
.5 .37471 L
.5 .40117 L
.5 .42682 L
.5 .45447 L
.5 .48167 L
.5 .50853 L
.5 .53805 L
.5 .5676 L
.5 .60043 L
.5 .63369 L
.5 .66742 L
.5 .7054 L
.5 .74225 L
s
1 0 0 r
.59408 .01481 m
.58857 .05203 L
.58322 .09022 L
.5788 .12404 L
.57505 .15493 L
.5716 .18627 L
.56876 .21515 L
.56625 .24466 L
.56431 .27217 L
.56286 .29794 L
.56229 .31078 L
.56178 .32481 L
.56141 .33802 L
.56128 .34391 L
.56116 .35033 L
.56111 .35381 L
.56107 .35703 L
.56104 .36037 L
.56101 .36339 L
.56099 .36636 L
.56098 .36772 L
.56098 .36916 L
.56097 .3707 L
.56097 .37138 L
.56097 .37212 L
.56097 .37291 L
.56097 .37364 L
.56097 .37409 L
.56097 .37452 L
.56097 .37531 L
.56097 .37605 L
.56097 .37684 L
.56097 .37758 L
.56097 .37827 L
.56097 .37986 L
.56098 .38153 L
.56099 .38316 L
.561 .38468 L
.56102 .38813 L
.56108 .39387 L
.56117 .40001 L
.56129 .40663 L
.56145 .41383 L
.56183 .42694 L
.56232 .43996 L
.56295 .45388 L
.5644 .47933 L
.56639 .50717 L
.56876 .53485 L
.57178 .56545 L
Mistroke
.57519 .59628 L
.57898 .62739 L
.58356 .66229 L
.58855 .69787 L
.59408 .73519 L
Mfstroke
0 0 1 r
.68453 .0357 m
.67373 .07077 L
.66324 .10674 L
.65456 .1386 L
.64722 .1677 L
.64044 .19722 L
.63488 .22442 L
.62995 .25223 L
.62614 .27813 L
.62331 .30241 L
.62219 .31451 L
.62118 .32772 L
.62046 .34016 L
.6202 .34572 L
.61998 .35176 L
.61987 .35504 L
.61979 .35807 L
.61972 .36121 L
.61967 .36406 L
.61964 .36686 L
.61962 .36815 L
.61961 .3695 L
.6196 .37095 L
.6196 .37159 L
.61959 .37228 L
.61959 .37303 L
.61959 .37372 L
.61959 .37414 L
.61959 .37454 L
.61959 .3753 L
.61959 .37599 L
.61959 .37673 L
.61959 .37743 L
.6196 .37808 L
.6196 .37957 L
.61962 .38115 L
.61963 .38269 L
.61965 .38412 L
.6197 .38737 L
.61982 .39278 L
.61999 .39856 L
.62022 .4048 L
.62054 .41157 L
.62129 .42393 L
.62225 .43619 L
.62349 .4493 L
.62633 .47328 L
.63023 .4995 L
.63488 .52558 L
.6408 .5544 L
Mistroke
.6475 .58344 L
.65492 .61275 L
.66391 .64562 L
.6737 .67913 L
.68453 .7143 L
Mfstroke
1 0 0 r
.7679 .06964 m
.75221 .1012 L
.73699 .13357 L
.72439 .16225 L
.71373 .18843 L
.70389 .215 L
.69581 .23948 L
.68866 .26451 L
.68313 .28782 L
.67902 .30967 L
.67739 .32056 L
.67593 .33245 L
.67487 .34365 L
.67451 .34865 L
.67418 .35409 L
.67403 .35703 L
.67391 .35977 L
.67381 .36259 L
.67374 .36516 L
.67368 .36768 L
.67366 .36883 L
.67365 .37005 L
.67363 .37136 L
.67363 .37194 L
.67362 .37256 L
.67362 .37322 L
.67362 .37385 L
.67362 .37423 L
.67362 .37459 L
.67362 .37527 L
.67362 .37589 L
.67362 .37656 L
.67362 .37719 L
.67363 .37777 L
.67364 .37912 L
.67366 .38053 L
.67368 .38192 L
.6737 .38321 L
.67378 .38613 L
.67394 .391 L
.67419 .3962 L
.67454 .40182 L
.675 .40792 L
.67609 .41903 L
.67747 .43007 L
.67927 .44187 L
.6834 .46345 L
.68907 .48705 L
.69581 .51052 L
.7044 .53646 L
Mistroke
.71414 .56259 L
.7249 .58897 L
.73796 .61855 L
.75217 .64871 L
.7679 .68036 L
Mfstroke
0 0 1 r
.84098 .11531 m
.82101 .14215 L
.80163 .16968 L
.78559 .19407 L
.77203 .21634 L
.7595 .23893 L
.74922 .25975 L
.74012 .28103 L
.73308 .30086 L
.72785 .31944 L
.72577 .3287 L
.72391 .33881 L
.72257 .34834 L
.7221 .35259 L
.72169 .35722 L
.7215 .35972 L
.72135 .36204 L
.72122 .36445 L
.72113 .36663 L
.72106 .36877 L
.72103 .36975 L
.72101 .37079 L
.72099 .3719 L
.72099 .37239 L
.72098 .37292 L
.72098 .37349 L
.72097 .37402 L
.72097 .37434 L
.72097 .37465 L
.72097 .37523 L
.72097 .37576 L
.72097 .37632 L
.72098 .37686 L
.72098 .37736 L
.721 .3785 L
.72102 .37971 L
.72105 .38088 L
.72108 .38198 L
.72117 .38447 L
.72139 .38861 L
.72171 .39303 L
.72214 .39781 L
.72274 .40299 L
.72412 .41245 L
.72588 .42184 L
.72817 .43187 L
.73342 .45022 L
.74064 .47029 L
.74922 .49025 L
.76016 .51231 L
Mistroke
.77254 .53454 L
.78625 .55696 L
.80287 .58212 L
.82095 .60777 L
.84098 .63469 L
Mfstroke
1 0 0 r
.90095 .17097 m
.87746 .19205 L
.85468 .21368 L
.83582 .23284 L
.81988 .25034 L
.80514 .26809 L
.79305 .28445 L
.78235 .30117 L
.77407 .31675 L
.76792 .33135 L
.76548 .33862 L
.7633 .34657 L
.76172 .35405 L
.76117 .35739 L
.76067 .36103 L
.76045 .363 L
.76028 .36482 L
.76013 .36671 L
.76002 .36842 L
.75994 .37011 L
.75991 .37088 L
.75988 .37169 L
.75986 .37256 L
.75985 .37295 L
.75985 .37337 L
.75984 .37381 L
.75984 .37423 L
.75984 .37448 L
.75983 .37473 L
.75983 .37518 L
.75984 .37559 L
.75984 .37604 L
.75984 .37646 L
.75985 .37685 L
.75987 .37775 L
.75989 .3787 L
.75993 .37962 L
.75996 .38048 L
.76007 .38244 L
.76033 .38569 L
.7607 .38917 L
.76121 .39292 L
.76191 .39699 L
.76354 .40442 L
.76561 .4118 L
.7683 .41968 L
.77448 .4341 L
.78296 .44987 L
.79305 .46555 L
.80591 .48288 L
Mistroke
.82048 .50035 L
.83659 .51797 L
.85613 .53774 L
.8774 .55789 L
.90095 .57903 L
Mfstroke
0 0 1 r
.94551 .23446 m
.91941 .24899 L
.8941 .26388 L
.87315 .27708 L
.85543 .28913 L
.83906 .30136 L
.82562 .31263 L
.81373 .32415 L
.80453 .33488 L
.7977 .34493 L
.79498 .34994 L
.79256 .35542 L
.79081 .36057 L
.79019 .36287 L
.78965 .36538 L
.7894 .36673 L
.78921 .36799 L
.78904 .36929 L
.78892 .37047 L
.78883 .37163 L
.78879 .37216 L
.78876 .37272 L
.78874 .37332 L
.78873 .37359 L
.78873 .37388 L
.78872 .37418 L
.78872 .37447 L
.78871 .37465 L
.78871 .37481 L
.78871 .37512 L
.78871 .37541 L
.78872 .37572 L
.78872 .37601 L
.78873 .37628 L
.78875 .37689 L
.78878 .37755 L
.78881 .37818 L
.78886 .37878 L
.78898 .38012 L
.78926 .38236 L
.78967 .38476 L
.79025 .38734 L
.79102 .39015 L
.79283 .39527 L
.79513 .40035 L
.79812 .40578 L
.80498 .41571 L
.81441 .42657 L
.82562 .43737 L
.83991 .44931 L
Mistroke
.8561 .46134 L
.874 .47348 L
.89571 .48709 L
.91935 .50098 L
.94551 .51554 L
Mfstroke
1 0 0 r
.97295 .30335 m
.94525 .31076 L
.91838 .31835 L
.89613 .32508 L
.87732 .33123 L
.85994 .33746 L
.84568 .3432 L
.83306 .34907 L
.82329 .35454 L
.81603 .35967 L
.81315 .36223 L
.81058 .36502 L
.80872 .36764 L
.80807 .36882 L
.80749 .37009 L
.80723 .37078 L
.80702 .37143 L
.80684 .37209 L
.80672 .37269 L
.80662 .37328 L
.80658 .37355 L
.80655 .37384 L
.80653 .37414 L
.80652 .37428 L
.80651 .37443 L
.8065 .37458 L
.8065 .37473 L
.8065 .37482 L
.8065 .3749 L
.8065 .37506 L
.8065 .37521 L
.8065 .37537 L
.80651 .37551 L
.80651 .37565 L
.80653 .37597 L
.80656 .3763 L
.8066 .37662 L
.80665 .37693 L
.80678 .37761 L
.80708 .37875 L
.80751 .37998 L
.80812 .38129 L
.80894 .38272 L
.81087 .38533 L
.8133 .38792 L
.81648 .39069 L
.82377 .39575 L
.83378 .40129 L
.84568 .4068 L
.86085 .41288 L
Mistroke
.87803 .41902 L
.89704 .4252 L
.92009 .43215 L
.94518 .43922 L
.97295 .44665 L
Mfstroke
0 0 1 r
.98221 .375 m
.95397 .375 L
.92657 .375 L
.90389 .375 L
.88471 .375 L
.86699 .375 L
.85245 .375 L
.83958 .375 L
.82962 .375 L
.82223 .375 L
.81666 .375 L
.81351 .375 L
.8125 .375 L
.81359 .375 L
.81677 .375 L
.82245 .375 L
.8302 .375 L
.83983 .375 L
.85248 .375 L
.86709 .375 L
.88533 .375 L
.90568 .375 L
.92798 .375 L
.95477 .375 L
.98221 .375 L
s
.01779 .375 m
.01779 .37358 L
.0178 .37228 L
.01782 .37078 L
.01784 .36937 L
.01791 .36686 L
.018 .36413 L
.01813 .36112 L
.01831 .35794 L
.01872 .35223 L
.01926 .34634 L
.01988 .34083 L
.0217 .32832 L
.02413 .31562 L
.02687 .30405 L
.0348 .27831 L
.04366 .25632 L
.05537 .23286 L
.08431 .18887 L
.11923 .14967 L
.16326 .11213 L
.21168 .08063 L
.26303 .05515 L
.29058 .04419 L
.32182 .03374 L
.35274 .02529 L
.38153 .019 L
.41184 .01394 L
.42869 .01179 L
.44473 .01017 L
.46001 .00901 L
.46774 .00857 L
.47629 .00819 L
.48355 .00796 L
.48764 .00787 L
.48958 .00784 L
.49139 .00781 L
.49312 .00779 L
.49469 .00777 L
.49644 .00776 L
.4983 .00775 L
.5001 .00775 L
.50205 .00775 L
.50388 .00776 L
.50558 .00777 L
.50757 .00779 L
.50946 .00782 L
.51301 .00788 L
.51683 .00797 L
.52099 .0081 L
Mistroke
.52847 .00839 L
.53539 .00874 L
.55123 .00983 L
.56803 .01142 L
.58422 .01339 L
.60161 .016 L
.63275 .02194 L
.66299 .02936 L
.69412 .03882 L
.74782 .05996 L
.80068 .08789 L
.84652 .1196 L
.88896 .15792 L
.923 .19867 L
.94885 .24076 L
.9594 .26338 L
.96845 .28789 L
.97177 .29898 L
.97484 .31101 L
.97706 .32146 L
.97904 .33294 L
.98044 .34353 L
.98138 .35341 L
.98175 .35888 L
.98199 .36385 L
.98209 .3666 L
.98213 .36805 L
.98216 .36959 L
.98218 .37093 L
.9822 .37241 L
.98221 .37375 L
.98221 .375 L
Mfstroke
1 0 0 r
.09541 .375 m
.09541 .374 L
.09542 .3731 L
.09544 .37205 L
.09546 .37106 L
.09551 .3693 L
.09559 .36739 L
.0957 .36529 L
.09585 .36306 L
.09619 .35907 L
.09665 .35495 L
.09717 .35109 L
.09869 .34234 L
.10074 .33345 L
.10303 .32536 L
.10969 .30734 L
.11712 .29196 L
.12694 .27554 L
.15122 .24476 L
.18052 .21733 L
.21746 .19106 L
.25809 .16902 L
.30117 .1512 L
.32429 .14352 L
.35051 .13621 L
.37645 .1303 L
.4006 .1259 L
.42603 .12236 L
.44017 .12085 L
.45363 .11972 L
.46645 .11891 L
.47294 .1186 L
.48011 .11834 L
.4862 .11818 L
.48963 .11811 L
.49126 .11809 L
.49278 .11807 L
.49423 .11805 L
.49555 .11804 L
.49701 .11803 L
.49858 .11803 L
.50008 .11803 L
.50172 .11803 L
.50326 .11803 L
.50468 .11804 L
.50635 .11806 L
.50794 .11808 L
.51092 .11812 L
.51412 .11818 L
.51761 .11827 L
Mistroke
.52389 .11847 L
.5297 .11872 L
.54298 .11948 L
.55708 .1206 L
.57067 .12198 L
.58525 .1238 L
.61138 .12795 L
.63675 .13315 L
.66287 .13977 L
.70792 .15456 L
.75228 .1741 L
.79074 .19629 L
.82634 .22311 L
.8549 .25162 L
.87659 .28107 L
.88545 .29689 L
.89304 .31404 L
.89583 .32181 L
.8984 .33023 L
.90027 .33754 L
.90193 .34557 L
.9031 .35298 L
.90389 .35989 L
.9042 .36372 L
.9044 .3672 L
.90448 .36913 L
.90452 .37014 L
.90454 .37121 L
.90456 .37215 L
.90458 .37318 L
.90459 .37412 L
.90459 .375 L
Mfstroke
0 0 1 r
.14762 .375 m
.14762 .37437 L
.14763 .37379 L
.14764 .37313 L
.14766 .3725 L
.1477 .37139 L
.14777 .37018 L
.14787 .36885 L
.148 .36744 L
.14829 .3649 L
.14869 .36229 L
.14915 .35985 L
.15047 .3543 L
.15225 .34867 L
.15425 .34354 L
.16005 .33212 L
.16652 .32238 L
.17508 .31197 L
.19623 .29247 L
.22174 .27509 L
.25392 .25844 L
.28931 .24447 L
.32683 .23318 L
.34696 .22832 L
.36979 .22368 L
.39239 .21994 L
.41343 .21715 L
.43558 .2149 L
.44789 .21395 L
.45961 .21323 L
.47078 .21272 L
.47643 .21252 L
.48267 .21235 L
.48798 .21225 L
.49097 .21221 L
.49239 .2122 L
.49371 .21218 L
.49497 .21217 L
.49612 .21217 L
.4974 .21216 L
.49876 .21216 L
.50007 .21216 L
.50149 .21216 L
.50284 .21216 L
.50408 .21217 L
.50553 .21218 L
.50692 .21219 L
.50951 .21222 L
.5123 .21226 L
.51534 .21231 L
Mistroke
.5208 .21244 L
.52586 .2126 L
.53744 .21308 L
.54971 .21379 L
.56155 .21466 L
.57425 .21581 L
.59701 .21845 L
.6191 .22174 L
.64186 .22594 L
.6811 .23531 L
.71972 .24769 L
.75322 .26175 L
.78423 .27875 L
.80911 .29682 L
.828 .31548 L
.83571 .3255 L
.84233 .33637 L
.84475 .34129 L
.84699 .34663 L
.84862 .35126 L
.85006 .35635 L
.85109 .36105 L
.85177 .36542 L
.85204 .36785 L
.85222 .37006 L
.85229 .37128 L
.85232 .37192 L
.85234 .3726 L
.85236 .3732 L
.85237 .37385 L
.85238 .37444 L
.85238 .375 L
Mfstroke
1 0 0 r
.17768 .375 m
.17769 .37469 L
.17769 .37442 L
.1777 .37409 L
.17772 .37379 L
.17776 .37325 L
.17782 .37266 L
.17791 .37202 L
.17803 .37133 L
.1783 .37011 L
.17867 .36884 L
.17908 .36766 L
.1803 .36497 L
.18193 .36224 L
.18375 .35975 L
.18906 .35422 L
.19498 .34949 L
.2028 .34445 L
.22215 .33499 L
.24549 .32656 L
.27492 .3185 L
.30728 .31172 L
.34161 .30625 L
.36002 .30389 L
.3809 .30165 L
.40157 .29983 L
.42082 .29848 L
.44107 .29739 L
.45233 .29693 L
.46306 .29658 L
.47327 .29633 L
.47844 .29624 L
.48415 .29615 L
.48901 .2961 L
.49174 .29608 L
.49304 .29608 L
.49425 .29607 L
.4954 .29607 L
.49645 .29606 L
.49762 .29606 L
.49887 .29606 L
.50007 .29606 L
.50137 .29606 L
.5026 .29606 L
.50373 .29606 L
.50506 .29607 L
.50633 .29607 L
.5087 .29609 L
.51125 .29611 L
.51403 .29613 L
Mistroke
.51903 .2962 L
.52366 .29627 L
.53424 .29651 L
.54547 .29685 L
.5563 .29727 L
.56792 .29783 L
.58873 .29911 L
.60894 .3007 L
.62975 .30274 L
.66564 .30728 L
.70098 .31328 L
.73162 .3201 L
.75998 .32834 L
.78274 .3371 L
.80001 .34615 L
.80707 .35101 L
.81312 .35627 L
.81534 .35866 L
.81739 .36125 L
.81887 .36349 L
.8202 .36596 L
.82113 .36824 L
.82176 .37036 L
.82201 .37153 L
.82217 .3726 L
.82223 .3732 L
.82226 .37351 L
.82228 .37384 L
.8223 .37413 L
.82231 .37444 L
.82231 .37473 L
.82232 .375 L
Mfstroke
0 0 1 r
.1875 .375 m
.19003 .375 L
.19853 .375 L
.2118 .375 L
.2292 .375 L
.25239 .375 L
.27889 .375 L
.31105 .375 L
.34537 .375 L
.38093 .375 L
.42084 .375 L
.46064 .375 L
.49954 .375 L
.54095 .375 L
.58013 .375 L
.62034 .375 L
.65698 .375 L
.68968 .375 L
.72118 .375 L
.74776 .375 L
.77147 .375 L
.7895 .375 L
.80209 .375 L
.81012 .375 L
.8125 .375 L
s
1 0 0 r
.17768 .375 m
.17769 .37531 L
.17769 .37558 L
.1777 .37591 L
.17772 .37621 L
.17776 .37675 L
.17782 .37734 L
.17791 .37798 L
.17803 .37867 L
.1783 .37989 L
.17867 .38116 L
.17908 .38234 L
.1803 .38503 L
.18193 .38776 L
.18375 .39025 L
.18906 .39578 L
.19498 .40051 L
.2028 .40555 L
.22215 .41501 L
.24549 .42344 L
.27492 .4315 L
.30728 .43828 L
.34161 .44375 L
.36002 .44611 L
.3809 .44835 L
.40157 .45017 L
.42082 .45152 L
.44107 .45261 L
.45233 .45307 L
.46306 .45342 L
.47327 .45367 L
.47844 .45376 L
.48415 .45385 L
.48901 .4539 L
.49174 .45392 L
.49304 .45392 L
.49425 .45393 L
.4954 .45393 L
.49645 .45394 L
.49762 .45394 L
.49887 .45394 L
.50007 .45394 L
.50137 .45394 L
.5026 .45394 L
.50373 .45394 L
.50506 .45393 L
.50633 .45393 L
.5087 .45391 L
.51125 .45389 L
.51403 .45387 L
Mistroke
.51903 .4538 L
.52366 .45373 L
.53424 .45349 L
.54547 .45315 L
.5563 .45273 L
.56792 .45217 L
.58873 .45089 L
.60894 .4493 L
.62975 .44726 L
.66564 .44272 L
.70098 .43672 L
.73162 .4299 L
.75998 .42166 L
.78274 .4129 L
.80001 .40385 L
.80707 .39899 L
.81312 .39373 L
.81534 .39134 L
.81739 .38875 L
.81887 .38651 L
.8202 .38404 L
.82113 .38176 L
.82176 .37964 L
.82201 .37847 L
.82217 .3774 L
.82223 .3768 L
.82226 .37649 L
.82228 .37616 L
.8223 .37587 L
.82231 .37556 L
.82231 .37527 L
.82232 .375 L
Mfstroke
0 0 1 r
.14762 .375 m
.14762 .37563 L
.14763 .37621 L
.14764 .37687 L
.14766 .3775 L
.1477 .37861 L
.14777 .37982 L
.14787 .38115 L
.148 .38256 L
.14829 .3851 L
.14869 .38771 L
.14915 .39015 L
.15047 .3957 L
.15225 .40133 L
.15425 .40646 L
.16005 .41788 L
.16652 .42762 L
.17508 .43803 L
.19623 .45753 L
.22174 .47491 L
.25392 .49156 L
.28931 .50553 L
.32683 .51682 L
.34696 .52168 L
.36979 .52632 L
.39239 .53006 L
.41343 .53285 L
.43558 .5351 L
.44789 .53605 L
.45961 .53677 L
.47078 .53728 L
.47643 .53748 L
.48267 .53765 L
.48798 .53775 L
.49097 .53779 L
.49239 .5378 L
.49371 .53782 L
.49497 .53783 L
.49612 .53783 L
.4974 .53784 L
.49876 .53784 L
.50007 .53784 L
.50149 .53784 L
.50284 .53784 L
.50408 .53783 L
.50553 .53782 L
.50692 .53781 L
.50951 .53778 L
.5123 .53774 L
.51534 .53769 L
Mistroke
.5208 .53756 L
.52586 .5374 L
.53744 .53692 L
.54971 .53621 L
.56155 .53534 L
.57425 .53419 L
.59701 .53155 L
.6191 .52826 L
.64186 .52406 L
.6811 .51469 L
.71972 .50231 L
.75322 .48825 L
.78423 .47125 L
.80911 .45318 L
.828 .43452 L
.83571 .4245 L
.84233 .41363 L
.84475 .40871 L
.84699 .40337 L
.84862 .39874 L
.85006 .39365 L
.85109 .38895 L
.85177 .38458 L
.85204 .38215 L
.85222 .37994 L
.85229 .37872 L
.85232 .37808 L
.85234 .3774 L
.85236 .3768 L
.85237 .37615 L
.85238 .37556 L
.85238 .375 L
Mfstroke
1 0 0 r
.09541 .375 m
.09541 .376 L
.09542 .3769 L
.09544 .37795 L
.09546 .37894 L
.09551 .3807 L
.09559 .38261 L
.0957 .38471 L
.09585 .38694 L
.09619 .39093 L
.09665 .39505 L
.09717 .39891 L
.09869 .40766 L
.10074 .41655 L
.10303 .42464 L
.10969 .44266 L
.11712 .45804 L
.12694 .47446 L
.15122 .50524 L
.18052 .53267 L
.21746 .55894 L
.25809 .58098 L
.30117 .5988 L
.32429 .60648 L
.35051 .61379 L
.37645 .6197 L
.4006 .6241 L
.42603 .62764 L
.44017 .62915 L
.45363 .63028 L
.46645 .63109 L
.47294 .6314 L
.48011 .63166 L
.4862 .63182 L
.48963 .63189 L
.49126 .63191 L
.49278 .63193 L
.49423 .63195 L
.49555 .63196 L
.49701 .63197 L
.49858 .63197 L
.50008 .63197 L
.50172 .63197 L
.50326 .63197 L
.50468 .63196 L
.50635 .63194 L
.50794 .63192 L
.51092 .63188 L
.51412 .63182 L
.51761 .63173 L
Mistroke
.52389 .63153 L
.5297 .63128 L
.54298 .63052 L
.55708 .6294 L
.57067 .62802 L
.58525 .6262 L
.61138 .62205 L
.63675 .61685 L
.66287 .61023 L
.70792 .59544 L
.75228 .5759 L
.79074 .55371 L
.82634 .52689 L
.8549 .49838 L
.87659 .46893 L
.88545 .45311 L
.89304 .43596 L
.89583 .42819 L
.8984 .41977 L
.90027 .41246 L
.90193 .40443 L
.9031 .39702 L
.90389 .39011 L
.9042 .38628 L
.9044 .3828 L
.90448 .38087 L
.90452 .37986 L
.90454 .37879 L
.90456 .37785 L
.90458 .37682 L
.90459 .37588 L
.90459 .375 L
Mfstroke
0 0 1 r
.01779 .375 m
.01779 .37642 L
.0178 .37772 L
.01782 .37922 L
.01784 .38063 L
.01791 .38314 L
.018 .38587 L
.01813 .38888 L
.01831 .39206 L
.01872 .39777 L
.01926 .40366 L
.01988 .40917 L
.0217 .42168 L
.02413 .43438 L
.02687 .44595 L
.0348 .47169 L
.04366 .49368 L
.05537 .51714 L
.08431 .56113 L
.11923 .60033 L
.16326 .63787 L
.21168 .66937 L
.26303 .69485 L
.29058 .70581 L
.32182 .71626 L
.35274 .72471 L
.38153 .731 L
.41184 .73606 L
.42869 .73821 L
.44473 .73983 L
.46001 .74099 L
.46774 .74143 L
.47629 .74181 L
.48355 .74204 L
.48764 .74213 L
.48958 .74216 L
.49139 .74219 L
.49312 .74221 L
.49469 .74223 L
.49644 .74224 L
.4983 .74225 L
.5001 .74225 L
.50205 .74225 L
.50388 .74224 L
.50558 .74223 L
.50757 .74221 L
.50946 .74218 L
.51301 .74212 L
.51683 .74203 L
.52099 .7419 L
Mistroke
.52847 .74161 L
.53539 .74126 L
.55123 .74017 L
.56803 .73858 L
.58422 .73661 L
.60161 .734 L
.63275 .72806 L
.66299 .72064 L
.69412 .71118 L
.74782 .69004 L
.80068 .66211 L
.84652 .6304 L
.88896 .59208 L
.923 .55133 L
.94885 .50924 L
.9594 .48662 L
.96845 .46211 L
.97177 .45102 L
.97484 .43899 L
.97706 .42854 L
.97904 .41706 L
.98044 .40647 L
.98138 .39659 L
.98175 .39112 L
.98199 .38615 L
.98209 .3834 L
.98213 .38195 L
.98216 .38041 L
.98218 .37907 L
.9822 .37759 L
.98221 .37625 L
.98221 .375 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 186.313},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
  ImageRangeCache->{{{0, 287}, {185.313, 0}} -> {-1, -1, 0, 0}}],
 StyleBox["  \n\t\t\t\tFigure 5.A",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  The mapping  ",
 Cell[BoxData[
  RowBox[{"w", " ", "=", 
   RowBox[{
    RowBox[{"u", "+", 
     RowBox[{"\[ImaginaryI]", " ", "v"}]}], "=", 
    RowBox[{"sin", " ", "z"}]}]}]]],
 ". "
}], "Text"],

Cell[TextData[{
 "These equations in turn are used to obtain the following important \
identities \n\n",
 StyleBox["(5-34)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"sin", " ", "z"}], " ", "=", " ", 
   RowBox[{
    RowBox[{"sin", 
     RowBox[{"(", 
      RowBox[{"x", "+", 
       RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{"sin", " ", "x", " ", "cosh", " ", "y"}], " ", "+", " ", 
     RowBox[{
     "\[ImaginaryI]", " ", "cos", " ", "x", " ", "sinh", " ", "y"}]}]}]}]]],
 ", \n\n",
 StyleBox["(5-35)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"cos", " ", "z"}], " ", "=", " ", 
   RowBox[{
    RowBox[{"cos", 
     RowBox[{"(", 
      RowBox[{"x", "+", 
       RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{"cos", " ", "x", " ", "cosh", " ", "y"}], " ", "-", " ", 
     RowBox[{
     "\[ImaginaryI]", " ", "sin", " ", "x", " ", "sinh", " ", "y"}]}]}]}]]],
 ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 "\tSubtracting Equation ",
 StyleBox["(5-31) ",
  FontColor->RGBColor[0, 0, 1]],
 "from Equation ",
 StyleBox["(5-30)",
  FontColor->RGBColor[0, 0, 1]],
 " and solving for ",
 Cell[BoxData[
  RowBox[{"sin", " ", "z"}]]],
 " gives \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"sin", " ", "z"}], "  ", "=", " ", 
    RowBox[{
     RowBox[{
      FractionBox["1", 
       RowBox[{"2", "\[ImaginaryI]"}]], 
      RowBox[{"(", " ", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", "z"}]], " ", "-", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", "z"}]]}], " ", ")"}]}], " ", 
     "=", "  ", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"2", "\[ImaginaryI]"}]], 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}]], " ", "-", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", 
          RowBox[{"(", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}]]}], ")"}]}]}]}], 
   "\n"}], "\[IndentingNewLine]", 
  RowBox[{"             ", 
   RowBox[{"=", "  ", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"2", "\[ImaginaryI]"}]], 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "y"}], "+", 
         RowBox[{"\[ImaginaryI]", " ", "x"}]}]], " ", "-", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"y", "-", 
         RowBox[{"\[ImaginaryI]", " ", "x"}]}]]}], ")"}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"             ", 
   RowBox[{"=", "  ", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"2", "\[ImaginaryI]"}]], 
     RowBox[{
      StyleBox["(",
       FontSize->16], 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", "y"}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"cos", " ", "x"}], "+", 
          RowBox[{"\[ImaginaryI]", " ", "sin", " ", "x"}]}], ")"}]}], "-", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", "y"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"cos", " ", "x"}], "-", 
          RowBox[{"\[ImaginaryI]", " ", "sin", " ", "x"}]}], ")"}]}]}], 
      StyleBox[")",
       FontSize->16]}]}]}], "\[IndentingNewLine]"}], "\n", 
  RowBox[{"             ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{"sin", " ", "x", 
      FractionBox[
       RowBox[{
        SuperscriptBox["\[ExponentialE]", "y"], "+", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", "y"}]]}], "2"]}], " ", "+", " ", 
     RowBox[{"\[ImaginaryI]", " ", "cos", " ", "x", 
      FractionBox[
       RowBox[{
        SuperscriptBox["\[ExponentialE]", "y"], "-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", "y"}]]}], "2"]}]}]}], "\n"}], "\[IndentingNewLine]", 
  RowBox[{"             ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{"sin", " ", "x", " ", "cosh", " ", "y"}], "  ", "+", " ", 
     RowBox[{
     "\[ImaginaryI]", "  ", "cos", " ", "x", " ", "sinh", " ", 
      "y"}]}]}]}]}]],
 "   \n\nwhere  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"cosh", " ", "y"}], " ", "=", 
   FractionBox[
    RowBox[{
     SuperscriptBox["\[ExponentialE]", "y"], "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", "y"}]]}], "2"]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"sinh", " ", "y"}], " ", "=", 
   FractionBox[
    RowBox[{
     SuperscriptBox["\[ExponentialE]", "y"], "-", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", "y"}]]}], "2"]}]]],
 ",  respectively, are the hyperbolic cosine and hyperbolic sine functions \
that you studied in calculus."
}], "Text"],

Cell[TextData[{
 "\tSimilarly\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"cos", " ", "z"}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", "z"}]], " ", "+", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", "z"}]]}], " ", ")"}]}], " ", 
     "=", "  ", 
     RowBox[{
      FractionBox["1", "2"], 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}]], " ", "+", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", 
          RowBox[{"(", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}]]}], ")"}]}]}]}], 
   "\n"}], "\[IndentingNewLine]", 
  RowBox[{"            ", 
   RowBox[{"=", "  ", 
    RowBox[{
     FractionBox["1", "2"], 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "y"}], "+", 
         RowBox[{"\[ImaginaryI]", " ", "x"}]}]], " ", "+", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"y", "-", 
         RowBox[{"\[ImaginaryI]", " ", "x"}]}]]}], ")"}]}]}], 
   "\[IndentingNewLine]"}], "\n", 
  RowBox[{"            ", 
   RowBox[{"=", " ", 
    RowBox[{
     FractionBox["1", "2"], 
     RowBox[{
      StyleBox["(",
       FontSize->16], 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", "y"}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"cos", " ", "x"}], "+", 
          RowBox[{"\[ImaginaryI]", " ", "sin", " ", "x"}]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", "y"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"cos", " ", "x"}], "-", 
          RowBox[{"\[ImaginaryI]", " ", "sin", " ", "x"}]}], ")"}]}]}], 
      StyleBox[")",
       FontSize->16]}]}]}], "\n"}], "\[IndentingNewLine]", 
  RowBox[{"            ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{"cos", " ", "x", 
      FractionBox[
       RowBox[{
        SuperscriptBox["\[ExponentialE]", "y"], "+", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", "y"}]]}], "2"]}], " ", "-", " ", 
     RowBox[{"\[ImaginaryI]", "  ", "sin", " ", "x", 
      FractionBox[
       RowBox[{
        SuperscriptBox["\[ExponentialE]", "y"], "-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", "y"}]]}], "2"]}]}]}], "\n"}], "\[IndentingNewLine]", 
  RowBox[{"            ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{"cos", " ", "x", " ", "Cosh", " ", "y"}], "  ", "-", " ", 
     RowBox[{
     "\[ImaginaryI]", "  ", "sin", " ", "x", " ", "sinh", " ", 
      "y"}]}]}]}]}]],
 "    "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration for the real and imaginary parts of Sin \
and Cos.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", " ", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", "z"}]], "\[Equal]", 
      RowBox[{
       RowBox[{"Cos", "[", "z", "]"}], "+", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"Sin", "[", "z", "]"}]}]}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"ComplexExpand", "[", " ", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "z"}]], "\[Equal]", 
     RowBox[{
      RowBox[{"Cos", "[", "z", "]"}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"Sin", "[", "z", "]"}]}]}]}], " ", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.39928669565625*^9, 3.399286698890625*^9}, 
   3.3998267446091275`*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
    "Print", "[", " ", 
     "\"\<\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\(-\[ImaginaryI]\)\\\ z\
\)]\) \[Equal] Cos[-z] + \[ImaginaryI] Sin[-z]\>\"", " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"ComplexExpand", "[", " ", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "z"}]], "\[Equal]", 
     RowBox[{
      RowBox[{"Cos", "[", 
       RowBox[{"-", "z"}], "]"}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{"-", "z"}], "]"}]}]}]}], " ", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.399286700375*^9, 3.399286701578125*^9}, 
   3.399826748531002*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", " ", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", "z"}]], "\[Equal]", 
      RowBox[{
       RowBox[{"Cos", "[", "z", "]"}], "-", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"Sin", "[", "z", "]"}]}]}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"ComplexExpand", "[", " ", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "z"}]], "\[Equal]", 
     RowBox[{
      RowBox[{"Cos", "[", "z", "]"}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"Sin", "[", "z", "]"}]}]}]}], " ", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.399286702546875*^9, 3.399286703625*^9}, 
   3.3998267515466275`*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", " ", 
     RowBox[{
      RowBox[{"Sin", "[", "z", "]"}], "\[Equal]", 
      FractionBox[
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", "z"}]], "-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", "z"}]]}], 
       RowBox[{"2", "\[ImaginaryI]"}]]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"ComplexExpand", "[", " ", 
    RowBox[{
     RowBox[{"Sin", "[", "z", "]"}], "\[Equal]", 
     FractionBox[
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "z"}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "z"}]]}], 
      RowBox[{"2", "\[ImaginaryI]"}]]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.39928670565625*^9, 3.39928670665625*^9}, 
   3.399826753781002*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", " ", 
     RowBox[{
      RowBox[{"Cos", "[", "z", "]"}], "\[Equal]", 
      FractionBox[
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", "z"}]], "+", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", "z"}]]}], "2"]}], "]"}], ";"}],
    " ", "\[IndentingNewLine]", 
   RowBox[{"ComplexExpand", "[", "  ", 
    RowBox[{
     RowBox[{"Cos", "[", "z", "]"}], "\[Equal]", 
     FractionBox[
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "z"}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "z"}]]}], "2"]}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.399286709515625*^9, 3.39928671078125*^9}, 
   3.399826755874752*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"Sin", "[", 
       RowBox[{"x", "+", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "==", 
      RowBox[{"ComplexExpand", "[", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{"x", "+", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], " ", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{
       RowBox[{"Sin", "[", 
        RowBox[{"x", "+", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "==", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{"x", "+", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}]}], "]"}], " ", "]"}], 
    ";"}], " "}]}]], "Input",
 CellChangeTimes->{{3.39928671215625*^9, 3.39928671309375*^9}, 
   3.3998267582341275`*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"Cos", "[", 
       RowBox[{"x", "+", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "==", 
      RowBox[{"ComplexExpand", "[", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"x", "+", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], " ", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{
       RowBox[{"Cos", "[", 
        RowBox[{"x", "+", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "==", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"x", "+", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}]}], "]"}], " ", "]"}], 
    ";"}], " "}]}]], "Input",
 CellChangeTimes->{{3.39928671446875*^9, 3.399286715890625*^9}, 
   3.399826760687252*^9}]
}, Closed]],

Cell[TextData[{
 "\tEquipped with Identities ",
 StyleBox["(5-32)",
  FontColor->RGBColor[0, 0, 1]],
 " - ",
 StyleBox["(5-35)",
  FontColor->RGBColor[0, 0, 1]],
 ", we can now establish many other properties of the trigonometric \
functions.  We begin with some periodic results.  For all complex numbers ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{"x", "+", 
    RowBox[{"\[ImaginaryI]", " ", "y"}]}]}]]],
 ",  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"sin", 
     RowBox[{"(", 
      RowBox[{"z", "+", 
       RowBox[{"2", "\[Pi]"}]}], ")"}]}], " ", "=", " ", 
    RowBox[{"sin", " ", "z"}]}], " ", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"cos", 
     RowBox[{"(", 
      RowBox[{"z", "+", 
       RowBox[{"2", "\[Pi]"}]}], ")"}]}], " ", "=", " ", 
    RowBox[{"cos", " ", "z"}]}], " ", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "   ", 
   RowBox[{
    RowBox[{"sin", 
     RowBox[{"(", 
      RowBox[{"z", "+", "\[Pi]"}], ")"}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{"-", " ", "sin"}], " ", "z"}]}], " ", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "   ", 
   RowBox[{
    RowBox[{"cos", 
     RowBox[{"(", 
      RowBox[{"z", "+", "\[Pi]"}], ")"}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{"-", " ", "cos"}], " ", "z"}]}], " ", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "   ", 
   RowBox[{
    RowBox[{"tan", 
     RowBox[{"(", 
      RowBox[{"z", "+", "\[Pi]"}], ")"}]}], " ", "=", " ", 
    RowBox[{"tan", " ", "z"}]}], " ", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "   ", 
   RowBox[{
    RowBox[{"cot", 
     RowBox[{"(", 
      RowBox[{"z", "+", "\[Pi]"}], ")"}]}], " ", "=", " ", 
    RowBox[{"cot", " ", 
     RowBox[{"z", 
      StyleBox[" ",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox[".",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]]}]}]}]}]]],
 "     "
}], "Text"],

Cell[TextData[{
 "Clearly, ",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{
    RowBox[{"sin", " ", 
     RowBox[{"(", 
      RowBox[{"z", "+", 
       RowBox[{"2", "\[Pi]"}]}], ")"}]}], " ", "=", " ", 
    RowBox[{"sin", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"x", "+", 
         RowBox[{"2", "\[Pi]"}]}], ")"}], "+", 
       RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}]}]}]]],
 ".  By Identity ",
 StyleBox["(5-34)",
  FontColor->RGBColor[0, 0, 1]],
 " this expression is  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"sin", " ", 
     RowBox[{"(", 
      RowBox[{"z", "+", 
       RowBox[{"2", "\[Pi]"}]}], ")"}]}], " ", "=", "  ", 
    RowBox[{
     RowBox[{"sin", " ", 
      RowBox[{"(", 
       RowBox[{"x", "+", 
        RowBox[{"2", "\[Pi]"}]}], ")"}], " ", "cosh", " ", "y"}], " ", "+", 
     " ", 
     RowBox[{"\[ImaginaryI]", " ", "cos", " ", 
      RowBox[{"(", 
       RowBox[{"x", "+", 
        RowBox[{"2", "\[Pi]"}]}], ")"}], " ", "sinh", " ", "y"}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                          ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      RowBox[{"sin", " ", "x", " ", "cosh", " ", "y"}], "  ", "+", "  ", 
      RowBox[{
      "\[ImaginaryI]", " ", "cos", " ", "x", " ", "sinh", " ", "y"}]}]}], 
    "  ", "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                          ", 
   RowBox[{"=", "  ", 
    RowBox[{"sin", " ", "z"}]}]}]}]],
 "   \n\nAgain, the proofs for the other periodic results are left as \
exercises."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration for trigonometric identities.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< Sin[z+2\[Pi]] = \>\"", ",", 
      RowBox[{"Sin", "[", 
       RowBox[{"z", "+", 
        RowBox[{"2", "\[Pi]"}]}], "]"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Sin[z+2n\[Pi]] = \>\"", ",", 
      RowBox[{"Simplify", "[", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"z", "+", 
          RowBox[{"2", "n", " ", "\[Pi]"}]}], "]"}], ",", 
        RowBox[{"Element", "[", 
         RowBox[{"n", ",", "Integers"}], "]"}]}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"Simplify", "[", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"z", "+", 
          RowBox[{"2", "n", " ", "\[Pi]"}]}], "]"}], ",", 
        RowBox[{"Element", "[", 
         RowBox[{"n", ",", "Integers"}], "]"}]}], "]"}], "\[Equal]", 
      RowBox[{"Sin", "[", "z", "]"}]}], "  ", "]"}], ";"}]}]}]], "Input",
 CellChangeTimes->{
  3.3992867346875*^9, 3.3998267657341275`*^9, {3.399827019468502*^9, 
   3.399827035249752*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< Cos[z+2\[Pi]] = \>\"", ",", 
      RowBox[{"Cos", "[", 
       RowBox[{"z", "+", 
        RowBox[{"2", "\[Pi]"}]}], "]"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Cos[z+2n\[Pi]] = \>\"", ",", 
      RowBox[{"Simplify", "[", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"z", "+", 
          RowBox[{"2", "n", " ", "\[Pi]"}]}], "]"}], ",", 
        RowBox[{"Element", "[", 
         RowBox[{"n", ",", "Integers"}], "]"}]}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"Simplify", "[", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"z", "+", 
          RowBox[{"2", "n", " ", "\[Pi]"}]}], "]"}], ",", 
        RowBox[{"Element", "[", 
         RowBox[{"n", ",", "Integers"}], "]"}]}], "]"}], "\[Equal]", 
      RowBox[{"Cos", "[", "z", "]"}]}], "  ", "]"}], ";"}]}]}]], "Input",
 CellChangeTimes->{
  3.3992867379375*^9, 3.3998267677966275`*^9, {3.3998269979841275`*^9, 
   3.3998270143278775`*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<      Sin[z+\[Pi]] = \>\"", ",", 
      RowBox[{"Sin", "[", 
       RowBox[{"z", "+", "\[Pi]"}], "]"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Sin[z+(2n+1)\[Pi]] = \>\"", ",", 
      RowBox[{"Simplify", "[", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"z", "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", "n"}], "+", "1"}], ")"}], " ", "\[Pi]"}]}], "]"}], 
        ",", 
        RowBox[{"Element", "[", 
         RowBox[{"n", ",", "Integers"}], "]"}]}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"Simplify", "[", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"z", "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", "n"}], "+", "1"}], ")"}], " ", "\[Pi]"}]}], "]"}], 
        ",", 
        RowBox[{"Element", "[", 
         RowBox[{"n", ",", "Integers"}], "]"}]}], "]"}], "\[Equal]", 
      RowBox[{"-", 
       RowBox[{"Sin", "[", "z", "]"}]}]}], "  ", "]"}], ";"}]}]}]], "Input",
 CellChangeTimes->{
  3.399286738796875*^9, {3.399826971312252*^9, 3.399826988906002*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<      Cos[z+\[Pi]] = \>\"", ",", 
      RowBox[{"Cos", "[", 
       RowBox[{"z", "+", "\[Pi]"}], "]"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Cos[z+(2n+1)\[Pi]] = \>\"", ",", 
      RowBox[{"Simplify", "[", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"z", "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", "n"}], "+", "1"}], ")"}], " ", "\[Pi]"}]}], "]"}], 
        ",", 
        RowBox[{"Element", "[", 
         RowBox[{"n", ",", "Integers"}], "]"}]}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"Simplify", "[", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"z", "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", "n"}], "+", "1"}], ")"}], " ", "\[Pi]"}]}], "]"}], 
        ",", 
        RowBox[{"Element", "[", 
         RowBox[{"n", ",", "Integers"}], "]"}]}], "]"}], "\[Equal]", 
      RowBox[{"-", 
       RowBox[{"Cos", "[", "z", "]"}]}]}], "  ", "]"}], ";"}]}]}]], "Input",
 CellChangeTimes->{
  3.399286739765625*^9, 3.399826770187252*^9, {3.3998269397653775`*^9, 
   3.399826963718502*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<      Tan[z+\[Pi]] = \>\"", ",", 
      RowBox[{"Tan", "[", 
       RowBox[{"z", "+", "\[Pi]"}], "]"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Tan[z+(2n+1)\[Pi]] = \>\"", ",", 
      RowBox[{"Simplify", "[", 
       RowBox[{
        RowBox[{"Tan", "[", 
         RowBox[{"z", "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", "n"}], "+", "1"}], ")"}], " ", "\[Pi]"}]}], "]"}], 
        ",", 
        RowBox[{"Element", "[", 
         RowBox[{"n", ",", "Integers"}], "]"}]}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"Simplify", "[", 
       RowBox[{
        RowBox[{"Tan", "[", 
         RowBox[{"z", "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", "n"}], "+", "1"}], ")"}], " ", "\[Pi]"}]}], "]"}], 
        ",", 
        RowBox[{"Element", "[", 
         RowBox[{"n", ",", "Integers"}], "]"}]}], "]"}], "\[Equal]", 
      RowBox[{"Tan", "[", "z", "]"}]}], "  ", "]"}], ";"}]}]}]], "Input",
 CellChangeTimes->{
  3.399286742296875*^9, 3.3998267729528775`*^9, {3.3998268995153775`*^9, 
   3.399826933937252*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<      Cot[z+\[Pi]] = \>\"", ",", 
      RowBox[{"Cot", "[", 
       RowBox[{"z", "+", "\[Pi]"}], "]"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Cot[z+(2n+1)\[Pi]] = \>\"", ",", 
      RowBox[{"Simplify", "[", 
       RowBox[{
        RowBox[{"Cot", "[", 
         RowBox[{"z", "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", "n"}], "+", "1"}], ")"}], " ", "\[Pi]"}]}], "]"}], 
        ",", 
        RowBox[{"Element", "[", 
         RowBox[{"n", ",", "Integers"}], "]"}]}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"Simplify", "[", 
       RowBox[{
        RowBox[{"Cot", "[", 
         RowBox[{"z", "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", "n"}], "+", "1"}], ")"}], " ", "\[Pi]"}]}], "]"}], 
        ",", 
        RowBox[{"Element", "[", 
         RowBox[{"n", ",", "Integers"}], "]"}]}], "]"}], "\[Equal]", 
      RowBox[{"Cot", "[", "z", "]"}]}], "  ", "]"}], ";"}]}]}]], "Input",
 CellChangeTimes->{
  3.3992867433125*^9, {3.3998267830466275`*^9, 3.3998268202028775`*^9}, {
   3.399826860624752*^9, 3.3998268921716275`*^9}}]
}, Closed]],

Cell[TextData[{
 "\tIf  ",
 Cell[BoxData[
  RowBox[{"z", 
   StyleBox[",",
    FontFamily->"Times New Roman"], " ", 
   RowBox[{
    SubscriptBox["z", "1"], "  ", 
    StyleBox["and",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], "  ", 
    SubscriptBox["z", "2"]}]}]]],
 "  are any complex numbers, then \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"sin", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["z", "1"], "+", 
       SubscriptBox["z", "2"]}], ")"}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{"sin", 
      RowBox[{"(", 
       SubscriptBox["z", "1"], ")"}], "cos", 
      RowBox[{"(", 
       SubscriptBox["z", "2"], ")"}]}], "  ", "+", "  ", 
     RowBox[{"cos", " ", 
      SubscriptBox["z", "1"], " ", "sin", " ", 
      SubscriptBox["z", "2"]}]}]}], " ", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "\n", 
   RowBox[{
    RowBox[{"cos", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["z", "1"], "+", 
       SubscriptBox["z", "2"]}], ")"}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{"cos", 
      RowBox[{"(", 
       SubscriptBox["z", "1"], ")"}], "cos", 
      RowBox[{"(", 
       SubscriptBox["z", "2"], ")"}]}], "  ", "-", "  ", 
     RowBox[{"sin", " ", 
      SubscriptBox["z", "1"], " ", "sin", " ", 
      SubscriptBox["z", "2"]}]}]}], " ", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "\n", "\[IndentingNewLine]", "       ", 
   RowBox[{
    RowBox[{"sin", 
     RowBox[{"(", 
      RowBox[{"2", "z"}], ")"}]}], " ", "=", " ", 
    RowBox[{"2", " ", "sin", " ", "z", " ", "cos", " ", "z"}]}], " ", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "\n", "\[IndentingNewLine]", "       ", 
   RowBox[{
    RowBox[{"cos", 
     RowBox[{"(", 
      RowBox[{"2", " ", "z"}], ")"}]}], " ", "=", " ", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"cos", " ", "z"}], ")"}], "2"], "  ", "-", "  ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"sin", " ", "z"}], ")"}], "2"]}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "\[IndentingNewLine]", "\n", "  ", 
   RowBox[{
    RowBox[{"sin", 
     RowBox[{"(", 
      RowBox[{
       FractionBox["\[Pi]", "2"], "+", "z"}], ")"}]}], " ", "=", "  ", 
    RowBox[{
     RowBox[{"sin", 
      RowBox[{"(", 
       RowBox[{
        FractionBox["\[Pi]", "2"], "-", "z"}], ")"}]}], " ", "=", "  ", 
     RowBox[{"cos", " ", 
      RowBox[{"z", 
       StyleBox[" ",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], 
       StyleBox[".",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]]}]}]}]}]}]]],
 "  \n"
}], "Text"],

Cell[TextData[{
 "\tWe demonstrate that ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"cos", 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["z", "1"], "+", 
      SubscriptBox["z", "2"]}], ")"}]}], "=", 
   RowBox[{
    RowBox[{"cos", 
     RowBox[{"(", 
      SubscriptBox["z", "1"], ")"}], "cos", 
     RowBox[{"(", 
      SubscriptBox["z", "2"], ")"}]}], "-", 
    RowBox[{"sin", " ", 
     SubscriptBox["z", "1"], " ", "sin", " ", 
     SubscriptBox["z", "2"]}]}]}]]],
 " by making use of Identities ",
 StyleBox["(5-32)",
  FontColor->RGBColor[0, 0, 1]],
 " - ",
 StyleBox["(5-35)",
  FontColor->RGBColor[0, 0, 1]],
 ":  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"     ", 
   RowBox[{
    RowBox[{"cos", " ", 
     SubscriptBox["z", "1"], " ", "cos", " ", 
     SubscriptBox["z", "2"]}], " ", "=", " ", 
    RowBox[{
     FractionBox["1", "4"], " ", 
     RowBox[{"(", " ", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["z", "1"], "+", 
           SubscriptBox["z", "2"]}], ")"}]}]], "+", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["z", "1"], "-", 
           SubscriptBox["z", "2"]}], ")"}]}]], "+", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["z", "2"], "-", 
           SubscriptBox["z", "1"]}], ")"}]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["z", "1"], "+", 
           SubscriptBox["z", "2"]}], ")"}]}]]}], ")"}]}]}]}]]],
 ",   and  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"-", "  ", "sin"}], " ", 
    SubscriptBox["z", "1"], " ", "sin", " ", 
    SubscriptBox["z", "2"]}], " ", "=", " ", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["z", "1"], "+", 
          SubscriptBox["z", "2"]}], ")"}]}]], "-", "  ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["z", "1"], "-", 
          SubscriptBox["z", "2"]}], ")"}]}]], "-", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["z", "2"], "-", 
          SubscriptBox["z", "1"]}], ")"}]}]], "+", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["z", "1"], "+", 
          SubscriptBox["z", "2"]}], ")"}]}]]}], ")"}]}]}]]],
 " \n\nAdding these expressions gives\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"cos", " ", 
     SubscriptBox["z", "1"], " ", "cos", " ", 
     SubscriptBox["z", "2"]}], " ", "-", " ", 
    RowBox[{"sin", " ", 
     SubscriptBox["z", "1"], " ", "sin", " ", 
     SubscriptBox["z", "2"]}]}], "=", 
   RowBox[{
    RowBox[{
     FractionBox["1", "2"], 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["z", "1"], "+", 
           SubscriptBox["z", "2"]}], ")"}]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["z", "1"], "+", 
           SubscriptBox["z", "2"]}], ")"}]}]]}], ")"}]}], " ", "=", " ", 
    RowBox[{"cos", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["z", "1"], "+", 
       SubscriptBox["z", "2"]}], ")"}]}]}]}]]],
 "\n\nwhich is what we wanted."
}], "Text"],

Cell[TextData[{
 StyleBox["Demonstration.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Establish the identity  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"cos", 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["z", "1"], "+", 
      SubscriptBox["z", "2"]}], ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"cos", 
     RowBox[{"(", 
      SubscriptBox["z", "1"], ")"}], "cos", 
     RowBox[{"(", 
      SubscriptBox["z", "2"], ")"}]}], "  ", "-", "  ", 
    RowBox[{"sin", 
     RowBox[{"(", 
      SubscriptBox["z", "1"], ")"}], "sin", 
     RowBox[{"(", 
      SubscriptBox["z", "2"], ")"}]}]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration Method (i).",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s \"ComplexExpand\" procedure and the identities ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Cos", "[", "z", "]"}], " ", "=", 
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "z"}]], "+", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", " ", "\[ImaginaryI]"}], " ", "z"}]]}], "2"], "  ", 
     StyleBox["and",
      FontFamily->"Times New Roman"], "  ", 
     RowBox[{"Sin", "[", "z", "]"}]}], " ", "=", 
    FractionBox[
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", "  ", "z"}]], "-", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", " ", "\[ImaginaryI]"}], " ", "z"}]]}], 
     RowBox[{"2", "\[ImaginaryI]"}]]}]}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", 
     RowBox[{"w", ",", "x", ",", "y", ",", "z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "1"], " ", "=", " ", 
     RowBox[{
      SubscriptBox["x", "1"], " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["y", "1"]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "2"], " ", "=", " ", 
     RowBox[{
      SubscriptBox["x", "2"], " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["y", "2"]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["w", "1"], " ", "=", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{
       SubscriptBox["z", "1"], " ", "+", " ", 
       SubscriptBox["z", "2"]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["w", "2"], " ", "=", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"Cos", "[", 
        SubscriptBox["z", "1"], "]"}], 
       RowBox[{"Cos", "[", 
        SubscriptBox["z", "2"], "]"}]}], " ", "-", " ", 
      RowBox[{
       RowBox[{"Sin", "[", 
        SubscriptBox["z", "1"], "]"}], 
       RowBox[{"Sin", "[", 
        SubscriptBox["z", "2"], "]"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["w", "3"], " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{
       SubscriptBox["w", "1"], ",", 
       RowBox[{
        RowBox[{"Cos", "[", "z_", "]"}], " ", "\[Rule]", 
        FractionBox[
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"\[ImaginaryI]", " ", "z"}]], "+", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", " ", "\[ImaginaryI]"}], " ", "z"}]]}], "2"]}]}], 
      "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["w", "4"], " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{
       SubscriptBox["w", "2"], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"Cos", "[", "z_", "]"}], " ", "\[Rule]", 
          FractionBox[
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"\[ImaginaryI]", " ", "z"}]], "+", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{
              RowBox[{"-", " ", "\[ImaginaryI]"}], "  ", "z"}]]}], "2"]}], 
         ",", "\n", "                           ", 
         RowBox[{
          RowBox[{"Sin", "[", "z_", "]"}], " ", "\[Rule]", 
          FractionBox[
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"\[ImaginaryI]", "  ", "z"}]], "-", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{
              RowBox[{"-", " ", "\[ImaginaryI]"}], " ", "z"}]]}], 
           RowBox[{"2", "\[ImaginaryI]"}]]}]}], "}"}]}], "]"}]}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["w", "5"], " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      SubscriptBox["w", "3"], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["w", "6"], " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      SubscriptBox["w", "4"], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["w", "7"], " ", "=", " ", 
     RowBox[{"Apart", "[", 
      SubscriptBox["w", "5"], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["w", "8"], " ", "=", " ", 
     RowBox[{"Apart", "[", 
      SubscriptBox["w", "6"], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["w", "9"], " ", "=", " ", 
     RowBox[{"Expand", "[", 
      RowBox[{
       SubscriptBox["w", "7"], ",", 
       RowBox[{"Trig", "\[Rule]", "True"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["w", "0"], " ", "=", " ", 
     RowBox[{"Expand", "[", 
      RowBox[{
       SubscriptBox["w", "8"], ",", 
       RowBox[{"Trig", "\[Rule]", "True"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(w\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["w", "1"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(w\), \(2\)]\) = \>\"", ",", 
      SubscriptBox["w", "2"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(w\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["w", "3"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(w\), \(2\)]\) = \>\"", ",", 
      SubscriptBox["w", "4"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(w\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["w", "5"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(w\), \(2\)]\) = \>\"", ",", 
      SubscriptBox["w", "6"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(w\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["w", "7"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(w\), \(2\)]\) = \>\"", ",", 
      SubscriptBox["w", "8"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(w\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["w", "9"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(w\), \(2\)]\) = \>\"", ",", 
      SubscriptBox["w", "0"]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Is \!\(\*SubscriptBox[\(w\), \(1\)]\) = \!\(\*SubscriptBox[\(w\), \
\(2\)]\) ?  \>\"", ",", 
      RowBox[{
       RowBox[{"Expand", "[", 
        RowBox[{
         SubscriptBox["w", "9"], ",", 
         RowBox[{"Trig", "\[Rule]", "True"}]}], "]"}], " ", "\[Equal]", "  ", 
       
       RowBox[{"Expand", "[", 
        RowBox[{
         SubscriptBox["w", "0"], ",", 
         RowBox[{"Trig", "\[Rule]", "True"}]}], "]"}]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399286754921875*^9}],

Cell[TextData[{
 "\nTherefore,  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"cos", 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["z", "1"], "+", 
      SubscriptBox["z", "2"]}], ")"}]}], "=", 
   RowBox[{
    RowBox[{"cos", 
     RowBox[{"(", 
      SubscriptBox["z", "1"], ")"}], "cos", 
     RowBox[{"(", 
      SubscriptBox["z", "2"], ")"}]}], " ", "-", " ", 
    RowBox[{"sin", 
     RowBox[{"(", 
      SubscriptBox["z", "1"], ")"}], "sin", 
     RowBox[{"(", 
      SubscriptBox["z", "2"], ")"}]}]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration Method (ii).",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s \"ComplexExpand\" procedure."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", 
     RowBox[{"v", ",", "w", ",", "x", ",", "y", ",", "z"}], "]"}], ";"}], " ",
    "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["v", "1"], " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"Cos", "[", 
       RowBox[{
        SubscriptBox["x", "1"], "+", 
        RowBox[{"\[ImaginaryI]", " ", 
         SubscriptBox["y", "1"]}], " ", "+", " ", 
        SubscriptBox["x", "2"], "+", 
        RowBox[{"\[ImaginaryI]", " ", 
         SubscriptBox["y", "2"]}]}], "]"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["v", "2"], " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"Cos", "[", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["x", "1"], "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          SubscriptBox["y", "1"]}]}], ")"}], "]"}], "]"}]}], ";"}], " ", "\n",
    
   RowBox[{
    RowBox[{
     SubscriptBox["v", "3"], " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"Cos", "[", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["x", "2"], "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          SubscriptBox["y", "2"]}]}], ")"}], "]"}], "]"}]}], ";"}], " ", "\n",
    
   RowBox[{
    RowBox[{
     SubscriptBox["v", "4"], " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"Sin", "[", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["x", "1"], "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          SubscriptBox["y", "1"]}]}], ")"}], "]"}], "]"}]}], ";"}], " ", "\n",
    
   RowBox[{
    RowBox[{
     SubscriptBox["v", "5"], " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"Sin", "[", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["x", "2"], "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          SubscriptBox["y", "2"]}]}], ")"}], "]"}], "]"}]}], ";"}], " ", "\n",
    
   RowBox[{
    RowBox[{
     SubscriptBox["v", "6"], " ", "=", " ", 
     RowBox[{
      RowBox[{
       SubscriptBox["v", "2"], " ", 
       SubscriptBox["v", "3"]}], " ", "-", " ", 
      RowBox[{
       SubscriptBox["v", "4"], " ", 
       SubscriptBox["v", "5"]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<\!\(\*SubscriptBox[\(w\), \(1\)]\) = Cos[\!\(\*SubscriptBox[\(z\), \
\(1\)]\)+\!\(\*SubscriptBox[\(z\), \(2\)]\)]\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<\!\(\*SubscriptBox[\(w\), \(2\)]\) = Cos[\!\(\*SubscriptBox[\(z\), \
\(1\)]\)]Cos[\!\(\*SubscriptBox[\(z\), \
\(2\)]\)]-Sin[\!\(\*SubscriptBox[\(z\), \
\(1\)]\)]Sin[\!\(\*SubscriptBox[\(z\), \(2\)]\)]\>\"", "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(w\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["v", "1"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(w\), \(2\)]\) = \>\"", ",", 
      SubscriptBox["v", "6"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["v", "7"], " ", "=", " ", 
     RowBox[{"Expand", "[", 
      RowBox[{
       SubscriptBox["v", "6"], ",", 
       RowBox[{"Trig", "\[Rule]", "True"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(w\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["v", "1"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(w\), \(2\)]\) = \>\"", ",", 
      SubscriptBox["v", "7"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["v", "1"], " ", "=", " ", 
     RowBox[{"Expand", "[", 
      RowBox[{
       SubscriptBox["v", "1"], ",", 
       RowBox[{"Trig", "\[Rule]", "True"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(w\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["v", "1"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(w\), \(2\)]\) = \>\"", ",", 
      SubscriptBox["v", "7"]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Is \!\(\*SubscriptBox[\(w\), \(1\)]\) = \!\(\*SubscriptBox[\(w\), \
\(2\)]\) ?  \>\"", ",", 
      RowBox[{
       SubscriptBox["v", "1"], " ", "\[Equal]", " ", 
       SubscriptBox["v", "7"]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39928676625*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "Therefore,  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"cos", 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["z", "1"], "+", 
      SubscriptBox["z", "2"]}], ")"}]}], "=", 
   RowBox[{
    RowBox[{"cos", 
     RowBox[{"(", 
      SubscriptBox["z", "1"], ")"}], "cos", 
     RowBox[{"(", 
      SubscriptBox["z", "2"], ")"}]}], " ", "-", " ", 
    RowBox[{"sin", 
     RowBox[{"(", 
      SubscriptBox["z", "1"], ")"}], "sin", 
     RowBox[{"(", 
      SubscriptBox["z", "2"], ")"}]}]}]}]]],
 ".  "
}], "Text"]
}, Closed]],

Cell[TextData[{
 "\tA solution to the equation  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", "0"}]]],
 "  is called a zero of the given function  ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", "z", ")"}]}]]],
 ".  As we now show, the zeros of the sine and cosine function are exactly \
where you might expect them to be.  We have  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"sin", " ", "z"}], "=", "0"}]]],
 "  iff  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{"n", " ", "\[Pi]"}]}]]],
 ",  where ",
 StyleBox["n",
  FontFamily->"Courier New"],
 " is any integer, and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"cos", " ", "z"}], "=", "0"}]]],
 "  iff  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"n", "+", 
      FractionBox["1", "2"]}], ")"}], " ", "\[Pi]"}]}]]],
 ",  where ",
 StyleBox["n",
  FontFamily->"Courier New"],
 " is any integer.\n\n\tWe show the result for ",
 Cell[BoxData[
  RowBox[{"cos", " ", "z"}]]],
 " and leave the result for ",
 Cell[BoxData[
  RowBox[{"sin", " ", "z"}]]],
 " as an exercise.  When we use Identity ",
 StyleBox["(5-35)",
  FontColor->RGBColor[0, 0, 1]],
 ",  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"cos", " ", "z"}], "=", "0"}]]],
 "  iff  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"0", " ", "=", " ", 
   RowBox[{
    RowBox[{"cos", " ", "x", " ", "cosh", " ", "y"}], " ", "-", " ", 
    RowBox[{
    "\[ImaginaryI]", " ", "sin", " ", "x", " ", "sinh", " ", "y"}]}]}]]],
 ".  \n\nEquating the real and imaginary parts of this equation gives \n\n\t\t\
\t",
 Cell[BoxData[
  RowBox[{"0", "=", 
   RowBox[{"cos", " ", "x", " ", "cosh", " ", "y"}]}]]],
 "   and   ",
 Cell[BoxData[
  RowBox[{"0", "=", 
   RowBox[{"sin", " ", "x", " ", "sinh", " ", "y"}]}]]],
 ".  \n\nThe real-valued function ",
 StyleBox["cosh y",
  FontFamily->"Courier New"],
 " is never zero, so the equation  ",
 Cell[BoxData[
  RowBox[{"0", "=", 
   RowBox[{"cos", " ", "x", " ", "cosh", " ", "y"}]}]]],
 "  implies that  ",
 Cell[BoxData[
  RowBox[{"0", "=", 
   RowBox[{"cos", " ", "x"}]}]]],
 ",  from which we obtain ",
 Cell[BoxData[
  RowBox[{"x", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"n", "+", 
      FractionBox["1", "2"]}], ")"}], " ", "\[Pi]"}]}]]],
 " for any integer ",
 StyleBox["n",
  FontFamily->"Courier New"],
 " .  Using the values for  ",
 Cell[BoxData[
  RowBox[{"z", " ", "=", " ", 
   RowBox[{
    RowBox[{"x", "+", 
     RowBox[{"\[ImaginaryI]", " ", "y"}]}], " ", "=", " ", 
    RowBox[{"x", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"n", "+", 
         FractionBox["1", "2"]}], ")"}], " ", "\[Pi]"}], "+", 
      RowBox[{"\[ImaginaryI]", " ", "y"}]}]}]}]}]]],
 "  in the equation  ",
 Cell[BoxData[
  RowBox[{"0", "=", 
   RowBox[{"sin", " ", "x", " ", "sinh", " ", "y"}]}]]],
 "  yields  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"0", "=", 
   RowBox[{
    RowBox[{"sin", 
     RowBox[{
      StyleBox["(",
       FontSize->16], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"n", "+", 
         FractionBox["1", "2"]}], ")"}], " ", "\[Pi]"}], ")"}], " ", "sinh", 
     " ", "y"}], " ", "=", " ", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], "n"], "sinh", " ", "y"}]}]}]]],
 ".  \n\nwhich implies that  ",
 Cell[BoxData[
  RowBox[{"y", "=", "0"}]]],
 ",  so the only zeros for ",
 Cell[BoxData[
  RowBox[{"cos", " ", "z"}]]],
 " are the values ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"n", "+", 
      FractionBox["1", "2"]}], ")"}], "\[Pi]"}]}]]],
 "  for  ",
 StyleBox["n",
  FontFamily->"Courier New"],
 "  an integer. "
}], "Text",
 CellChangeTimes->{{3.399286278453125*^9, 3.399286280375*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 "First, use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s \"Solve\" procedure to find some of the solutions to  cos(z) = 0.  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", 
     RowBox[{"x", ",", "y", ",", "z"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"cosZ", ",", "eq1", ",", "eq2"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"cosZ", " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"Cos", "[", 
       RowBox[{"x", " ", "+", " ", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eq1", " ", "=", " ", 
     RowBox[{
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"Re", "[", "cosZ", "]"}], "]"}], " ", "\[Equal]", " ", "0"}]}],
     ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"eq2", " ", "=", " ", 
     RowBox[{
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"Im", "[", "cosZ", "]"}], "]"}], " ", "\[Equal]", " ", "0"}]}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"Cos", "[", 
       RowBox[{"x", " ", "+", " ", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], " ", "\[Equal]", " ", 
      "0"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"cosZ", " ", "\[Equal]", " ", "0"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "eq1", " ", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "eq2", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"eq1", ",", "eq2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "y"}], "}"}]}], "]"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399286776046875*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Remark.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 " It is assumed that both  x  and  y  are real numbers. Hence, the only two \
valid solution in the above list are  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"y", "\[Rule]", "0"}], ",", 
     RowBox[{"x", "\[Rule]", 
      RowBox[{"-", 
       FractionBox["\[Pi]", "2"]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"y", "\[Rule]", "0"}], ",", 
     RowBox[{"x", "\[Rule]", 
      FractionBox["\[Pi]", "2"]}]}], "}"}]}]]],
 ".  \nThis is another way to solve the equation  cos(z) = 0."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", "z", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", "solset", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"solset", "=", 
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Cos", "[", "z", "]"}], "\[Equal]", "0"}], ",", "z"}], 
      "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "solset", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The solutions are to cos(z) = 0 are:\>\"", "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<2 n \[Pi] + \>\"", ",", " ", 
      SubscriptBox["solset", 
       RowBox[{"\[LeftDoubleBracket]", 
        RowBox[{"2", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]]}], 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<2 n \[Pi] \>\"", ",", 
      SubscriptBox["solset", 
       RowBox[{"\[LeftDoubleBracket]", 
        RowBox[{"1", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]]}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399286782203125*^9}],

Cell["We can also list some of the solutions.", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", "n", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"n", "=", "0"}], ",", 
      RowBox[{"n", "\[LessEqual]", "5"}], ",", 
      RowBox[{"n", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{
       "\"\<Cos[\!\(\*FractionBox[\(\[Pi]\), \(2\)]\)+ \>\"", ",", "n", ",", 
        "\"\< \[Pi]] = \>\"", ",", 
        RowBox[{"Cos", "[", 
         RowBox[{
          FractionBox["\[Pi]", "2"], "+", 
          RowBox[{"n", " ", "\[Pi]"}]}], "]"}]}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399286788234375*^9}],

Cell["Or by showing that the system of equations is satisfied.", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Cos[\!\(\*FractionBox[\(\[Pi]\), \(2\)]\)]Cosh[0] = \>\"", ",", 
      RowBox[{
       RowBox[{"Cos", "[", 
        FractionBox["\[Pi]", "2"], "]"}], 
       RowBox[{"Cosh", "[", "0", "]"}]}], ",", "\n", 
      "\"\<,   -Sin[\!\(\*FractionBox[\(\[Pi]\), \(2\)]\)]Sinh[0] = \>\"", 
      ",", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"Sin", "[", 
         FractionBox["\[Pi]", "2"], "]"}]}], 
       RowBox[{"Sinh", "[", "0", "]"}]}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Cos[\!\(\*FractionBox[\(\[Pi]\), \(2\)]\)+\[Pi]]Cosh[0] = \>\"", 
      ",", 
      RowBox[{
       RowBox[{"Cos", "[", 
        RowBox[{
         FractionBox["\[Pi]", "2"], "+", "\[Pi]"}], "]"}], 
       RowBox[{"Cosh", "[", "0", "]"}]}], ",", "\n", 
      "\"\<,   -Sin[\!\(\*FractionBox[\(\[Pi]\), \(2\)]\)+\[Pi]]Sinh[0] = \
\>\"", ",", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"Sin", "[", 
         RowBox[{
          FractionBox["\[Pi]", "2"], "+", "\[Pi]"}], "]"}]}], 
       RowBox[{"Sinh", "[", "0", "]"}]}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Cos[\!\(\*FractionBox[\(\[Pi]\), \(2\)]\)+2\[Pi]]Cosh[0] = \>\"", 
      ",", 
      RowBox[{
       RowBox[{"Cos", "[", 
        RowBox[{
         FractionBox["\[Pi]", "2"], "+", 
         RowBox[{"2", "\[Pi]"}]}], "]"}], 
       RowBox[{"Cosh", "[", "0", "]"}]}], ",", "\n", 
      "\"\<,   -Sin[\!\(\*FractionBox[\(\[Pi]\), \(2\)]\)+2\[Pi]]Sinh[0] = \>\
\"", ",", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"Sin", "[", 
         RowBox[{
          FractionBox["\[Pi]", "2"], "+", 
          RowBox[{"2", "\[Pi]"}]}], "]"}]}], 
       RowBox[{"Sinh", "[", "0", "]"}]}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Cos[\!\(\*FractionBox[\(\[Pi]\), \(2\)]\)+3\[Pi]]Cosh[0] = \>\"", 
      ",", 
      RowBox[{
       RowBox[{"Cos", "[", 
        RowBox[{
         FractionBox["\[Pi]", "2"], "+", 
         RowBox[{"3", "\[Pi]"}]}], "]"}], 
       RowBox[{"Cosh", "[", "0", "]"}]}], ",", "\n", 
      "\"\<,   -Sin[\!\(\*FractionBox[\(\[Pi]\), \(2\)]\)+3\[Pi]]Sinh[0] = \>\
\"", ",", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"Sin", "[", 
         RowBox[{
          FractionBox["\[Pi]", "2"], "+", 
          RowBox[{"3", "\[Pi]"}]}], "]"}]}], 
       RowBox[{"Sinh", "[", "0", "]"}]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399286793625*^9}],

Cell[TextData[{
 "Finally, we could just let ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " do it. "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", "n", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"Print", "[", 
    RowBox[{
    "\"\<Cos[(n+\!\(\*FractionBox[\(1\), \(2\)]\))\[Pi]] = \>\"", ",", 
     RowBox[{"Cos", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"n", "+", 
         FractionBox["1", "2"]}], ")"}], "\[Pi]"}], "]"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Print", "[", 
    RowBox[{
    "\"\<Cos[(n+\!\(\*FractionBox[\(1\), \(2\)]\))\[Pi]] = \>\"", ",", 
     RowBox[{"Simplify", "[", 
      RowBox[{
       RowBox[{"Cos", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"n", "+", 
           FractionBox["1", "2"]}], ")"}], "\[Pi]"}], "]"}], ",", 
       RowBox[{"Element", "[", 
        RowBox[{"n", ",", "Integers"}], "]"}]}], "]"}]}], "]"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399286798390625*^9, 3.399286799734375*^9}, {
  3.3998271601716275`*^9, 3.3998271612341275`*^9}}]
}, Closed]],

Cell[TextData[{
 "\tWhat does the mapping ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{"sin", " ", "z"}]}]]],
 " look like?  We can get a graph of the mapping  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{"sin", " ", "z"}], "=", 
    RowBox[{
     RowBox[{"sin", 
      RowBox[{"(", 
       RowBox[{"x", "+", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "=", 
     RowBox[{
      RowBox[{"sin", " ", "x", " ", "cosh", " ", "y"}], "+", 
      RowBox[{
      "\[ImaginaryI]", " ", "cos", " ", "x", " ", "sinh", " ", 
       "y"}]}]}]}]}]]],
 "  by using parametric methods.  Let's consider the vertical line segments \
in the ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " plane obtained by successfully setting  ",
 Cell[BoxData[
  RowBox[{"x", "=", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["\[Pi]", "2"]}], "+", 
    FractionBox[
     RowBox[{"k", " ", "\[Pi]"}], "12"]}]}]]],
 "  for ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"k", "=", "0"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "1", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   StyleBox["...",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "12"}]]],
 ",  and for each ",
 StyleBox["x",
  FontFamily->"Courier New"],
 " value and letting ",
 StyleBox["y",
  FontFamily->"Courier New"],
 " vary continuously, ",
 Cell[BoxData[
  RowBox[{"3", "\[LessEqual]", "y", "\[LessEqual]", "3"}]]],
 ".  In the exercises we ask you to show that the images of these vertical \
segments are hyperbolas in the uv plane, as Figure 5.7 illustrates.  In \
Chapter 9, we give a more detailed analysis of the mapping  ",
 Cell[BoxData[
  RowBox[{"w", " ", "=", " ", 
   RowBox[{"sin", " ", "z"}]}]]],
 ". "
}], "Text",
 CellChangeTimes->{3.399286255859375*^9}],

Cell[TextData[{
 "\t",
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.285714 0.309017 0.103006 [
[.0512 .29652 -17.4375 -20.875 ]
[.0512 .29652 17.4375 0 ]
[.9488 .29652 -12.8125 -20.875 ]
[.9488 .29652 12.8125 0 ]
[1.025 .30902 0 -6.5 ]
[1.025 .30902 9 6.5 ]
[.4875 0 -16.375 -6.5 ]
[.4875 0 0 6.5 ]
[.4875 .10301 -16.375 -6.5 ]
[.4875 .10301 0 6.5 ]
[.4875 .20601 -16.375 -6.5 ]
[.4875 .20601 0 6.5 ]
[.4875 .41202 -9.5 -6.5 ]
[.4875 .41202 0 6.5 ]
[.4875 .51503 -9.5 -6.5 ]
[.4875 .51503 0 6.5 ]
[.4875 .61803 -9.5 -6.5 ]
[.4875 .61803 0 6.5 ]
[.5 .64303 -4.34375 0 ]
[.5 .64303 4.34375 13 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.0512 .30902 m
.0512 .31527 L
s
gsave
.0512 .29652 -78.4375 -24.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.875 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 16.688 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
%%BeginResource: font Helvetica-MISO
%%BeginFont: Helvetica-MISO
/Helvetica /Helvetica-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
65.563 9.438 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.438 9.438 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
64.438 16.688 moveto
(\\200\\200\\200\\200) show
69.938 16.688 moveto
(\\200\\200\\200\\200) show
75.438 16.688 moveto
(\\200) show
77.063 16.688 moveto
(\\200) show
68.813 23.875 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.875 16.688 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.9488 .30902 m
.9488 .31527 L
s
gsave
.9488 .29652 -73.8125 -24.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.875 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 16.688 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
%%BeginResource: font Helvetica-MISO
%%BeginFont: Helvetica-MISO
/Helvetica /Helvetica-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
76.750 9.438 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
75.438 16.688 moveto
(\\200\\200\\200\\200) show
80.938 16.688 moveto
(\\200) show
81.563 16.688 moveto
(\\200) show
76.563 23.875 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
84.625 16.688 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
68.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
gsave
.4875 0 -77.375 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.875 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
gsave
.4875 .10301 -77.375 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.875 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .20601 m
.50625 .20601 L
s
gsave
.4875 .20601 -77.375 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.875 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .41202 m
.50625 .41202 L
s
gsave
.4875 .41202 -70.5 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .51503 m
.50625 .51503 L
s
gsave
.4875 .51503 -70.5 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .61803 m
.50625 .61803 L
s
gsave
.4875 .61803 -70.5 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -65.3438 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
67.688 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.01429 .30902 m
.05369 .30902 L
.09667 .30902 L
.13703 .30902 L
.17585 .30902 L
.21717 .30902 L
.25694 .30902 L
.29922 .30902 L
.33995 .30902 L
.37913 .30902 L
.42081 .30902 L
.46095 .30902 L
.49954 .30902 L
.54064 .30902 L
.58018 .30902 L
.62223 .30902 L
.66273 .30902 L
.70169 .30902 L
.74315 .30902 L
.78306 .30902 L
.82548 .30902 L
.86634 .30902 L
.90567 .30902 L
.94749 .30902 L
.98571 .30902 L
s
.5 .165 .165 r
.0512 0 m
.0512 .61803 L
s
1 0 1 r
.126 0 m
.126 .61803 L
s
0 0 1 r
.2008 0 m
.2008 .61803 L
s
0 1 1 r
.2756 0 m
.2756 .61803 L
s
0 1 0 r
.3504 0 m
.3504 .61803 L
s
1 0 0 r
.4252 0 m
.4252 .61803 L
s
.5 .165 .165 r
.5 0 m
.5 .61803 L
s
1 0 0 r
.5748 0 m
.5748 .61803 L
s
0 1 0 r
.6496 0 m
.6496 .61803 L
s
0 1 1 r
.7244 0 m
.7244 .61803 L
s
0 0 1 r
.7992 0 m
.7992 .61803 L
s
1 0 1 r
.874 0 m
.874 .61803 L
s
.5 .165 .165 r
.9488 0 m
.9488 .61803 L
s
.009 w
.5 0 m
.5 .61803 L
s
.012 w
.0512 0 m
.0512 .61803 L
s
.9488 0 m
.9488 .61803 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\
eJztnc9u1DAQh73JbgEJ2kL5c0BqtyekPgiceIhVQWolEKj0vpW4ANf2hNqH
4AnDeux4Xe9sWoGgUeazdmNrnMT+fhk7yaTpvp2dHr3/ODs9PpxN35zMPh8d
H36Zvv50sjDVI+dGU+fcr6nz5WZRjItm8Wn2/cJbbi6f+az2m14Fw1yyiQt7
a9LXp8tQeumzys0PDh6LofZ7TCtuR5vLbFutrdFsbmXb0FxIlV9spJ0uV65T
N4qKzWwvK73KWuvsldL7prRJ46/+pyitbSO01ipTtDtY7PudbmBAgLEs9dE5
sSSEwNbmBsAmsMACCyywwAILLLDAAgsssMACC2xvYCVSNbEZl5L9LW0mIlRt
kqD0WFFh6QZFhYFw/T1Fj7EFr2htBO7jGMgFkG6YnCDFEUxMi63N1LkfWGCB
BRZYYIEFFlhggQUWWGCB7Tms+VilWQHaVKWg5FoVigpC+MMXoHQIcyHc3rxz
8cRn8ihBc0AbQ6BKGkyDKDtK57QHK/9Onru6SqgV8vh219NbHrHhiaI9gY6e
8kyp0p5FDk8U7Zy+F0R5rlRVJkTRXi3cDaLIRLvmoa2NYVR1KJBPvHW6ZBy8
JHXijZMs96JDhZXmH4VbooETP/CUuwaPMbDADgBWv36zMHNV68jj9ckLycap
PuaD16W8LcyuWKRRUaRGnFKcMJImpSTO0GDS4fPxNDahhniJiLEX2G2cUnYK
J2i/Pm1ZEqIMn/m0bUkALVQWPUCyh9k0EE8nLsgUpAo2l9m2Wluj2dzKtplp
ocJqa6tb5MbO1pReNaVNWhPK8g2G0KQhX2BWMHx7ASywwAILLLDAAgsssMAC
CyywwAILrAHYPv39LwL0T4CigpdChi8AL4WE1qxhm3d8Uyd+YIEFFlhggQUW
WGCBBRZYYIEFtuew/BBDspkK0Wn/14DfYLiObSpkyW8wxDGQCyDdMDk3iiOY
mhFNnfaBBRZYYIEFFlhggQUWWGCBBRbYnsMaDdAQoIu27lBtUXHHsft3oXTN
Vz+Uq39VgH6GqnnHQb8MpbM0HK6CQdbYv335u9L8Raj6oVSd31hV7tCni7+p
+tahwvmfQbvRbw0TYpM=\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1, -3, 0, 0}}],
 StyleBox["     ",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.05 0.309017 0.0309017 [
[0 .29652 -10.9375 -13 ]
[0 .29652 10.9375 0 ]
[.25 .29652 -8.1875 -13 ]
[.25 .29652 8.1875 0 ]
[.75 .29652 -4.75 -13 ]
[.75 .29652 4.75 0 ]
[1 .29652 -7.5 -13 ]
[1 .29652 7.5 0 ]
[1.025 .30902 0 -6.5 ]
[1.025 .30902 9.5 6.5 ]
[.4875 0 -21.875 -6.5 ]
[.4875 0 0 6.5 ]
[.4875 .15451 -16.375 -6.5 ]
[.4875 .15451 0 6.5 ]
[.4875 .46353 -9.5 -6.5 ]
[.4875 .46353 0 6.5 ]
[.4875 .61803 -15 -6.5 ]
[.4875 .61803 0 6.5 ]
[.5 .64303 -4.4375 0 ]
[.5 .64303 4.4375 13 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
gsave
0 .29652 -71.9375 -17 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.875 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.25 .30902 m
.25 .31527 L
s
gsave
.25 .29652 -69.1875 -17 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.875 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.75 .30902 m
.75 .31527 L
s
gsave
.75 .29652 -65.75 -17 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
1 .30902 m
1 .31527 L
s
gsave
1 .29652 -68.5 -17 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(u) show
68.500 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
gsave
.4875 0 -82.875 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.875 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.5 .15451 m
.50625 .15451 L
s
gsave
.4875 .15451 -77.375 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.875 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.5 .46353 m
.50625 .46353 L
s
gsave
.4875 .46353 -70.5 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.5 .61803 m
.50625 .61803 L
s
gsave
.4875 .61803 -76 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -65.4375 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(v) show
67.875 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 1 r
.5 Mabswid
0 .22661 m
.019 .22977 L
.14982 .25158 L
.24966 .26834 L
.31801 .27996 L
.3692 .28889 L
.40331 .29515 L
.42573 .29967 L
.434 .30157 L
.44107 .30342 L
.44604 .30503 L
.44918 .3064 L
.45033 .3071 L
.45074 .30741 L
.4511 .30774 L
.45126 .30793 L
.45138 .30809 L
.45149 .30826 L
.45157 .30842 L
.45164 .3086 L
.45166 .3087 L
.45168 .30874 L
.45169 .3088 L
.4517 .30888 L
.4517 .30897 L
.4517 .30902 L
.4517 .30906 L
.4517 .30915 L
.45169 .30923 L
.45167 .30931 L
.45165 .30939 L
.45163 .30946 L
.45156 .30963 L
.45147 .3098 L
.45124 .31013 L
.45088 .3105 L
.45001 .31115 L
.44891 .31178 L
.44527 .31328 L
.44056 .31475 L
.42533 .31845 L
.40267 .32301 L
.36724 .3295 L
.31822 .33804 L
.25222 .34926 L
.15392 .36577 L
.0216 .38784 L
s
.0216 .38784 m
0 .39143 L
s
0 0 1 r
0 .13129 m
.06875 .15591 L
.18604 .19806 L
.27555 .23043 L
.33683 .25288 L
.38273 .27013 L
.41331 .28222 L
.43342 .29097 L
.44082 .29463 L
.44716 .29821 L
.45162 .30132 L
.45444 .30396 L
.45547 .3053 L
.45583 .30591 L
.45615 .30656 L
.4563 .30691 L
.45641 .30724 L
.45651 .30756 L
.45658 .30786 L
.45664 .30821 L
.45666 .3084 L
.45667 .30849 L
.45668 .30859 L
.45669 .30876 L
.4567 .30892 L
.4567 .30901 L
.4567 .30911 L
.45669 .30928 L
.45668 .30942 L
.45667 .30958 L
.45665 .30973 L
.45663 .30987 L
.45657 .31019 L
.45649 .31053 L
.45628 .31117 L
.45596 .31188 L
.45518 .31315 L
.45419 .31435 L
.45093 .31725 L
.44671 .3201 L
.43305 .32724 L
.41273 .33605 L
.38097 .34858 L
.33702 .36508 L
.27785 .38677 L
.18971 .41865 L
.07108 .46128 L
s
.07108 .46128 m
0 .48674 L
s
0 1 1 r
0 .00078 m
.00964 .00675 L
.14789 .0925 L
.24365 .1521 L
.31674 .19788 L
.36678 .22963 L
.40425 .25402 L
.42922 .27112 L
.44563 .28349 L
.45168 .28866 L
.45686 .29374 L
.4605 .29813 L
.4628 .30187 L
.46364 .30377 L
.46394 .30463 L
.4642 .30554 L
.46432 .30604 L
.46441 .3065 L
.46449 .30696 L
.46455 .30738 L
.4646 .30788 L
.46462 .30814 L
.46462 .30827 L
.46463 .30841 L
.46464 .30865 L
.46464 .30888 L
.46464 .30901 L
.46464 .30914 L
.46464 .30938 L
.46463 .30959 L
.46462 .30982 L
.46461 .31003 L
.46459 .31023 L
.46454 .31068 L
.46448 .31116 L
.4643 .31207 L
.46404 .31306 L
.4634 .31486 L
.4626 .31656 L
.45993 .32067 L
.45649 .32469 L
.44533 .33478 L
.42875 .34725 L
.40281 .36497 L
.36693 .3883 L
.31861 .41897 L
.24665 .46406 L
.14979 .52435 L
.00528 .61399 L
s
.00528 .61399 m
0 .61726 L
s
0 1 0 r
.21022 0 m
.25102 .04384 L
.31873 .11683 L
.37041 .17291 L
.4058 .21179 L
.43229 .24166 L
.44995 .2626 L
.46156 .27776 L
.46584 .28409 L
.46949 .2903 L
.47207 .29569 L
.4737 .30026 L
.47429 .30259 L
.4745 .30364 L
.47469 .30476 L
.47477 .30537 L
.47483 .30593 L
.47489 .3065 L
.47493 .30702 L
.47497 .30762 L
.47498 .30794 L
.47499 .3081 L
.47499 .30828 L
.475 .30857 L
.475 .30885 L
.475 .30901 L
.475 .30917 L
.475 .30947 L
.47499 .30972 L
.47498 .31 L
.47497 .31026 L
.47496 .3105 L
.47493 .31106 L
.47488 .31164 L
.47476 .31275 L
.47458 .31397 L
.47412 .31617 L
.47355 .31826 L
.47167 .32328 L
.46923 .32821 L
.46135 .34058 L
.44962 .35584 L
.43128 .37754 L
.4059 .40612 L
.37174 .44368 L
.32086 .49891 L
.25236 .57275 L
s
.25236 .57275 m
.21021 .61803 L
s
1 0 0 r
.36539 0 m
.37112 .01325 L
.40617 .09466 L
.43292 .1572 L
.45124 .20058 L
.46495 .23389 L
.47409 .25725 L
.4801 .27415 L
.48231 .28121 L
.48421 .28814 L
.48554 .29415 L
.48638 .29925 L
.48669 .30185 L
.4868 .30302 L
.4869 .30426 L
.48694 .30495 L
.48697 .30557 L
.487 .30621 L
.48702 .30679 L
.48704 .30746 L
.48705 .30782 L
.48705 .308 L
.48705 .30819 L
.48706 .30852 L
.48706 .30883 L
.48706 .30901 L
.48706 .30919 L
.48706 .30952 L
.48705 .30981 L
.48705 .31011 L
.48705 .3104 L
.48704 .31067 L
.48702 .31129 L
.487 .31194 L
.48693 .31318 L
.48684 .31454 L
.4866 .317 L
.48631 .31932 L
.48533 .32493 L
.48407 .33043 L
.47999 .34422 L
.47392 .36124 L
.46443 .38544 L
.45129 .41732 L
.43361 .45922 L
.40727 .52081 L
.37181 .60317 L
s
.37181 .60317 m
.36539 .61803 L
s
.5 .165 .165 r
.5 0 m
.5 .00281 L
.5 .0871 L
.5 .15185 L
.5 .19675 L
.5 .23124 L
.5 .25542 L
.5 .27292 L
.5 .28741 L
.5 .29891 L
.5 .3089 L
.5 .31955 L
.5 .33094 L
.5 .34565 L
.5 .36399 L
.5 .38742 L
.5 .42137 L
.5 .46649 L
.5 .5334 L
s
.5 .5334 m
.5 .61803 L
s
1 0 0 r
.63461 0 m
.62888 .01325 L
.59383 .09466 L
.56708 .1572 L
.54876 .20058 L
.53505 .23389 L
.52591 .25725 L
.5199 .27415 L
.51769 .28121 L
.51579 .28814 L
.51446 .29415 L
.51362 .29925 L
.51331 .30185 L
.5132 .30302 L
.5131 .30426 L
.51306 .30495 L
.51303 .30557 L
.513 .30621 L
.51298 .30679 L
.51296 .30746 L
.51295 .30782 L
.51295 .308 L
.51295 .30819 L
.51294 .30852 L
.51294 .30883 L
.51294 .30901 L
.51294 .30919 L
.51294 .30952 L
.51295 .30981 L
.51295 .31011 L
.51295 .3104 L
.51296 .31067 L
.51298 .31129 L
.513 .31194 L
.51307 .31318 L
.51316 .31454 L
.5134 .317 L
.51369 .31932 L
.51467 .32493 L
.51593 .33043 L
.52001 .34422 L
.52608 .36124 L
.53557 .38544 L
.54871 .41732 L
.56639 .45922 L
.59273 .52081 L
.62819 .60317 L
s
.62819 .60317 m
.63461 .61803 L
s
0 1 0 r
.78978 0 m
.74898 .04384 L
.68127 .11683 L
.62959 .17291 L
.5942 .21179 L
.56771 .24166 L
.55005 .2626 L
.53844 .27776 L
.53416 .28409 L
.53051 .2903 L
.52793 .29569 L
.5263 .30026 L
.52571 .30259 L
.5255 .30364 L
.52531 .30476 L
.52523 .30537 L
.52517 .30593 L
.52511 .3065 L
.52507 .30702 L
.52503 .30762 L
.52502 .30794 L
.52501 .3081 L
.52501 .30828 L
.525 .30857 L
.525 .30885 L
.525 .30901 L
.525 .30917 L
.525 .30947 L
.52501 .30972 L
.52502 .31 L
.52503 .31026 L
.52504 .3105 L
.52507 .31106 L
.52512 .31164 L
.52524 .31275 L
.52542 .31397 L
.52588 .31617 L
.52645 .31826 L
.52833 .32328 L
.53077 .32821 L
.53865 .34058 L
.55038 .35584 L
.56872 .37754 L
.5941 .40612 L
.62826 .44368 L
.67914 .49891 L
.74764 .57275 L
s
.74764 .57275 m
.78979 .61803 L
s
0 1 1 r
1 .00078 m
.99036 .00675 L
.85211 .0925 L
.75635 .1521 L
.68326 .19788 L
.63322 .22963 L
.59575 .25402 L
.57078 .27112 L
.55437 .28349 L
.54832 .28866 L
.54314 .29374 L
.5395 .29813 L
.5372 .30187 L
.53636 .30377 L
.53606 .30463 L
.5358 .30554 L
.53568 .30604 L
.53559 .3065 L
.53551 .30696 L
.53545 .30738 L
.5354 .30788 L
.53538 .30814 L
.53538 .30827 L
.53537 .30841 L
.53536 .30865 L
.53536 .30888 L
.53536 .30901 L
.53536 .30914 L
.53536 .30938 L
.53537 .30959 L
.53538 .30982 L
.53539 .31003 L
.53541 .31023 L
.53546 .31068 L
.53552 .31116 L
.5357 .31207 L
.53596 .31306 L
.5366 .31486 L
.5374 .31656 L
.54007 .32067 L
.54351 .32469 L
.55467 .33478 L
.57125 .34725 L
.59719 .36497 L
.63307 .3883 L
.68139 .41897 L
.75335 .46406 L
.85021 .52435 L
.99472 .61399 L
s
.99472 .61399 m
1 .61726 L
s
0 0 1 r
1 .13129 m
.93125 .15591 L
.81396 .19806 L
.72445 .23043 L
.66317 .25288 L
.61727 .27013 L
.58669 .28222 L
.56658 .29097 L
.55918 .29463 L
.55284 .29821 L
.54838 .30132 L
.54556 .30396 L
.54453 .3053 L
.54417 .30591 L
.54385 .30656 L
.5437 .30691 L
.54359 .30724 L
.54349 .30756 L
.54342 .30786 L
.54336 .30821 L
.54334 .3084 L
.54333 .30849 L
.54332 .30859 L
.54331 .30876 L
.5433 .30892 L
.5433 .30901 L
.5433 .30911 L
.54331 .30928 L
.54332 .30942 L
.54333 .30958 L
.54335 .30973 L
.54337 .30987 L
.54343 .31019 L
.54351 .31053 L
.54372 .31117 L
.54404 .31188 L
.54482 .31315 L
.54581 .31435 L
.54907 .31725 L
.55329 .3201 L
.56695 .32724 L
.58727 .33605 L
.61903 .34858 L
.66298 .36508 L
.72215 .38677 L
.81029 .41865 L
.92892 .46128 L
s
.92892 .46128 m
1 .48674 L
s
1 0 1 r
1 .22661 m
.981 .22977 L
.85018 .25158 L
.75034 .26834 L
.68199 .27996 L
.6308 .28889 L
.59669 .29515 L
.57427 .29967 L
.566 .30157 L
.55893 .30342 L
.55396 .30503 L
.55082 .3064 L
.54967 .3071 L
.54926 .30741 L
.5489 .30774 L
.54874 .30793 L
.54862 .30809 L
.54851 .30826 L
.54843 .30842 L
.54836 .3086 L
.54834 .3087 L
.54832 .30874 L
.54831 .3088 L
.5483 .30888 L
.5483 .30897 L
.5483 .30902 L
.5483 .30906 L
.5483 .30915 L
.54831 .30923 L
.54833 .30931 L
.54835 .30939 L
.54837 .30946 L
.54844 .30963 L
.54853 .3098 L
.54876 .31013 L
.54912 .3105 L
.54999 .31115 L
.55109 .31178 L
.55473 .31328 L
.55944 .31475 L
.57467 .31845 L
.59733 .32301 L
.63276 .3295 L
.68178 .33804 L
.74778 .34926 L
.84608 .36577 L
.9784 .38784 L
s
.9784 .38784 m
1 .39143 L
s
0 g
0 .30902 m
.00592 .30902 L
.05537 .30902 L
.10292 .30902 L
.15353 .30902 L
.20226 .30902 L
.25404 .30902 L
.30393 .30902 L
.35193 .30902 L
.403 .30902 L
.45216 .30902 L
.49944 .30902 L
.54978 .30902 L
.59822 .30902 L
.64973 .30902 L
.69935 .30902 L
.74707 .30902 L
.79786 .30902 L
.84675 .30902 L
.89871 .30902 L
.94877 .30902 L
.99694 .30902 L
s
.99694 .30902 m
1 .30902 L
s
.5 .165 .165 r
.009 w
.5 0 m
.5 .61803 L
s
0 .30902 m
.4475 .30902 L
s
.5525 .30902 m
1 .30902 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{287.5, 177.625},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
  ImageRangeCache->{{{0, 286.5}, {176.625, 0}} -> {-11, -10, 0, 0}}],
 StyleBox["  \n\t\t\tFigure 5.7",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Vertical segments mapped onto hyperbolas by  ",
 Cell[BoxData[
  RowBox[{"w", " ", "=", 
   RowBox[{"sin", " ", "z"}]}]]],
 ". "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["\<\
Enter the formula f[z] = Sin[z] and graph the transformation.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", "z", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "wplane"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"Iden", "[", "z_", "]"}], " ", "=", " ", "z"}], ";"}], " ", "\n",
    
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"Sin", "[", "z", "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"CartesianMap", "[", 
    RowBox[{"Iden", ",", " ", 
     RowBox[{"{", 
      RowBox[{
       FractionBox[
        RowBox[{"-", "\[Pi]"}], "2"], ",", 
       FractionBox["\[Pi]", "2"], ",", 
       FractionBox["\[Pi]", "16"]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1", ",", "0.25"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.7"}], ",", "1.7"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.1"}], ",", "1.1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["1.1", "1.7"]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", 
             FractionBox["\[Pi]", "2"]}], ",", 
            "\"\<\!\(\*FractionBox[\(-\[Pi]\), \(2\)]\)     \>\""}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{
            FractionBox["\[Pi]", "2"], ",", 
            "\"\<    \!\(\*FractionBox[\(\[Pi]\), \(2\)]\)\>\""}], "}"}]}], 
         "}"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The lines forming the rectangle \!\(\*FractionBox[\(-\[Pi]\), \
\(2\)]\) \[LessEqual] x \[LessEqual] \!\(\*FractionBox[\(\[Pi]\), \(2\)]\), \
-1 \[LessEqual] y \[LessEqual] 1.\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{"CartesianMap", "[", 
    RowBox[{"f", ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox[
        RowBox[{"-", "\[Pi]"}], "2"], ",", 
       FractionBox["\[Pi]", "2"], ",", 
       FractionBox["\[Pi]", "16"]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1", ",", "0.25"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.6"}], ",", "1.6"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.2"}], ",", "1.2"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["1.2", "1.6"]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", "\"\<The image hyperbolas and ellipses,\>\"", "]"}],
     ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<under the mapping  w = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39928681925*^9, 3.399286826796875*^9}, {
  3.399826172249752*^9, 3.3998261724216275`*^9}},
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", "z", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "wplane"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"Iden", "[", "z_", "]"}], " ", "=", " ", "z"}], ";"}], " ", "\n",
    
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"Sin", "[", "z", "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"CartesianMap", "[", 
    RowBox[{"Iden", ",", " ", 
     RowBox[{"{", 
      RowBox[{
       FractionBox[
        RowBox[{"-", "\[Pi]"}], "2"], ",", 
       FractionBox["\[Pi]", "2"], ",", 
       FractionBox["\[Pi]", "12"]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "3", ",", "0.5"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.7"}], ",", "1.7"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "3"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["1.1", "1.7"]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", 
             FractionBox["\[Pi]", "2"]}], ",", 
            "\"\<\!\(\*FractionBox[\(-\[Pi]\), \(2\)]\)     \>\""}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{
            FractionBox["\[Pi]", "2"], ",", 
            "\"\<    \!\(\*FractionBox[\(\[Pi]\), \(2\)]\)\>\""}], "}"}]}], 
         "}"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "3", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The lines forming the rectangle \!\(\*FractionBox[\(-\[Pi]\), \
\(2\)]\) \[LessEqual] x \[LessEqual] \!\(\*FractionBox[\(\[Pi]\), \(2\)]\), \
-1 \[LessEqual] y \[LessEqual] 1.\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{"CartesianMap", "[", 
    RowBox[{"f", ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox[
        RowBox[{"-", "\[Pi]"}], "2"], ",", 
       FractionBox["\[Pi]", "2"], ",", 
       FractionBox["\[Pi]", "12"]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "3", ",", "0.25"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "10.6"}], ",", "10.6"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "10.2"}], ",", "10.2"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["1.2", "1.6"]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "10"}], ",", "10", ",", "5"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "10"}], ",", "10", ",", "5"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", "\"\<The image hyperbolas and ellipses,\>\"", "]"}],
     ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<under the mapping  w = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399286831984375*^9, 3.399286848859375*^9}, {
  3.399826177812252*^9, 3.3998261779841275`*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 "\tFigure 5.7 suggests one big difference between the real and complex sine \
functions.  The real sine has the property that  ",
 Cell[BoxData[
  RowBox[{"|", 
   RowBox[{"sin", " ", "x"}], "|", 
   RowBox[{"\[LessEqual]", "1"}]}]]],
 "  for all real ",
 StyleBox["x",
  FontFamily->"Courier New"],
 ".  In Figure 5.7, however, the modulus of the complex sine appears to be \
unbounded, which is indeed the case.  Using Identity ",
 StyleBox["(5-34)",
  FontColor->RGBColor[0, 0, 1]],
 " gives  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"|", 
     RowBox[{"sin", " ", "z"}], 
     SuperscriptBox["|", "2"]}], "  ", "=", " ", 
    RowBox[{
     RowBox[{"|", 
      RowBox[{"sin", 
       RowBox[{"(", 
        RowBox[{"x", "+", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], 
      SuperscriptBox["|", "2"]}], " ", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", "                 ", 
     RowBox[{"=", " ", 
      RowBox[{
       RowBox[{"|", 
        RowBox[{
         RowBox[{"sin", " ", "x", " ", "cosh", " ", "y"}], " ", "+", " ", 
         RowBox[{
         "\[ImaginaryI]", " ", "cos", " ", "x", " ", "sinh", " ", "y"}]}], 
        SuperscriptBox["|", "2"]}], "\[IndentingNewLine]", 
       "\[IndentingNewLine]", "               ", 
       RowBox[{"=", " ", 
        RowBox[{
         RowBox[{
          SuperscriptBox["sin", "2"], " ", "x", " ", 
          SuperscriptBox["cosh", "2"], " ", "y"}], " ", "+", " ", 
         RowBox[{
          SuperscriptBox["cos", "2"], " ", "x", " ", 
          SuperscriptBox["sinh", "2"], " ", "y"}]}]}]}]}]}]}], 
   "\[IndentingNewLine]"}], "\n", 
  RowBox[{"                      ", 
   RowBox[{"=", " ", 
    RowBox[{
     RowBox[{
      SuperscriptBox["sin", "2"], " ", "x", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["cosh", "2"], " ", "y"}], "-", 
        RowBox[{
         SuperscriptBox["sinh", "2"], " ", "y"}]}], ")"}]}], " ", "+", " ", 
     RowBox[{
      SuperscriptBox["sinh", "2"], " ", "y", "  ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["cos", "2"], " ", "x"}], " ", "+", 
        RowBox[{
         SuperscriptBox["sin", "2"], " ", "x"}]}], ")"}], " "}]}]}]}]}]],
 "   \n\nThe identities  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["cosh", "2"], " ", "y"}], "-", 
    RowBox[{
     SuperscriptBox["sinh", "2"], " ", "y"}]}], " ", "=", " ", "1"}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["cos", "2"], " ", "x"}], " ", "+", 
    RowBox[{
     SuperscriptBox["sin", "2"], " ", "x"}]}], " ", "=", " ", "1"}]]],
 "  then yield  \n\n",
 StyleBox["(5-36)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", 
    RowBox[{"sin", " ", "z"}], 
    SuperscriptBox["|", "2"]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     SuperscriptBox["sin", "2"], " ", "x"}], " ", "+", " ", 
    RowBox[{
     SuperscriptBox["sinh", "2"], " ", "y"}]}]}]]],
 ".  \n\nA similar derivation produces  \n\n",
 StyleBox["(5-37)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", 
    RowBox[{"cos", " ", "z"}], 
    SuperscriptBox["|", "2"]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     SuperscriptBox["cos", "2"], " ", "x"}], " ", "+", " ", 
    RowBox[{
     SuperscriptBox["sinh", "2"], " ", "y"}]}]}]]],
 ".  "
}], "Text",
 CellChangeTimes->{3.39928624278125*^9}],

Cell[TextData[{
 "\tIf we set ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{
    SubscriptBox["x", "0"], "+", 
    RowBox[{"\[ImaginaryI]", " ", "y", " "}]}]}]]],
 " in Identity ",
 StyleBox["(5-36)",
  FontColor->RGBColor[0, 0, 1]],
 " and let  ",
 Cell[BoxData[
  RowBox[{"y", "\[Rule]", "\[Infinity]"}]]],
 ",  we get  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    UnderscriptBox["lim", 
     RowBox[{"y", "\[Rule]", "\[Infinity]"}]], " ", 
    RowBox[{"|", 
     RowBox[{"sin", " ", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["x", "0"], "+", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], 
     SuperscriptBox["|", "2"]}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["sin", "2"], " ", 
      SubscriptBox["x", "0"]}], "  ", "+", "  ", 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"y", "\[Rule]", "\[Infinity]"}]], " ", 
      RowBox[{
       SuperscriptBox["sinh", "2"], " ", "y"}]}]}], "  ", "=", "  ", 
    "\[Infinity]"}]}]]],
 "\n\nAs advertised, we have shown that ",
 Cell[BoxData[
  RowBox[{"sin", " ", "z"}]]],
 " is not a bounded function; it is also evident from Identity ",
 StyleBox["(5-37)",
  FontColor->RGBColor[0, 0, 1]],
 " that ",
 Cell[BoxData[
  RowBox[{"cos", " ", "z"}]]],
 " is unbounded."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", "w", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", "aw", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"w", "  ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"Sin", "[", 
       RowBox[{"x", " ", "+", " ", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"aw", " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{
       RowBox[{"Abs", "[", "w", "]"}], ",", "\n", "       ", 
       RowBox[{"TargetFunctions", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Im", ",", "Re"}], "}"}]}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"aw1", "=", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{
       SuperscriptBox["aw", "2"], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox[
           RowBox[{"Cos", "[", "x", "]"}], "2"], "\[Rule]", 
          RowBox[{"1", "-", 
           SuperscriptBox[
            RowBox[{"Sin", "[", "x", "]"}], "2"]}]}], ",", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"Cosh", "[", "y", "]"}], "2"], "\[Rule]", 
          RowBox[{"1", "+", 
           SuperscriptBox[
            RowBox[{"Sinh", "[", "y", "]"}], "2"]}]}]}], "}"}]}], "]"}]}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"aw2", "=", 
     RowBox[{"Simplify", "[", "aw1", "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<   Sin[x+\[ImaginaryI]y] = \>\"", ",", "w"}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      SuperscriptBox["\"\<|Sin[x+\[ImaginaryI]y]|\>\"", "2"], ",", 
      "\"\< = \>\"", ",", 
      SuperscriptBox["aw", "2"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      SuperscriptBox["\"\<|Sin[x+\[ImaginaryI]y]|\>\"", "2"], ",", 
      "\"\< = \>\"", ",", "aw1"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      SuperscriptBox["\"\<|Sin[x+\[ImaginaryI]y]|\>\"", "2"], ",", 
      "\"\< = \>\"", ",", "aw2"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.3992868580625*^9},
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", "w", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", "aw", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"w", "  ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"Cos", "[", 
       RowBox[{"x", " ", "+", " ", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"aw", " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{
       RowBox[{"Abs", "[", "w", "]"}], ",", "\n", "       ", 
       RowBox[{"TargetFunctions", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Im", ",", "Re"}], "}"}]}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"aw1", "=", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{
       SuperscriptBox["aw", "2"], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox[
           RowBox[{"Sin", "[", "x", "]"}], "2"], "\[Rule]", 
          RowBox[{"1", "-", 
           SuperscriptBox[
            RowBox[{"Cos", "[", "x", "]"}], "2"]}]}], ",", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"Cosh", "[", "y", "]"}], "2"], "\[Rule]", 
          RowBox[{"1", "+", 
           SuperscriptBox[
            RowBox[{"Sinh", "[", "y", "]"}], "2"]}]}]}], "}"}]}], "]"}]}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"aw2", "=", 
     RowBox[{"Simplify", "[", "aw1", "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<   Cos[x+\[ImaginaryI]y] = \>\"", ",", "w"}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      SuperscriptBox["\"\<|Cos[x+\[ImaginaryI]y]|\>\"", "2"], ",", 
      "\"\< = \>\"", ",", 
      SuperscriptBox["aw", "2"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      SuperscriptBox["\"\<|Cos[x+\[ImaginaryI]y]|\>\"", "2"], ",", 
      "\"\< = \>\"", ",", "aw1"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      SuperscriptBox["\"\<|Cos[x+\[ImaginaryI]y]|\>\"", "2"], ",", 
      "\"\< = \>\"", ",", "aw2"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399286861671875*^9},
 AspectRatioFixed->True]
}, Closed]],

Cell["\<\
\tThe periodic character of the trigonometric functions makes apparent that \
any point in their ranges is actually the image of infinitely many points.\
\>", "Text"],

Cell[TextData[{
 StyleBox["Example 5.10.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Find all the values of  ",
 StyleBox["z",
  FontFamily->"Courier New"],
 "  for which  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"cos", " ", "z"}], "=", 
   RowBox[{"cosh", " ", "2"}]}]]],
 "."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "Solution.  Starting with Identity ",
 StyleBox["(5-35)",
  FontColor->RGBColor[0, 0, 1]],
 ", we write \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"cos", " ", "z"}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     RowBox[{"cos", " ", "x", " ", "cosh", " ", "y"}], " ", "-", " ", 
     RowBox[{"\[ImaginaryI]", " ", "sin", " ", "x", " ", "sinh", " ", "y"}]}],
     "  ", "=", "  ", 
    RowBox[{"cosh", " ", "2"}]}]}]]],
 ".  \n\nIf we equate real and imaginary parts, then we get \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"cos", " ", "x", " ", "cosh", " ", "y"}], " ", "=", " ", 
   RowBox[{"cosh", " ", "2"}]}]]],
 "   and   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"sin", " ", "x", " ", "sinh", " ", "y"}], " ", "=", " ", "0"}]]],
 ".  \n\nThe equation  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"sin", " ", "x", " ", "sinh", " ", "y"}], "=", "0"}]]],
 "  implies either that  ",
 Cell[BoxData[
  RowBox[{"x", "=", 
   RowBox[{"n", " ", "\[Pi]"}]}]]],
 ", where ",
 StyleBox["n",
  FontFamily->"Courier New"],
 " is an integer, or that ",
 Cell[BoxData[
  RowBox[{"y", "=", "0"}]]],
 ".  Using ",
 Cell[BoxData[
  RowBox[{"y", "=", "0"}]]],
 " in the equation ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"cos", " ", "x", " ", "cosh", " ", "y"}], "=", 
   RowBox[{"cosh", " ", "2"}]}]]],
 "  leads to the impossible situation  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"cos", " ", "x"}], "=", 
   RowBox[{
    FractionBox[
     RowBox[{"cosh", " ", "2"}], 
     RowBox[{"cosh", " ", "0"}]], "=", 
    RowBox[{
     RowBox[{"cosh", " ", "2"}], ">", "1"}]}]}]]],
 ".  Therefore  ",
 Cell[BoxData[
  RowBox[{"x", "=", 
   RowBox[{"n", " ", "\[Pi]"}]}]]],
 ", where ",
 StyleBox["n",
  FontFamily->"Courier New"],
 " is an integer.  Since  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"cosh", " ", "y"}], "\[GreaterEqual]", "1"}]]],
 "  for all values of ",
 StyleBox["y",
  FontFamily->"Courier New"],
 ", the term ",
 Cell[BoxData[
  RowBox[{"cos", " ", "x"}]]],
 " in the equation  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"cos", " ", "x", " ", "cosh", " ", "y"}], "=", 
   RowBox[{"cosh", " ", "2"}]}]]],
 "  must also be positive.  For this reason we eliminate the odd values of ",
 StyleBox["n",
  FontFamily->"Courier New"],
 " and get  ",
 Cell[BoxData[
  RowBox[{"x", "=", 
   RowBox[{"2", "k", " ", "\[Pi]"}]}]]],
 ", where ",
 StyleBox["k",
  FontFamily->"Courier New"],
 " is an integer."
}], "Text"],

Cell[TextData[{
 "\tFinally, we solve the equation  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"cos", " ", 
    RowBox[{"(", 
     RowBox[{"2", "k", " ", "\[Pi]"}], ")"}], " ", "cosh", " ", "y"}], "=", 
   RowBox[{
    RowBox[{"cosh", " ", "y"}], "=", 
    RowBox[{"cosh", " ", "2"}]}]}]]],
 "  and use the fact that ",
 Cell[BoxData[
  RowBox[{"cosh", " ", "y"}]]],
 " is an even function to conclude that  ",
 Cell[BoxData[
  RowBox[{"y", "=", 
   RowBox[{"\[PlusMinus]", "2"}]}]]],
 ".  Therefore the solutions to the equation  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"cos", " ", "z"}], "=", 
   RowBox[{"cosh", " ", "2"}]}]]],
 "  are  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{
    RowBox[{"2", " ", "\[Pi]", " ", "k"}], "\[PlusMinus]", 
    RowBox[{"2", "\[ImaginaryI]"}]}]}]]],
 ",  where ",
 StyleBox["k",
  FontFamily->"Courier New"],
 " is an integer."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 5.10.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 "First, use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s \"Solve\" procedure to find some of the solutions to  cos z = cosh 2.  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", 
     RowBox[{"x", ",", "y", ",", "z"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"cosZ", ",", "eq1", ",", "eq2"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"cosZ", " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"Cos", "[", 
       RowBox[{"x", " ", "+", " ", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eq1", " ", "=", " ", 
     RowBox[{
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"Re", "[", "cosZ", "]"}], "]"}], " ", "\[Equal]", " ", 
      RowBox[{"Cosh", "[", "2", "]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"eq2", " ", "=", " ", 
     RowBox[{
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"Im", "[", "cosZ", "]"}], "]"}], " ", "\[Equal]", " ", "0"}]}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"Cos", "[", 
       RowBox[{"x", " ", "+", " ", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], " ", "\[Equal]", "  ", 
      RowBox[{"Cosh", "[", "2", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"cosZ", " ", "\[Equal]", " ", "0"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "eq1", " ", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "eq2", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"eq1", ",", "eq2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "y"}], "}"}]}], "]"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.3992868698125*^9}],

Cell["This is another way to solve the equation  cos(z) = cosh(2).", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", "z", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", "solset", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"solset", "=", 
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Cos", "[", "z", "]"}], "\[Equal]", 
        RowBox[{"Cosh", "[", "2", "]"}]}], ",", "z"}], "]"}]}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", "solset", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The solutions are to cos(z) = cosh(2) are:\>\"", "]"}],
     ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<2 k \[Pi] + \>\"", ",", " ", 
      SubscriptBox["solset", 
       RowBox[{"\[LeftDoubleBracket]", 
        RowBox[{"2", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]]}], 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<2 k \[Pi] \>\"", ",", 
      SubscriptBox["solset", 
       RowBox[{"\[LeftDoubleBracket]", 
        RowBox[{"1", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]]}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399286874328125*^9}],

Cell["We can also list some of the solutions.", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", "k", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"k", "=", "0"}], ",", 
      RowBox[{"k", "\[LessEqual]", "5"}], ",", 
      RowBox[{"k", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{"\"\<Cos[\>\"", ",", 
        RowBox[{"2", "k"}], ",", "\"\< \[Pi] + 2\[ImaginaryI]] = \>\"", ",", 
        RowBox[{"Cos", "[", 
         RowBox[{
          RowBox[{"2", "k", " ", "\[Pi]"}], "+", 
          RowBox[{"2", "\[ImaginaryI]"}]}], "]"}]}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"k", "=", "0"}], ",", 
      RowBox[{"k", "\[LessEqual]", "5"}], ",", 
      RowBox[{"k", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{"\"\<Cos[\>\"", ",", 
        RowBox[{"2", "k"}], ",", "\"\< \[Pi] - 2\[ImaginaryI]] = \>\"", ",", 
        RowBox[{"Cos", "[", 
         RowBox[{
          RowBox[{"2", "k", " ", "\[Pi]"}], "-", 
          RowBox[{"2", "\[ImaginaryI]"}]}], "]"}]}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399286878796875*^9}]
}, Closed]],

Cell[TextData[{
 "\tThe hyperbolic functions also have practical use in putting the tangent \
function into the Cartesian form ",
 Cell[BoxData[
  RowBox[{"u", "+", 
   RowBox[{"\[ImaginaryI]", " ", "v"}]}]]],
 ".  \nUsing Definition 5.6, and Equations ",
 StyleBox["(5-34)",
  FontColor->RGBColor[0, 0, 1]],
 " and ",
 StyleBox["(5-35)",
  FontColor->RGBColor[0, 0, 1]],
 ", we have  \n\n",
 StyleBox["(5-38)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"tan", " ", "z"}], "=", 
   RowBox[{
    RowBox[{"tan", 
     RowBox[{"(", 
      RowBox[{"x", "+", 
       RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "=", " ", 
    RowBox[{
     FractionBox[
      RowBox[{"sin", 
       RowBox[{"(", 
        RowBox[{"x", "+", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], 
      RowBox[{"cos", 
       RowBox[{"(", 
        RowBox[{"x", "+", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}]], "=", " ", 
     FractionBox[
      RowBox[{
       RowBox[{"sin", " ", "x", " ", "cosh", " ", "y"}], "  ", "+", "  ", 
       RowBox[{
       "\[ImaginaryI]", " ", "cos", " ", "x", " ", "sinh", " ", "y"}]}], 
      RowBox[{
       RowBox[{"cos", " ", "x", " ", "cosh", " ", "y"}], " ", "-", " ", 
       RowBox[{
       "\[ImaginaryI]", " ", "sin", " ", "x", " ", "sinh", " ", 
        "y"}]}]]}]}]}]]],
 ".  \n\nIf we multiply each term on the right by the conjugate of the \
denominator, the simplified result is  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"tan", " ", "z"}], "  ", "=", "  ", 
   FractionBox[
    RowBox[{
     RowBox[{"cos", " ", "x", "  ", "sin", " ", "x"}], "  ", "+", " ", 
     RowBox[{
     "\[ImaginaryI]", " ", "cosh", " ", "y", " ", "sinh", " ", "y"}]}], 
    RowBox[{
     RowBox[{
      SuperscriptBox["cos", "2"], "x", " ", 
      SuperscriptBox["cosh", "2"], "y"}], " ", "+", " ", 
     RowBox[{
      SuperscriptBox["sin", "2"], "x", " ", 
      SuperscriptBox["sinh", "2"], "y"}]}]]}]]],
 "\n\nWe leave it as an exercise to show that the identities  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["cosh", "2"], "y"}], "-", 
    RowBox[{
     SuperscriptBox["sinh", "2"], "y"}]}], "=", "1"}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"sinh", " ", "2", " ", "y"}], "=", 
   RowBox[{"2", "cosh", " ", "y", " ", "sinh", " ", "y"}]}]]],
 "  can be used in simplifying Equation ",
 StyleBox["(5-38)",
  FontColor->RGBColor[0, 0, 1]],
 " to get  \n\n",
 StyleBox["(5-39)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"tan", " ", "z"}], "  ", "=", "  ", 
   RowBox[{
    FractionBox[
     RowBox[{"sin", 
      RowBox[{"(", 
       RowBox[{"2", " ", "x"}], ")"}]}], 
     RowBox[{
      RowBox[{"cos", 
       RowBox[{"(", 
        RowBox[{"2", " ", "x"}], ")"}]}], "+", 
      RowBox[{"cosh", 
       RowBox[{"(", 
        RowBox[{"2", " ", "y"}], ")"}]}]}]], " ", "+", " ", 
    RowBox[{"\[ImaginaryI]", 
     FractionBox[
      RowBox[{" ", 
       RowBox[{"sinh", 
        RowBox[{"(", 
         RowBox[{"2", " ", "y"}], ")"}]}]}], 
      RowBox[{
       RowBox[{"cos", 
        RowBox[{"(", 
         RowBox[{"2", " ", "x"}], ")"}]}], "+", 
       RowBox[{"cosh", 
        RowBox[{"(", 
         RowBox[{"2", " ", "y"}], ")"}]}]}]]}]}]}]]]
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"x", "=", "0"}], ";", 
    RowBox[{"y", "=", "0"}], ";", 
    RowBox[{"w", "=", "0"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Remove", "[", 
     RowBox[{"w", ",", "x", ",", "y"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"cos", ",", "sin"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["w", "1"], " ", "=", " ", 
     FractionBox[
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"Sin", "[", 
        RowBox[{"x", "+", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"Cos", "[", 
        RowBox[{"x", "+", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]]}], ";"}], "\n", 
   
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Tan[x+\[ImaginaryI]y] = \>\"", ",", 
      SubscriptBox["w", "1"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"d01", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"Cos", "[", "x", "]"}], " ", 
       RowBox[{"cosh", "[", "y", "]"}]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"Sin", "[", "x", "]"}], " ", 
       RowBox[{"sinh", "[", "y", "]"}]}]}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"d02", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"cos", "[", "x", "]"}], " ", 
       RowBox[{"Cosh", "[", "y", "]"}]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"sin", "[", "x", "]"}], " ", 
       RowBox[{"Sinh", "[", "y", "]"}]}]}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"n1", "=", 
     RowBox[{
      RowBox[{"Numerator", "[", 
       SubscriptBox["w", "1"], "]"}], "d01"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"d1", "=", 
     RowBox[{
      RowBox[{"Denominator", "[", 
       SubscriptBox["w", "1"], "]"}], "d02"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["w", "2"], " ", "=", 
     FractionBox["n1", "d1"]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Tan[x+\[ImaginaryI]y] = \>\"", ",", 
      SubscriptBox["w", "2"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"d", "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"Conjugate", "[", 
       RowBox[{"Denominator", "[", 
        SubscriptBox["w", "1"], "]"}], "]"}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"n2", "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{
       RowBox[{"Numerator", "[", 
        SubscriptBox["w", "1"], "]"}], "d"}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"d2", "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{
       RowBox[{"Denominator", "[", 
        SubscriptBox["w", "1"], "]"}], "d"}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["w", "3"], " ", "=", 
     FractionBox["n2", "d2"]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Tan[x+\[ImaginaryI]y] = \>\"", ",", 
      SubscriptBox["w", "3"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"n3", "=", 
     RowBox[{"Simplify", "[", "n2", "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"d3", "=", "d2"}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["w", "4"], " ", "=", 
     FractionBox["n3", "d3"]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Tan[x+\[ImaginaryI]y] = \>\"", ",", 
      SubscriptBox["w", "4"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"n4", "=", 
     RowBox[{"Simplify", "[", "n3", "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"d4", "=", 
     RowBox[{"Simplify", "[", "d3", "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["w", "5"], " ", "=", 
     FractionBox["n4", "d4"]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Tan[x+\[ImaginaryI]y] = \>\"", ",", 
      SubscriptBox["w", "5"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["w", "5"], " ", "=", 
     RowBox[{"ExpandNumerator", "[", 
      SubscriptBox["w", "5"], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Tan[x+\[ImaginaryI]y] = \>\"", ",", 
      SubscriptBox["w", "5"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["w", "6"], " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{
       SubscriptBox["w", "5"], ",", 
       RowBox[{
        RowBox[{"2", " ", 
         RowBox[{"Cos", "[", "x", "]"}], " ", 
         RowBox[{"Sin", "[", "x", "]"}]}], "\[Rule]", 
        RowBox[{"Sin", "[", 
         RowBox[{"2", "x"}], "]"}]}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Tan[x+\[ImaginaryI]y] = \>\"", ",", 
      SubscriptBox["w", "6"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["w", "7"], " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{
       SubscriptBox["w", "6"], ",", 
       RowBox[{
        RowBox[{"2", " ", "\[ImaginaryI]", " ", 
         RowBox[{"Cosh", "[", "y", "]"}], " ", 
         RowBox[{"Sinh", "[", "y", "]"}]}], "\[Rule]", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"Sinh", "[", 
          RowBox[{"2", "y"}], "]"}]}]}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Tan[x+\[ImaginaryI]y] = \>\"", ",", 
      SubscriptBox["w", "7"]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399286889703125*^9, 3.399286892109375*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 "\tAs with ",
 Cell[BoxData[
  RowBox[{"sin", " ", "z"}]]],
 ", we obtain a graph of the mapping ",
 Cell[BoxData[
  RowBox[{"w", " ", "=", 
   RowBox[{"tan", " ", "z"}]}]]],
 " parametrically.  Consider the vertical line segments in the ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " plane obtained by successively setting  ",
 Cell[BoxData[
  RowBox[{"x", "=", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["\[Pi]", "4"]}], "+", 
    FractionBox[
     RowBox[{"k", " ", "\[Pi]"}], "16"]}]}]]],
 "  for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"k", "=", "0"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "1", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   StyleBox["...",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "8"}]]],
 ",  and for each ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " value letting y vary continuously, ",
 Cell[BoxData[
  RowBox[{"3", "\[LessEqual]", "y", "\[LessEqual]", "3"}]]],
 ".  In the exercises we ask you to show that the images of these vertical \
segments are circular arcs in the ",
 StyleBox["uv",
  FontFamily->"Courier New"],
 " plane, as Figure 5.8 shows.  In Chapter 9, we give a more detailed \
investigation of the mapping  ",
 Cell[BoxData[
  RowBox[{"w", " ", "=", 
   RowBox[{"tan", " ", "z"}]}]]],
 ". "
}], "Text"],

Cell[TextData[{
 "\t",
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 220 220 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.574713 0.5 0.166667 [
[.04862 .4875 -17.4375 -20.875 ]
[.04862 .4875 17.4375 0 ]
[.95138 .4875 -12.8125 -20.875 ]
[.95138 .4875 12.8125 0 ]
[1.025 .5 0 -6.5 ]
[1.025 .5 9 6.5 ]
[.4875 0 -16.375 -6.5 ]
[.4875 0 0 6.5 ]
[.4875 .16667 -16.375 -6.5 ]
[.4875 .16667 0 6.5 ]
[.4875 .33333 -16.375 -6.5 ]
[.4875 .33333 0 6.5 ]
[.4875 .66667 -9.5 -6.5 ]
[.4875 .66667 0 6.5 ]
[.4875 .83333 -9.5 -6.5 ]
[.4875 .83333 0 6.5 ]
[.4875 1 -9.5 -6.5 ]
[.4875 1 0 6.5 ]
[.5 1.025 -4.34375 0 ]
[.5 1.025 4.34375 13 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04862 .5 m
.04862 .50625 L
s
gsave
.04862 .4875 -78.4375 -24.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.875 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 16.688 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
%%BeginResource: font Helvetica-MISO
%%BeginFont: Helvetica-MISO
/Helvetica /Helvetica-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
65.563 9.438 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.438 9.438 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
64.438 16.688 moveto
(\\200\\200\\200\\200) show
69.938 16.688 moveto
(\\200\\200\\200\\200) show
75.438 16.688 moveto
(\\200) show
77.063 16.688 moveto
(\\200) show
68.813 23.875 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.875 16.688 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.95138 .5 m
.95138 .50625 L
s
gsave
.95138 .4875 -73.8125 -24.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.875 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 16.688 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
%%BeginResource: font Helvetica-MISO
%%BeginFont: Helvetica-MISO
/Helvetica /Helvetica-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
76.750 9.438 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
75.438 16.688 moveto
(\\200\\200\\200\\200) show
80.938 16.688 moveto
(\\200) show
81.563 16.688 moveto
(\\200) show
76.563 23.875 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
84.625 16.688 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
68.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
gsave
.4875 0 -77.375 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.875 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.5 .16667 m
.50625 .16667 L
s
gsave
.4875 .16667 -77.375 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.875 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .33333 m
.50625 .33333 L
s
gsave
.4875 .33333 -77.375 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.875 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .66667 m
.50625 .66667 L
s
gsave
.4875 .66667 -70.5 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .83333 m
.50625 .83333 L
s
gsave
.4875 .83333 -70.5 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 1 m
.50625 1 L
s
gsave
.4875 1 -70.5 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.5 0 m
.5 1 L
s
gsave
.5 1.025 -65.3438 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
67.688 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
0 .5 m
.02472 .5 L
.07049 .5 L
.11348 .5 L
.15481 .5 L
.19881 .5 L
.24117 .5 L
.28619 .5 L
.32956 .5 L
.37128 .5 L
.41567 .5 L
.45842 .5 L
.49951 .5 L
.54327 .5 L
.58539 .5 L
.63017 .5 L
.6733 .5 L
.71478 .5 L
.75893 .5 L
.80144 .5 L
.8466 .5 L
.89012 .5 L
.932 .5 L
.97653 .5 L
s
.97653 .5 m
1 .5 L
s
1 0 1 r
.015 w
.04862 0 m
.04862 1 L
s
0 0 1 r
.16147 0 m
.16147 1 L
s
0 1 0 r
.27431 0 m
.27431 1 L
s
1 0 0 r
.38716 0 m
.38716 1 L
s
0 1 1 r
.5 0 m
.5 1 L
s
1 0 0 r
.61284 0 m
.61284 1 L
s
0 1 0 r
.72569 0 m
.72569 1 L
s
0 0 1 r
.83853 0 m
.83853 1 L
s
1 0 1 r
.95138 0 m
.95138 1 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{220, 220},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\
eJztnFluwjAQhocsFRQoS/PSN07TPvUORKgSVKpAFKk9LHdJvWTDOKlQGYek
f6TEo0zib+yxnXGs5DU+rN8+4sNmFS9e9vFuvVl9Lp63e3HK7xHRUe4LknIi
xPRwpCRJpLI6iWXiy6u/9YmlSkJSGQgp2+X2paWZTDzBSCItUSElFGVakYmQ
AnnjnbrRP8nUy+4wFXn2dJZpARKXPl1mzTjTarsUOeJBTWqLywQd1jgu4IaP
8mbEXrkRAAAAAAAAAAAAAABuACrADN2Fk0YAzR5YFtOVwIIvyuxmuvJgscHn
rgJMXNrcQQEAAAAAAAAAAAAAcARoJFZvBFrMkcJafIfnSObc1MncweHiVSOV
2v4xAAA+gGr9FJhvCFiQtqXq6U2ZMZDJnVR4bHgvZ8xK0IqXND6vGRXUuZbu
LU5htcm3A1NzhobfeG0xX1SWDBlllzPiw5wxdzQSsANUjY7TznV9inYGZZvq
YdOu1F37AbZ1B4+tMXhVtLQ3mc+bNGUc1U5HkkctqUdRkI8kzRukvRSaZhCz
o+zAsq8CNgtUbSgDZtxdYWIUNtvlFnLDpxav61BIRyD9Ug0riQpJ5phqKT+X
WM7R2b0iv4GU+pYe2WSZO+rlzjwvAAAAAAAAAAAAAAC4DPB/Fs5uEOpmjQ7L
ZW3smAAAAAAAAAAAAAAAOAJ0/SOrsQWKT6tYWxM+rQIAAAAAAAAAAAAA4FoA
hzFeo7FsI9G7bRXDzQzpqsVd1jgu/aPg2V8Irf8q3Fis2mnVu0W1/VVlZii3
3V9U65qibmtKlibU+wHnP6A/\
\>"],
  ImageRangeCache->{{{0, 219}, {219, 0}} -> {0, -3, 0, 0}}],
 StyleBox["     ",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 220 220 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.5 0.47619 [
[1.025 .5 0 -6.5 ]
[1.025 .5 9.5 6.5 ]
[.5 1.025 -4.4375 0 ]
[.5 1.025 4.4375 13 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(u) show
68.500 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.5 1 L
s
gsave
.5 1.025 -65.4375 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(v) show
67.875 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 1 r
.015 w
.49764 .02382 m
.49701 .02382 L
.49616 .02383 L
.49505 .02384 L
.49347 .02385 L
.49164 .02388 L
.48912 .02393 L
.48577 .02402 L
.48166 .02416 L
.47642 .02439 L
.47026 .02474 L
.46237 .0253 L
.45126 .02631 L
.43786 .02788 L
.4194 .03068 L
.39534 .03545 L
.36627 .04297 L
.33057 .05497 L
.29043 .0724 L
.23766 .10259 L
.18398 .14378 L
.12661 .20447 L
.09603 .24788 L
.07078 .29377 L
.06027 .31725 L
.05022 .34363 L
.04266 .36734 L
.03577 .39395 L
.03229 .41052 L
.02959 .42605 L
.02751 .44075 L
.02659 .44861 L
.02574 .45711 L
.02511 .46478 L
.02464 .47182 L
.02429 .47856 L
.02403 .48567 L
.02386 .4932 L
.02381 .50021 L
.02388 .50791 L
.02397 .51221 L
.02408 .51612 L
.02438 .52326 L
.02475 .52994 L
.02595 .54508 L
.02757 .55975 L
.02981 .57538 L
.03513 .60321 L
.04134 .62801 L
.06121 .68499 L
Mistroke
.08521 .7339 L
.11125 .77501 L
.14104 .8129 L
.19598 .86651 L
.25627 .90909 L
.30553 .93467 L
.34641 .95074 L
.3771 .96006 L
.40247 .9661 L
.42452 .97017 L
.44085 .9725 L
.45449 .97401 L
.46516 .97491 L
.47295 .97542 L
.4785 .97571 L
.48331 .9759 L
.487 .97601 L
.49002 .97609 L
.49219 .97613 L
.49399 .97615 L
.49534 .97617 L
.49642 .97618 L
.49764 .97618 L
Mfstroke
0 0 1 r
.49782 .02472 m
.49646 .02529 L
.494 .02634 L
.49015 .02801 L
.48418 .03068 L
.47389 .03548 L
.458 .04346 L
.43122 .05853 L
.39172 .08489 L
.33828 .13012 L
.30602 .16443 L
.26851 .2139 L
.25157 .24109 L
.23417 .27366 L
.2192 .30728 L
.20696 .341 L
.19583 .38063 L
.19113 .40245 L
.18712 .42625 L
.18565 .4373 L
.18432 .44934 L
.18331 .46078 L
.18293 .46624 L
.18262 .47134 L
.18236 .47635 L
.18217 .48093 L
.18201 .48601 L
.18189 .49147 L
.18183 .4967 L
.18183 .5024 L
.18188 .50778 L
.18198 .51276 L
.18213 .51786 L
.18234 .52323 L
.18286 .53281 L
.18362 .54308 L
.18468 .55427 L
.18718 .57417 L
.19017 .59242 L
.19925 .63291 L
.21198 .67372 L
.22659 .71012 L
.24434 .74605 L
.27919 .80148 L
.3478 .87889 L
.39991 .92102 L
.43519 .94383 L
.45997 .95756 L
.47509 .96509 L
.48505 .96972 L
Mistroke
.49089 .97232 L
.49436 .97381 L
.49661 .97477 L
.49782 .97528 L
Mfstroke
0 1 0 r
.49834 .02548 m
.4973 .02653 L
.49543 .02843 L
.49252 .03141 L
.48803 .03609 L
.4804 .04425 L
.46882 .05718 L
.4499 .07984 L
.42325 .11559 L
.38942 .16953 L
.37012 .20642 L
.34866 .25562 L
.32989 .31076 L
.32254 .33797 L
.31557 .36925 L
.31234 .3868 L
.30972 .40343 L
.30741 .42093 L
.30571 .43702 L
.3044 .453 L
.30392 .46037 L
.30351 .46817 L
.30316 .47655 L
.30304 .48027 L
.30294 .48427 L
.30285 .48857 L
.3028 .49258 L
.30277 .49504 L
.30276 .49736 L
.30276 .50172 L
.30278 .50572 L
.30283 .51003 L
.3029 .5141 L
.30299 .51784 L
.30328 .52649 L
.3037 .53557 L
.30422 .54442 L
.30481 .55262 L
.30652 .5711 L
.31041 .60126 L
.31591 .63247 L
.32318 .66461 L
.33235 .69745 L
.3513 .75105 L
.39205 .8351 L
.42612 .8885 L
.45083 .92132 L
.46903 .94306 L
.48049 .95585 L
.4882 .96409 L
Mistroke
.49278 .96886 L
.49551 .97166 L
.4973 .97348 L
.49834 .97452 L
Mfstroke
1 0 0 r
.4991 .02599 m
.49854 .02735 L
.49753 .02981 L
.49597 .03366 L
.49357 .03964 L
.48952 .04993 L
.48346 .06589 L
.47373 .09297 L
.46042 .13369 L
.44413 .19149 L
.43513 .22907 L
.42537 .27732 L
.41702 .32944 L
.41381 .35459 L
.41078 .38313 L
.40939 .399 L
.40826 .41397 L
.40727 .42965 L
.40654 .44402 L
.40598 .45826 L
.40578 .46481 L
.4056 .47175 L
.40545 .47919 L
.4054 .48249 L
.40536 .48604 L
.40532 .48985 L
.4053 .49342 L
.40529 .49559 L
.40528 .49766 L
.40528 .50152 L
.40529 .50507 L
.40531 .5089 L
.40534 .51252 L
.40538 .51583 L
.4055 .52351 L
.40568 .53158 L
.40591 .53945 L
.40616 .54675 L
.40689 .56323 L
.40856 .59025 L
.41093 .61843 L
.41409 .64779 L
.41811 .67821 L
.42655 .72911 L
.44537 .81332 L
.46183 .87087 L
.47421 .90839 L
.48357 .9344 L
.48957 .9502 L
.49366 .96059 L
Mistroke
.49611 .96669 L
.49758 .9703 L
.49854 .97266 L
.4991 .97401 L
Mfstroke
0 1 1 r
.5 .02616 m
.5 .02764 L
.5 .0303 L
.5 .03444 L
.5 .04087 L
.5 .0519 L
.5 .06887 L
.5 .09739 L
.5 .13964 L
.5 .19853 L
.5 .28405 L
.5 .38733 L
.5 .49865 L
.5 .61707 L
.5 .71827 L
.5 .80386 L
.5 .86369 L
.5 .90337 L
.5 .93118 L
.5 .94818 L
.5 .9594 L
.5 .96599 L
.5 .96989 L
.5 .97242 L
.5 .97384 L
s
1 0 0 r
.5009 .02599 m
.50146 .02735 L
.50247 .02981 L
.50403 .03366 L
.50643 .03964 L
.51048 .04993 L
.51654 .06589 L
.52627 .09297 L
.53958 .13369 L
.55587 .19149 L
.56487 .22907 L
.57463 .27732 L
.58298 .32944 L
.58619 .35459 L
.58922 .38313 L
.59061 .399 L
.59174 .41397 L
.59273 .42965 L
.59346 .44402 L
.59402 .45826 L
.59422 .46481 L
.5944 .47175 L
.59455 .47919 L
.5946 .48249 L
.59464 .48604 L
.59468 .48985 L
.5947 .49342 L
.59471 .49559 L
.59472 .49766 L
.59472 .50152 L
.59471 .50507 L
.59469 .5089 L
.59466 .51252 L
.59462 .51583 L
.5945 .52351 L
.59432 .53158 L
.59409 .53945 L
.59384 .54675 L
.59311 .56323 L
.59144 .59025 L
.58907 .61843 L
.58591 .64779 L
.58189 .67821 L
.57345 .72911 L
.55463 .81332 L
.53817 .87087 L
.52579 .90839 L
.51643 .9344 L
.51043 .9502 L
.50634 .96059 L
Mistroke
.50389 .96669 L
.50242 .9703 L
.50146 .97266 L
.5009 .97401 L
Mfstroke
0 1 0 r
.50166 .02548 m
.5027 .02653 L
.50457 .02843 L
.50748 .03141 L
.51197 .03609 L
.5196 .04425 L
.53118 .05718 L
.5501 .07984 L
.57675 .11559 L
.61058 .16953 L
.62988 .20642 L
.65134 .25562 L
.67011 .31076 L
.67746 .33797 L
.68443 .36925 L
.68766 .3868 L
.69028 .40343 L
.69259 .42093 L
.69429 .43702 L
.6956 .453 L
.69608 .46037 L
.69649 .46817 L
.69684 .47655 L
.69696 .48027 L
.69706 .48427 L
.69715 .48857 L
.6972 .49258 L
.69723 .49504 L
.69724 .49736 L
.69724 .50172 L
.69722 .50572 L
.69717 .51003 L
.6971 .5141 L
.69701 .51784 L
.69672 .52649 L
.6963 .53557 L
.69578 .54442 L
.69519 .55262 L
.69348 .5711 L
.68959 .60126 L
.68409 .63247 L
.67682 .66461 L
.66765 .69745 L
.6487 .75105 L
.60795 .8351 L
.57388 .8885 L
.54917 .92132 L
.53097 .94306 L
.51951 .95585 L
.5118 .96409 L
Mistroke
.50722 .96886 L
.50449 .97166 L
.5027 .97348 L
.50166 .97452 L
Mfstroke
0 0 1 r
.50218 .02472 m
.50354 .02529 L
.506 .02634 L
.50985 .02801 L
.51582 .03068 L
.52611 .03548 L
.542 .04346 L
.56878 .05853 L
.60828 .08489 L
.66172 .13012 L
.69398 .16443 L
.73149 .2139 L
.74843 .24109 L
.76583 .27366 L
.7808 .30728 L
.79304 .341 L
.80417 .38063 L
.80887 .40245 L
.81288 .42625 L
.81435 .4373 L
.81568 .44934 L
.81669 .46078 L
.81707 .46624 L
.81738 .47134 L
.81764 .47635 L
.81783 .48093 L
.81799 .48601 L
.81811 .49147 L
.81817 .4967 L
.81817 .5024 L
.81812 .50778 L
.81802 .51276 L
.81787 .51786 L
.81766 .52323 L
.81714 .53281 L
.81638 .54308 L
.81532 .55427 L
.81282 .57417 L
.80983 .59242 L
.80075 .63291 L
.78802 .67372 L
.77341 .71012 L
.75566 .74605 L
.72081 .80148 L
.6522 .87889 L
.60009 .92102 L
.56481 .94383 L
.54003 .95756 L
.52491 .96509 L
.51495 .96972 L
Mistroke
.50911 .97232 L
.50564 .97381 L
.50339 .97477 L
.50218 .97528 L
Mfstroke
1 0 1 r
.50236 .02382 m
.50299 .02382 L
.50384 .02383 L
.50495 .02384 L
.50653 .02385 L
.50836 .02388 L
.51088 .02393 L
.51423 .02402 L
.51834 .02416 L
.52358 .02439 L
.52974 .02474 L
.53763 .0253 L
.54874 .02631 L
.56214 .02788 L
.5806 .03068 L
.60466 .03545 L
.63373 .04297 L
.66943 .05497 L
.70957 .0724 L
.76234 .10259 L
.81602 .14378 L
.87339 .20447 L
.90397 .24788 L
.92922 .29377 L
.93973 .31725 L
.94978 .34363 L
.95734 .36734 L
.96423 .39395 L
.96771 .41052 L
.97041 .42605 L
.97249 .44075 L
.97341 .44861 L
.97426 .45711 L
.97489 .46478 L
.97536 .47182 L
.97571 .47856 L
.97597 .48567 L
.97614 .4932 L
.97619 .50021 L
.97612 .50791 L
.97603 .51221 L
.97592 .51612 L
.97562 .52326 L
.97525 .52994 L
.97405 .54508 L
.97243 .55975 L
.97019 .57538 L
.96487 .60321 L
.95866 .62801 L
.93879 .68499 L
Mistroke
.91479 .7339 L
.88875 .77501 L
.85896 .8129 L
.80402 .86651 L
.74373 .90909 L
.69447 .93467 L
.65359 .95074 L
.6229 .96006 L
.59753 .9661 L
.57548 .97017 L
.55915 .9725 L
.54551 .97401 L
.53484 .97491 L
.52705 .97542 L
.5215 .97571 L
.51669 .9759 L
.513 .97601 L
.50998 .97609 L
.50781 .97613 L
.50601 .97615 L
.50466 .97617 L
.50358 .97618 L
.50236 .97618 L
Mfstroke
0 g
gsave
1.00952 .44286 -65.75 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
68.500 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
-0.01905 .44286 -68.9375 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.375 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
74.875 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.45714 1.00952 -65.75 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
68.500 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.45238 -0.02381 -68.9375 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.375 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
74.875 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{220, 220},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
  ImageRangeCache->{{{0, 219}, {219, 0}} -> {-1, -1, 0, 0}}],
 StyleBox["  \n\tFigure 5.8",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Vertical segments mapped onto circular arcs by  ",
 Cell[BoxData[
  RowBox[{"w", " ", "=", 
   RowBox[{"tan", " ", "z"}]}]]],
 ". "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["\<\
Enter the formula f[z] = Tan[z] and graph the transformation.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", "z", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "Iden"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"Iden", "[", "z_", "]"}], " ", "=", " ", "z"}], ";"}], " ", "\n",
    
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"Tan", "[", "z", "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"CartesianMap", "[", 
    RowBox[{"Iden", ",", " ", 
     RowBox[{"{", 
      RowBox[{
       FractionBox[
        RowBox[{"-", "\[Pi]"}], "4"], ",", 
       FractionBox["\[Pi]", "4"], ",", 
       FractionBox["\[Pi]", "16"]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "3", ",", "0.25"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "3.2"}], ",", "3.2"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          FractionBox[
           RowBox[{"-", "\[Pi]"}], "4"], ",", 
          FractionBox["\[Pi]", "4"], ",", 
          FractionBox["\[Pi]", "4"]}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "3", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The lines forming the rectangle \!\(\*FractionBox[\(-\[Pi]\), \
\(4\)]\) \[LessEqual] x \[LessEqual] \!\(\*FractionBox[\(\[Pi]\), \(4\)]\), \
-3 \[LessEqual] y \[LessEqual] 3.\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{"CartesianMap", "[", 
    RowBox[{"f", ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox[
        RowBox[{"-", "\[Pi]"}], "4"], ",", 
       FractionBox["\[Pi]", "4"], ",", 
       FractionBox["\[Pi]", "16"]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "3", ",", "0.25"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.1"}], ",", "1.1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.1"}], ",", "1.1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", "\"\<The image disk  |w| < 1,\>\"", "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<under the mapping  w = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39928689975*^9, 3.3992869163125*^9}, {
  3.399826183781002*^9, 3.399826183937252*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell["\<\
\tHow should we define the complex hyperbolic functions?  We begin with\
\>", "Text"],

Cell[TextData[{
 " ",
 StyleBox["Definition 5.7.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "   The hyperbolic cosine and hyperbolic sine functions are  \n\n\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"cosh", " ", "z"}], " ", "=", " ", 
    RowBox[{
     FractionBox["1", "2"], 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", "z"], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", "z"}]]}], ")"}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"sinh", " ", "z"}], " ", "=", " ", 
   RowBox[{
    FractionBox["1", "2"], 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", "z"], "-", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", "z"}]]}], ")"}]}]}]}]],
 "  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
\tWith these definitions in place, we can now easily create the other complex \
hyperbolic trigonometric functions, provided the denominators in the \
following expressions are not zero.\
\>", "Text"],

Cell[TextData[{
 " ",
 StyleBox["Definition 5.8.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "   Identities for the hyperbolic trigonometric functions are  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"tanh", " ", "z"}], " ", "=", " ", 
    FractionBox[
     RowBox[{"sinh", " ", "z"}], 
     RowBox[{"cosh", " ", "z"}]]}], " ", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"coth", " ", "z"}], " ", "=", " ", 
    FractionBox[
     RowBox[{"cosh", " ", "z"}], 
     RowBox[{"sinh", " ", "z"}]]}], " ", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"sech", " ", "z"}], " ", "=", " ", 
    FractionBox["1", 
     RowBox[{"cosh", " ", "z"}]]}], " ", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"csch", " ", "z"}], " ", "=", " ", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"sinh", " ", "z"}]], " ", 
     StyleBox[".",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]]}]}]}]]],
 "    "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "\tAs the series for the complex hyperbolic sine and cosine agree with the \
real hyperbolic sine and cosine when ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " is real, the remaining complex hyperbolic trigonometric functions likewise \
agree with their real counterparts.  Many other properties are also shared.  \
We state several results without proof, as they follow from the definitions \
we gave using standard operations, such as the quotient rule for derivatives. \
 We ask you to establish some of these identities in the exercises."
}], "Text",
 CellChangeTimes->{{3.39928617425*^9, 3.399286180265625*^9}}],

Cell[TextData[{
 "\tThe derivatives of the hyperbolic functions follow the same rules as in \
calculus:  \n\n\t\t\t",
 Cell[BoxData[GridBox[{
    {
     RowBox[{
      RowBox[{
       RowBox[{
        FractionBox["d", "dz"], "cosh", " ", "z"}], " ", "=", " ", 
       RowBox[{"sinh", " ", "z"}]}], " ", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "                "}], 
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], 
     RowBox[{
      RowBox[{
       RowBox[{
        FractionBox["d", "dz"], "Sinh", " ", "z"}], " ", "=", " ", 
       RowBox[{"cosh", " ", "z"}]}], " ", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "                "}]},
    {
     RowBox[{"\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{
         FractionBox["d", "dz"], "Tanh", " ", "z"}], " ", "=", " ", 
        RowBox[{
         SuperscriptBox["sech", "2"], "z"}]}], " ", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "              "}]}], 
     RowBox[{"\[IndentingNewLine]", 
      StyleBox["and",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]]}], 
     RowBox[{"\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{
         FractionBox["d", "dz"], "coth", " ", "z"}], " ", "=", " ", 
        RowBox[{
         RowBox[{"-", " ", 
          SuperscriptBox["csch", "2"]}], "z"}]}], " ", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "          "}]}]},
    {
     RowBox[{"\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{
         FractionBox["d", "dz"], "sech", " ", "z"}], " ", "=", " ", 
        RowBox[{
         RowBox[{"-", " ", "sech"}], " ", "z", " ", "Tanh", " ", "z"}]}], " ",
        
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]]}]}], 
     RowBox[{"\[IndentingNewLine]", 
      StyleBox["and",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]]}], 
     RowBox[{"\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        FractionBox["d", "dz"], "csch", " ", "z"}], " ", "=", " ", 
       RowBox[{
        RowBox[{"-", " ", "csch"}], " ", "z", " ", "coth", " ", 
        RowBox[{"z", 
         StyleBox[" ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontVariations->{"StrikeThrough"->False,
          "Underline"->False},
          FontColor->GrayLevel[0]], 
         StyleBox[".",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontVariations->{"StrikeThrough"->False,
          "Underline"->False},
          FontColor->GrayLevel[0]]}]}]}]}]}
   }]]],
 "  "
}], "Text"],

Cell[TextData[{
 "\tThe hyperbolic cosine and hyperbolic sine can be expressed as  \n\n\t\t\t\
",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"cosh", " ", "z"}], "  ", "=", " ", 
    RowBox[{
     RowBox[{"cosh", 
      RowBox[{"(", 
       RowBox[{"x", "+", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], " ", "=", " ", 
     RowBox[{
      RowBox[{"cos", " ", "y", "  ", "cosh", " ", "x"}], "  ", "+", " ", 
      RowBox[{
      "\[ImaginaryI]", " ", "sinh", " ", "x", " ", "sin", " ", "y"}]}]}]}], 
   "\n"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"sinh", " ", "z"}], " ", "=", " ", 
   RowBox[{
    RowBox[{"sinh", 
     RowBox[{"(", 
      RowBox[{"x", "+", 
       RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "  ", "=", " ", 
    RowBox[{
     RowBox[{"sinh", " ", "x", " ", "cos", " ", "y"}], "  ", "+", " ", 
     RowBox[{
     "\[ImaginaryI]", " ", "cosh", " ", "x", "  ", "sin", " ", "y"}]}]}]}]}]]
}], "Text"],

Cell[TextData[{
 "\tSome of the important identities involving the hyperbolic functions are  \
\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["cosh", "2"], "z"}], " ", "-", " ", 
     RowBox[{
      SuperscriptBox["sinh", "2"], "z"}]}], " ", "=", " ", "1"}], " ", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "\[IndentingNewLine]", "\n", 
   RowBox[{
    RowBox[{"sinh", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["z", "1"], "+", 
       SubscriptBox["z", "2"]}], ")"}]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{"sinh", " ", 
      SubscriptBox["z", "1"], " ", "cosh", " ", 
      SubscriptBox["z", "2"]}], "  ", "+", " ", 
     RowBox[{"cosh", " ", 
      SubscriptBox["z", "1"], " ", "sinh", " ", 
      SubscriptBox["z", "2"]}]}]}], " ", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "\[IndentingNewLine]", "\n", 
   RowBox[{
    RowBox[{"cosh", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["z", "1"], "+", 
       SubscriptBox["z", "2"]}], ")"}]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{"cosh", " ", 
      SubscriptBox["z", "1"], " ", "cosh", " ", 
      SubscriptBox["z", "2"]}], "  ", "+", " ", 
     RowBox[{"sinh", " ", 
      SubscriptBox["z", "1"], " ", "sinh", " ", 
      SubscriptBox["z", "2"]}]}]}], " ", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "\[IndentingNewLine]", "\n", 
   RowBox[{
    RowBox[{"cosh", 
     RowBox[{"(", 
      RowBox[{"z", "+", 
       RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]"}]}], ")"}]}], " ", "=", " ",
     
    RowBox[{"cosh", " ", "z"}]}], " ", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "\[IndentingNewLine]", "\n", 
   RowBox[{
    RowBox[{"sinh", 
     RowBox[{"(", 
      RowBox[{"z", "+", 
       RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]"}]}], ")"}]}], " ", "=", " ",
     
    RowBox[{"sinh", " ", "z"}]}], " ", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "\[IndentingNewLine]", "\n", 
   RowBox[{
    RowBox[{"cosh", 
     RowBox[{"(", 
      RowBox[{"-", "z"}], ")"}]}], " ", "=", "  ", 
    RowBox[{"cosh", " ", "z"}]}], " ", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "\[IndentingNewLine]", "\n", 
   RowBox[{
    RowBox[{"sinh", 
     RowBox[{"(", 
      RowBox[{"-", "z"}], ")"}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{"-", " ", "sinh"}], " ", 
     RowBox[{"z", " ", 
      StyleBox[".",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]]}]}]}]}]]],
 "    "
}], "Text"],

Cell["\<\
The \"legacy version\" being used to implement the commands \"CartesianMap \
and PolarMap.\"  The following Initialization Cell will load these \
subroutines. \
\>", "Text",
 CellChangeTimes->{{3.399722161203125*^9, 3.399722165296875*^9}, {
  3.39972222759375*^9, 3.3997223229375*^9}, {3.399722389046875*^9, 
  3.399722641234375*^9}, {3.399722683734375*^9, 3.3997227230625*^9}, {
  3.3997227559375*^9, 3.399722850765625*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Initialization Cell",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text",
 CellChangeTimes->{{3.399722161203125*^9, 3.399722165296875*^9}, {
  3.39972222759375*^9, 3.3997223229375*^9}, {3.399722389046875*^9, 
  3.399722641234375*^9}, {3.399722683734375*^9, 3.3997227230625*^9}, {
  3.3997227559375*^9, 3.399722850765625*^9}, {3.399742279828125*^9, 
  3.39974228209375*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}]], "Input",\

 InitializationCell->True]
}, Closed]],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Exponential Function",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/ExponentialFunBib.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Complex Logarithms",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/LogarithmFunBib.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Conformal Mapping",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/ConformalMappingBib.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Smith Chart",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/SmithChartBib.html"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/complex.html"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2008 John H. Mathews, Russell W. \
Howell",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/"], None}],
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[0, 1, 0]]], "Text",
 CellChangeTimes->{{3.3992862041875*^9, 3.399286204296875*^9}}]
},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{963, 610},
WindowMargins->{{1, Automatic}, {Automatic, 0}},
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "CHAPTER 1"->{
  Cell[568, 21, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"CHAPTER 1", 286279, 11411}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"],
Cell[905, 32, 131, 2, 29, "Text"],
Cell[1039, 36, 1401, 45, 181, "Text"],
Cell[2443, 83, 2177, 77, 181, "Text",
 Evaluatable->False],
Cell[4623, 162, 746, 29, 42, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[5394, 195, 150, 4, 29, "Text",
 Evaluatable->False],
Cell[5547, 201, 216, 6, 29, "Text"],
Cell[5766, 209, 1055, 31, 152, "Input"],
Cell[6824, 242, 146, 4, 29, "Text",
 Evaluatable->False],
Cell[6973, 248, 3398, 97, 411, "Input"],
Cell[10374, 347, 127, 5, 29, "Text"],
Cell[10504, 354, 4859, 133, 393, "Input"]
}, Closed]],
Cell[15378, 490, 642, 25, 39, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[16045, 519, 151, 4, 29, "Text",
 Evaluatable->False],
Cell[16199, 525, 262, 8, 29, "Text",
 Evaluatable->False],
Cell[16464, 535, 1053, 31, 152, "Input"],
Cell[17520, 568, 146, 4, 29, "Text",
 Evaluatable->False],
Cell[17669, 574, 3130, 89, 411, "Input"],
Cell[20802, 665, 129, 5, 47, "Text"],
Cell[20934, 672, 4601, 124, 393, "Input"]
}, Closed]],
Cell[25550, 799, 250, 6, 26, "Text",
 Evaluatable->False],
Cell[25803, 807, 725, 31, 36, "Text"],
Cell[CellGroupData[{
Cell[26553, 842, 165, 4, 29, "Text",
 Evaluatable->False],
Cell[26721, 848, 253, 7, 68, "Input"],
Cell[26977, 857, 251, 7, 68, "Input"],
Cell[27231, 866, 221, 6, 68, "Input"],
Cell[27455, 874, 219, 6, 68, "Input"]
}, Closed]],
Cell[27689, 883, 407, 9, 44, "Text"],
Cell[28099, 894, 683, 30, 35, "Text"],
Cell[CellGroupData[{
Cell[28807, 928, 109, 2, 29, "Text"],
Cell[28919, 932, 3107, 104, 261, "Text"],
Cell[32029, 1038, 277, 11, 35, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[32343, 1054, 162, 4, 26, "Text",
 Evaluatable->False],
Cell[32508, 1060, 309, 8, 52, "Input"],
Cell[32820, 1070, 327, 9, 52, "Input"]
}, Closed]],
Cell[33162, 1082, 1101, 41, 139, "Text"],
Cell[34266, 1125, 1015, 43, 47, "Text"],
Cell[CellGroupData[{
Cell[35306, 1172, 161, 4, 29, "Text",
 Evaluatable->False],
Cell[35470, 1178, 313, 8, 52, "Input"],
Cell[35786, 1188, 295, 7, 52, "Input"],
Cell[36084, 1197, 447, 13, 72, "Input"]
}, Closed]],
Cell[36546, 1213, 273, 9, 26, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[36844, 1226, 159, 4, 29, "Text",
 Evaluatable->False],
Cell[37006, 1232, 168, 5, 29, "Text"],
Cell[37177, 1239, 1899, 55, 280, "Input"]
}, Closed]],
Cell[39091, 1297, 344, 12, 26, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[39460, 1313, 160, 4, 29, "Text",
 Evaluatable->False],
Cell[39623, 1319, 168, 5, 29, "Text"],
Cell[39794, 1326, 2116, 61, 300, "Input"]
}, Closed]],
Cell[41925, 1390, 2459, 79, 200, "Text"],
Cell[CellGroupData[{
Cell[44409, 1473, 140, 4, 29, "Text",
 Evaluatable->False],
Cell[44552, 1479, 2228, 82, 183, "Text"],
Cell[46783, 1563, 90, 2, 29, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[46910, 1570, 165, 4, 26, "Text",
 Evaluatable->False],
Cell[47078, 1576, 309, 8, 52, "Input"],
Cell[47390, 1586, 330, 9, 52, "Input"],
Cell[47723, 1597, 338, 9, 52, "Input"],
Cell[48064, 1608, 359, 10, 52, "Input"]
}, Closed]],
Cell[48438, 1621, 1868, 58, 152, "Text"],
Cell[50309, 1681, 1181, 43, 160, "Text"],
Cell[51493, 1726, 52649, 2927, 222, "Text"],
Cell[104145, 4655, 1050, 35, 101, "Text"],
Cell[CellGroupData[{
Cell[105220, 4694, 94, 2, 29, "Text"],
Cell[105317, 4698, 3992, 125, 290, "Text"],
Cell[109312, 4825, 3020, 93, 207, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[112369, 4923, 196, 5, 26, "Text",
 Evaluatable->False],
Cell[112568, 4930, 818, 22, 76, "Input"],
Cell[113389, 4954, 764, 21, 76, "Input"],
Cell[114156, 4977, 863, 24, 76, "Input"],
Cell[115022, 5003, 1002, 28, 111, "Input"],
Cell[116027, 5033, 940, 27, 109, "Input"],
Cell[116970, 5062, 904, 26, 72, "Input"],
Cell[117877, 5090, 903, 26, 72, "Input"]
}, Closed]],
Cell[118795, 5119, 3352, 112, 271, "Text"],
Cell[122150, 5233, 1590, 51, 178, "Text"],
Cell[CellGroupData[{
Cell[123765, 5288, 175, 4, 29, "Text",
 Evaluatable->False],
Cell[123943, 5294, 1183, 34, 92, "Input"],
Cell[125129, 5330, 1187, 34, 92, "Input"],
Cell[126319, 5366, 1360, 41, 92, "Input"],
Cell[127682, 5409, 1388, 42, 92, "Input"],
Cell[129073, 5453, 1367, 41, 92, "Input"],
Cell[130443, 5496, 1391, 41, 92, "Input"]
}, Closed]],
Cell[131849, 5540, 3771, 127, 220, "Text"],
Cell[135623, 5669, 3999, 130, 227, "Text"],
Cell[139625, 5801, 684, 26, 29, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[140334, 5831, 111, 2, 29, "Text"],
Cell[140448, 5835, 916, 29, 41, "Text"],
Cell[141367, 5866, 6618, 186, 711, "Input"],
Cell[147988, 6054, 577, 23, 47, "Text",
 Evaluatable->False]
}, Closed]],
Cell[CellGroupData[{
Cell[148602, 6082, 112, 2, 26, "Text"],
Cell[148717, 6086, 120, 5, 29, "Text"],
Cell[148840, 6093, 4877, 142, 492, "Input"],
Cell[153720, 6237, 529, 21, 29, "Text"]
}, Closed]],
Cell[154264, 6261, 3740, 138, 347, "Text"],
Cell[CellGroupData[{
Cell[158029, 6403, 100, 2, 29, "Text"],
Cell[158132, 6407, 166, 5, 29, "Text"],
Cell[158301, 6414, 1906, 56, 272, "Input"],
Cell[160210, 6472, 683, 22, 53, "Text",
 Evaluatable->False],
Cell[160896, 6496, 1208, 34, 192, "Input"],
Cell[162107, 6532, 101, 2, 29, "Text",
 Evaluatable->False],
Cell[162211, 6536, 745, 20, 131, "Input"],
Cell[162959, 6558, 118, 2, 29, "Text",
 Evaluatable->False],
Cell[163080, 6562, 2864, 83, 368, "Input"],
Cell[165947, 6647, 166, 7, 29, "Text",
 Evaluatable->False],
Cell[166116, 6656, 1012, 28, 140, "Input"]
}, Closed]],
Cell[167143, 6687, 2474, 85, 86, "Text"],
Cell[169620, 6774, 30510, 1464, 213, "Text"],
Cell[CellGroupData[{
Cell[200155, 8242, 100, 2, 29, "Text"],
Cell[200258, 8246, 85, 2, 29, "Text"],
Cell[200346, 8250, 4195, 121, 351, "Input"],
Cell[204544, 8373, 4202, 121, 351, "Input"]
}, Closed]],
Cell[208761, 8497, 3485, 112, 341, "Text"],
Cell[212249, 8611, 1316, 47, 103, "Text"],
Cell[CellGroupData[{
Cell[213590, 8662, 100, 2, 29, "Text"],
Cell[213693, 8666, 2544, 73, 323, "Input"],
Cell[216240, 8741, 2546, 73, 323, "Input"]
}, Closed]],
Cell[218801, 8817, 176, 3, 26, "Text"],
Cell[218980, 8822, 351, 15, 29, "Text",
 Evaluatable->False],
Cell[219334, 8839, 2426, 88, 216, "Text"],
Cell[221763, 8929, 879, 32, 47, "Text"],
Cell[CellGroupData[{
Cell[222667, 8965, 110, 2, 29, "Text"],
Cell[222780, 8969, 170, 5, 29, "Text"],
Cell[222953, 8976, 1938, 55, 272, "Input"],
Cell[224894, 9033, 122, 2, 29, "Text",
 Evaluatable->False],
Cell[225019, 9037, 1248, 35, 192, "Input"],
Cell[226270, 9074, 101, 2, 29, "Text",
 Evaluatable->False],
Cell[226374, 9078, 1379, 36, 172, "Input"]
}, Closed]],
Cell[227768, 9117, 3310, 109, 256, "Text"],
Cell[CellGroupData[{
Cell[231103, 9230, 146, 4, 29, "Text",
 Evaluatable->False],
Cell[231252, 9236, 5456, 163, 727, "Input"]
}, Closed]],
Cell[236723, 9402, 2021, 71, 74, "Text"],
Cell[238747, 9475, 27632, 1305, 255, "Text"],
Cell[CellGroupData[{
Cell[266404, 10784, 100, 2, 29, "Text"],
Cell[266507, 10788, 85, 2, 29, "Text"],
Cell[266595, 10792, 3891, 112, 347, "Input"]
}, Closed]],
Cell[270501, 10907, 95, 2, 26, "Text"],
Cell[270599, 10911, 862, 30, 115, "Text",
 Evaluatable->False],
Cell[271464, 10943, 210, 4, 47, "Text"],
Cell[271677, 10949, 1859, 62, 188, "Text",
 Evaluatable->False],
Cell[273539, 11013, 638, 11, 65, "Text"],
Cell[274180, 11026, 4158, 131, 161, "Text"],
Cell[278341, 11159, 949, 28, 104, "Text"],
Cell[279293, 11189, 3650, 120, 294, "Text"],
Cell[282946, 11311, 435, 8, 29, "Text"],
Cell[CellGroupData[{
Cell[283406, 11323, 407, 7, 29, "Text"],
Cell[283816, 11332, 132, 4, 31, "Input",
 InitializationCell->True]
}, Closed]],
Cell[283963, 11339, 281, 7, 26, "Text"],
Cell[284247, 11348, 282, 7, 29, "Text"],
Cell[284532, 11357, 278, 7, 29, "Text"],
Cell[284813, 11366, 281, 7, 29, "Text"],
Cell[285097, 11375, 265, 6, 29, "Text"],
Cell[285365, 11383, 249, 5, 29, "Text"],
Cell[285617, 11390, 318, 7, 29, "Text"]
}
]
*)

(* End of internal cache information *)
