(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     71413,       2277]
NotebookOptionsPosition[     68649,       2184]
NotebookOutlinePosition[     69173,       2208]
CellTagsIndexPosition[     69100,       2203]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["Chapter 6  Complex Integration",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
 StyleBox["Overview",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "\n\n\tOf the two main topics studied in calculus - differentiation and \
integration - we have so far only studied derivatives of complex functions.  \
We now turn to the problem of integrating complex functions.  The theory you \
will learn is elegant, powerful, and a useful tool for physicists and \
engineers.  It also connects widely with other branches of mathematics.  For \
example, even though the ideas presented here belong to the general area of \
mathematics known as analysis, you will see as an application of them one of \
the simplest proofs of the fundamental theorem of algebra. "
}], "Text",
 CellChangeTimes->{{3.39928771425*^9, 3.399287720546875*^9}, 
   3.399882467875*^9}],

Cell[TextData[StyleBox["6.1  Complex Integrals",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell["\<\
\tIn Chapter 3 we saw how the derivative of a complex function is defined.  \
We now turn our attention to the problem of integrating complex functions.  \
We will find that integrals of analytic functions are well behaved and that \
many properties from calculus carry over to the complex case.  \
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
\tWe introduce the integral of a complex function by defining the integral of \
a complex-valued function of a real variable\
\>", "Text"],

Cell[TextData[{
 StyleBox["Definition 6.1 (",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Definite Integral",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/FundamentalTheoremsofCalculus.html"], 
    None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 StyleBox[" of a Complex Integrand).",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Let  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "t", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"u", 
     RowBox[{"(", "t", ")"}]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", "v", 
     RowBox[{"(", "t", ")"}]}]}]}]]],
 "  where ",
 StyleBox["u(t)",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["v(t)",
  FontFamily->"Courier New"],
 " are real-valued functions of the real variable ",
 StyleBox["t",
  FontFamily->"Courier New"],
 " for  ",
 Cell[BoxData[
  RowBox[{"a", "\[LessEqual]", "t", "\[LessEqual]", "b"}]]],
 " .  Then\n\n",
 StyleBox["(6-1)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[Integral]", "a", "b"], " ", 
    RowBox[{"f", 
     RowBox[{"(", "t", ")"}], 
     RowBox[{"\[DifferentialD]", "t"}]}]}], "  ", "=", "   ", 
   RowBox[{
    RowBox[{
     SubsuperscriptBox["\[Integral]", "a", "b"], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"u", 
         RowBox[{"(", "t", ")"}]}], "+", 
        RowBox[{"\[ImaginaryI]", " ", "v", 
         RowBox[{"(", "t", ")"}]}]}], ")"}], 
      RowBox[{"\[DifferentialD]", "t"}]}]}], "   ", "=", "  ", 
    RowBox[{
     RowBox[{
      SubsuperscriptBox["\[Integral]", "a", "b"], " ", 
      RowBox[{"u", 
       RowBox[{"(", "t", ")"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}], "  ", "+", "  ", 
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{
       SubsuperscriptBox["\[Integral]", "a", "b"], " ", 
       RowBox[{"v", 
        RowBox[{"(", "t", ")"}], 
        RowBox[{"\[DifferentialD]", "t"}]}]}]}]}]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "\tWe generally evaluate integrals of this type by finding the \
antiderivatives of ",
 StyleBox["u(t)",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["v(t)",
  FontFamily->"Courier New"],
 " and evaluating the definite integrals on the right side of Equation ",
 StyleBox["(6-1)",
  FontColor->RGBColor[0, 0, 1]],
 ".  That is, if  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"U", "'"}], 
    RowBox[{"(", "t", ")"}]}], " ", "=", " ", 
   RowBox[{"u", 
    RowBox[{"(", "t", ")"}]}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"V", "'"}], 
    RowBox[{"(", "t", ")"}]}], " ", "=", " ", 
   RowBox[{"v", 
    RowBox[{"(", "t", ")"}]}]}]]],
 ",  we have  \n\n",
 StyleBox["(6-2)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[Integral]", "a", "b"], " ", 
    RowBox[{"f", 
     RowBox[{"(", "t", ")"}], 
     RowBox[{"\[DifferentialD]", "t"}]}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubsuperscriptBox["\[Integral]", "a", "b"], " ", 
      RowBox[{"u", 
       RowBox[{"(", "t", ")"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}], "  ", "+", "  ", 
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{
       SubsuperscriptBox["\[Integral]", "a", "b"], " ", 
       RowBox[{"v", 
        RowBox[{"(", "t", ")"}], 
        RowBox[{"\[DifferentialD]", "t"}]}]}]}]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{"U", 
      RowBox[{"(", "b", ")"}]}], "-", 
     RowBox[{"U", 
      RowBox[{"(", "a", ")"}]}], " ", "+", " ", 
     RowBox[{"\[ImaginaryI]", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"V", 
         RowBox[{"(", "b", ")"}]}], "-", 
        RowBox[{"V", 
         RowBox[{"(", "a", ")"}]}]}], ")"}]}]}]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Example 6.1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Show that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[Integral]", "0", "1"], " ", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"t", "-", "\[ImaginaryI]"}], ")"}], "3"], 
     RowBox[{"\[DifferentialD]", "t"}]}]}], "  ", "=", " ", 
   RowBox[{"-", 
    FractionBox["5", "4"]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "Solution.  We write the integrand in terms of its real and imaginary parts, \
i.e.,   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "t", ")"}]}], " ", "=", " ", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"t", "-", "\[ImaginaryI]"}], ")"}], "3"], "  ", "=", "  ", 
    RowBox[{
     SuperscriptBox["t", "3"], "-", 
     RowBox[{"3", " ", "t"}], " ", "+", " ", 
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "3"}], " ", 
         SuperscriptBox["t", "2"]}], "+", "1"}], ")"}]}]}]}]}]]],
 ".  Here,  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"u", 
    RowBox[{"(", "t", ")"}]}], " ", "=", "  ", 
   RowBox[{
    SuperscriptBox["t", "3"], "-", 
    RowBox[{"3", " ", "t"}]}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"v", 
    RowBox[{"(", "t", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"-", " ", "3"}], " ", 
     SuperscriptBox["t", "2"]}], "+", "1"}]}]]],
 ".  The integrals of ",
 StyleBox["u(t)",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["v(t)",
  FontFamily->"Courier New"],
 " are  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[Integral]", "0", "1"], " ", 
    RowBox[{"u", 
     RowBox[{"(", "t", ")"}], 
     RowBox[{"\[DifferentialD]", "t"}]}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     SubsuperscriptBox["\[Integral]", "0", "1"], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["t", "3"], "-", 
        RowBox[{"3", " ", "t"}]}], ")"}], 
      RowBox[{"\[DifferentialD]", "t"}]}]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         SuperscriptBox["t", "4"], "4"], "-", 
        FractionBox[
         RowBox[{"3", " ", 
          SuperscriptBox["t", "2"]}], "2"]}], ")"}], 
      UnderoverscriptBox["\[VerticalSeparator]", 
       RowBox[{"t", "=", "0"}], 
       RowBox[{"t", "=", "1"}]]}], "  ", "=", "  ", 
     RowBox[{"-", 
      FractionBox["5", "4"]}]}]}]}]]],
 ",   and  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[Integral]", "0", "1"], " ", 
    RowBox[{"v", 
     RowBox[{"(", "t", ")"}], 
     RowBox[{"\[DifferentialD]", "t"}]}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     SubsuperscriptBox["\[Integral]", "0", "1"], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "3"}], " ", 
         SuperscriptBox["t", "2"]}], "+", "1"}], ")"}], 
      RowBox[{"\[DifferentialD]", "t"}]}]}], "   ", "=", "  ", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["t", "3"]}], "+", "t"}], ")"}], 
      UnderoverscriptBox["\[VerticalSeparator]", 
       RowBox[{"t", "=", "0"}], 
       RowBox[{"t", "=", "1"}]]}], "  ", "=", "  ", "0"}]}]}]]],
 ".  \n\nHence, by Definition ",
 StyleBox["(6-1)",
  FontColor->RGBColor[0, 0, 1]],
 ",  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     SubsuperscriptBox["\[Integral]", "0", "1"], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"t", "-", "\[ImaginaryI]"}], ")"}], "3"], 
      RowBox[{"\[DifferentialD]", "t"}]}]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", "1"], " ", 
      RowBox[{"u", 
       RowBox[{"(", "t", ")"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}], " ", "+", " ", 
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{
       SubsuperscriptBox["\[Integral]", "0", "1"], " ", 
       RowBox[{"v", 
        RowBox[{"(", "t", ")"}], 
        RowBox[{"\[DifferentialD]", "t"}]}]}]}]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                             ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["5", "4"]}], "+", " ", 
      RowBox[{"0", "\[ImaginaryI]"}]}], "  ", "=", "  ", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["5", "4"]}], " "}]}]}]}]}]]
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 6.1.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 StyleBox["Method (i).",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  Expand the integrand f[t] into its real and imaginary parts, then \
integrate u[t] and v[t]."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", 
     RowBox[{"t", ",", "u", ",", "v", ",", "w"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "f", ",", "Int", ",", "ImInt", ",", "ImVal", ",", "ReInt", ",", "ReVal", 
      ",", "Val"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"w", "=", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"t", " ", "-", " ", "\[ImaginaryI]"}], ")"}], "3"]}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", "w", "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"u", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"Re", "[", 
       RowBox[{"f", "[", "t", "]"}], "]"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"v", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"Im", "[", 
       RowBox[{"f", "[", "t", "]"}], "]"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"U", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"u", "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"V", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"v", "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Int", " ", "=", " ", 
     RowBox[{
      RowBox[{"U", "[", "t", "]"}], " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"V", "[", "t", "]"}]}]}]}], ";"}], " ", "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"ReVal", " ", "=", "  ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", "1"], 
      RowBox[{
       RowBox[{"u", "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ImVal", " ", "=", "  ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", "1"], 
      RowBox[{
       RowBox[{"v", "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Val", " ", "=", " ", 
     RowBox[{"ReVal", " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", "ImVal"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[t] = \>\"", ",", 
      RowBox[{"f", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<f[t] = u[t] + \[ImaginaryI] v[t]\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<u[t] = \>\"", ",", 
      RowBox[{"u", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<v[t] = \>\"", ",", 
      RowBox[{"v", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<U[t] = \[Integral]u[t]\[DifferentialD]t = \>\"", ",", 
      RowBox[{"U", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<V[t] = \[Integral]v[t]\[DifferentialD]t = \>\"", ",", 
      RowBox[{"V", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\[Integral]u[t]\[DifferentialD]t + \[ImaginaryI] \[Integral]v[t]\
\[DifferentialD]t = (\>\"", ",", 
      RowBox[{"U", "[", "t", "]"}], ",", "\"\<) + \[ImaginaryI](\>\"", ",", 
      RowBox[{"V", "[", "t", "]"}], ",", "\"\<)\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(0\), \(1\)]\)\>\"", ",", 
      "w", ",", 
      "\"\<\[DifferentialD]t = \!\(\*SubsuperscriptBox[\(\[Integral]\), \
\(0\), \(1\)]\)u[t]\[DifferentialD]t + \[ImaginaryI] \!\(\*SubsuperscriptBox[\
\(\[Integral]\), \(0\), \(1\)]\)v[t]\[DifferentialD]t\>\""}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(0\), \(1\)]\)\>\"", ",", 
      "w", ",", 
      "\"\<\[DifferentialD]t = (U[1]-U[0]) + \[ImaginaryI](V[1]-V[0])\>\""}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(0\), \(1\)]\)\>\"", ",", 
      "w", ",", "\"\<\[DifferentialD]t = (\>\"", ",", "ReVal", ",", 
      "\"\<) + \[ImaginaryI](\>\"", ",", "ImVal", ",", "\"\<)\>\""}], "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(0\), \(1\)]\)\>\"", ",", 
      "w", ",", "\"\<\[DifferentialD]t = \>\"", ",", "Val"}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399287767953125*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Method (ii).",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  Compute the integral directly using a complex function for the \
integrand."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", "t", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "F", ",", "val"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "t_", "]"}], " ", "=", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"t", " ", "-", " ", "\[ImaginaryI]"}], ")"}], "3"]}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"f", "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"val", " ", "=", " ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", "1"], 
      RowBox[{
       RowBox[{"f", "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[t] = \>\"", ",", 
      RowBox[{"f", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[t] = \[Integral]\>\"", ",", 
      RowBox[{"f", "[", "t", "]"}], ",", "\"\<\[DifferentialD]t = \>\"", ",", 
      
      RowBox[{"F", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(0\), \(1\)]\)\>\"", ",", 
      
      RowBox[{"f", "[", "t", "]"}], ",", 
      "\"\<\[DifferentialD]t = F[1] - F[0]\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(0\), \(1\)]\)\>\"", ",", 
      
      RowBox[{"f", "[", "t", "]"}], ",", "\"\<\[DifferentialD]t = (\>\"", ",",
       
      RowBox[{"F", "[", "1", "]"}], " ", ",", "\"\<) - (\>\"", ",", 
      RowBox[{"F", "[", "0", "]"}], ",", "\"\<)\>\""}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(0\), \(1\)]\)\>\"", ",", 
      
      RowBox[{"f", "[", "t", "]"}], ",", "\"\<\[DifferentialD]t = \>\"", ",", 
      "val"}], "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39928777403125*^9},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 6.2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Show that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[Integral]", "0", 
     RowBox[{"\[Pi]", "/", "2"}]], " ", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"t", "+", 
       RowBox[{"\[ImaginaryI]", " ", "t"}]}]], 
     RowBox[{"\[DifferentialD]", "t"}]}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     FractionBox["1", "2"], 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox["\[Pi]", "2"]], "-", "1"}], ")"}]}], " ", "+", " ", 
    RowBox[{
     FractionBox[
      RowBox[{"\[ImaginaryI]", " "}], "2"], 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox["\[Pi]", "2"]], "+", "1"}], ")"}]}]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "Solution.  We use the method suggested by Definitions ",
 StyleBox["(6-1)",
  FontColor->RGBColor[0, 0, 1]],
 " and ",
 StyleBox["(6-2)",
  FontColor->RGBColor[0, 0, 1]],
 ".  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     SubsuperscriptBox["\[Integral]", "0", 
      RowBox[{"\[Pi]", "/", "2"}]], " ", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"t", " ", "+", " ", 
        RowBox[{"\[ImaginaryI]", " ", "t"}]}]], 
      RowBox[{"\[DifferentialD]", "t"}]}]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", 
       RowBox[{"\[Pi]", "/", "2"}]], " ", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", "t"], 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "t"}]], 
       RowBox[{"\[DifferentialD]", "t"}]}]}], "  ", "=", "  ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", 
       RowBox[{"\[Pi]", "/", "2"}]], " ", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", "t"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"cos", " ", "t"}], "+", 
         RowBox[{"\[ImaginaryI]", " ", "sin", " ", "t"}]}], ")"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}]}], "  ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                            ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", 
       RowBox[{"\[Pi]", "/", "2"}]], " ", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", "t"], " ", "cos", " ", "t", "  ", 
       RowBox[{"\[DifferentialD]", "t"}]}]}], " ", "+", " ", 
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{
       SubsuperscriptBox["\[Integral]", "0", 
        RowBox[{"\[Pi]", "/", "2"}]], " ", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", "t"], " ", "sin", " ", "t", "  ", 
        RowBox[{"\[DifferentialD]", "t"}]}]}]}]}]}]}]}]],
 "  "
}], "Text"],

Cell[TextData[{
 "We can evaluate each of the integrals via integration by parts.  For \
example,  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     SubsuperscriptBox["\[Integral]", "0", 
      RowBox[{"\[Pi]", "/", "2"}]], " ", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", "t"], " ", "cos", " ", "t", "  ", 
      RowBox[{"\[DifferentialD]", "t"}]}]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", "t"], " ", "sin", " ", "t"}], ")"}], 
     
     UnderoverscriptBox["\[VerticalSeparator]", 
      RowBox[{"t", "=", "0"}], 
      RowBox[{"t", "=", 
       RowBox[{"\[Pi]", "/", "2"}]}]], "   ", 
     RowBox[{"-", "    ", 
      RowBox[{
       SubsuperscriptBox["\[Integral]", "0", 
        RowBox[{"\[Pi]", "/", "2"}]], 
       RowBox[{"sin", " ", "t", "  ", 
        SuperscriptBox["\[ExponentialE]", "t"], 
        RowBox[{"\[DifferentialD]", "t"}]}]}]}]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                                 ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"\[Pi]", "/", "2"}]], " ", "sin", 
         FractionBox["\[Pi]", "2"]}], " ", "-", " ", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", "0"], " ", "sin", " ", "0"}]}], 
       ")"}], "  ", "-", "  ", 
      RowBox[{
       SubsuperscriptBox["\[Integral]", "0", 
        RowBox[{"\[Pi]", "/", "2"}]], 
       RowBox[{"sin", " ", "t", "  ", 
        SuperscriptBox["\[ExponentialE]", "t"], 
        RowBox[{"\[DifferentialD]", "t"}]}]}]}]}], " ", "\[IndentingNewLine]",
     " "}]}], "\[IndentingNewLine]", 
  RowBox[{"                                 ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"\[Pi]", "/", "2"}]], "1"}], "-", 
        RowBox[{"1", "*", "0"}]}], ")"}], "  ", "-", "   ", 
      RowBox[{
       SubsuperscriptBox["\[Integral]", "0", 
        RowBox[{"\[Pi]", "/", "2"}]], " ", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", "t"], "sin", " ", "t", "  ", 
        RowBox[{"\[DifferentialD]", "t"}]}]}]}]}], " ", 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                                 ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[Pi]", "/", "2"}]], "  ", "-", "   ", 
      RowBox[{
       SubsuperscriptBox["\[Integral]", "0", 
        RowBox[{"\[Pi]", "/", "2"}]], " ", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", "t"], "sin", " ", "t", "  ", 
        RowBox[{"\[DifferentialD]", "t"}]}]}]}]}], " ", 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                                 ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[Pi]", "/", "2"}]], "  ", "-", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", "t"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "cos"}], " ", "t"}], ")"}]}], ")"}]}], 
      UnderoverscriptBox["\[VerticalSeparator]", 
       RowBox[{"t", "=", "0"}], 
       RowBox[{"t", "=", 
        RowBox[{"\[Pi]", "/", "2"}]}]], "  ", 
      RowBox[{"+", "   ", 
       RowBox[{
        SubsuperscriptBox["\[Integral]", "0", 
         RowBox[{"\[Pi]", "/", "2"}]], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", " ", "cos"}], " ", "t", " ", 
           SuperscriptBox["\[ExponentialE]", "t"]}], ")"}], 
         RowBox[{"\[DifferentialD]", "t"}]}]}]}]}]}], " ", 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                                 ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[Pi]", "/", "2"}]], "  ", "+", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", "t"], " ", "cos", " ", "t"}], 
        ")"}]}], 
      UnderoverscriptBox["\[VerticalSeparator]", 
       RowBox[{"t", "=", "0"}], 
       RowBox[{"t", "=", 
        RowBox[{"\[Pi]", "/", "2"}]}]], "  ", 
      RowBox[{"-", "   ", 
       RowBox[{
        SubsuperscriptBox["\[Integral]", "0", 
         RowBox[{"\[Pi]", "/", "2"}]], " ", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", "t"], "cos", " ", "t", "  ", 
         RowBox[{"\[DifferentialD]", "t"}]}]}]}]}]}], " ", 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                                 ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[Pi]", "/", "2"}]], "  ", "+", " ", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[Pi]", "/", "2"}]], "*", "0"}], "-", 
      RowBox[{"1", "*", "1"}], "  ", "-", "   ", 
      RowBox[{
       SubsuperscriptBox["\[Integral]", "0", 
        RowBox[{"\[Pi]", "/", "2"}]], " ", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", "t"], "cos", " ", "t", "  ", 
        RowBox[{"\[DifferentialD]", "t"}]}]}]}]}], " ", 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                                 ", 
   RowBox[{"=", "  ", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[Pi]", "/", "2"}]], "-", "1", "  ", "-", "   ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", 
       RowBox[{"\[Pi]", "/", "2"}]], " ", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", "t"], "cos", " ", "t", "  ", 
       RowBox[{
        RowBox[{"\[DifferentialD]", "t"}], " "}]}]}]}]}]}]}]],
 "   "
}], "Text"],

Cell[TextData[{
 "Adding  ",
 Cell[BoxData[
  RowBox[{
   SubsuperscriptBox["\[Integral]", "0", 
    RowBox[{"\[Pi]", "/", "2"}]], " ", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", "t"], "cos", " ", "t", " ", 
    RowBox[{"\[DifferentialD]", "t"}]}]}]]],
 "  to both sides of this equation and then dividing by ",
 StyleBox["2",
  FontFamily->"Courier New"],
 " gives  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[Integral]", "0", 
     RowBox[{"\[Pi]", "/", "2"}]], " ", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", "t"], " ", "cos", " ", "t", " ", 
     RowBox[{"\[DifferentialD]", "t"}]}]}], " ", "=", " ", 
   RowBox[{
    FractionBox["1", "2"], 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[Pi]", "/", "2"}]], "-", "1"}], ")"}]}]}]]],
 ".  Likewise,  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[ImaginaryI]", " ", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", "0", 
      RowBox[{"\[Pi]", "/", "2"}]], 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", "t"], " ", "sin", " ", "t", " ", 
      RowBox[{"\[DifferentialD]", "t"}]}]}]}], " ", "=", " ", 
   RowBox[{"\[ImaginaryI]", " ", 
    FractionBox["1", "2"], 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[Pi]", "/", "2"}]], "+", "1"}], ")"}]}]}]]],
 ".  Therefore,  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[Integral]", "0", 
     RowBox[{"\[Pi]", "/", "2"}]], " ", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"t", "+", 
       RowBox[{"\[ImaginaryI]", " ", "t"}]}]], 
     RowBox[{"\[DifferentialD]", "t"}]}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     FractionBox["1", "2"], 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox["\[Pi]", "2"]], "-", "1"}], ")"}]}], " ", "+", " ", 
    RowBox[{
     FractionBox[
      RowBox[{"\[ImaginaryI]", " "}], "2"], 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox["\[Pi]", "2"]], "+", "1"}], ")"}]}]}]}]]],
 ". "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 6.2.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 StyleBox["Method (i).",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  Expand the integrand f[t] into its real and imaginary parts, then \
integrate u[t] and v[t]."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", 
     RowBox[{"t", ",", "u", ",", "v", ",", "w"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "f", ",", "Int", ",", "ImInt", ",", "ImVal", ",", "ReInt", ",", "ReVal", 
      ",", "Val"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"w", "=", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"t", " ", "+", " ", 
       RowBox[{"\[ImaginaryI]", " ", "t"}]}]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", "w", "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"u", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"Re", "[", 
       RowBox[{"f", "[", "t", "]"}], "]"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"v", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"Im", "[", 
       RowBox[{"f", "[", "t", "]"}], "]"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"U", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"u", "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"V", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"v", "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Int", " ", "=", " ", 
     RowBox[{
      RowBox[{"U", "[", "t", "]"}], " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"V", "[", "t", "]"}]}]}]}], ";"}], " ", "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"ReVal", " ", "=", "  ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", 
       RowBox[{"\[Pi]", "/", "2"}]], 
      RowBox[{
       RowBox[{"u", "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ImVal", " ", "=", "  ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", 
       RowBox[{"\[Pi]", "/", "2"}]], 
      RowBox[{
       RowBox[{"v", "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Val", " ", "=", " ", 
     RowBox[{"ReVal", " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", "ImVal"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[t] = \>\"", ",", 
      RowBox[{"f", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<f[t] = u[t] + \[ImaginaryI] v[t]\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<u[t] = \>\"", ",", 
      RowBox[{"u", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<v[t] = \>\"", ",", 
      RowBox[{"v", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<U[t] = \[Integral]u[t]\[DifferentialD]t = \>\"", ",", 
      RowBox[{"U", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<V[t] = \[Integral]v[t]\[DifferentialD]t = \>\"", ",", 
      RowBox[{"V", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<U[\!\(\*FractionBox[\(\[Pi]\), \(2\)]\)] = \>\"", ",", 
      RowBox[{"U", "[", 
       FractionBox["\[Pi]", "2"], "]"}], ",", "\"\<,   \>\"", ",", " ", 
      "\"\<U[0] = \>\"", ",", 
      RowBox[{"U", "[", "0", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<V[\!\(\*FractionBox[\(\[Pi]\), \(2\)]\)] = \>\"", ",", 
      RowBox[{"V", "[", 
       FractionBox["\[Pi]", "2"], "]"}], ",", "\"\<,   \>\"", ",", 
      "\"\<V[0] = \>\"", ",", 
      RowBox[{"V", "[", "0", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\[Integral]u[t]\[DifferentialD]t + \[ImaginaryI] \[Integral]v[t]\
\[DifferentialD]t = \>\"", ",", "Int"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(0\), \(\[Pi]/2\)]\)\>\"",
       ",", "w", ",", 
      "\"\<\[DifferentialD]t = \!\(\*SubsuperscriptBox[\(\[Integral]\), \
\(0\), \(\[Pi]/2\)]\)u[t]\[DifferentialD]t + \[ImaginaryI] \
\!\(\*SubsuperscriptBox[\(\[Integral]\), \(0\), \(\[Pi]/2\)]\)v[t]\
\[DifferentialD]t\>\""}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(0\), \(\[Pi]/2\)]\)\>\"",
       ",", "w", ",", 
      "\"\<\[DifferentialD]t = (U[1]-U[0]) + \[ImaginaryI](V[1]-V[0])\>\""}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(0\), \(\[Pi]/2\)]\)\>\"",
       ",", "w", ",", "\"\<\[DifferentialD]t = \>\"", ",", "ReVal", ",", 
      "\"\< + \[ImaginaryI](\>\"", ",", "ImVal", ",", "\"\<)\>\""}], "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(0\), \(\[Pi]/2\)]\)\>\"",
       ",", "w", ",", "\"\<\[DifferentialD]t = \>\"", ",", "Val"}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39928778478125*^9},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 "\tComplex integrals have properties that are similar to those of real \
integrals.  We now trace through several commonalities.  Let  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "t", ")"}]}], "=", 
   RowBox[{
    RowBox[{"u", 
     RowBox[{"(", "t", ")"}]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", "v", 
     RowBox[{"(", "t", ")"}]}]}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"g", 
    RowBox[{"(", "t", ")"}]}], "=", 
   RowBox[{
    RowBox[{"p", 
     RowBox[{"(", "t", ")"}]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", "q", 
     RowBox[{"(", "t", ")"}]}]}]}]]],
 "  be continuous on  ",
 Cell[BoxData[
  RowBox[{
  "a", " ", "\[LessEqual]", " ", "t", " ", "\[LessEqual]", " ", "b"}]]],
 ". "
}], "Text"],

Cell[TextData[{
 "Using Definition ",
 StyleBox["(6-1)",
  FontColor->RGBColor[0, 0, 1]],
 ", we can easily show that the integral of their sum is the sum of their \
integrals, that is\n\n",
 StyleBox["(6-3)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[Integral]", "a", "b"], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"f", 
        RowBox[{"(", "t", ")"}]}], "+", 
       RowBox[{"g", 
        RowBox[{"(", "t", ")"}]}]}], ")"}], 
     RowBox[{"\[DifferentialD]", "t"}]}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     SubsuperscriptBox["\[Integral]", "a", "b"], " ", 
     RowBox[{"f", 
      RowBox[{"(", "t", ")"}], 
      RowBox[{"\[DifferentialD]", "t"}]}]}], "  ", "+", "  ", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", "a", "b"], " ", 
     RowBox[{"g", 
      RowBox[{"(", "t", ")"}], 
      RowBox[{"\[DifferentialD]", "t"}]}]}]}]}]]],
 ".  \n"
}], "Text"],

Cell[TextData[{
 "If we divide the interval  ",
 Cell[BoxData[
  RowBox[{"a", "\[LessEqual]", "t", "\[LessEqual]", "b"}]]],
 "  into  ",
 Cell[BoxData[
  RowBox[{"a", "\[LessEqual]", "t", "\[LessEqual]", "c"}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{"c", "\[LessEqual]", "t", "\[LessEqual]", "b"}]]],
 "  and integrate ",
 StyleBox["f(t)",
  FontFamily->"Courier New"],
 " over these subintervals by using ",
 StyleBox["(6-1)",
  FontColor->RGBColor[0, 0, 1]],
 ", then we get  \n\n",
 StyleBox["(6-4)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[Integral]", "a", "b"], " ", 
    RowBox[{"f", 
     RowBox[{"(", "t", ")"}], 
     RowBox[{"\[DifferentialD]", "t"}]}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     SubsuperscriptBox["\[Integral]", "a", "c"], " ", 
     RowBox[{"f", 
      RowBox[{"(", "t", ")"}], 
      RowBox[{"\[DifferentialD]", "t"}]}]}], "  ", "+", "  ", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", "c", "b"], " ", 
     RowBox[{"f", 
      RowBox[{"(", "t", ")"}], 
      RowBox[{"\[DifferentialD]", "t"}]}]}]}]}]]],
 ".  \n"
}], "Text"],

Cell[TextData[{
 "Similarly, if  ",
 Cell[BoxData[
  RowBox[{"\[Alpha]", "+", 
   RowBox[{"\[ImaginaryI]", " ", "\[Beta]"}]}]]],
 "  denotes a complex constant, then\n\n",
 StyleBox["(6-5)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[Integral]", "a", "b"], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"c", "+", 
       RowBox[{"\[ImaginaryI]", " ", "d"}]}], ")"}], "f", 
     RowBox[{"(", "t", ")"}], 
     RowBox[{"\[DifferentialD]", "t"}]}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"c", "+", 
      RowBox[{"\[ImaginaryI]", " ", "d"}]}], ")"}], 
    RowBox[{
     SubsuperscriptBox["\[Integral]", "a", "b"], "  ", 
     RowBox[{"f", 
      RowBox[{"(", "t", ")"}], 
      RowBox[{"\[DifferentialD]", "t"}]}]}]}]}]]],
 ".  \n"
}], "Text"],

Cell[TextData[{
 "If the limits of integration are reversed, then\n\n",
 StyleBox["(6-6)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[Integral]", "a", "b"], " ", 
    RowBox[{"f", 
     RowBox[{"(", "t", ")"}], 
     RowBox[{"\[DifferentialD]", "t"}]}]}], "  ", "=", "  ", 
   RowBox[{"-", " ", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", "b", "a"], " ", 
     RowBox[{"f", 
      RowBox[{"(", "t", ")"}], 
      RowBox[{"\[DifferentialD]", "t"}]}]}]}]}]]],
 ".  \n"
}], "Text"],

Cell[TextData[{
 "The integral of the product ",
 StyleBox["f(t)g(t)",
  FontFamily->"Courier New"],
 " becomes\n\n",
 StyleBox["(6-7)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      SubsuperscriptBox["\[Integral]", "a", "b"], " ", 
      RowBox[{"f", 
       RowBox[{"(", "t", ")"}], "g", 
       RowBox[{"(", "t", ")"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}], "  ", "=", "  ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "a", "b"], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"u", 
          RowBox[{"(", "t", ")"}]}], "+", 
         RowBox[{"\[ImaginaryI]", " ", "v", 
          RowBox[{"(", "t", ")"}]}]}], ")"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"p", 
          RowBox[{"(", "t", ")"}]}], "+", 
         RowBox[{"\[ImaginaryI]", " ", "q", 
          RowBox[{"(", "t", ")"}]}]}], ")"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], "\[IndentingNewLine]"}], 
   " "}], "\[IndentingNewLine]", 
  RowBox[{" ", 
   RowBox[{"=", "   ", 
    RowBox[{
     RowBox[{
      SubsuperscriptBox["\[Integral]", "a", "b"], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"u", 
          RowBox[{"(", "t", ")"}], " ", "p", 
          RowBox[{"(", "t", ")"}]}], "-", 
         RowBox[{"v", 
          RowBox[{"(", "t", ")"}], " ", "q", 
          RowBox[{"(", "t", ")"}]}]}], ")"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}], "  ", "+", "  ", 
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{
       SubsuperscriptBox["\[Integral]", "a", "b"], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"u", 
           RowBox[{"(", "t", ")"}], " ", "q", 
           RowBox[{"(", "t", ")"}]}], "+", 
          RowBox[{"v", 
           RowBox[{"(", "t", ")"}], " ", "p", 
           RowBox[{"(", "t", ")"}]}]}], ")"}], 
        RowBox[{"\[DifferentialD]", "t"}]}]}]}]}]}]}]}]],
 "   \n"
}], "Text"],

Cell[TextData[{
 StyleBox["Example 6.3.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Let us verify property ",
 StyleBox["(6-5)",
  FontColor->RGBColor[0, 0, 1]],
 ".  We start by writing \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"c", "+", 
         RowBox[{"\[ImaginaryI]", " ", "d"}]}], ")"}], "f", 
       RowBox[{"(", "t", ")"}]}], "  ", "=", "  ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"c", "+", 
         RowBox[{"\[ImaginaryI]", " ", "d"}]}], ")"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"u", 
          RowBox[{"(", "t", ")"}]}], "+", 
         RowBox[{"\[ImaginaryI]", " ", "v", 
          RowBox[{"(", "t", ")"}]}]}], ")"}]}]}], "\[IndentingNewLine]"}], 
    "\[IndentingNewLine]", "                                ", 
    RowBox[{"=", "  ", 
     RowBox[{
      RowBox[{"c", " ", "u", 
       RowBox[{"(", "t", ")"}]}], "-", 
      RowBox[{"d", " ", "v", 
       RowBox[{"(", "t", ")"}]}], "  ", "+", "  ", 
      RowBox[{"\[ImaginaryI]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"c", " ", "v", 
          RowBox[{"(", "t", ")"}]}], " ", "+", " ", 
         RowBox[{"d", " ", "u", 
          RowBox[{"(", "t", ")"}]}]}], ")"}]}]}]}]}]}]]],
 "  \n\nUsing Definition ",
 StyleBox["(6-1)",
  FontColor->RGBColor[0, 0, 1]],
 ", we write the left side of Equation ",
 StyleBox["(6-5)",
  FontColor->RGBColor[0, 0, 1]],
 " as  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[Integral]", "a", "b"], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"c", "+", 
       RowBox[{"\[ImaginaryI]", " ", "d"}]}], ")"}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"u", 
        RowBox[{"(", "t", ")"}]}], "+", 
       RowBox[{"\[ImaginaryI]", " ", "v", 
        RowBox[{"(", "t", ")"}]}]}], ")"}], 
     RowBox[{"\[DifferentialD]", "t"}]}]}], "  ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"=", "  ", 
   RowBox[{
    RowBox[{"c", " ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "a", "b"], " ", 
      RowBox[{"u", 
       RowBox[{"(", "t", ")"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], " ", "-", " ", 
    RowBox[{"d", " ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "a", "b"], " ", 
      RowBox[{"v", 
       RowBox[{"(", "t", ")"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], "  ", "+", "  ", 
    RowBox[{"\[ImaginaryI]", " ", "c", " ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "a", "b"], " ", 
      RowBox[{"v", 
       RowBox[{"(", "t", ")"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], " ", "+", " ", 
    RowBox[{"\[ImaginaryI]", " ", "d", " ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "a", "b"], " ", 
      RowBox[{"u", 
       RowBox[{"(", "t", ")"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}]}]}]}]],
 "  \n\nwhich is equivalent to  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[Integral]", "a", "b"], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"c", "+", 
       RowBox[{"\[ImaginaryI]", " ", "d"}]}], ")"}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"u", 
        RowBox[{"(", "t", ")"}]}], "+", 
       RowBox[{"\[ImaginaryI]", " ", "v", 
        RowBox[{"(", "t", ")"}]}]}], ")"}], 
     RowBox[{"\[DifferentialD]", "t"}]}]}], "  ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{"c", " ", 
      RowBox[{
       SubsuperscriptBox["\[Integral]", "a", "b"], " ", 
       RowBox[{"u", 
        RowBox[{"(", "t", ")"}], 
        RowBox[{"\[DifferentialD]", "t"}]}]}]}], "+", " ", 
     RowBox[{"\[ImaginaryI]", " ", "d", " ", 
      RowBox[{
       SubsuperscriptBox["\[Integral]", "a", "b"], " ", 
       RowBox[{"u", 
        RowBox[{"(", "t", ")"}], 
        RowBox[{"\[DifferentialD]", "t"}]}]}]}], "  ", "+", "  ", 
     RowBox[{"c", " ", "\[ImaginaryI]", 
      RowBox[{
       SubsuperscriptBox["\[Integral]", "a", "b"], " ", 
       RowBox[{"v", 
        RowBox[{"(", "t", ")"}], 
        RowBox[{"\[DifferentialD]", "t"}]}]}]}], " ", "+", 
     RowBox[{"\[ImaginaryI]", " ", "d", " ", "\[ImaginaryI]", "  ", 
      RowBox[{
       SubsuperscriptBox["\[Integral]", "a", "b"], " ", 
       RowBox[{"v", 
        RowBox[{"(", "t", ")"}], 
        RowBox[{"\[DifferentialD]", "t"}]}]}]}]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"c", "+", " ", 
        RowBox[{"\[ImaginaryI]", " ", "d"}]}], ")"}], " ", 
      RowBox[{
       SubsuperscriptBox["\[Integral]", "a", "b"], " ", 
       RowBox[{"u", 
        RowBox[{"(", "t", ")"}], 
        RowBox[{"\[DifferentialD]", "t"}]}]}]}], "  ", "+", "  ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"c", "+", 
        RowBox[{"\[ImaginaryI]", " ", "d"}]}], ")"}], " ", "\[ImaginaryI]", 
      " ", 
      RowBox[{
       SubsuperscriptBox["\[Integral]", "a", "b"], " ", 
       RowBox[{"v", 
        RowBox[{"(", "t", ")"}], 
        RowBox[{"\[DifferentialD]", "t"}]}]}]}]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"=", "  ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"c", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", "d"}]}], ")"}], 
    RowBox[{"(", " ", 
     RowBox[{
      RowBox[{
       SubsuperscriptBox["\[Integral]", "a", "b"], " ", 
       RowBox[{"u", 
        RowBox[{"(", "t", ")"}], 
        RowBox[{"\[DifferentialD]", "t"}]}]}], " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{
        SubsuperscriptBox["\[Integral]", "a", "b"], " ", 
        RowBox[{"v", 
         RowBox[{"(", "t", ")"}], 
         RowBox[{"\[DifferentialD]", "t"}]}]}]}]}], " ", ")"}]}]}]}]],
 "   \n\nTherefore,  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[Integral]", "a", "b"], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"c", "+", 
       RowBox[{"\[ImaginaryI]", " ", "d"}]}], ")"}], "f", 
     RowBox[{"(", "t", ")"}], 
     RowBox[{"\[DifferentialD]", "t"}]}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"c", "+", 
      RowBox[{"\[ImaginaryI]", " ", "d"}]}], ")"}], 
    RowBox[{
     SubsuperscriptBox["\[Integral]", "a", "b"], " ", 
     RowBox[{"f", 
      RowBox[{"(", "t", ")"}], 
      RowBox[{"\[DifferentialD]", "t"}]}]}]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 6.3.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "c", ",", "d", ",", "int1", ",", "int2", ",", "t", ",", "u", ",", "v"}], 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"int1", " ", "=", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"c", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "d"}]}], ")"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"u", "[", "t", "]"}], " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"v", "[", "t", "]"}]}]}], ")"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"int2", " ", "=", " ", 
     RowBox[{"MapAll", "[", 
      RowBox[{"Distribute", ",", "int1"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"int1", ",", "\"\< = \>\""}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "int2", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"int2", " ", "\[Equal]", " ", 
      RowBox[{"MapAll", "[", 
       RowBox[{"Distribute", ",", "int1"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{
  3.3992877961875*^9, {3.39928782675*^9, 3.3992878374375*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 "\tIt is worthwhile to point out the similarity between equation ",
 StyleBox["(6-2)",
  FontColor->RGBColor[0, 0, 1]],
 " and its counterpart in calculus.  Suppose that ",
 StyleBox["U",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["V",
  FontFamily->"Courier New"],
 " are differentiable on  ",
 Cell[BoxData[
  RowBox[{"a", "<", "t", "<", "b"}]]],
 "  \nand  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"F", 
    RowBox[{"(", "t", ")"}]}], "=", 
   RowBox[{
    RowBox[{"U", 
     RowBox[{"(", "t", ")"}]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", "V", 
     RowBox[{"(", "t", ")"}]}]}]}]]],
 ".  Since ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"F", "'"}], 
    RowBox[{"(", "t", ")"}]}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"U", "'"}], 
      RowBox[{"(", "t", ")"}]}], "+", 
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{"V", "'"}], 
      RowBox[{"(", "t", ")"}]}]}], "=", 
    RowBox[{
     RowBox[{
      RowBox[{"u", 
       RowBox[{"(", "t", ")"}]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", "v", 
       RowBox[{"(", "t", ")"}]}]}], "=", 
     RowBox[{"f", 
      RowBox[{"(", "t", ")"}]}]}]}]}]]],
 ",  equation ",
 StyleBox["(6-2)",
  FontColor->RGBColor[0, 0, 1]],
 " takes on the familiar form \n\n",
 StyleBox["(6-8)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[Integral]", "a", "b"], " ", 
    RowBox[{"f", 
     RowBox[{"(", "t", ")"}], 
     RowBox[{"\[DifferentialD]", "t"}]}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     RowBox[{"F", 
      RowBox[{"(", "t", ")"}]}], 
     SubsuperscriptBox["|", 
      RowBox[{"t", "=", "a"}], 
      RowBox[{"t", "=", "b"}]]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{"F", 
      RowBox[{"(", "b", ")"}]}], "-", 
     RowBox[{"F", 
      RowBox[{"(", "a", ")"}]}]}]}]}]]],
 ".\n\t\t\t\nwhere ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"F", "'"}], 
    RowBox[{"(", "t", ")"}]}], "=", 
   RowBox[{"f", 
    RowBox[{"(", "t", ")"}]}]}]]],
 ".  We can view Equation ",
 StyleBox["(6-8)",
  FontColor->RGBColor[0, 0, 1]],
 " as an extension of the fundamental theorem of calculus.  In Section 6.5 we \
show how to generalize this extension to analytic functions of a complex \
variable.  For now, we simply note an important case of Equation ",
 StyleBox["(6-8)",
  FontColor->RGBColor[0, 0, 1]],
 ": \n\n",
 StyleBox["(6-9)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[Integral]", "a", "b"], " ", 
    RowBox[{
     RowBox[{"f", "'"}], 
     RowBox[{"(", "t", ")"}], 
     RowBox[{"\[DifferentialD]", "t"}]}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "b", ")"}]}], "-", 
    RowBox[{"f", 
     RowBox[{"(", "a", ")"}]}]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 StyleBox["Example 6.4.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Use Equation ",
 StyleBox["(6-8)",
  FontColor->RGBColor[0, 0, 1]],
 " to show that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[Integral]", "0", 
     RowBox[{"\[Pi]", "/", "2"}]], " ", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"t", "+", 
       RowBox[{"\[ImaginaryI]", " ", "t"}]}]], 
     RowBox[{"\[DifferentialD]", "t"}]}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     FractionBox["1", "2"], 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[Pi]", "/", "2"}]], "-", "1"}], ")"}]}], "+", 
    RowBox[{
     FractionBox[
      RowBox[{"\[ImaginaryI]", " "}], "2"], 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[Pi]", "/", "2"}]], "+", "1"}], ")"}]}]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "Solution.  We seek a function ",
 StyleBox["F",
  FontFamily->"Courier New"],
 " with the property that   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"F", "'"}], 
    RowBox[{"(", "t", ")"}]}], "=", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}], " ", "t"}]]}]]],
 ".  We note that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"F", 
    RowBox[{"(", "t", ")"}]}], "=", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"1", "+", "\[ImaginaryI]"}]], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}], " ", "t"}]]}]}]]],
 " satisfies this requirement, so \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     SubsuperscriptBox["\[Integral]", "0", 
      RowBox[{"\[Pi]", "/", "2"}]], " ", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"t", "+", 
        RowBox[{"\[ImaginaryI]", " ", "t"}]}]], 
      RowBox[{"\[DifferentialD]", "t"}]}]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      RowBox[{"(", " ", 
       RowBox[{
        FractionBox["1", 
         RowBox[{"1", "+", "\[ImaginaryI]"}]], " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}], " ", "t"}]]}], ")"}], 
      UnderoverscriptBox["\[VerticalSeparator]", 
       RowBox[{"t", "=", "0"}], 
       RowBox[{"t", "=", 
        RowBox[{"\[Pi]", "/", "2"}]}]]}], "  ", "=", "  ", 
     RowBox[{
      RowBox[{
       FractionBox["1", 
        RowBox[{"1", "+", "\[ImaginaryI]"}]], " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}], " ", 
         RowBox[{"\[Pi]", "/", "2"}]}]]}], " ", "-", " ", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"1", "+", "\[ImaginaryI]"}]], " ", 
       SuperscriptBox["\[ExponentialE]", "0"]}]}]}]}], 
   "  "}], "\[IndentingNewLine]", 
  RowBox[{"                           ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      RowBox[{
       RowBox[{
        FractionBox["1", 
         RowBox[{"1", "+", "\[ImaginaryI]"}]], " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{" ", 
          RowBox[{"\[Pi]", "/", "2"}]}]], 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", "  ", 
          RowBox[{"\[Pi]", "/", "2"}]}]]}], "-", " ", 
       FractionBox["1", 
        RowBox[{"1", "+", "\[ImaginaryI]"}]]}], "  ", "=", "  ", 
      RowBox[{
       RowBox[{
        FractionBox["1", 
         RowBox[{"1", "+", "\[ImaginaryI]"}]], " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{" ", 
          RowBox[{"\[Pi]", "/", "2"}]}]], "\[ImaginaryI]"}], " ", "-", " ", 
       FractionBox["1", 
        RowBox[{"1", "+", "\[ImaginaryI]"}]]}]}]}], "  ", 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                           ", 
   RowBox[{
    RowBox[{"=", "   ", 
     RowBox[{
      RowBox[{
       FractionBox["1", 
        RowBox[{"1", "+", "\[ImaginaryI]"}]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[ImaginaryI]", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{" ", 
            RowBox[{"\[Pi]", "/", "2"}]}]]}], " ", "-", "1"}], ")"}]}], "  ", 
      "=", "  ", 
      RowBox[{
       FractionBox["1", "2"], 
       RowBox[{"(", 
        RowBox[{"1", "-", "\[ImaginaryI]"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"\[Pi]", "/", "2"}]]}]}], ")"}]}]}]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                           ", 
   RowBox[{"=", "   ", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[Pi]", "/", "2"}]], "-", "1"}], ")"}]}], "+", " ", 
     RowBox[{
      FractionBox["\[ImaginaryI]", "2"], " ", 
      RowBox[{"(", " ", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[Pi]", "/", "2"}]], "+", "1"}], ")"}]}]}]}]}]}]],
 "  \n\nwhich is the same result we obtained in Example 6.2, but with a lot \
less work."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Explore ",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 StyleBox["Solution 6.4.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]
}], "Text"],

Cell[TextData[{
 "\n",
 StyleBox["Method (ii).",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  Compute the integral directly using a complex function for the \
integrand."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", "t", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "F", ",", "val"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "t_", "]"}], "=", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"t", " ", "+", " ", 
       RowBox[{"\[ImaginaryI]", " ", "t"}]}]]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"\[Integral]", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"t", "+", 
         RowBox[{"\[ImaginaryI]", " ", "t"}]}]], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"val", " ", "=", " ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", 
       RowBox[{"\[Pi]", "/", "2"}]], 
      RowBox[{
       RowBox[{"f", "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[t] = \>\"", ",", 
      RowBox[{"f", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[t] = \[Integral]\>\"", ",", 
      RowBox[{"f", "[", "t", "]"}], ",", "\"\<\[DifferentialD]t = \>\"", ",", 
      
      RowBox[{"F", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(0\), \(\[Pi]/2\)]\)\>\"",
       ",", 
      RowBox[{"f", "[", "t", "]"}], ",", 
      "\"\<\[DifferentialD]t = F[1] - F[0]\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(0\), \(\[Pi]/2\)]\)\>\"",
       ",", 
      RowBox[{"f", "[", "t", "]"}], ",", "\"\<\[DifferentialD]t = \>\"", ",", 
      
      RowBox[{"F", "[", "1", "]"}], " ", ",", "\"\< - (\>\"", ",", 
      RowBox[{"F", "[", "0", "]"}], ",", "\"\<)\>\""}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(0\), \(\[Pi]/2\)]\)\>\"",
       ",", 
      RowBox[{"f", "[", "t", "]"}], ",", "\"\<\[DifferentialD]t = \>\"", ",", 
      "val"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(0\), \(\[Pi]/2\)]\)\>\"",
       ",", 
      RowBox[{"f", "[", "t", "]"}], ",", "\"\<\[DifferentialD]t = \>\"", ",", 
      
      RowBox[{"ComplexExpand", "[", "val", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399287848234375*^9},
 AspectRatioFixed->True],

Cell["\<\
Which is the same result we obtained in Example 6.2, but with a lot less \
work.\
\>", "Text"]
}, Closed]],

Cell[TextData[{
 StyleBox["Remark 6.1",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  Example 6.4 illustrates the potential computational advantage we have \
when we lift our sights to the complex domain.  Using ordinary calculus \
techniques to evaluate ",
 Cell[BoxData[
  RowBox[{
   SubsuperscriptBox["\[Integral]", "0", 
    RowBox[{"\[Pi]", "/", "2"}]], " ", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", "t"], " ", "cos", " ", "t", "  ", 
    RowBox[{"\[DifferentialD]", "t"}]}]}]]],
 ", for example, required a lengthy integration by parts procedure (Example \
6.2).  When we recognize this expression as the real part of ",
 Cell[BoxData[
  RowBox[{
   SubsuperscriptBox["\[Integral]", "0", 
    RowBox[{"\[Pi]", "/", "2"}]], " ", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"t", "+", 
      RowBox[{"\[ImaginaryI]", " ", "t"}]}]], 
    RowBox[{"\[DifferentialD]", "t"}]}]}]]],
 ", however, the solution comes quickly.  This is just one of the many \
reasons why good physicists and engineers, in addition to mathematicians, \
benefit from a thorough working knowledge of complex analysis."
}], "Text"],

Cell[TextData[{
 StyleBox["Extra Example 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Show that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[Integral]", "0", "\[Pi]"], " ", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "t"}]], 
     RowBox[{"\[DifferentialD]", "t"}]}]}], " ", "=", " ", 
   RowBox[{"2", "\[ImaginaryI]"}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Explore ",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 StyleBox["Solution for Extra Example 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]
}], "Text"],

Cell["\<\
Compute the integral directly using a complex function for the integrand.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "F", ",", "int", ",", "t", ",", "val"}], "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "t_", "]"}], " ", "=", " ", 
     SuperscriptBox[
      RowBox[{"\[ExponentialE]", " "}], 
      RowBox[{"\[ImaginaryI]", " ", "t"}]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "t_", "]"}], "=", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"f", "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"val", " ", "=", " ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", "\[Pi]"], 
      RowBox[{
       RowBox[{"f", "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[t] = \>\"", ",", 
      RowBox[{"f", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[t] = \[Integral]f[t]\[DifferentialD]t = \>\"", ",", 
      RowBox[{"F", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[\[Pi]] = \>\"", ",", 
      RowBox[{"F", "[", "\[Pi]", "]"}], ",", "\"\<,  F[0] = \>\"", ",", 
      RowBox[{"F", "[", "0", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(0\), \(\[Pi]\)]\)f[t]\
\[DifferentialD]t = F[\[Pi]] - F[0]\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(0\), \(\[Pi]\)]\)f[t]\
\[DifferentialD]t = (\>\"", ",", 
      RowBox[{"F", "[", "\[Pi]", "]"}], ",", "\"\<) - (\>\"", ",", 
      RowBox[{"F", "[", "0", "]"}], ",", "\"\<) = \>\"", ",", "val"}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[{
 StyleBox[ButtonBox["Complex Integral",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/ComplexIntegralBib.html"], 
    None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0, 1]],
 "  "
}], "Text"],

Cell[TextData[{
 StyleBox[ButtonBox["Contour Integrals",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/ContourIntegralBib.html"], 
    None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0, 1]],
 "  "
}], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/complex.html"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2008 John H. Mathews, Russell W. \
Howell",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/"], None}],
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[0, 1, 0]]], "Text",
 CellChangeTimes->{{3.399287869359375*^9, 3.399287869484375*^9}}]
},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{923, 628},
WindowMargins->{{17, Automatic}, {Automatic, 0}},
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "CHAPTER 1"->{
  Cell[568, 21, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"CHAPTER 1", 68990, 2196}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"],
Cell[905, 32, 118, 2, 29, "Text"],
Cell[1026, 36, 791, 14, 119, "Text"],
Cell[1820, 52, 110, 2, 29, "Text"],
Cell[1933, 56, 367, 7, 47, "Text",
 Evaluatable->False],
Cell[2303, 65, 148, 3, 29, "Text"],
Cell[2454, 70, 2092, 73, 87, "Text",
 Evaluatable->False],
Cell[4549, 145, 1835, 66, 87, "Text",
 Evaluatable->False],
Cell[6387, 213, 494, 19, 35, "Text",
 Evaluatable->False],
Cell[6884, 234, 4046, 138, 274, "Text"],
Cell[CellGroupData[{
Cell[10955, 376, 109, 2, 29, "Text"],
Cell[11067, 380, 205, 6, 29, "Text"],
Cell[11275, 388, 5561, 153, 736, "Input"],
Cell[16839, 543, 235, 8, 29, "Text",
 Evaluatable->False],
Cell[17077, 553, 2490, 71, 348, "Input"]
}, Closed]],
Cell[19582, 627, 907, 32, 39, "Text",
 Evaluatable->False],
Cell[20492, 661, 1949, 56, 111, "Text"],
Cell[22444, 719, 5814, 160, 404, "Text"],
Cell[28261, 881, 2117, 69, 108, "Text"],
Cell[CellGroupData[{
Cell[30403, 954, 109, 2, 29, "Text"],
Cell[30515, 958, 251, 8, 29, "Text",
 Evaluatable->False],
Cell[30769, 968, 6266, 170, 821, "Input"]
}, Closed]],
Cell[37050, 1141, 760, 27, 44, "Text"],
Cell[37813, 1170, 962, 33, 87, "Text"],
Cell[38778, 1205, 1135, 39, 87, "Text"],
Cell[39916, 1246, 829, 29, 87, "Text"],
Cell[40748, 1277, 550, 19, 87, "Text"],
Cell[41301, 1298, 1972, 64, 129, "Text"],
Cell[43276, 1364, 6477, 200, 464, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[49778, 1568, 109, 2, 29, "Text"],
Cell[49890, 1572, 1352, 38, 185, "Input"]
}, Closed]],
Cell[51257, 1613, 2831, 105, 178, "Text"],
Cell[54091, 1720, 975, 35, 35, "Text",
 Evaluatable->False],
Cell[55069, 1757, 4392, 134, 242, "Text"],
Cell[CellGroupData[{
Cell[59486, 1895, 185, 7, 29, "Text"],
Cell[59674, 1904, 242, 9, 47, "Text",
 Evaluatable->False],
Cell[59919, 1915, 2954, 83, 384, "Input"],
Cell[62876, 2000, 104, 3, 29, "Text"]
}, Closed]],
Cell[62995, 2006, 1150, 28, 88, "Text"],
Cell[64148, 2036, 476, 17, 33, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[64649, 2057, 201, 7, 29, "Text"],
Cell[64853, 2066, 143, 4, 29, "Text",
 Evaluatable->False],
Cell[64999, 2072, 2172, 60, 331, "Input"]
}, Closed]],
Cell[67186, 2135, 281, 7, 26, "Text"],
Cell[67470, 2144, 298, 10, 29, "Text"],
Cell[67771, 2156, 299, 10, 29, "Text"],
Cell[68073, 2168, 249, 5, 29, "Text"],
Cell[68325, 2175, 320, 7, 29, "Text"]
}
]
*)

(* End of internal cache information *)
