(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    397659,      11553]
NotebookOptionsPosition[    388603,      11284]
NotebookOutlinePosition[    389405,      11317]
CellTagsIndexPosition[    389330,      11312]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["6.2  Contours and Contour Integrals",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
 "\tIn Section 6.1 we learned how to evaluate integrals of the form  ",
 Cell[BoxData[
  RowBox[{
   SubsuperscriptBox["\[Integral]", "a", "b"], " ", 
   RowBox[{"f", 
    RowBox[{"(", "t", ")"}], 
    RowBox[{"\[DifferentialD]", "t"}]}]}]]],
 ",  where ",
 StyleBox["f(t)",
  FontFamily->"Courier New"],
 " was complex-valued and  ",
 Cell[BoxData[
  RowBox[{"[", 
   RowBox[{"a", ",", "b"}], "]"}]]],
 "  was an interval on the real axis (so that ",
 StyleBox["t",
  FontFamily->"Courier New"],
 " was real, with  ",
 Cell[BoxData[
  RowBox[{"t", "\[Element]", 
   RowBox[{"[", 
    RowBox[{"a", ",", "b"}], "]"}]}]]],
 ").  In this section, we define and evaluate integrals of the form  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["\[Integral]", "C"], " ", 
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}], " ", 
    RowBox[{"\[DifferentialD]", "z"}]}]}]]],
 ",  where ",
 StyleBox["f(t)",
  FontFamily->"Courier New"],
 " is complex-valued and ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " is a contour in the plane (so that ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " is complex, with  ",
 Cell[BoxData[
  RowBox[{"z", "\[Element]", "C"}]]],
 ").  Our main result is Theorem 6.1, which shows how to transform the latter \
type of integral into the kind we investigated in Section 6.1. "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "\tWe will use concepts first introduced in Section 1.6.  Recall that to \
represent a curve ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " we used the parametric notation\n\n",
 StyleBox["(6-10)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"C", ":", " ", 
    RowBox[{"z", 
     RowBox[{"(", "t", ")"}]}]}], "=", " ", 
   RowBox[{
    RowBox[{"x", 
     RowBox[{"(", "t", ")"}]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", "y", 
     RowBox[{"(", "t", ")"}]}]}]}]]],
 "  for ",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{"a", "\[LessEqual]", "t", "\[LessEqual]", "b"}]}]]],
 ",\n\nwhere ",
 StyleBox["x(t)",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["y(t)",
  FontFamily->"Courier New"],
 " are continuous functions.  We now place a few more restrictions on the \
type of curve to be described.  The following discussion leads to the concept \
of a contour, which is a type of curve that is adequate for the study of \
integration."
}], "Text",
 Evaluatable->False,
 CellChangeTimes->{3.399287919890625*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "\tRecall that ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " is simple if it does not cross itself, which means that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"z", 
    RowBox[{"(", 
     SubscriptBox["t", "1"], ")"}]}], "\[NotEqual]", 
   RowBox[{"z", 
    RowBox[{"(", 
     SubscriptBox["t", "2"], ")"}]}]}]]],
 "  whenever  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["t", "1"], "\[NotEqual]", 
   SubscriptBox["t", "2"]}]]],
 ", except possibly when ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["t", "1"], "=", "a"}]]],
 " and ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["t", "2"], "=", "b"}]]],
 ".  A curve ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " with the property that ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"z", 
    RowBox[{"(", "a", ")"}]}], "=", 
   RowBox[{"z", 
    RowBox[{"(", "b", ")"}]}]}]]],
 "  is a closed curve.  If   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"z", 
    RowBox[{"(", "a", ")"}]}], "=", 
   RowBox[{"z", 
    RowBox[{"(", "b", ")"}]}]}]]],
 "  is the only point of intersection, then we say that ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " is a simple closed curve.  As the parameter ",
 StyleBox["t",
  FontFamily->"Courier New"],
 " increases from the value ",
 Cell[BoxData[
  RowBox[{"t", "=", "a"}]]],
 " to the value ",
 Cell[BoxData[
  RowBox[{"t", "=", "b"}]]],
 ", the point ",
 Cell[BoxData[
  RowBox[{"z", 
   RowBox[{"(", "t", ")"}]}]]],
 " starts at the initial point ",
 Cell[BoxData[
  RowBox[{"z", 
   RowBox[{"(", "a", ")"}]}]]],
 ", moves along the curve ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " , and ends up at the terminal point ",
 Cell[BoxData[
  RowBox[{"z", 
   RowBox[{"(", "b", ")"}]}]]],
 ".  If ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " is simple, then ",
 Cell[BoxData[
  RowBox[{"z", 
   RowBox[{"(", "t", ")"}]}]]],
 " moves continuously from ",
 Cell[BoxData[
  RowBox[{"z", 
   RowBox[{"(", "a", ")"}]}]]],
 " to ",
 Cell[BoxData[
  RowBox[{"z", 
   RowBox[{"(", "b", ")"}]}]]],
 " as ",
 StyleBox["t",
  FontFamily->"Courier New"],
 " increases and the curve is given an orientation, which we indicate by \
drawing arrows along the curve.  Figure 6.1 illustrates how the terms simple \
and closed describe a curve."
}], "Text",
 Evaluatable->False,
 CellChangeTimes->{3.399287926875*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "\t\t\t",
 Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
  ImageSize->{520, 362},
  ImageMargins->0],
 StyleBox["\n\t\t\t",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Figure 6.1",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/contourintegral/\
ContourIntegralMod/Images/mat0601.gif"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 "  The terms simple and closed used to describe curves."
}], "Text",
 CellChangeTimes->{{3.399294863140625*^9, 3.3992948783125*^9}}],

Cell[TextData[{
 "\tThe complex-valued function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"z", 
    RowBox[{"(", "t", ")"}]}], "=", " ", 
   RowBox[{
    RowBox[{"x", 
     RowBox[{"(", "t", ")"}]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", "y", 
     RowBox[{"(", "t", ")"}]}]}]}]]],
 "  is said to be differentiable on ",
 Cell[BoxData[
  RowBox[{"[", 
   RowBox[{"a", ",", "b"}], "]"}]]],
 " if both ",
 Cell[BoxData[
  RowBox[{"x", 
   RowBox[{"(", "t", ")"}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{"y", 
   RowBox[{"(", "t", ")"}]}]]],
 " are differentiable for ",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{"a", "\[LessEqual]", "t", "\[LessEqual]", "b"}]}]]],
 ".  Here we require the one-sided derivatives of ",
 Cell[BoxData[
  RowBox[{"x", 
   RowBox[{"(", "t", ")"}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{"y", 
   RowBox[{"(", "t", ")"}]}]]],
 " to exist at the endpoints of the interval.  As in Section 6.1, the \
derivative ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"z", "'"}], 
   RowBox[{"(", "t", ")"}]}]]],
 " is \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"z", "'"}], 
    RowBox[{"(", "t", ")"}]}], " ", "=", "  ", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "'"}], 
     RowBox[{"(", "t", ")"}]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     RowBox[{"y", "'"}], 
     RowBox[{"(", "t", ")"}]}]}]}]]],
 "   for   ",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{"a", "\[LessEqual]", "t", "\[LessEqual]", "b"}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "\tThe curve ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " defined by Equation ",
 StyleBox["(6-10)",
  FontColor->RGBColor[0, 0, 1]],
 " is said to be a smooth curve if ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"z", "'"}], 
   RowBox[{"(", "t", ")"}]}]]],
 " is continuous and nonzero on the interval.  If ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " is a smooth curve, then ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " has a nonzero tangent vector at each point ",
 Cell[BoxData[
  RowBox[{"z", 
   RowBox[{"(", "t", ")"}]}]]],
 ", which is given by the vector ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"z", "'"}], 
   RowBox[{"(", "t", ")"}]}]]],
 ".  If  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"x", "'"}], 
    RowBox[{"(", 
     SubscriptBox["t", "0"], ")"}]}], "=", "0"}]]],
 ",  then the tangent vector  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"z", "'"}], 
    RowBox[{"(", 
     SubscriptBox["t", "0"], ")"}]}], "=", 
   RowBox[{"\[ImaginaryI]", " ", 
    RowBox[{"y", "'"}], 
    RowBox[{"(", 
     SubscriptBox["t", "0"], ")"}]}]}]]],
 "  is vertical.  If  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"x", "'"}], 
    RowBox[{"(", 
     SubscriptBox["t", "0"], ")"}]}], "\[NotEqual]", "0"}]]],
 ",  then the slope ",
 Cell[BoxData[
  FractionBox["dy", "dx"]]],
 " of the tangent line to ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " at the point ",
 Cell[BoxData[
  RowBox[{"z", 
   RowBox[{"(", 
    SubscriptBox["t", "0"], ")"}]}]]],
 " is given by ",
 Cell[BoxData[
  FractionBox[
   RowBox[{
    RowBox[{"y", "'"}], 
    RowBox[{"(", 
     SubscriptBox["t", "0"], ")"}]}], 
   RowBox[{
    RowBox[{"x", "'"}], 
    RowBox[{"(", 
     SubscriptBox["t", "0"], ")"}]}]]]],
 ".  Hence for a smooth curve the angle of inclination ",
 Cell[BoxData[
  RowBox[{"\[Theta]", 
   RowBox[{"(", "t", ")"}]}]]],
 " of its tangent vector ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"z", "'"}], 
   RowBox[{"(", "t", ")"}]}]]],
 " is defined for all values of ",
 Cell[BoxData[
  RowBox[{"t", "\[Element]", 
   RowBox[{"[", 
    RowBox[{"a", ",", "b"}], "]"}]}]]],
 " and is continuous.  Thus a smooth curve has no corners or cusps.  Figure \
6.2 illustrates this concept."
}], "Text"],

Cell[TextData[{
 "\t\t\t",
 Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
  ImageSize->{400, 150},
  ImageMargins->0],
 StyleBox["\n\t\t\t",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Figure 6.2",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/contourintegral/\
ContourIntegralMod/Images/mat0602.gif"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 "  The term smooth used to describe curves."
}], "Text",
 CellChangeTimes->{{3.399294900609375*^9, 3.399294912734375*^9}}],

Cell[TextData[{
 "\tIf ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " is a smooth curve, then ",
 Cell[BoxData[
  RowBox[{"\[DifferentialD]", "s"}]]],
 ", the differential of arc length, is given by  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[DifferentialD]", "s"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     SqrtBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"[", 
         RowBox[{
          RowBox[{"x", "'"}], 
          RowBox[{"(", "t", ")"}]}], "]"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{"[", 
         RowBox[{
          RowBox[{"y", "'"}], 
          RowBox[{"(", "t", ")"}]}], "]"}], "2"]}]], 
     RowBox[{"\[DifferentialD]", "t"}]}], " ", "=", " ", 
    RowBox[{"|", 
     RowBox[{
      RowBox[{"z", "'"}], 
      RowBox[{"(", "t", ")"}]}], "|", 
     RowBox[{"\[DifferentialD]", "t"}]}]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "\tThe function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"s", 
    RowBox[{"(", "t", ")"}]}], " ", "=", " ", 
   SqrtBox[
    RowBox[{
     SuperscriptBox[
      RowBox[{"[", 
       RowBox[{
        RowBox[{"x", "'"}], 
        RowBox[{"(", "t", ")"}]}], "]"}], "2"], "+", 
     SuperscriptBox[
      RowBox[{"[", 
       RowBox[{
        RowBox[{"y", "'"}], 
        RowBox[{"(", "t", ")"}]}], "]"}], "2"]}]]}]]],
 "  is continuous, as ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"x", "'"}], 
   RowBox[{"(", "t", ")"}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "'"}], 
   RowBox[{"(", "t", ")"}]}]]],
 " are continuous functions, so the ",
 StyleBox[ButtonBox["length",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/ArcLength.html"], None}],
  FontVariations->{"Underline"->True}],
 " ",
 Cell[BoxData[
  RowBox[{"L", 
   RowBox[{"(", "C", ")"}]}]]],
 " of the curve ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " is  \n\n",
 StyleBox["(6-11)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"L", 
    RowBox[{"(", "C", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     SubsuperscriptBox["\[Integral]", "a", "b"], " ", 
     RowBox[{
      SqrtBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"[", 
          RowBox[{
           RowBox[{"x", "'"}], 
           RowBox[{"(", "t", ")"}]}], "]"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"[", 
          RowBox[{
           RowBox[{"y", "'"}], 
           RowBox[{"(", "t", ")"}]}], "]"}], "2"]}]], 
      RowBox[{"\[DifferentialD]", "t"}]}]}], " ", "=", " ", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", "a", "b"], " ", 
     RowBox[{"|", 
      RowBox[{
       RowBox[{"z", "'"}], 
       RowBox[{"(", "t", ")"}]}], "|", 
      RowBox[{"\[DifferentialD]", "t"}]}]}]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "\tNow consider ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " to be a curve with parameterization  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"C", ":", " ", 
    RowBox[{
     SubscriptBox["z", "1"], 
     RowBox[{"(", "t", ")"}]}]}], "=", " ", 
   RowBox[{
    RowBox[{"x", 
     RowBox[{"(", "t", ")"}]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", "y", 
     RowBox[{"(", "t", ")"}]}]}]}]]],
 "   for   ",
 Cell[BoxData[
  RowBox[{"a", "\[LessEqual]", "t", "\[LessEqual]", "b"}]]],
 ".  \n\n\tThe opposite curve",
 StyleBox[" ",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 " ",
 Cell[BoxData[
  RowBox[{"-", "C"}]]],
 "  traces out the same set of points in the plane, but in the reverse order, \
and has the parametrization  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"-", 
    RowBox[{"C", ":", " ", 
     RowBox[{
      SubscriptBox["z", "2"], 
      RowBox[{"(", "t", ")"}]}]}]}], "=", " ", 
   RowBox[{
    RowBox[{"x", 
     RowBox[{"(", 
      RowBox[{"-", "t"}], ")"}]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", "y", 
     RowBox[{"(", 
      RowBox[{"-", "t"}], ")"}]}]}]}]]],
 "   for   ",
 Cell[BoxData[
  RowBox[{"a", "\[LessEqual]", "t", "\[LessEqual]", "b"}]]],
 ".  \n\nSince  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["z", "2"], 
    RowBox[{"(", "t", ")"}]}], "=", 
   RowBox[{
    SubscriptBox["z", "1"], 
    RowBox[{"(", 
     RowBox[{"-", "t"}], ")"}]}]}]]],
 ",  ",
 Cell[BoxData[
  RowBox[{"-", "C"}]]],
 "  is merely ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " traversed in the opposite sense, as illustrated in Figure 6.3.  "
}], "Text"],

Cell[TextData[{
 "\t\t\t",
 Cell[GraphicsData["CompressedBitmap", "\<\
eJy1W2uMXVUVPjP33pnpY0qLbVVKoRRBEBBJ/WFMNKAFLFgTH4gPiDSkhRKN
BIgEhRSQaE0UUIOmQYVGDAZjDBqjgR/8NAYKBW3LowX6nFJKW0URFHPd397f
t+c75+6ZuWP0JvfM3H32Xu+19trrrLNy1XVXrv7SquvWXr5qyfnXrLr6yrWX
X7vkvC9fE4ZaA1U1cG9VVVcsqdrh/2741y/4bMRl+v+PxD/t7mOPPdZdtmxZ
96KLLsL/e+Jwq3v99dd3hWYwXlvdHTt2dPmpfp6gzMCfwe769euHuPDQoUN5
Umnsz/HawZI8jr8PP/xwGO2df1Rh7M6EvM1bYaluB1pFkIBt2LAhzsCvYQMG
DsPfajPHwB2EkaGEMRAppG2bR+KreRx74IEHIh4jLuASybizfPny+Jt/jc52
gc5BYgQujqX5YSAREoGtWbMGfx8lb8KHVbgFKkFZ+Js5EufpV+/YbKoHWE3f
UT2kORA6ziNwzJs3L34pvSydcR6FCVBhaOM8zoqrYGmgAF/8hpQwD9QTO35X
4hSUwWixDpzig3VhfuYK8uT6zD3gSsezeAUewAJuUA5cgOsGynXVHeQ74sgW
NNTDJ+bXcSeDx7g+SSuB+nAP/AjX0qVLo7QfJSzQSzukQw3FuZRjlk/gYZQs
gXyZjZZjzExcRtlgCYBB2DhLg0YGYIBhsQm4EJ2LGOQ3x8A21ZTZgnjq7tZx
U4+UpOCT5oPdupEOR6OTiYgn0Agz0DqpE55ze+LVfUGSFUsgib5TiwKMtnke
RCmwmif02fa5llqvErMzapZFS8hqAW5YutaDRdE4OyklTBEVELaEohWm/Oo7
iWFnrukSEsJEDLcpazBh4VD6qcna122K15EeZkEumIKNBHqkenmcySQshgGM
mwX+YqnLF+Ca5mawJIFk0DVjoQFqS+jlOSkZIh5X8lCUA0WelReIepR8QMSK
m3KmkQJdo0mXAVLTUJ27EietjBbuOxivLZFJKro1exwfS9s9XIkqGYTwXJay
VfED2WIMX0bJvIsCp6ibE68zIwzuhFHCNJGayQROb68xo/2/xasnGq4LOdww
7wAwxIavhSoz1VoU5dQgs3AdTuwHZ5obp4xEDIpK2gjM7Bgo5xgSbfmzOAY+
YKCg8WlTKwSFXwuy0hvAgFr7ooABuLh4xjQk355vhCj7oViVM3Hzj79mGCqF
jOc4ZgZRHc0xC0raI+aaLBVGhg2sUO0wDmSTc21MYJlFRCFPI3M9itp/4dXX
u3848NfutiOvdf/x5r/3x+GhOHz/8y93f/j0WPee517q/mrnK7h9T1o8SjrG
XvtnnLHuiV3hV7o+8crfstkpD8ZYuFub982n9nQPv/GvOOPHdbAEGSe2OR30
CewuzgsERTCY0eE8EKt5P0pgZxeo0HSgaoL1eUO4/qQO55GxI/X7eya6QREJ
wd19wgGvkxHg98UIlNWPfKDIhnwkdoiupCWykLWJ3wLbMjkCXUGbGP7dnsNx
4iCn37FlXwa7L1470Rju3/Fy98bHd4bvLqihuteNtRWtErfClOqAjYnqjb3T
deuA2TvHgLGGoH430P0Sh0GahsOUxiIwYncjJjEKgBI3tTh3ovv7/QZ8crKF
7mZXmqQ1dhPH5EvB2CRNRREoQbeu4hjQwpQCqAxCdhFMpwnCb13VEBZMJFjq
jZwKw8NwWNKE4rc+bVAgHDhJsJ7BeLMluzMXG458gBB8MR08YOn3t41lg4MB
yj5vIFr5X4BZXTxNtOlGO5KOuXDJYAfvrTPmGD5h1oJxSDmMLyDMGzftzEaE
7/qn9gLoDVxlLg8+JgC20IIgqare4yT1AFrJYcgGJgV+AqDhzONgNI9WFmr4
JrMNNAMW0OgLtMHeJHM4cjOe3PzE7u7PgpMHwquvlP3nY2WSFFChCiAKLFci
DtMmIw4gsCas7WR5xzDSve3JPd27to51HwxTApgOYQCiJHiiS3CoSW50t2A2
K6hz4KVBM+i2XR+Yquzg/ucPNoy5E+0AQvrp9gORiDC9utYdH3Dk5Bc0cMLO
mjhBYgCSiiwjUaoycFpNpIFRd4bFc+3OKe1KZRoPT9wHqvMs/GA8+GPetuGb
8D1IdWGcNzPOcVOXRn/xwsHuxsD2d4M6gggGoSN6BoI+poIsgru6EYJgDyv6
pGRRnNeJHCjixX1l0/jGfW+Aq4hBC5iTJACVpJOQgut925MgAw5P71hSq84y
siB3CK3VIAsO8TaSpXnyOQRjVQFFMsKPVA3UUD9zuC9yKjfdKIVjCmS9i2PQ
s6zH932RtZTznjz09+6GZ/abP3eiG0kxIAuyWWrSChanPRVTvrdlLAr6Jka7
wMUcujtyYaT4SKPjMQSHpHrF8rRJ5AgzYI5YnWpuASYgAM+TNG8tUVvCBwbe
2j9F72iI0EOdU3QyNQtMt23enbHB4No2H/eh7eOTCJXIeKbYMkZEhk47VnWr
mnVJVN4kQGhKGZw8GuQrJXt3w9iC6jKZMjb40RWUlOdHgYWFfZJz4iT6BAoF
oKTPIU88o3uStHbDZmGDi5MAm3mKM+yBVAKEqnH2TNpKY1buqN7JMdg006ea
AEXxMrOLpgCxTnpWiVr7OL7h/y9wOabCXZBeLeyTxEVGosZ0pgfakt5F9umm
d7grHEdrMQfkeUyFDRIPI0yWuJ89JpM47EPlkjNsbfPEAA0K1fuMTMxrBq6H
9h4J++fLNc9SKL+Ea8E2RBv2/yxap2UpbU6a1gdiCPDcySW9M4187p+58AIw
9QCRdmiwwLO2ck1ISdSmTKGStv14wvQjH7Oc+NMbxPtOG2zggwQHc7Czdm37
8/DyeVopolk6fu0C4TMxrPKiF+VJCv27k70PH4ae2klQen1/w9R8njYaD4FY
K0klEVFg7Zhjiq3f7znMQmGI5hKNhVSlD4B1junr7mf384SR0FHPccbniAfo
Rdp92w8syHiWcoKr7K5tY62CK3zAYGEcKWlIeqQJP7HPrXN55I0388Eh7Mwy
BT12RAVNsRPALQrqdLbc+K2novUIIhP4wdNRJnEDDyDnFzCeEMeGG5a1M+cA
SCk+xHV/PPBqHS0N/i28j1QQ9+Gl4k41TOwqp5A7K0RlPEFd506Tu4f2Hs4g
Nm5/aX4B4xKOeZFINoozm5IgcdhT5Klx2I4SiBnupuhTYlJPBCHQjo2J4uPo
Wr4lruNB/COc74dW3yProbATrchdAYWX+X3SodAJGLdsrpekaGJxxtkFsZXE
IX/CN/Ci0i4e6KBw7s/NVCd2cXgmJ1ZWFFBLHF5luRRX3fDyytF9EiFZgIfb
NtfrY5aiVx+2eZOV5+js8ymatGPtlAqVXmPvV60eCRd+66lu0NrigmQAAVvH
hfQeKMm3Cfwfxi7DbRHm7nJ0f6gXkE/Y6C0NV9FxBTN0fsTvyeqK8+ry8Mga
9KgCh572s8I/CBUda0JQeZGVzerXzqWXO+dPAnA+JYe5t1o+j0pC8P4LiA87
BhIUBN4NIXIGMgm2knAUk5FWncVlOGhpUwF0kPmbhDv5Dc+q3W//aV9UFmvp
Z1hQ4CYS2X1k31+q1Y62XgYKVJ3JlYhWNxHzzY8nzGJGzzj1MApusJr3ZFWK
wSkjC4o73UjCBB3m4Zjyg6m6ZFJGS/dqZ4nRD7Shg6O7nx3f4CCfF199fSWR
qNEHv1ZzDNOwDL4wWHDA00i8EjqPKufyXqkDZ3GdYDfUYA06nco4PKEOmsrY
P1qgvNTbU+oP+hRRW3wDZ6Wq86mmoSaT5xO0R/wSulJ7UYqQlQ7TyK8sbT2Z
c+CRVGiOgXAiQREF3lek2OuCKfX/lPqULjaVan9kGlmThO+pbqul/ibv/Cn1
S80t0FGTTpmck0xEKs/ITtYF31RYXE5mJ2tcKomsVSDV+1T00LFt5LNXKpfL
PYwEDZ9CdiySZwmePQ0yveuoROasPslM7LCu1kOtDvPQ9504aW8qH1Ul4H76
pVzA3pNQ79fq1LZNwAKMdmG+BK1aHmOI6kk+LEGfMw1yrQWqSO6saZI7kAT+
9gLVwYRPImVWfsr7HKN5dvjehq2ycHubxIYi196kAoqD+Yhg9obV5OtHoyDE
EwkJMdqDIvMDRQMnskVRldqvSh1ts/ogdgC0DgAkBXtMgdxgqumwORItuXnI
++3uw5qmTNi7xtwSWK+rvNOp1q1Wa7XBCrXZOYPqUfNQ6zJEEnQCmecpP99j
pebcAqHeAThRn5cTPHtqggdA7wCg1MTbSzJOVccTipd6B7lv8Vib66A4AOrZ
jCUIWUwQtGo1k/XHqQLdnFdaq7HPULQFHjC2mEtKFUwPeucZ6FpbcLC+YvdZ
nYPZ0+FgAENURtTDogl4YLVNJc5eVaQMnnxkhKVHZs5XqXvN/QJjwSUzvFLb
oq/9rJHv7kgz0bMYqEC5j5c5dQBZ0SepkYRmHa4vuin4MEbB67SoJ/IKIvBZ
QVF11qtzyO5UBvW+D6Z3OW/xYvNK4pqs2a/UT6g++/ENfqjWq4sPyxaX8HZz
m2Q3QJu3oQg3M/hF4HhWgxEU8b30yBoB6y39MzI6fUaonuNoA838igTj/FOr
vkjUaltTs5erRJUJxKyPk5PJ+hW9HzIKUO3XlsgVG0zl8pcYMfUI1PaHULiv
Wh30xU/uwYRW7Ll3q+H/yCUunCY7o32xM4D1Hq2OJxpQ5I6DfHKYO4QdK+MH
0h5kr4F1KOTqpJ6ngo1PktRy92XDr2XT4IuBV52duO8btTKXS83OS4+nb91c
77exOnhUojotxh9JJ/rlHyunQ/9oH/RT+DF2RQ2cQEC+Iahq7w8OZlqUVaH2
cpOIWlGb/el4WOlHb1VELzPNs98gaf7xXcHzhX+8C2bIpKqn65cW8M/uEz/Z
13NUO2MHOa7LD5kgEvYSXGGQlbR7Xiyb8PO0xiQpOOiDk0hZzgwuQRJ7RS4r
oB7tE3WDUesgGa8abBvLPUDyLG++VFeEt/O6N4gk171O9Ws45hV1NV/88sWD
3n+0poBmdp9oButclurD3gZ7Da3POonjB9ZSe5HG24plAP5com1OK+BrOc/b
lGfamN52KOFgcUPNEaV+Ua+v7+c8i505sfD679cT2JPItrZldcrAmQ/Sgvx5
ehDZN9LKiG4aPdJLiKlU+VT7KfiGO3rxUqdtzPhWAqUemqmKeYOFsecn0DMO
4SUYrcJY6uWslP33vOxXTV1Oa3ZwQAqp933I4Yk0kDtUACPQ/rYfqUtlgz5e
+atKlawhRxM/EFhY4zJVZWjrNFB5E/8UqHhKDncbLE35hl/Vb+2olQs6yc97
523pA6f48Pff8CGcVgGVB0uJ42uJS51oaBbxV8dANLnqLdqM73+Oyis1Wwo4
9Caf3njUh/Bbk4CWwgtc+BttHcrSuMj6Lr3Ip+JHqSCypQA/cT9T9pPh6z3K
Bq7JUPk7euRo0YQYywWf0gHYX73xeRJe8qRRxxE/VhWPHDStEHjbBRwa8zfw
vprYOZa3Sm/g9VtS0bkYUiqxvS1eR0qbajw7gA2rKU2FwrmRBsiNik2F1+mK
x3w//ypwOhl6DL3lfwDX/b9I9lC2AX357pyH/LpgRvJrc/j6jsHT4db/FvKM
CSHby3IlL6+dRqqpX5kTI0phZaP+hnOgfuv/EQXfo0tvVeR+RD886ASI+KAt
yg4Nuydc0q4t6bJ62sDk2buO4uKJGfueCad2am/Da58lhlO4zDPnjoFSlry3
ME+24Vs1wepxqweNUtI6VpjnaZDAcmOPHEyRP1YD/wF2GJS5\
\>"], "Graphics",
  ImageSize->{416, 103},
  ImageMargins->0],
 StyleBox["\n\t\t\t",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Figure 6.3",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/contourintegral/\
ContourIntegralMod/Images/mat0603.gif"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 "  The curve  ",
 Cell[BoxData["C"]],
 "  and its opposite curve  ",
 Cell[BoxData[
  RowBox[{"-", "C"}]]],
 "."
}], "Text",
 CellChangeTimes->{{3.3992949233125*^9, 3.399294934640625*^9}}],

Cell[TextData[{
 "\tA curve ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " that is constructed by joining finitely many smooth curves end to end is \
called a ",
 StyleBox[ButtonBox["contour",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/Contour.html"], None}],
  FontVariations->{"Underline"->True}],
 ".  Let  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["C", "1"], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   SubscriptBox["C", "2"], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "...", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   SubscriptBox["C", "n"]}]]],
 "  denote ",
 StyleBox["n",
  FontFamily->"Courier New"],
 " smooth curves such that the terminal point of the curve  ",
 Cell[BoxData[
  SubscriptBox["C", "k"]]],
 "  coincides with the initial point of  ",
 Cell[BoxData[
  SubscriptBox["C", 
   RowBox[{"k", "+", "1"}]]]],
 "  for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"k", "=", "1"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "2", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "...", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{"n", "-", "1"}]}]]],
 ".  We express the contour C by the equation\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"C", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["C", "1"], "+", 
      SubscriptBox["C", "2"], "+"}], "..."}], "+", 
    SubscriptBox["C", "n"]}]}]]],
 ".\n\nA synonym for contour is path.  "
}], "Text"],

Cell[TextData[{
 StyleBox["Example 6.5.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Find a parameterization of the polygonal path  ",
 Cell[BoxData[
  RowBox[{"C", "=", 
   RowBox[{
    SubscriptBox["C", "1"], "+", 
    SubscriptBox["C", "2"], "+", 
    SubscriptBox["C", "3"]}]}]]],
 "  from  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"-", "1"}], "+", 
   RowBox[{"\[ImaginaryI]", "  ", 
    StyleBox["to",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], "  ", "3"}], "-", "\[ImaginaryI]"}]]],
 "  shown in Figure 6.4.\nHere  ",
 Cell[BoxData[
  SubscriptBox["C", "1"]]],
 "  is the line from  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"-", "1"}], "+", 
   RowBox[{"\[ImaginaryI]", "  ", 
    StyleBox["to",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]]}], "  ", "-", "1"}]]],
 ",  ",
 Cell[BoxData[
  SubscriptBox["C", "2"]]],
 "  is the line from  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"-", "1"}], "  ", 
    StyleBox["to",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], "  ", "1"}], "+", "\[ImaginaryI]"}]]],
 ",  and  ",
 Cell[BoxData[
  SubscriptBox["C", "3"]]],
 "  is the line from  ",
 Cell[BoxData[
  RowBox[{"1", "+", 
   RowBox[{"\[ImaginaryI]", "  ", 
    StyleBox["to",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], "  ", "3"}], "-", "\[ImaginaryI]"}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["\t\t\t",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
  ImageSize->{348, 205},
  ImageMargins->0],
 StyleBox["\n\t\t\t",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Figure 6.4",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/contourintegral/\
ContourIntegralMod/Images/mat0604.gif"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 "  The polygonal path ",
 Cell[BoxData[
  RowBox[{"C", "=", 
   RowBox[{
    SubscriptBox["C", "1"], "+", 
    SubscriptBox["C", "2"], "+", 
    SubscriptBox["C", "3"]}]}]]],
 " from  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"-", "1"}], "+", 
   RowBox[{"\[ImaginaryI]", "  ", 
    StyleBox["to",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], "  ", "3"}], "-", "\[ImaginaryI]"}]]],
 ".  "
}], "Text",
 CellChangeTimes->{{3.3992949405*^9, 3.399294951515625*^9}, {
  3.3993082821875*^9, 3.399308288046875*^9}}],

Cell[TextData[{
 "Solution.  We express ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " as three smooth curves, or  ",
 Cell[BoxData[
  RowBox[{"C", "=", 
   RowBox[{
    SubscriptBox["C", "1"], "+", 
    SubscriptBox["C", "2"], "+", 
    SubscriptBox["C", "3"]}]}]]],
 ".  If we set  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "0"], "=", 
   RowBox[{
    RowBox[{"-", "1"}], "+", "\[ImaginaryI]"}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], "=", 
   RowBox[{"-", "1"}]}]]],
 ",  we can use Equation ",
 StyleBox["(1-48)",
  FontColor->RGBColor[0, 0, 1],
  Background->None],
 " to get a formula for the straight-line segment joining two points:  \n\n\t\
\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["C", "1"], ":", "  ", 
    RowBox[{
     SubscriptBox["z", "1"], 
     RowBox[{"(", "t", ")"}]}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "0"], " ", "+", " ", 
     RowBox[{"t", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["z", "1"], "-", 
        SubscriptBox["z", "0"]}], ")"}]}]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "\[ImaginaryI]"}], ")"}], " ", "+", " ", 
     RowBox[{"t", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "-", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[ImaginaryI]"}], ")"}]}], 
       ")"}]}]}]}]}]]],
 ",  \n\nfor ",
 Cell[BoxData[
  RowBox[{"0", "\[LessEqual]", "t", "\[LessEqual]", "1"}]]],
 ".  When simplified, this formula becomes  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["C", "1"], ":", "  ", 
    RowBox[{
     SubscriptBox["z", "1"], 
     RowBox[{"(", "t", ")"}]}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"-", "1"}], " ", "+", " ", 
    RowBox[{"\[ImaginaryI]", " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", "t"}], ")"}]}]}]}]]],
 ",   for   ",
 Cell[BoxData[
  RowBox[{"0", "\[LessEqual]", "t", "\[LessEqual]", "1"}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "\nSimilarly, the segments ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["C", "2"], " ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], " ", 
   SubscriptBox["C", "3"]}]]],
 " are given by  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["C", "2"], ":", "  ", 
    RowBox[{
     SubscriptBox["z", "2"], 
     RowBox[{"(", "t", ")"}]}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"-", "1"}], "+", 
    RowBox[{"2", "t"}], " ", "+", " ", 
    RowBox[{"\[ImaginaryI]", " ", "t"}]}]}]]],
 ",   for   ",
 Cell[BoxData[
  RowBox[{"0", "\[LessEqual]", "t", "\[LessEqual]", "1"}]]],
 ",   and   \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["C", "3"], ":", "  ", 
    RowBox[{
     SubscriptBox["z", "3"], 
     RowBox[{"(", "t", ")"}]}]}], "  ", "=", "  ", 
   RowBox[{"1", "+", 
    RowBox[{"2", "t"}], " ", "+", " ", 
    RowBox[{"\[ImaginaryI]", " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"2", "t"}]}], ")"}]}]}]}]]],
 ",   for   ",
 Cell[BoxData[
  RowBox[{"0", "\[LessEqual]", "t", "\[LessEqual]", "1"}]]],
 ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Explore ",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 StyleBox["Solution 6.5.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]
}], "Text"],

Cell["Enter the four points and construct the three line segments.", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"t", "=", 
     RowBox[{"x", "=", 
      RowBox[{"y", "=", 
       RowBox[{"z", "=", "0"}]}]}]}], ";", " ", 
    RowBox[{"Remove", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"V1", ",", "V2", ",", "V3", ",", "Z1", ",", "Z2", ",", "Z3"}], 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "0"], " ", "=", " ", 
     RowBox[{
      RowBox[{"-", " ", "1"}], " ", "+", " ", "\[ImaginaryI]"}]}], ";"}], " ",
    "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "1"], " ", "=", " ", 
     RowBox[{"-", " ", "1"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["x", "0"], "=", 
     RowBox[{"Re", "[", 
      SubscriptBox["z", "0"], "]"}]}], ";", " ", 
    RowBox[{
     SubscriptBox["y", "0"], "=", 
     RowBox[{"Im", "[", 
      SubscriptBox["z", "0"], "]"}]}], ";", " ", 
    RowBox[{
     SubscriptBox["x", "1"], "=", 
     RowBox[{"Re", "[", 
      SubscriptBox["z", "1"], "]"}]}], ";", " ", 
    RowBox[{
     SubscriptBox["y", "1"], "=", 
     RowBox[{"Im", "[", 
      SubscriptBox["z", "1"], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"Z1", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{
      SubscriptBox["x", "0"], " ", "+", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["x", "1"], "-", 
         SubscriptBox["x", "0"]}], ")"}], "t"}], " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["y", "0"], " ", "+", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["y", "1"], "-", 
            SubscriptBox["y", "0"]}], ")"}], "t"}]}], ")"}]}]}]}], ";"}], " ",
    "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "0"], " ", "=", " ", 
     RowBox[{"-", " ", "1"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "1"], " ", "=", " ", 
     RowBox[{"1", " ", "+", " ", "\[ImaginaryI]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["x", "0"], "=", 
     RowBox[{"Re", "[", 
      SubscriptBox["z", "0"], "]"}]}], ";", " ", 
    RowBox[{
     SubscriptBox["y", "0"], "=", 
     RowBox[{"Im", "[", 
      SubscriptBox["z", "0"], "]"}]}], ";", " ", 
    RowBox[{
     SubscriptBox["x", "1"], "=", 
     RowBox[{"Re", "[", 
      SubscriptBox["z", "1"], "]"}]}], ";", " ", 
    RowBox[{
     SubscriptBox["y", "1"], "=", 
     RowBox[{"Im", "[", 
      SubscriptBox["z", "1"], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"Z2", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{
      SubscriptBox["x", "0"], " ", "+", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["x", "1"], "-", 
         SubscriptBox["x", "0"]}], ")"}], "t"}], " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["y", "0"], " ", "+", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["y", "1"], "-", 
            SubscriptBox["y", "0"]}], ")"}], "t"}]}], ")"}]}]}]}], ";"}], " ",
    "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "0"], " ", "=", " ", 
     RowBox[{"1", " ", "+", " ", "\[ImaginaryI]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "1"], " ", "=", " ", 
     RowBox[{"3", " ", "-", " ", "\[ImaginaryI]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["x", "0"], "=", 
     RowBox[{"Re", "[", 
      SubscriptBox["z", "0"], "]"}]}], ";", " ", 
    RowBox[{
     SubscriptBox["y", "0"], "=", 
     RowBox[{"Im", "[", 
      SubscriptBox["z", "0"], "]"}]}], ";", " ", 
    RowBox[{
     SubscriptBox["x", "1"], "=", 
     RowBox[{"Re", "[", 
      SubscriptBox["z", "1"], "]"}]}], ";", " ", 
    RowBox[{
     SubscriptBox["y", "1"], "=", 
     RowBox[{"Im", "[", 
      SubscriptBox["z", "1"], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"Z3", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{
      SubscriptBox["x", "0"], " ", "+", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["x", "1"], "-", 
         SubscriptBox["x", "0"]}], ")"}], "t"}], " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["y", "0"], " ", "+", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["y", "1"], "-", 
            SubscriptBox["y", "0"]}], ")"}], "t"}]}], ")"}]}]}]}], ";"}], " ",
    "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(Z\), \(1\)]\)[t] = \>\"", ",", 
      RowBox[{"Z1", "[", "t", "]"}], ",", 
      "\"\<,       for  0 \[LessEqual] t \[LessEqual] 1,\>\""}], "]"}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(Z\), \(2\)]\)[t] = \>\"", ",", 
      RowBox[{"Z2", "[", "t", "]"}], ",", 
      "\"\<,       for  0 \[LessEqual] t \[LessEqual] 1,\>\""}], "]"}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(Z\), \(3\)]\)[t] = \>\"", ",", 
      RowBox[{"Z3", "[", "t", "]"}], ",", 
      "\"\<,  for  0 \[LessEqual] t \[LessEqual] 1.\>\""}], "]"}], ";"}], " ",
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(Z\), \(1\)]\)[t] = \>\"", ",", 
      RowBox[{"Z1", "[", "t", "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(Z\), \(1\)]\)[0] = \>\"", ",", 
      RowBox[{"Z1", "[", "0", "]"}]}], " ", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(Z\), \(1\)]\)[1] = \>\"", ",", 
      RowBox[{"Z1", "[", "1", "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(Z\), \(2\)]\)[t] = \>\"", ",", 
      RowBox[{"Z2", "[", "t", "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(Z\), \(2\)]\)[0] = \>\"", ",", 
      RowBox[{"Z2", "[", "0", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(Z\), \(2\)]\)[1] = \>\"", ",", 
      RowBox[{"Z2", "[", "1", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(Z\), \(3\)]\)[t] = \>\"", ",", 
      RowBox[{"Z3", "[", "t", "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(Z\), \(3\)]\)[0] = \>\"", ",", 
      RowBox[{"Z3", "[", "0", "]"}]}], " ", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(Z\), \(3\)]\)[1] = \>\"", ",", 
      RowBox[{"Z3", "[", "1", "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39928818640625*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "We can use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to graph these line segments."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"V1", "[", "t_", "]"}], "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Re", "[", 
         RowBox[{"Z1", "[", "t", "]"}], "]"}], ",", 
        RowBox[{"Im", "[", 
         RowBox[{"Z1", "[", "t", "]"}], "]"}]}], "}"}], "]"}]}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"V2", "[", "t_", "]"}], "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Re", "[", 
         RowBox[{"Z2", "[", "t", "]"}], "]"}], ",", 
        RowBox[{"Im", "[", 
         RowBox[{"Z2", "[", "t", "]"}], "]"}]}], "}"}], "]"}]}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"V3", "[", "t_", "]"}], "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Re", "[", 
         RowBox[{"Z3", "[", "t", "]"}], "]"}], ",", 
        RowBox[{"Im", "[", 
         RowBox[{"Z3", "[", "t", "]"}], "]"}]}], "}"}], "]"}]}], ";"}], " ", 
   "\n", 
   RowBox[{"ParametricPlot", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"V1", "[", "t", "]"}], ",", 
        RowBox[{"V2", "[", "t", "]"}], ",", 
        RowBox[{"V3", "[", "t", "]"}]}], "}"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "1"}], "}"}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "3", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red", ",", "Green"}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<C: \!\(\*SubscriptBox[\(Z\), \(1\)]\)[t] = \>\"", ",", 
      RowBox[{"Z1", "[", "t", "]"}], ",", 
      "\"\<,     for 0 \[LessEqual] t \[LessEqual] 1.\>\""}], "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<   \!\(\*SubscriptBox[\(Z\), \(2\)]\)[t] = \>\"", ",", 
      RowBox[{"Z2", "[", "t", "]"}], ",", 
      "\"\<,     for 0 \[LessEqual] t \[LessEqual] 1.\>\""}], "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<   \!\(\*SubscriptBox[\(Z\), \(3\)]\)[t] = \>\"", ",", 
      RowBox[{"Z3", "[", "t", "]"}], ",", 
      "\"\<, for 0 \[LessEqual] t \[LessEqual] 1.\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39928819290625*^9, 3.3992882345*^9}, {
  3.39988154678125*^9, 3.399881547734375*^9}, {3.39988210003125*^9, 
  3.399882127703125*^9}}]
}, Closed]],

Cell[TextData[{
 "\tWe are now ready to define the integral of a complex function along a \
contour ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " in the plane with initial point ",
 StyleBox["A",
  FontFamily->"Courier New"],
 " and terminal point ",
 StyleBox["B",
  FontFamily->"Courier New"],
 ".  Our approach is to mimic what is done in calculus.  We create a \
partition  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["P", "n"], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["z", "0"], "=", "A"}], 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], 
     SubscriptBox["z", "1"], 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], 
     SubscriptBox["z", "2"], 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "...", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], 
     RowBox[{
      SubscriptBox["z", "n"], "=", "B"}]}], "}"}]}]]],
 "  of points that proceed along ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " from ",
 StyleBox["A",
  FontFamily->"Courier New"],
 " to ",
 StyleBox["B",
  FontFamily->"Courier New"],
 " and form the differences  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["\[CapitalDelta]z", "k"], "=", 
   RowBox[{
    SubscriptBox["z", "k"], "-", 
    SubscriptBox["z", 
     RowBox[{"k", "-", "1"}]]}]}]]],
 "  for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"k", "=", "1"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "2", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "...", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "n"}]]],
 ".  Between each pair of partition points  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", 
    RowBox[{"k", "-", "1"}]], "  ", "and", "  ", 
   SubscriptBox["z", "k"]}]]],
 "  we select a point  ",
 Cell[BoxData[
  SubscriptBox["c", "k"]]],
 "  on ",
 StyleBox["C",
  FontFamily->"Courier New"],
 ", as shown in Figure 6.5, and evaluate the function  ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", 
    SubscriptBox["c", "k"], ")"}]}]]],
 ".  These values are used to make a ",
 StyleBox[ButtonBox["Riemann Sum",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/RiemannSum.html"], None}],
  FontVariations->{"Underline"->True}],
 " for the partition:  \n\n",
 StyleBox["(6-12)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"S", 
    RowBox[{"(", 
     SubscriptBox["P", "n"], ")"}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"k", "=", "1"}], "n"], 
     RowBox[{"f", 
      RowBox[{"(", 
       SubscriptBox["c", "k"], ")"}], 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["z", "k"], "-", 
        SubscriptBox["z", 
         RowBox[{"k", "-", "1"}]]}], ")"}]}]}], "  ", "=", "  ", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"k", "=", "1"}], "n"], 
     RowBox[{"f", 
      RowBox[{"(", 
       SubscriptBox["c", "k"], ")"}], 
      SubscriptBox["\[CapitalDelta]z", "k"]}]}]}]}]]],
 "."
}], "Text",
 CellChangeTimes->{3.399287976859375*^9}],

Cell[TextData[{
 "\t\t\t",
 Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
  ImageSize->{388, 263},
  ImageMargins->0],
 StyleBox["\n\t\t\t",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Figure 6.5",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/contourintegral/\
ContourIntegralMod/Images/mat0605.gif"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 "  Partition points ",
 Cell[BoxData[
  RowBox[{"{", 
   SubscriptBox["z", "k"], "}"}]]],
 " and function evaluation points ",
 Cell[BoxData[
  RowBox[{"{", 
   SubscriptBox["c", "k"], "}"}]]],
 " \n\t\t\t\t\tfor a Riemann sum along the contour ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " from ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{
    RowBox[{"A", " ", 
     StyleBox["to",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], " ", "z"}], "=", "B"}]}]]],
 "."
}], "Text",
 CellChangeTimes->{{3.39929495878125*^9, 3.39929497475*^9}}],

Cell[TextData[{
 "\tAssume now that there exists a unique complex number ",
 StyleBox["L",
  FontFamily->"Courier New"],
 " that is the limit of every sequence ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{"S", 
    RowBox[{"(", 
     SubscriptBox["P", "n"], ")"}]}], "}"}]]],
 " of ",
 StyleBox[ButtonBox["Riemann sums",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/RiemannSum.html"], None}],
  FontVariations->{"Underline"->True}],
 " given in Equation ",
 StyleBox["(6-12)",
  FontColor->RGBColor[0, 0, 1]],
 ", where the maximum of ",
 Cell[BoxData[
  RowBox[{"|", 
   SubscriptBox["\[CapitalDelta]z", "k"], "|"}]]],
 " tends toward ",
 StyleBox["0",
  FontFamily->"Courier New"],
 " for the sequence of partitions.  We define the number ",
 StyleBox["L",
  FontFamily->"Courier New"],
 " as the value of the integral of the function ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " taken along the contour ",
 StyleBox["C",
  FontFamily->"Courier New"],
 "."
}], "Text",
 CellChangeTimes->{3.39928798740625*^9}],

Cell[TextData[{
 StyleBox["Definition 6.2 (",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Complex Integral",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/ContourIntegral.html"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 StyleBox[").",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Let ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " be a contour.  Then  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["\[Integral]", "C"], " ", 
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}], " ", 
     RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "=", "  ", 
   RowBox[{
    UnderscriptBox["lim", 
     RowBox[{"n", " ", "\[Rule]", " ", "\[Infinity]"}]], " ", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"k", "=", "1"}], "n"], 
     RowBox[{"f", 
      RowBox[{"(", 
       SubscriptBox["c", "k"], ")"}], 
      SubscriptBox["\[CapitalDelta]z", "k"]}]}]}]}]]],
 ",  \n\nprovided that the limit exists in the sense previously discussed."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "\tNote that in Definition 6.2, the value of the integral depends on the \
contour.  In Section 6.3 the ",
 StyleBox[ButtonBox["Cauchy",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Cauchy.\
html"], None}],
  FontVariations->{"Underline"->True}],
 StyleBox["-",
  FontSize->14,
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 StyleBox[ButtonBox["Goursat",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Goursat.\
html"], None}],
  FontVariations->{"Underline"->True}],
 " theorem will establish the remarkable fact that, if ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " is analytic, then ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["\[Integral]", "C"], " ", 
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}], " ", 
    RowBox[{"\[DifferentialD]", "z"}]}]}]]],
 " is independent of the contour."
}], "Text"],

Cell[TextData[{
 StyleBox["Example 6.6.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Use a Riemann sum to get an approximation for the integral  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["\[Integral]", "C"], " ", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", "z"], " ", 
    RowBox[{"\[DifferentialD]", "z"}]}]}]]],
 "  where ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " is a the line segment joining the point  ",
 Cell[BoxData[
  RowBox[{"A", " ", "=", 
   RowBox[{
    RowBox[{"0", "  ", 
     StyleBox["to",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", "B"}], "=", 
    RowBox[{"2", "+", 
     FractionBox[
      RowBox[{"\[ImaginaryI]", " ", "\[Pi]"}], "4"]}]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "Solution.  Set ",
 StyleBox["n=8",
  FontFamily->"Courier New"],
 " in Equation ",
 StyleBox["(6-12)",
  FontColor->RGBColor[0, 0, 1]],
 " and form the partition  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["P", "8"], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["z", "k"], "=", 
      RowBox[{
       FractionBox["k", "4"], "+", 
       RowBox[{"\[ImaginaryI]", 
        FractionBox[
         RowBox[{" ", 
          RowBox[{"k", " ", "\[Pi]"}]}], "32"]}]}]}], 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", 
     RowBox[{
      RowBox[{
       StyleBox["for",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "  ", "k"}], "=", "0"}], 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "1", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "2", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "...", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "8"}], "}"}]}]]],
 ".  For this situation, we have a uniform increment  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["\[CapitalDelta]z", "k"], "=", 
   RowBox[{
    FractionBox["1", "4"], "+", 
    RowBox[{"\[ImaginaryI]", 
     FractionBox["\[Pi]", "32"]}]}]}]]],
 ".  \nFor convenience we select  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["c", "k"], " ", "=", " ", 
   RowBox[{
    FractionBox[
     RowBox[{
      SubscriptBox["z", 
       RowBox[{"k", "-", "1"}]], "+", 
      SubscriptBox["z", "k"]}], "2"], " ", "=", " ", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"2", "k"}], "-", "1"}], "8"], "+", 
     RowBox[{"\[ImaginaryI]", 
      FractionBox[
       RowBox[{" ", 
        RowBox[{"\[Pi]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", "k"}], "-", "1"}], ")"}]}]}], "64"]}]}]}]}]]],
 "  for  ",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{
    RowBox[{"k", "=", "0"}], 
    StyleBox[",",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], "1", 
    StyleBox[",",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], "2", 
    StyleBox[",",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], "...", 
    StyleBox[",",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], "8"}]}]]],
 ".  Figure 6.6 shows the points ",
 Cell[BoxData[
  RowBox[{"{", 
   SubscriptBox["z", "k"], "}"}]]],
 " and ",
 Cell[BoxData[
  RowBox[{"{", 
   SubscriptBox["c", "k"], "}"}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "\t\t\t",
 Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
  ImageSize->{395, 246},
  ImageMargins->0],
 StyleBox["\n\t\t\t",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Figure 6.6",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/contourintegral/\
ContourIntegralMod/Images/mat0606.gif"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 "  Partition and evaluation points for the Riemann sum ",
 Cell[BoxData[
  RowBox[{"S", 
   RowBox[{"(", 
    SubscriptBox["P", "8"], ")"}]}]]],
 "."
}], "Text",
 CellChangeTimes->{{3.39929497990625*^9, 3.399294991734375*^9}}],

Cell[TextData[{
 "One possible Riemann sum, then, is  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"S", 
    RowBox[{"(", 
     SubscriptBox["P", "8"], ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"k", "=", "1"}], "8"], 
     RowBox[{"f", 
      RowBox[{"(", 
       SubscriptBox["c", "k"], ")"}], 
      SubscriptBox["\[CapitalDelta]z", "k"]}]}], " ", "=", " ", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"k", "=", "1"}], "8"], 
     RowBox[{"exp", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{
          RowBox[{"2", "k"}], "-", "1"}], "8"], "+", 
        RowBox[{"\[ImaginaryI]", 
         FractionBox[
          RowBox[{" ", 
           RowBox[{"\[Pi]", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", "k"}], "-", "1"}], ")"}]}]}], "64"]}]}], ")"}], 
      RowBox[{"(", 
       RowBox[{
        FractionBox["1", "4"], "+", 
        RowBox[{"\[ImaginaryI]", 
         FractionBox["\[Pi]", "32"]}]}], ")"}]}]}]}]}]]],
 "  \n\nBy rounding the terms in this Riemann sum to five decimal digits, we \
obtain an approximation for the integral:  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{"S", 
    RowBox[{"(", 
     SubscriptBox["P", "8"], ")"}]}], "  ", "\[TildeTilde]", "  ", 
   RowBox[{"0.27749", "\[InvisibleSpace]", "+", 
    RowBox[{"0.12501", " ", "\[ImaginaryI]"}], " ", "+", " ", "0.33885", "+", 
    
    RowBox[{"0.19467", " ", "\[ImaginaryI]"}], " ", "+", " ", "0.40850", 
    "\[InvisibleSpace]", "+", 
    RowBox[{"0.29140", " ", "\[ImaginaryI]"}]}]}], "\[IndentingNewLine]", 
  RowBox[{"                 ", 
   RowBox[{
    RowBox[{"+", " ", "0.48532"}], "\[InvisibleSpace]", "+", 
    RowBox[{"0.42378", " ", "\[ImaginaryI]"}], " ", "+", " ", "0.56683", "+", 
    
    RowBox[{"0.60261", " ", "\[ImaginaryI]"}], " ", "+", " ", "0.64848", "+", 
    
    RowBox[{"0.84138", " ", "\[ImaginaryI]"}]}]}], "\[IndentingNewLine]", 
  RowBox[{"                 ", 
   RowBox[{
    RowBox[{
     RowBox[{"+", " ", "0.72276"}], "+", 
     RowBox[{"1.15676", " ", "\[ImaginaryI]"}], " ", "+", " ", "0.77798", "+",
      
     RowBox[{"1.56912", " ", "\[ImaginaryI]"}]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"S", 
    RowBox[{"(", 
     SubscriptBox["P", "8"], ")"}]}], "  ", "\[TildeTilde]", "  ", 
   RowBox[{"4.226201", " \[InvisibleSpace] ", "+", " ", 
    RowBox[{"5.20473", "  ", "\[ImaginaryI]", " "}]}]}]}]],
 " \n\nThis result compares favorably with the precise value of the integral, \
which you will soon see equals  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"exp", 
     RowBox[{"(", 
      RowBox[{"2", "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "\[Pi]"}], "4"]}], ")"}]}], "-", "1"}], 
   "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", "2"], 
      FractionBox[
       SqrtBox["2"], "2"]}], "+", " ", 
     RowBox[{"\[ImaginaryI]", " ", 
      SuperscriptBox["\[ExponentialE]", "2"], 
      FractionBox[
       SqrtBox["2"], "2"]}]}], "  ", "=", "  ", 
    RowBox[{"4.22485", "\[InvisibleSpace] ", "+", " ", 
     RowBox[{"5.22485", " ", "\[ImaginaryI]"}]}]}]}]]],
 ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Explore ",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 StyleBox["Solution 6.6.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]
}], "Text"],

Cell[TextData[{
 "Enter the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], "=", 
   SuperscriptBox["\[ExponentialE]", "z"]}]],
  AspectRatioFixed->True],
 "  and compute the approximating Riemann sum.  \n",
 StyleBox["For illustration.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]],
 "  We use n = 8 terms in the sum."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", 
     RowBox[{"a", ",", "b", ",", "c", ",", "z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"dz", ",", "f", ",", "k", ",", "n", ",", "RiemannSum"}], "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     SuperscriptBox["\[ExponentialE]", "z"]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"a", " ", "=", " ", "0"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"b", " ", "=", " ", 
     RowBox[{"2", " ", "+", 
      FractionBox[
       RowBox[{" ", 
        RowBox[{"\[ImaginaryI]", " ", "\[Pi]"}]}], "4"]}]}], ";"}], " ", "\n",
    
   RowBox[{
    RowBox[{"n", " ", "=", " ", "8"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"dz", " ", "=", " ", 
     FractionBox[
      RowBox[{"b", "-", "a"}], "n"]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "k_"], " ", "=", " ", 
     RowBox[{"Expand", "[", 
      RowBox[{"a", " ", "+", " ", 
       RowBox[{"k", " ", "dz"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["c", "k_"], " ", "=", " ", 
     RowBox[{"Expand", "[", 
      FractionBox[
       RowBox[{
        SubscriptBox["z", 
         RowBox[{"k", "-", "1"}]], " ", "+", " ", 
        SubscriptBox["z", "k"]}], "2"], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"RiemannSum", " ", "=", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"k", "=", "1"}], "n"], 
      RowBox[{
       RowBox[{"f", "[", 
        SubscriptBox["c", "k"], "]"}], "dz"}]}]}], " ", ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<n = \>\"", ",", "n"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<{\!\(\*SubscriptBox[\(z\), \(k\)]\)} = \>\"", ",", 
      RowBox[{"Table", "[", 
       RowBox[{
        SubscriptBox["z", "k"], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", "1", ",", "n"}], "}"}]}], "]"}]}], "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<{\!\(\*SubscriptBox[\(c\), \(k\)]\)} = \>\"", ",", 
      RowBox[{"Table", "[", 
       RowBox[{
        SubscriptBox["c", "k"], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", "1", ",", "n"}], "}"}]}], "]"}]}], "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      OverscriptBox["\"\<\!\(\*UnderscriptBox[\(\[Sum]\), \(k = 1\)]\)\>\"", 
       "n"], ",", 
      "\"\<f[\!\(\*SubscriptBox[\(c\), \(k\)]\)]\!\(\*SubscriptBox[\(dz\), \
\(k\)]\) = \!\(\*UnderoverscriptBox[\(\[Sum]\), \(k = 1\), \
\(8\)]\)Exp[\!\(\*FractionBox[\(2  k - 1\), \
\(8\)]\)+\[ImaginaryI]\!\(\*FractionBox[\(\(\\\ \)\(\[Pi] \((2  k - 1)\)\)\), \
\(64\)]\)](\!\(\*FractionBox[\(1\), \
\(4\)]\)+\[ImaginaryI]\!\(\*FractionBox[\(\[Pi]\), \(32\)]\))\>\""}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      OverscriptBox["\"\<\!\(\*UnderscriptBox[\(\[Sum]\), \(k = 1\)]\)\>\"", 
       "n"], ",", 
      "\"\<f[\!\(\*SubscriptBox[\(c\), \(k\)]\)]\!\(\*SubscriptBox[\(dz\), \
\(k\)]\) = \>\""}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "RiemannSum", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      OverscriptBox["\"\<\!\(\*UnderscriptBox[\(\[Sum]\), \(k = 1\)]\)\>\"", 
       "n"], ",", 
      "\"\<f[\!\(\*SubscriptBox[\(c\), \(k\)]\)]\!\(\*SubscriptBox[\(dz\), \
\(k\)]\) = \>\""}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"k", "=", "1"}], "n"], 
        RowBox[{"f", "[", 
         SubscriptBox["c", "k"], "]"}]}], ")"}], "dz"}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      OverscriptBox["\"\<\!\(\*UnderscriptBox[\(\[Sum]\), \(k = 1\)]\)\>\"", 
       "n"], ",", 
      "\"\<f[\!\(\*SubscriptBox[\(c\), \(k\)]\)]\!\(\*SubscriptBox[\(dz\), \
\(k\)]\) = \>\"", ",", 
      RowBox[{"N", "[", "RiemannSum", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399288248546875*^9, 3.399288252578125*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "We are done!\n\n",
 StyleBox["Aside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  We can use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to check out some Riemann sum approximations."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"S", "[", "n_", "]"}], ":=", 
     RowBox[{"N", "[", 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"k", "=", "1"}], "n"], 
       RowBox[{
        RowBox[{"Exp", "[", 
         RowBox[{
          FractionBox["1", "n"], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", "k"}], "-", "1", "+", 
            RowBox[{"\[ImaginaryI]", 
             FractionBox[
              RowBox[{" ", 
               RowBox[{"\[Pi]", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", "k"}], "-", "1"}], ")"}]}]}], "8"]}]}], 
           ")"}]}], "]"}], 
        FractionBox["1", "n"], 
        RowBox[{"(", 
         RowBox[{"2", "+", 
          FractionBox[
           RowBox[{"\[ImaginaryI]", " ", "\[Pi]"}], "4"]}], ")"}]}]}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"i", "=", "3"}], ",", 
      RowBox[{"i", "\[LessEqual]", "13"}], ",", 
      RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"m", "=", 
        SuperscriptBox["2", "i"]}], ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{
         OverscriptBox[
          "\"\<\!\(\*UnderscriptBox[\(\[Sum]\), \(k = 1\)]\)\>\"", "m"], ",", 
         "\"\< f[\!\(\*SubscriptBox[\(c\), \
\(k\)]\)]\!\(\*SubscriptBox[\(dz\), \(k\)]\) = \>\"", ",", 
         RowBox[{"NumberForm", "[", 
          RowBox[{
           RowBox[{"S", "[", "m", "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"10", ",", "10"}], "}"}]}], "]"}]}], " ", "]"}], ";"}]}], 
     "  ", "]"}], ";"}], "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399288257296875*^9, 3.3992882586875*^9}}]
}, Closed]],

Cell[TextData[{
 "\tIn general, obtaining an exact value for an integral given by Definition \
6.2 is a daunting task.  Fortunately, there is a beautiful theory that allows \
for an easy computation of many contour integrals.  Suppose that we have a \
parametrization of the contour ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " given by the function ",
 Cell[BoxData[
  RowBox[{"z", 
   RowBox[{"(", "t", ")"}]}]]],
 " for ",
 Cell[BoxData[
  RowBox[{"a", "\[LessEqual]", "t", "\[LessEqual]", "b"}]]],
 ".  That is, ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " is the range of the function ",
 Cell[BoxData[
  RowBox[{"z", 
   RowBox[{"(", "t", ")"}]}]]],
 " over the interval ",
 Cell[BoxData[
  RowBox[{"[", 
   RowBox[{"a", 
    StyleBox[",",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], "b"}], "]"}]]],
 ", as Figure 6.7 shows."
}], "Text",
 CellChangeTimes->{3.399288000125*^9}],

Cell[TextData[{
 "\t",
 Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
  ImageSize->{611, 284},
  ImageMargins->0],
 StyleBox["\n\t\t\t",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Figure 6.7",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/contourintegral/\
ContourIntegralMod/Images/mat0607.gif"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 "  A parametrization of the contour ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " by ",
 Cell[BoxData[
  RowBox[{"z", 
   RowBox[{"(", "t", ")"}]}]]],
 " for ",
 Cell[BoxData[
  RowBox[{"a", "\[LessEqual]", "t", "\[LessEqual]", "b"}]]],
 ". "
}], "Text",
 CellChangeTimes->{{3.399294996921875*^9, 3.399295007671875*^9}}],

Cell[TextData[{
 "\tIt follows that  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"n", "\[Rule]", "\[Infinity]"}]], " ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"k", "=", "1"}], "n"], 
      RowBox[{"f", 
       RowBox[{"(", 
        SubscriptBox["c", "k"], ")"}], 
       SubscriptBox["\[CapitalDelta]z", "k"]}]}]}], "  ", "=", "  ", 
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"n", "\[Rule]", "\[Infinity]"}]], " ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"k", "=", "1"}], "n"], 
      RowBox[{"f", 
       RowBox[{"(", 
        SubscriptBox["c", "k"], ")"}], 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["z", "k"], "-", 
         SubscriptBox["z", 
          RowBox[{"k", "-", "1"}]]}], ")"}]}]}]}]}], "  ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                                              ", 
   RowBox[{"=", "  ", 
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"n", "\[Rule]", "\[Infinity]"}]], " ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"k", "=", "1"}], "n"], 
      RowBox[{"f", 
       RowBox[{"(", 
        RowBox[{"z", 
         RowBox[{"(", 
          SubscriptBox["\[Tau]", "k"], ")"}]}], ")"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"z", 
          RowBox[{"(", 
           SubscriptBox["t", "k"], ")"}]}], "-", 
         RowBox[{"z", 
          RowBox[{"(", 
           SubscriptBox["t", 
            RowBox[{"k", "-", "1"}]], ")"}]}]}], ")"}]}]}]}]}]}]}]],
 "   \n\nwhere ",
 Cell[BoxData[
  SubscriptBox["\[Tau]", "k"]]],
 " and ",
 Cell[BoxData[
  SubscriptBox["t", "k"]]],
 " are the points contained in the interval ",
 Cell[BoxData[
  RowBox[{"[", 
   RowBox[{"a", 
    StyleBox[",",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], "b"}], "]"}]]],
 " with the property that ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["c", "k"], "=", 
   RowBox[{"z", 
    RowBox[{"(", 
     SubscriptBox["\[Tau]", "k"], ")"}]}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "k"], "=", 
   RowBox[{"z", 
    RowBox[{"(", 
     SubscriptBox["t", "k"], ")"}]}]}]]],
 ", as is also shown in Figure 6.7.  If for all ",
 StyleBox["k",
  FontFamily->"Courier New"],
 " we multiply the kth term in the last sum by ",
 Cell[BoxData[
  FractionBox[
   RowBox[{
    SubscriptBox["t", "k"], "-", 
    SubscriptBox["t", 
     RowBox[{"k", "-", "1"}]]}], 
   RowBox[{
    SubscriptBox["t", "k"], "-", 
    SubscriptBox["t", 
     RowBox[{"k", "-", "1"}]]}]]]],
 ", then we get  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"n", "\[Rule]", "\[Infinity]"}]], " ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"k", "=", "1"}], "n"], 
      RowBox[{"f", 
       RowBox[{"(", 
        SubscriptBox["c", "k"], ")"}], 
       SubscriptBox["\[CapitalDelta]z", "k"]}]}]}], "  ", "=", "  ", 
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"n", "\[Rule]", "\[Infinity]"}]], " ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"k", "=", "1"}], "n"], 
      RowBox[{"f", 
       RowBox[{"(", 
        RowBox[{"z", 
         RowBox[{"(", 
          SubscriptBox["\[Tau]", "k"], ")"}]}], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{
          RowBox[{"z", 
           RowBox[{"(", 
            SubscriptBox["t", "k"], ")"}]}], "-", 
          RowBox[{"z", 
           RowBox[{"(", 
            SubscriptBox["t", 
             RowBox[{"k", "-", "1"}]], ")"}]}]}], 
         RowBox[{
          SubscriptBox["t", "k"], "-", 
          SubscriptBox["t", 
           RowBox[{"k", "-", "1"}]]}]], ")"}], 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["t", "k"], "-", 
         SubscriptBox["t", 
          RowBox[{"k", "-", "1"}]]}], ")"}]}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                                              ", 
   RowBox[{"=", "  ", 
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"n", "\[Rule]", "\[Infinity]"}]], " ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"k", "=", "1"}], "n"], 
      RowBox[{"f", 
       RowBox[{"(", 
        RowBox[{"z", 
         RowBox[{"(", 
          SubscriptBox["\[Tau]", "k"], ")"}]}], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{
          RowBox[{"z", 
           RowBox[{"(", 
            SubscriptBox["t", "k"], ")"}]}], "-", 
          RowBox[{"z", 
           RowBox[{"(", 
            SubscriptBox["t", 
             RowBox[{"k", "-", "1"}]], ")"}]}]}], 
         RowBox[{
          SubscriptBox["t", "k"], "-", 
          SubscriptBox["t", 
           RowBox[{"k", "-", "1"}]]}]], ")"}], 
       SubscriptBox["\[CapitalDelta]t", "k"]}]}]}]}]}]}]],
 "   "
}], "Text"],

Cell[TextData[{
 "\tThe quotient inside the last summation looks suspiciously like a \
derivative, and the entire quantity looks like a Riemann sum.  Assuming no \
difficulties, this last expression should equal  ",
 Cell[BoxData[
  RowBox[{
   SubsuperscriptBox["\[Integral]", "a", "b"], " ", 
   RowBox[{"f", 
    RowBox[{"(", 
     RowBox[{"z", 
      RowBox[{"(", "t", ")"}]}], ")"}], " ", 
    RowBox[{"z", "'"}], 
    RowBox[{"(", "t", ")"}], 
    RowBox[{"\[DifferentialD]", "t"}]}]}]]],
 ",  as defined in Section 6.1.  Of course, if we're to have any hope of this \
happening, we would have to get the same limit regardless of how we \
parametrize the contour ",
 StyleBox["C",
  FontFamily->"Courier New"],
 ".  As Theorem 6.1 states, this is indeed the case."
}], "Text",
 CellChangeTimes->{3.399288011421875*^9}],

Cell[TextData[{
 StyleBox["Theorem 6.1.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Suppose that ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", "z", ")"}]}]]],
 " is a continuous complex-valued function defined on a set containing the \
contour ",
 StyleBox["C",
  FontFamily->"Courier New"],
 ".  Let ",
 Cell[BoxData[
  RowBox[{"z", 
   RowBox[{"(", "t", ")"}]}]]],
 " be any parametrization of ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " for  ",
 Cell[BoxData[
  RowBox[{"a", "\[LessEqual]", "t", "\[LessEqual]", "b"}]]],
 ".  Then  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["\[Integral]", "C"], " ", 
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}], " ", 
     RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "=", "   ", 
   RowBox[{
    SubsuperscriptBox["\[Integral]", "a", "b"], " ", 
    RowBox[{"f", 
     RowBox[{"(", 
      RowBox[{"z", 
       RowBox[{"(", "t", ")"}]}], ")"}], " ", 
     RowBox[{"z", "'"}], 
     RowBox[{"(", "t", ")"}], 
     RowBox[{"\[DifferentialD]", "t"}]}]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "\tWe omit the proof of Theorem 6.1 because it involves ideas (e.g., as the \
theory of the Riemann--Stieltjes integral) that are beyond the scope of this \
book. A more rigorous development of the contour integral based on Riemann \
sums is presented in advanced texts such as ",
 ButtonBox["Lars Valerian Ahlfors",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Ahlfors.\
html"], None}],
 ", ",
 "Complex Analysis, 3rd ed. (New York: McGraw-Hill, 1979).  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
 "\tTwo important facets of Theorem 6.1 are worth mentioning.  First, Theorem \
6.1 makes the problem of evaluating complex-valued functions along contours \
easy, as it reduces the task to the evaluation of complex - valued functions \
over real intervals - a procedure that you studied in Section 6.1.  Second, \
according to Theorem 6.1, this transformation yields the same answer \
regardless of the parametrization we choose for",
 " ",
 StyleBox["C",
  FontFamily->"Courier New"],
 ". "
}], "Text"],

Cell[TextData[{
 StyleBox["Example 6.7.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Give an exact calculation of the integral in Example 6.6:  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["\[Integral]", "C"], " ", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", "z"], " ", 
    RowBox[{"\[DifferentialD]", "z"}]}]}]]],
 "  where ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " is a the line segment joining the point  ",
 Cell[BoxData[
  RowBox[{"A", " ", "=", 
   RowBox[{
    RowBox[{"0", "  ", 
     StyleBox["to",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", "B"}], "=", 
    RowBox[{"2", "+", 
     FractionBox[
      RowBox[{"\[ImaginaryI]", " ", "\[Pi]"}], "4"]}]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "\t\t\t",
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.5 0 0.5 [
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 10 6.28125 ]
[-0.0125 .19635 -16.1875 -9.125 ]
[-0.0125 .19635 0 9.125 ]
[-0.0125 .3927 -16.1875 -9.09375 ]
[-0.0125 .3927 0 9.09375 ]
[0 .525 -5 0 ]
[0 .525 5 12.5625 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(2)] 1 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .19635 m
.00625 .19635 L
s
gsave
-0.0125 .19635 -77.1875 -13.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26.25 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
66.063 9.313 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
64.750 15.125 moveto
(\\200\\200) show
69.000 15.125 moveto
(\\200) show
71.063 15.125 moveto
(\\200) show
66.063 21.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
0 .3927 m
.00625 .3927 L
s
gsave
-0.0125 .3927 -77.1875 -13.0938 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26.1875 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
66.063 9.313 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
64.750 15.125 moveto
(\\200\\200) show
69.000 15.125 moveto
(\\200) show
71.063 15.125 moveto
(\\200) show
66.063 21.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
0 0 m
0 .5 L
s
gsave
0 .525 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 1 r
.5 Mabswid
0 0 m
.04057 .01593 L
.08481 .0333 L
.12636 .04962 L
.16632 .06531 L
.20885 .08202 L
.2498 .09809 L
.29331 .11518 L
.33524 .13165 L
.37557 .14749 L
.41848 .16434 L
.4598 .18056 L
.49953 .19616 L
.54183 .21278 L
.58254 .22876 L
.62583 .24576 L
.66752 .26213 L
.70762 .27788 L
.7503 .29464 L
.79139 .31078 L
.83505 .32792 L
.87712 .34444 L
.9176 .36034 L
.96065 .37725 L
1 .3927 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 144},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\
eJzt2HlIFFEcB/BZd81tIaKtJDB1jYoOKgrpoIMOzOiOikI62DR081jTRRDp
QAQpOtYKQYoOpMjooKKQDjroQIqKDioKpCAigggi6J91mzdv+Tau77vOKP7X
6O7Mvvm87/vNW2dm3WX+UNHWUn8okO/35Vb4y4sC+ZW+hcEKvcnp0DSHT9O0
sE8T21F9M/YU1X+jWeJJ0w6KVbJoLhFbLrE1XO5qMFZOTfYxOkkU15bOeami
LUF6maItrbtiXJ3a/pUfFqsk0RDEVqxU8wRY3vYgRS8jNpSxeOUrn9yv20+i
NSWuYLEMNklz3fJHNVmqGemnaPOSZPkwqiq2GO+ycpxxfZwY5Q9HyeLZKdBv
jtxI+sWRB0k/ORqApB8cDUTSd468SPrG0RCgrxylAn3haBhq+sxRGlA7RxlA
HznKAnrP0UgU/paj0Uh6zdFYJL3kaDySnnM0EegpR5OB2jjKBnrE0TQU/oCj
GUi6x9EsJN3haA6SbnE0D0k3OFoA1MpRDtB1jnJR01WOFiPpMkdLkXSRoxVI
Os/RKiS1cLQG6AxH64CaOcoDOilR7LzXF4+Cb8QhHJdc3gK63LP6K/puxlBH
bffdgnGbrJRZgKEabQ9ViKGOWBkqAH6Iz3IxUFiiQWLlFiQF6WUoej9PKgfa
y1ElUD1HVUB1EnkVKEnRprpfV+MAa21PeA367jZNeNxHDVXHHei4017HXTj0
GlO1xqdGt4LXYpxqPp11yKziqB5JIY72IGk7R/uQFOToAJJKOGpA0jaODiOp
kKNGoAKOmoD8HB0D2sTRCRS+gaNTQHkcNQOt5+g0alrL0VkkreboHJJWcnQB
Scs5uoSkJRxdAVrE0TWgHI5ageZzdBOFz+XoNpJmc3QXSTM5uo+k6Rw9RNJU
jh4DZXPUBjRFoqFyfHLpeILqJkmeqkDx/1qJxzOMM0F2THyJeoFxxpm4tevv
Kww1RjKrl9E3GHSUaS6SGH8HPoLP7wegTIlUd8p2VJzOkyJ9tKs3t8mI7Tcn
Yu8t6RlP/LfVVxP5f1fvdxkv7H7zY2M7Q55pWqzVIVszFQV1dFtrfC+xdJiG
6XpCxPYaJ7ns1/kbnB5Ogub4C9X7l6c=\
\>"],
  ImageRangeCache->{{{0, 287}, {143, 0}} -> {0, 0, 0, 0}}],
 "   "
}], "Text"],

Cell[TextData[{
 "Solution.  We must compute  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["\[Integral]", "C"], " ", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", "z"], " ", 
     RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "=", "  ", 
   RowBox[{
    SubscriptBox["\[Integral]", "C"], " ", 
    RowBox[{"exp", 
     RowBox[{"(", "z", ")"}], " ", 
     RowBox[{"\[DifferentialD]", "z"}]}]}]}]]],
 ",  where C is the line segment joining  ",
 Cell[BoxData[
  RowBox[{"A", " ", "=", 
   RowBox[{
    RowBox[{"0", "  ", 
     StyleBox["to",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", "B"}], "=", 
    RowBox[{"2", "+", 
     FractionBox[
      RowBox[{"\[ImaginaryI]", " ", "\[Pi]"}], "4"]}]}]}]]],
 ".  According to Equation ",
 StyleBox["(1-48)",
  FontColor->RGBColor[0, 0, 1]],
 ", we can parametrize ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " by  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"z", 
    RowBox[{"(", "t", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"2", "+", 
      RowBox[{"\[ImaginaryI]", 
       FractionBox["\[Pi]", "4"]}]}], ")"}], "t"}]}]]],
 ",  for  ",
 Cell[BoxData[
  RowBox[{"0", "\[LessEqual]", "t", "\[LessEqual]", "1"}]]],
 ".  As  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"z", "'"}], 
    RowBox[{"(", "t", ")"}]}], " ", "=", " ", 
   RowBox[{"(", 
    RowBox[{"2", "+", 
     RowBox[{"\[ImaginaryI]", 
      FractionBox["\[Pi]", "4"]}]}], ")"}]}]]],
 ",  Theorem 6.1 guarantees that  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["\[Integral]", "C"], " ", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", "z"], " ", 
      RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Integral]", "C"], " ", 
      RowBox[{"exp", 
       RowBox[{"(", "z", ")"}], " ", 
       RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "=", "  ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", "1"], " ", 
      RowBox[{
       RowBox[{"Exp", "[", 
        RowBox[{"z", "[", "t", "]"}], "]"}], 
       RowBox[{
        RowBox[{"z", "'"}], "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", "1"], 
      RowBox[{
       RowBox[{"Exp", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"2", "+", 
           RowBox[{"\[ImaginaryI]", 
            FractionBox["\[Pi]", "4"]}]}], ")"}], " ", "t"}], "]"}], 
       RowBox[{"(", 
        RowBox[{"2", "+", 
         RowBox[{"\[ImaginaryI]", 
          FractionBox["\[Pi]", "4"]}]}], ")"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], " ", 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2", "+", 
        RowBox[{"\[ImaginaryI]", 
         FractionBox["\[Pi]", "4"]}]}], ")"}], 
      RowBox[{
       SubsuperscriptBox["\[Integral]", "0", "1"], " ", 
       RowBox[{
        RowBox[{"Exp", "[", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"2", "+", 
            RowBox[{"\[ImaginaryI]", 
             FractionBox["\[Pi]", "4"]}]}], ")"}], " ", "t"}], "]"}], 
        RowBox[{"\[DifferentialD]", "t"}]}]}]}]}], " ", "\[IndentingNewLine]",
     " "}]}], "\[IndentingNewLine]", 
  RowBox[{"                ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2", "+", 
        RowBox[{"\[ImaginaryI]", 
         FractionBox["\[Pi]", "4"]}]}], ")"}], 
      RowBox[{
       SubsuperscriptBox["\[Integral]", "0", "1"], 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"2", "t"}]], 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          FractionBox[
           RowBox[{"\[ImaginaryI]", " ", "\[Pi]"}], "4"], " ", "t"}]], 
        RowBox[{"\[DifferentialD]", "t"}]}]}]}]}], " ", 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2", "+", 
        RowBox[{"\[ImaginaryI]", 
         FractionBox["\[Pi]", "4"]}]}], ")"}], 
      RowBox[{
       SubsuperscriptBox["\[Integral]", "0", "1"], " ", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"2", "t"}]], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Cos", "[", 
           FractionBox[
            RowBox[{"\[Pi]", " ", "t"}], "4"], "]"}], "+", 
          RowBox[{"\[ImaginaryI]", "  ", 
           RowBox[{"Sin", "[", 
            FractionBox[
             RowBox[{"\[Pi]", " ", "t"}], "4"], "]"}]}]}], ")"}], 
        RowBox[{"\[DifferentialD]", "t"}]}]}]}]}], "\[IndentingNewLine]", 
    " "}]}], "\[IndentingNewLine]", 
  RowBox[{"                ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2", "+", 
        RowBox[{"\[ImaginaryI]", 
         FractionBox["\[Pi]", "4"]}]}], ")"}], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SubsuperscriptBox["\[Integral]", "0", "1"], " ", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"2", "t"}]], 
          RowBox[{"Cos", "[", 
           FractionBox[
            RowBox[{"\[Pi]", " ", "t"}], "4"], "]"}], 
          RowBox[{"\[DifferentialD]", "t"}]}]}], "  ", "+", "  ", 
        RowBox[{"\[ImaginaryI]", 
         RowBox[{
          SubsuperscriptBox["\[Integral]", "0", "1"], " ", 
          RowBox[{
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"2", "t"}]], 
           RowBox[{"Sin", "[", 
            FractionBox[
             RowBox[{"\[Pi]", " ", "t"}], "4"], "]"}], 
           RowBox[{"\[DifferentialD]", "t"}]}]}]}]}], ")"}]}]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2", "+", 
        RowBox[{"\[ImaginaryI]", 
         FractionBox["\[Pi]", "4"]}]}], ")"}], 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{"2", " ", 
          SqrtBox["2"], 
          SuperscriptBox["\[ExponentialE]", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"\[Pi]", "+", "8"}], ")"}]}], 
         RowBox[{
          SuperscriptBox["\[Pi]", "2"], "+", "64"}]], "-", 
        FractionBox["32", 
         RowBox[{
          SuperscriptBox["\[Pi]", "2"], "+", "64"}]], "+", 
        RowBox[{"\[ImaginaryI]", 
         RowBox[{"(", 
          RowBox[{
           FractionBox[
            RowBox[{
             RowBox[{"-", "2"}], " ", 
             SqrtBox["2"], 
             SuperscriptBox["\[ExponentialE]", "2"], " ", 
             RowBox[{"(", 
              RowBox[{"\[Pi]", "-", "8"}], ")"}]}], 
            RowBox[{
             SuperscriptBox["\[Pi]", "2"], "+", "64"}]], "+", 
           FractionBox[
            RowBox[{"4", " ", "\[Pi]"}], 
            RowBox[{
             SuperscriptBox["\[Pi]", "2"], "+", "64"}]]}], ")"}]}]}], 
       ")"}]}]}], "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                ", 
   RowBox[{"=", "  ", 
    RowBox[{"4.2248516741", "  ", "+", 
     RowBox[{"5.2248516741", " ", "\[ImaginaryI]"}]}]}]}]}]],
 "   \n\nEach integral in the last expression can be done using integration \
by parts. (There is a simpler way-see Remark 6.1.)  We leave as an exercise \
to show that the final answer simplifies to  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"exp", 
     RowBox[{"(", 
      RowBox[{"2", "+", 
       RowBox[{"\[ImaginaryI]", 
        FractionBox["\[Pi]", "4"]}]}], ")"}]}], "-", "1"}], " ", "=", " ", 
   RowBox[{"4.2248516741", "+", 
    RowBox[{"5.2248516741", " ", "\[ImaginaryI]"}]}]}]]],
 ",  as we claimed in Example 6.6. "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Explore ",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 StyleBox["Solution 6.7.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]
}], "Text"],

Cell[TextData[{
 "Enter the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], "=", 
   SuperscriptBox["\[ExponentialE]", "z"]}]],
  AspectRatioFixed->True],
 "  and set up the parameterization for the computing a contour integral."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", 
     RowBox[{
     "a", ",", "b", ",", "t", ",", "u", ",", "v", ",", "z", ",", "Z"}], "]"}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "int", ",", "val"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"a", " ", "=", " ", "0"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"b", " ", "=", " ", 
     RowBox[{"2", " ", "+", 
      FractionBox[
       RowBox[{" ", 
        RowBox[{"\[ImaginaryI]", " ", "\[Pi]"}]}], "4"]}]}], ";"}], " ", "\n",
    
   RowBox[{
    RowBox[{
     RowBox[{"z", "[", "t_", "]"}], " ", "=", "  ", 
     RowBox[{"a", " ", "+", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"b", " ", "-", " ", "a"}], ")"}], " ", "t"}]}]}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "Z_", "]"}], " ", "=", " ", 
     SuperscriptBox["\[ExponentialE]", "Z"]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "t_", "]"}], " ", "=", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"z", "[", "t", "]"}]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"u", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"Re", "[", 
       RowBox[{"f", "[", "t", "]"}], "]"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"v", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"Im", "[", 
       RowBox[{"f", "[", "t", "]"}], "]"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<        F[z] = \>\"", ",", 
      RowBox[{"F", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<        z[t] = \>\"", ",", 
      RowBox[{"z", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<     F[z[t]] = \>\"", ",", 
      RowBox[{"f", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<        u[t] = \>\"", ",", 
      RowBox[{"u", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<        v[t] = \>\"", ",", 
      RowBox[{"v", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<       z'[t] = \>\"", ",", 
      RowBox[{
       RowBox[{"z", "'"}], "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z[t]]z'[t] = \>\"", ",", 
      RowBox[{
       RowBox[{"f", "[", "t", "]"}], 
       RowBox[{
        RowBox[{"z", "'"}], "[", "t", "]"}]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39928827125*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Method (i).",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 " The first method uses a complex integrand  f[z[t]] z'[t]."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"int", ",", "val"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"int", " ", "=", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"f", "[", "t", "]"}], 
       RowBox[{
        RowBox[{"z", "'"}], "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"val", " ", "=", " ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", "1"], 
      RowBox[{
       RowBox[{"f", "[", "t", "]"}], 
       RowBox[{
        RowBox[{"z", "'"}], "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"V", "[", "t_", "]"}], "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Re", "[", 
         RowBox[{"z", "[", "t", "]"}], "]"}], ",", 
        RowBox[{"Im", "[", 
         RowBox[{"z", "[", "t", "]"}], "]"}]}], "}"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z[t]]z'[t] = \>\"", ",", 
      RowBox[{
       RowBox[{"f", "[", "t", "]"}], 
       RowBox[{
        RowBox[{"z", "'"}], "[", "t", "]"}]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< \[Integral]f[z[t]]z'[t]\[DifferentialD]t = \>\"", ",", "int"}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(0\), \
\(1\)]\)f[z[t]]z'[t]\[DifferentialD]t = \>\"", ",", "val"}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"val", "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"FullSimplify", "[", "val", "]"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(0\), \
\(1\)]\)f[z[t]]z'[t]\[DifferentialD]t = \>\"", ",", "val"}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(0\), \
\(1\)]\)f[z[t]]z'[t]\[DifferentialD]t = (\>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"Re", "[", "val", "]"}], "]"}], ",", 
      "\"\<) + \[ImaginaryI] (\>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"Im", "[", "val", "]"}], "]"}], ",", "\"\<)\>\""}], "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(0\), \
\(1\)]\)f[z[t]]z'[t]\[DifferentialD]t = \>\"", ",", 
      RowBox[{"N", "[", "val", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"ParametricPlot", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{"V", "[", "t", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "1"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["1", "2"]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "2", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", 
          FractionBox["\[Pi]", "4"], ",", 
          FractionBox["\[Pi]", "8"]}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Magenta"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(\[Integral]\), \(C\)]\) \>\"", ",", 
      RowBox[{"F", "[", "z", "]"}], ",", "\"\<\[DifferentialD]z = \>\"", ",", 
      
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"FullSimplify", "[", "val", "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(\[Integral]\), \(C\)]\) \>\"", ",", 
      RowBox[{"F", "[", "z", "]"}], ",", "\"\<\[DifferentialD]z = (\>\"", ",",
       
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"Re", "[", "val", "]"}], "]"}], ",", 
      "\"\<) + \[ImaginaryI](\>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"Im", "[", "val", "]"}], "]"}], ",", "\"\<)\>\""}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(\[Integral]\), \(C\)]\) \>\"", ",", 
      RowBox[{"F", "[", "z", "]"}], ",", "\"\<\[DifferentialD]z = \>\"", ",", 
      
      RowBox[{"N", "[", "val", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<C: z[t] = \>\"", ",", 
      RowBox[{"z", "[", "t", "]"}], ",", 
      "\"\<,  for  0 \[LessEqual] t \[LessEqual] 1.\>\""}], "]"}], ";"}], " ",
    "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39928827771875*^9, 3.399288288671875*^9}, {
  3.399881556265625*^9, 3.3998815565*^9}}],

Cell[TextData[{
 StyleBox["Method (ii).",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 " The second method uses a integrals of  u[t] z'[t] and  v[t] z'[t]."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "ImInt", ",", "ImVal", ",", "ReInt", ",", "ReVal", ",", "V", ",", 
      "Val"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ReInt", " ", "=", " ", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"u", "[", "t", "]"}], 
       RowBox[{
        RowBox[{"z", "'"}], "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ImInt", " ", "=", " ", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"v", "[", "t", "]"}], 
       RowBox[{
        RowBox[{"z", "'"}], "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"ReVal", " ", "=", "  ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", "1"], 
      RowBox[{
       RowBox[{"u", "[", "t", "]"}], 
       RowBox[{
        RowBox[{"z", "'"}], "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ImVal", " ", "=", "  ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", "1"], 
      RowBox[{
       RowBox[{"v", "[", "t", "]"}], 
       RowBox[{
        RowBox[{"z", "'"}], "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Val", " ", "=", "  ", 
     RowBox[{"ReVal", " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", "ImVal"}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"V", "[", "t_", "]"}], "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Re", "[", 
         RowBox[{"z", "[", "t", "]"}], "]"}], ",", 
        RowBox[{"Im", "[", 
         RowBox[{"z", "[", "t", "]"}], "]"}]}], "}"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<u[t]z'[t] = \>\"", ",", 
      RowBox[{
       RowBox[{"u", "[", "t", "]"}], 
       RowBox[{
        RowBox[{"z", "'"}], "[", "t", "]"}]}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<v[t]z'[t] = \>\"", ",", 
      RowBox[{
       RowBox[{"v", "[", "t", "]"}], 
       RowBox[{
        RowBox[{"z", "'"}], "[", "t", "]"}]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<\[Integral]u[t]z'[t]\[DifferentialD]t + \[ImaginaryI] \
\[Integral]v[t]z'[t]\[DifferentialD]t\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<= \>\"", ",", "ReInt", ",", "\"\< + \[ImaginaryI](\>\"", ",", 
      "ImInt", ",", "\"\<)\>\""}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(0\), \(1\)]\)u[t]z'[t]\
\[DifferentialD]t + \[ImaginaryI] \!\(\*SubsuperscriptBox[\(\[Integral]\), \
\(0\), \(1\)]\)v[t]z'[t]\[DifferentialD]t\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<= \>\"", ",", "ReVal", ",", "\"\< + \[ImaginaryI](\>\"", ",", 
      "ImVal", ",", "\"\<)\>\""}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<= \>\"", ",", 
      RowBox[{"ComplexExpand", "[", "Val", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<= \>\"", ",", 
      RowBox[{"Apart", "[", 
       RowBox[{"ComplexExpand", "[", "Val", "]"}], "]"}]}], "]"}], ";"}], " ",
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Val", "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"FullSimplify", "[", "Val", "]"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<= \>\"", ",", "Val"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<= (\>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"Re", "[", "Val", "]"}], "]"}], ",", 
      "\"\<) + \[ImaginaryI] (\>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"Im", "[", "Val", "]"}], "]"}], ",", "\"\<)\>\""}], "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<= \>\"", ",", 
      RowBox[{"N", "[", 
       RowBox[{"ComplexExpand", "[", "Val", "]"}], "]"}]}], "]"}], ";"}], " ",
    "\[IndentingNewLine]", 
   RowBox[{"ParametricPlot", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{"V", "[", "t", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "1"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["1", "2"]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "2", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", 
          FractionBox["\[Pi]", "4"], ",", 
          FractionBox["\[Pi]", "8"]}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Magenta"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(\[Integral]\), \(C\)]\) \>\"", ",", 
      RowBox[{"F", "[", "z", "]"}], ",", "\"\<\[DifferentialD]z = \>\"", ",", 
      
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"FullSimplify", "[", "val", "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(\[Integral]\), \(C\)]\) \>\"", ",", 
      RowBox[{"F", "[", "z", "]"}], ",", "\"\<\[DifferentialD]z = (\>\"", ",",
       
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"Re", "[", "val", "]"}], "]"}], ",", 
      "\"\<) + \[ImaginaryI](\>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"Im", "[", "val", "]"}], "]"}], ",", "\"\<)\>\""}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(\[Integral]\), \(C\)]\) \>\"", ",", 
      RowBox[{"F", "[", "z", "]"}], ",", "\"\<\[DifferentialD]z = \>\"", ",", 
      
      RowBox[{"N", "[", "val", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<C: z[t] = \>\"", ",", 
      RowBox[{"z", "[", "t", "]"}], ",", 
      "\"\<,  for  0 \[LessEqual] t \[LessEqual] 1.\>\""}], "]"}], ";"}], " ",
    "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39928829746875*^9, 3.399288302890625*^9}, {
  3.399881563703125*^9, 3.39988156396875*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 6.8.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Evaluate the contour integral  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["\[Integral]", "C"], " ", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"z", "-", "2"}]], " ", 
    RowBox[{"\[DifferentialD]", "z"}]}]}]]],
 "  where ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " is a the upper semicircle with radius ",
 StyleBox["1",
  FontFamily->"Courier New"],
 " centered at  ",
 Cell[BoxData[
  RowBox[{"x", "=", "2"}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "\t\t\t",
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .33333 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.333333 0 0.333333 [
[.33333 -0.0125 -3 -9 ]
[.33333 -0.0125 3 0 ]
[.66667 -0.0125 -3 -9 ]
[.66667 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 10 6.28125 ]
[-0.0125 .33333 -6 -4.5 ]
[-0.0125 .33333 0 4.5 ]
[0 .35833 -5 0 ]
[0 .35833 5 12.5625 ]
[ 0 0 0 0 ]
[ 1 .33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.33333 0 m
.33333 .00625 L
s
[(1)] .33333 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(2)] .66667 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(3)] 1 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .33333 m
.00625 .33333 L
s
[(1)] -0.0125 .33333 1 0 Mshowa
0 0 m
0 .33333 L
s
gsave
0 .35833 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .33333 L
0 .33333 L
closepath
clip
newpath
1 0 1 r
.5 Mabswid
1 0 m
1 .00129 L
.99999 .00247 L
.99998 .00383 L
.99996 .00511 L
.99992 .00739 L
.99985 .00987 L
.99976 .0126 L
.99964 .01549 L
.99936 .02067 L
.99898 .02601 L
.99855 .03101 L
.9973 .04237 L
.99561 .0539 L
.99372 .06439 L
.98824 .08776 L
.98212 .10772 L
.97402 .12901 L
.95402 .16894 L
.92988 .20452 L
.89944 .23859 L
.86597 .26719 L
.83048 .29031 L
.81143 .30026 L
.78983 .30974 L
.76846 .31741 L
.74856 .32312 L
.72761 .32772 L
.71596 .32967 L
.70487 .33114 L
.69431 .33219 L
.68896 .33259 L
.68306 .33293 L
.67803 .33314 L
.67521 .33322 L
.67387 .33326 L
.67262 .33328 L
.67142 .3333 L
.67034 .33331 L
.66913 .33332 L
.66784 .33333 L
.6666 .33333 L
.66525 .33333 L
.66398 .33332 L
.66281 .33331 L
.66143 .33329 L
.66013 .33327 L
.65767 .33321 L
.65503 .33313 L
.65216 .33302 L
Mistroke
.64699 .33275 L
.6422 .33243 L
.63125 .33145 L
.61964 .33 L
.60845 .32821 L
.59643 .32585 L
.57491 .32045 L
.554 .31372 L
.53248 .30513 L
.49536 .28595 L
.45882 .2606 L
.42713 .23181 L
.3978 .19703 L
.37427 .16004 L
.3564 .12184 L
.3491 .10132 L
.34285 .07907 L
.34055 .069 L
.33843 .05808 L
.33689 .04859 L
.33553 .03818 L
.33456 .02856 L
.33391 .0196 L
.33365 .01463 L
.33349 .01012 L
.33342 .00762 L
.33339 .0063 L
.33337 .00491 L
.33335 .00369 L
.33334 .00236 L
.33334 .00114 L
.33333 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 95.9375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\
eJztmH0zG1EUh28k9G9foJMq+jKDaFW1SCJBaL2Veqexk6aEUURoGTr1nakZ
Yybdc29ybON3EmtHZzLsmN3jt8957u7dJZsdtXJr6U0rl0lZwUTW2l7LpHaD
g1tZO/L7lPIFlVLJoKI6b5eFVd7+yT+hlVIZ2tRS3EtVgKoIVTVUhQy0oTd+
Zbp1u8FLMt2oAv9k9tImW8Igi4KsVVZEbqhoqXQu1447XPZ01nmWoqAqzJxz
qqX6DzfZh1UYQy9N5rcXtIkV96ur/SeOrHh8tSWnR0uzwyNMnlOBJhRxdYBr
cjfUCcgCN5mOW7pb/7viN8jaHhTVo4gC/BfIQtWoOAZZu6zoA/hRNSpiAD8E
2at7oIgD/MC74ifIXt+poh/gP7wr9kHWISsGAL7nXZED2RtZMQjwXe+KLMg6
ZUUC4DvuFEMA3wLZW3eK7yDrkhXDAN90p/gA8A2QvZMVHwGeAdn7O1WMAHwV
ZN2yYhTg37wr0iDrkRVjAE+BrFdWjAPcAllYVkwAPAmyiDvFF5BFZcUngC+B
rE9WTAJ8AWQxWTEF8DmQxWXFZ1rXEDsLGvvlxhmAT7IsITeicdAVKaNA54ju
ziFZMc+Hiv4yhuXGRWkcLRuRG9HtMcCNY3LjMkNxriZkPMkQeoIt02hxYw9X
UzKeYqiLq2kZTzPUUXLLQXyVoRBX8zKu/ycHCHrJ+KKM688iPTGNXC0bXL9k
0C94/KBxm+2PecQV0/gU4EihnwkeUWM9VXVUfa2g0F/v9XNqPeHrMn5RcVcD
Cy9NoPdWeOfirJ+x4NwEz8FgZ/Lkn+IuWs4cI1x/kVTY22wu2dUlKi6ntzsf
5fsLt4EKug==\
\>"],
  ImageRangeCache->{{{0, 287}, {94.9375, 0}} -> {0, 0, 0, 0}}],
 "  "
}], "Text"],

Cell[TextData[{
 "Solution.  The function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"z", 
    RowBox[{"(", "t", ")"}]}], "=", 
   RowBox[{"2", "+", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", "t"}]]}]}]]],
 ",  for  ",
 Cell[BoxData[
  RowBox[{"0", "\[LessEqual]", "t", "\[LessEqual]", "\[Pi]"}]]],
 "  is a parametrization for ",
 StyleBox["C",
  FontFamily->"Courier New"],
 ".  We apply Theorem 6.1 with  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   FractionBox["1", 
    RowBox[{"z", " ", "-", " ", "2"}]]}]]],
 ".  (Note: ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", 
     RowBox[{"z", 
      RowBox[{"(", "t", ")"}]}], ")"}]}], "=", 
   FractionBox["1", 
    RowBox[{
     RowBox[{"z", 
      RowBox[{"(", "t", ")"}]}], " ", "-", " ", "2"}]]}]]],
 "), and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"z", "'"}], 
    RowBox[{"(", "t", ")"}]}], "=", 
   RowBox[{"\[ImaginaryI]", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", "t"}]]}]}]]],
 ".)  Hence  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["\[Integral]", "C"], " ", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"z", "-", "2"}]], " ", 
     RowBox[{"\[DifferentialD]", "z"}]}]}], " ", "=", 
   RowBox[{
    RowBox[{
     SubsuperscriptBox["\[Integral]", "0", "\[Pi]"], 
     RowBox[{
      FractionBox["1", 
       RowBox[{
        RowBox[{"z", 
         RowBox[{"(", "t", ")"}]}], " ", "-", " ", "2"}]], 
      RowBox[{"z", "'"}], 
      RowBox[{"(", "t", ")"}], 
      RowBox[{"\[DifferentialD]", "t"}]}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", "\[Pi]"], 
      RowBox[{
       FractionBox["1", 
        RowBox[{"2", "+", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"\[ImaginaryI]", " ", "t"}]], " ", "-", " ", "2"}]], 
       "\[ImaginaryI]", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "t"}]], 
       RowBox[{"\[DifferentialD]", "t"}]}]}], " ", "=", " ", 
     RowBox[{
      RowBox[{
       SubsuperscriptBox["\[Integral]", "0", "\[Pi]"], 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"\[DifferentialD]", "t"}]}]}], " ", "=", " ", 
      RowBox[{"\[ImaginaryI]", " ", "\[Pi]"}]}]}]}]}]]],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Explore ",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 StyleBox["Solution 6.8.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]
}], "Text"],

Cell[TextData[{
 "Enter the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], "=", 
   FractionBox["1", 
    RowBox[{"z", " ", "-", " ", "2"}]]}]],
  AspectRatioFixed->True],
 "  and set up the parameterization and compute the contour integral."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", 
     RowBox[{"t", ",", "z"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "int", ",", "val", ",", "V"}], "]"}], ";"}], " ", "\n",
    
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox["1", 
      RowBox[{"z", " ", "-", " ", "2"}]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"z", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"2", " ", "+", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", "t"}]]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"int", " ", "=", " ", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"f", "[", 
        RowBox[{"z", "[", "t", "]"}], "]"}], 
       RowBox[{
        RowBox[{"z", "'"}], "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"val", " ", "=", " ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", "\[Pi]"], 
      RowBox[{
       RowBox[{"f", "[", 
        RowBox[{"z", "[", "t", "]"}], "]"}], 
       RowBox[{
        RowBox[{"z", "'"}], "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"V", "[", "t_", "]"}], "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Re", "[", 
         RowBox[{"z", "[", "t", "]"}], "]"}], ",", 
        RowBox[{"Im", "[", 
         RowBox[{"z", "[", "t", "]"}], "]"}]}], "}"}], "]"}]}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<               f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<               z[t] = \>\"", ",", 
      RowBox[{"z", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<            f[z[t]] = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"z", "[", "t", "]"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<              z'[t] = \>\"", ",", 
      RowBox[{
       RowBox[{"z", "'"}], "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<       f[z[t]]z'[t] = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"z", "[", "t", "]"}], "]"}], ",", 
      RowBox[{
       RowBox[{"z", "'"}], "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<       f[z[t]]z'[t] = \>\"", ",", 
      RowBox[{
       RowBox[{"f", "[", 
        RowBox[{"z", "[", "t", "]"}], "]"}], 
       RowBox[{
        RowBox[{"z", "'"}], "[", "t", "]"}]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<    \[Integral]f[z[t]]z'[t]\[DifferentialD]t = \>\"", ",", "int"}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<   \!\(\*SubsuperscriptBox[\(\[Integral]\), \(0\), \
\(\[Pi]\)]\)f[z[t]]z'[t]\[DifferentialD]t = \>\"", ",", "val"}], "]"}], ";"}],
    " ", "\n", 
   RowBox[{"ParametricPlot", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{"V", "[", "t", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "3.05"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["1", "3"]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "3", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "1", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Magenta"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(\[Integral]\), \(C\)]\) \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\<\[DifferentialD]z = \>\"", ",", 
      "val"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<C: z[t] = \>\"", ",", 
      RowBox[{"z", "[", "t", "]"}], ",", 
      "\"\<,  for  0 \[LessEqual] t \[LessEqual] \[Pi].\>\""}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39928831446875*^9, 3.3992883401875*^9}, {
  3.3998815711875*^9, 3.39988157146875*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 "\tTo help convince yourself that the value of the integral is independent \
of the parametrization chosen for the given contour, try working through \
Example 6.8 with  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"z", 
    RowBox[{"(", "t", ")"}]}], "=", 
   RowBox[{"2", "+", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]\[Pi]", " ", "t"}]]}]}]]],
 ",  for  ",
 Cell[BoxData[
  RowBox[{"0", "\[LessEqual]", "t", "\[LessEqual]", "1"}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "\tA convenient bookkeeping device can help you remember how to apply \
Theorem 6.1.  \n\nBecause  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["\[Integral]", "C"], " ", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"z", "-", "2"}]], " ", 
     RowBox[{"\[DifferentialD]", "z"}]}]}], " ", "=", 
   RowBox[{
    SubsuperscriptBox["\[Integral]", "a", "b"], 
    RowBox[{
     FractionBox["1", 
      RowBox[{
       RowBox[{"z", 
        RowBox[{"(", "t", ")"}]}], " ", "-", " ", "2"}]], 
     RowBox[{"z", "'"}], 
     RowBox[{"(", "t", ")"}], 
     RowBox[{"\[DifferentialD]", "t"}]}]}]}]]],
 ",  you can symbolically equate ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " with ",
 StyleBox["z(t)",
  FontFamily->"Courier New"],
 " and ",
 Cell[BoxData[
  RowBox[{"\[DifferentialD]", "z"}]]],
 " with  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"z", "'"}], 
   RowBox[{"(", "t", ")"}], 
   RowBox[{"\[DifferentialD]", "t"}]}]]],
 ".  \n\nThese identities should be easy to remember because ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " is supposed to be a point on the contour ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " parametrized by ",
 StyleBox["z(t)",
  FontFamily->"Courier New"],
 ", and ",
 Cell[BoxData[
  RowBox[{
   FractionBox[
    RowBox[{"\[DifferentialD]", "z"}], 
    RowBox[{"\[DifferentialD]", "t"}]], " ", "=", " ", 
   RowBox[{
    RowBox[{"z", "'"}], 
    RowBox[{"(", "t", ")"}]}]}]]],
 ", according to the Leibniz notation for the derivative."
}], "Text"],

Cell[TextData[{
 "\tIf  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"z", 
    RowBox[{"(", "t", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"x", 
     RowBox[{"(", "t", ")"}]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", "y", 
     RowBox[{"(", "t", ")"}]}]}]}]]],
 ",  then by the preceding paragraph we have\n\n",
 StyleBox["(6-13)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[DifferentialD]", "z"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"z", "'"}], 
     RowBox[{"(", "t", ")"}], 
     RowBox[{"\[DifferentialD]", "t"}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"x", "'"}], 
         RowBox[{"(", "t", ")"}]}], "+", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"y", "'"}], 
         RowBox[{"(", "t", ")"}]}]}], ")"}], 
      RowBox[{"\[DifferentialD]", "t"}]}], " ", "=", " ", 
     RowBox[{
      RowBox[{"\[DifferentialD]", "x"}], " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"\[DifferentialD]", "y"}]}]}]}]}]}]]],
 "  \n\nwhere  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[DifferentialD]", "x"}], " ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], " ", 
   RowBox[{"\[DifferentialD]", "y"}]}]]],
 "  are the differentials for ",
 Cell[BoxData[
  RowBox[{"x", 
   RowBox[{"(", "t", ")"}], " ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], " ", "y", 
   RowBox[{"(", "t", ")"}]}]]],
 ", respectively (i.e., ",
 Cell[BoxData[
  RowBox[{"\[DifferentialD]", "x"}]]],
 " is equated with ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"x", "'"}], 
   RowBox[{"(", "t", ")"}], 
   RowBox[{"\[DifferentialD]", "t"}]}]]],
 ", etc.).  The expression  ",
 Cell[BoxData[
  RowBox[{"\[DifferentialD]", "z"}]]],
 "  is often called the complex differential of ",
 StyleBox["z",
  FontFamily->"Courier New"],
 ".  Just as  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[DifferentialD]", "x"}], " ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], " ", 
   RowBox[{"\[DifferentialD]", "y"}]}]]],
 "  are intuitively considered to be small segments along the ",
 StyleBox["x",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["y",
  FontFamily->"Courier New"],
 " axes in real variables, we can think of  ",
 Cell[BoxData[
  RowBox[{"\[DifferentialD]", "z"}]],
  CellChangeTimes->{{3.399288053046875*^9, 3.39928805659375*^9}}],
 "  as representing a tiny piece of the contour  ",
 StyleBox["C",
  FontFamily->"Courier New"],
 ".  Moreover, if we write  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", 
    RowBox[{"\[DifferentialD]", "z"}], "|"}], " ", "=", " ", 
   RowBox[{
    RowBox[{"|", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"x", "'"}], 
         RowBox[{"(", "t", ")"}]}], "+", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"y", "'"}], 
         RowBox[{"(", "t", ")"}]}]}], ")"}], 
      RowBox[{"\[DifferentialD]", "t"}]}], "|"}], " ", "=", " ", 
    RowBox[{
     RowBox[{"|", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"x", "'"}], 
         RowBox[{"(", "t", ")"}]}], "+", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"y", "'"}], 
         RowBox[{"(", "t", ")"}]}]}], ")"}], "|", 
      RowBox[{"\[DifferentialD]", "t"}]}], "  ", "=", " ", 
     RowBox[{
      SqrtBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"[", 
          RowBox[{
           RowBox[{"x", "'"}], 
           RowBox[{"(", "t", ")"}]}], "]"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"[", 
          RowBox[{
           RowBox[{"y", "'"}], 
           RowBox[{"(", "t", ")"}]}], "]"}], "2"]}]], 
      RowBox[{
       RowBox[{"\[DifferentialD]", "t"}], " "}]}]}]}]}]]],
 "\n\nwe can put Equation ",
 StyleBox["(6-11)",
  FontColor->RGBColor[0, 0, 1]],
 " into the form  \n\n",
 StyleBox["(6-14)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"L", 
    RowBox[{"(", "C", ")"}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     SubsuperscriptBox["\[Integral]", "a", "b"], " ", 
     RowBox[{
      SqrtBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"[", 
          RowBox[{
           RowBox[{"x", "'"}], 
           RowBox[{"(", "t", ")"}]}], "]"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"[", 
          RowBox[{
           RowBox[{"y", "'"}], 
           RowBox[{"(", "t", ")"}]}], "]"}], "2"]}]], 
      RowBox[{"\[DifferentialD]", "t"}]}]}], "  ", "=", "  ", 
    RowBox[{
     UnderscriptBox["\[Integral]", "C"], " ", 
     RowBox[{"|", 
      RowBox[{"\[DifferentialD]", "z"}], "|"}]}]}]}]]],
 ".   \n\nso we can think of ",
 Cell[BoxData[
  RowBox[{"|", 
   RowBox[{"\[DifferentialD]", "z"}], "|"}]]],
 " as representing the length of  ",
 Cell[BoxData[
  RowBox[{"\[DifferentialD]", "z"}]]],
 "."
}], "Text",
 CellChangeTimes->{{3.39928806371875*^9, 3.399288124609375*^9}}],

Cell[TextData[{
 "\tSuppose   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    RowBox[{"u", 
     RowBox[{"(", "z", ")"}]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", "v", 
     RowBox[{"(", "t", ")"}]}]}]}]]],
 " , and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"z", 
    RowBox[{"(", "t", ")"}]}], "=", 
   RowBox[{
    RowBox[{"x", 
     RowBox[{"(", "t", ")"}]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", "y", 
     RowBox[{"(", "t", ")"}]}]}]}]]],
 "  is a parametrization for the contour ",
 StyleBox["C",
  FontFamily->"Courier New"],
 ".  Then\n\n",
 StyleBox["(6-15)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["\[Integral]", "C"], " ", 
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}], " ", 
      RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "=", "  ", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", "a", "b"], " ", 
     RowBox[{"f", 
      RowBox[{"(", 
       RowBox[{"z", 
        RowBox[{"(", "t", ")"}]}], ")"}], 
      RowBox[{"z", "'"}], 
      RowBox[{"(", "t", ")"}], 
      RowBox[{"\[DifferentialD]", "t"}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                       ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "a", "b"], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"u", 
          RowBox[{"(", 
           RowBox[{"z", 
            RowBox[{"(", "t", ")"}]}], ")"}]}], "+", 
         RowBox[{"\[ImaginaryI]", " ", "v", 
          RowBox[{"(", 
           RowBox[{"z", 
            RowBox[{"(", "t", ")"}]}], ")"}]}]}], ")"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"x", "'"}], 
          RowBox[{"(", "t", ")"}]}], "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"y", "'"}], 
          RowBox[{"(", "t", ")"}]}]}], ")"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                       ", 
   RowBox[{"=", "  ", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", "a", "b"], 
     RowBox[{
      RowBox[{"[", 
       RowBox[{
        RowBox[{"u", 
         RowBox[{"(", 
          RowBox[{"z", 
           RowBox[{"(", "t", ")"}]}], ")"}], " ", 
         RowBox[{"x", "'"}], 
         RowBox[{"(", "t", ")"}]}], "-", 
        RowBox[{"v", 
         RowBox[{"(", 
          RowBox[{"z", 
           RowBox[{"(", "t", ")"}]}], ")"}], " ", 
         RowBox[{"y", "'"}], 
         RowBox[{"(", "t", ")"}]}]}], "]"}], 
      RowBox[{"\[DifferentialD]", "t"}]}]}]}], "  "}], "\[IndentingNewLine]", 
 
  RowBox[{"                             ", 
   RowBox[{
    RowBox[{
     RowBox[{"+", "  ", "\[ImaginaryI]"}], " ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "a", "b"], 
      RowBox[{
       RowBox[{"[", 
        RowBox[{
         RowBox[{"v", 
          RowBox[{"(", 
           RowBox[{"z", 
            RowBox[{"(", "t", ")"}]}], ")"}], 
          RowBox[{"x", "'"}], 
          RowBox[{"(", "t", ")"}]}], "+", 
         RowBox[{"u", 
          RowBox[{"(", 
           RowBox[{"z", 
            RowBox[{"(", "t", ")"}]}], ")"}], 
          RowBox[{"y", "'"}], 
          RowBox[{"(", "t", ")"}]}]}], "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], "\[IndentingNewLine]", 
    " "}]}], "\[IndentingNewLine]", 
  RowBox[{"                       ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{
      SubsuperscriptBox["\[Integral]", "a", "b"], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"u", " ", 
          RowBox[{"x", "'"}]}], "-", 
         RowBox[{"v", "  ", 
          RowBox[{"y", "'"}]}]}], ")"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}], "  ", "+", "  ", 
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{
       SubsuperscriptBox["\[Integral]", "a", "b"], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"v", " ", 
           RowBox[{"x", "'"}]}], "+", 
          RowBox[{"u", " ", 
           RowBox[{"y", "'"}]}]}], ")"}], 
        RowBox[{"\[DifferentialD]", "t"}]}]}]}]}]}]}]}]],
 "  \n\nwhere we are equating ",
 StyleBox["u(t)",
  FontFamily->"Courier New"],
 " with ",
 StyleBox["u(z(t))",
  FontFamily->"Courier New"],
 ", ",
 StyleBox["x'",
  FontFamily->"Courier New"],
 " with ",
 StyleBox["x'(t)",
  FontFamily->"Courier New"],
 ", and so on. "
}], "Text"],

Cell[TextData[{
 "\tIf we use the differentials given in Equation ",
 StyleBox["(6-13)",
  FontColor->RGBColor[0, 0, 1]],
 ", then we can write Equation ",
 StyleBox["(6-15)",
  FontColor->RGBColor[0, 0, 1]],
 " in terms of line integrals of the real-valued functions ",
 StyleBox["u(t)",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["v(t)",
  FontFamily->"Courier New"],
 " , giving\n\n",
 StyleBox["(6-16)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["\[Integral]", "C"], " ", 
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}], " ", 
     RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     SubsuperscriptBox["\[Integral]", "a", "b"], " ", 
     RowBox[{"u", 
      RowBox[{"\[DifferentialD]", "x"}]}]}], " ", "-", 
    RowBox[{"v", " ", 
     RowBox[{"\[DifferentialD]", "y"}]}], "  ", "+", "  ", 
    RowBox[{"\[ImaginaryI]", " ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "a", "b"], " ", 
      RowBox[{"v", " ", 
       RowBox[{"\[DifferentialD]", "x"}]}]}]}], " ", "+", 
    RowBox[{"u", " ", 
     RowBox[{"\[DifferentialD]", "y"}]}]}]}]]],
 ",\n\nwhich is easy to remember if we recall that symbolically\n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}], " ", 
     RowBox[{"\[DifferentialD]", "z"}]}], "  ", "=", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"u", "+", 
       RowBox[{"\[ImaginaryI]", " ", "v"}]}], ")"}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[DifferentialD]", "x"}], "+", 
       RowBox[{"\[ImaginaryI]", 
        RowBox[{"\[DifferentialD]", "y"}]}]}], ")"}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                   ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{"u", 
      RowBox[{"\[DifferentialD]", "x"}]}], " ", "-", 
     RowBox[{"v", " ", 
      RowBox[{"\[DifferentialD]", "y"}]}], "  ", "+", " ", 
     RowBox[{"\[ImaginaryI]", 
      RowBox[{"(", " ", 
       RowBox[{
        RowBox[{"v", " ", 
         RowBox[{"\[DifferentialD]", "x"}]}], " ", "+", 
        RowBox[{"u", " ", 
         RowBox[{"\[DifferentialD]", "y"}]}]}], ")"}]}]}]}]}]}]],
 ".  "
}], "Text"],

Cell[TextData[{
 "\tWe emphasize that Equation ",
 StyleBox["(6-16)",
  FontColor->RGBColor[0, 0, 1]],
 " is merely a notational device for applying Theorem 6.1. You should \
carefully apply Theorem 6.1as illustrated in Examples 6.7 and 6.8 before \
using any shortcuts suggested by the latter."
}], "Text"],

Cell[TextData[{
 StyleBox["Example  6.9.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Show that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["\[Integral]", 
     SubscriptBox["C", "1"]], " ", 
    RowBox[{"z", " ", 
     RowBox[{"\[DifferentialD]", "z"}]}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Integral]", 
      SubscriptBox["C", "2"]], " ", 
     RowBox[{"z", " ", 
      RowBox[{"\[DifferentialD]", "z"}]}]}], " ", "=", " ", 
    RowBox[{"4", "+", 
     RowBox[{"2", "\[ImaginaryI]"}]}]}]}]]],
 ",   \nwhere  ",
 Cell[BoxData[
  SubscriptBox["C", "1"]]],
 " is the line segment from  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"-", "1"}], "-", 
   RowBox[{"\[ImaginaryI]", "  ", 
    StyleBox["to",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], "  ", "3"}], "+", "\[ImaginaryI]"}]]],
 ",  and ",
 Cell[BoxData[
  SubscriptBox["C", "2"]]],
 " is the portion of the parabola  ",
 Cell[BoxData[
  RowBox[{"x", "=", 
   RowBox[{
    SuperscriptBox["y", "2"], "+", 
    RowBox[{"2", "y"}]}]}]]],
 "  joining  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"-", "1"}], "-", 
   RowBox[{"\[ImaginaryI]", "  ", 
    StyleBox["to",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], "  ", "3"}], "+", "\[ImaginaryI]"}]]],
 ",  as indicated in Figure 6.8.  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["\t\t\t",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
  ImageSize->{494, 201},
  ImageMargins->0],
 StyleBox["\n\t\t\t",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Figure 6.8",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/contourintegral/\
ContourIntegralMod/Images/mat0608.gif"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 "  The two contours ",
 Cell[BoxData[
  SubscriptBox["C", "1"]]],
 " and ",
 Cell[BoxData[
  SubscriptBox["C", "2"]]],
 " joining  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"-", "1"}], "-", 
   RowBox[{"\[ImaginaryI]", "  ", 
    StyleBox["to",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], "  ", "3"}], "+", "\[ImaginaryI]"}]]],
 "."
}], "Text",
 CellChangeTimes->{{3.39929517140625*^9, 3.3992951836875*^9}, {
  3.399308303359375*^9, 3.399308306484375*^9}}],

Cell[TextData[{
 "Solution.  The line segment joining ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], 
     RowBox[{"-", "1"}]}], ")"}], " ", 
   StyleBox["to",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], " ", 
   RowBox[{"(", 
    RowBox[{"3", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "1"}], ")"}]}]]],
 " is given by the slope intercept formula  ",
 Cell[BoxData[
  RowBox[{"y", "=", 
   RowBox[{
    RowBox[{
     FractionBox["1", "2"], "x"}], "-", 
    FractionBox["1", "2"]}]}]]],
 ",  which can be written as  ",
 Cell[BoxData[
  RowBox[{"x", "=", 
   RowBox[{
    RowBox[{"2", "y"}], "+", "1"}]}]]],
 ".  \nIf we choose the parametrization  ",
 Cell[BoxData[
  RowBox[{"y", "=", "t"}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{"x", "=", 
   RowBox[{
    RowBox[{"2", "t"}], "+", "1"}]}]]],
 ",  we can write segment ",
 Cell[BoxData[
  SubscriptBox["C", "1"]]],
 " as\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["C", "1"], ":", "  ", 
    RowBox[{"z", 
     RowBox[{"(", "t", ")"}]}]}], "=", 
   RowBox[{
    RowBox[{"2", "t"}], "+", "1", "+", 
    RowBox[{"\[ImaginaryI]", " ", "t"}]}]}]]],
 "   and   ",
 Cell[BoxData[
  RowBox[{"dz", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"2", "+", "\[ImaginaryI]"}], ")"}], " ", "dt"}]}]]],
 "\n\nfor  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"-", "1"}], "\[LessEqual]", "t", "\[LessEqual]", "1"}]]],
 ".\n\nAlong ",
 Cell[BoxData[
  SubscriptBox["C", "1"]]],
 " we have  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", 
     RowBox[{"z", 
      RowBox[{"(", "t", ")"}]}], ")"}]}], "=", 
   RowBox[{
    RowBox[{"2", "t"}], "+", "1", "+", 
    RowBox[{"\[ImaginaryI]", " ", "t"}]}]}]]],
 ".  Applying Theorem 6.1 gives  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["\[Integral]", 
     SubscriptBox["C", "1"]], " ", 
    RowBox[{"z", " ", 
     RowBox[{"\[DifferentialD]", "z"}]}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     SubsuperscriptBox["\[Integral]", "a", "b"], 
     RowBox[{
      FractionBox["1", 
       RowBox[{
        RowBox[{"z", 
         RowBox[{"(", "t", ")"}]}], " ", "-", " ", "2"}]], 
      RowBox[{"z", "'"}], 
      RowBox[{"(", "t", ")"}], 
      RowBox[{"\[DifferentialD]", "t"}]}]}], " ", "=", "  ", 
    RowBox[{"=", " ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", 
       RowBox[{"-", "1"}], "1"], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", "t"}], "+", "1", "+", 
         RowBox[{"\[ImaginaryI]", " ", "t"}]}], ")"}], 
       RowBox[{"(", 
        RowBox[{"2", "+", "\[ImaginaryI]"}], ")"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}]}]}]]],
 ".  \n\nWe now multiply out the integrand and put it into its real and \
imaginary parts:  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["\[Integral]", 
      SubscriptBox["C", "1"]], " ", 
     RowBox[{"z", " ", 
      RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "=", "  ", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", 
      RowBox[{"-", "1"}], "1"], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", "t"}], "+", "1", "+", 
        RowBox[{"\[ImaginaryI]", " ", "t"}]}], ")"}], 
      RowBox[{"(", 
       RowBox[{"2", "+", "\[ImaginaryI]"}], ")"}], 
      RowBox[{"\[DifferentialD]", "t"}]}]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                 ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", 
       RowBox[{"-", "1"}], "1"], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", "t"}], "+", "2", "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"4", " ", "t"}], "+", "1"}], ")"}]}]}], ")"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                 ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      RowBox[{
       SubsuperscriptBox["\[Integral]", 
        RowBox[{"-", "1"}], "1"], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", "t"}], "+", "2"}], ")"}], 
        RowBox[{"\[DifferentialD]", "t"}]}]}], " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", 
       RowBox[{
        SubsuperscriptBox["\[Integral]", 
         RowBox[{"-", "1"}], "1"], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"4", " ", "t"}], "+", "1"}], ")"}], 
         RowBox[{"\[DifferentialD]", "t"}]}]}]}]}]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                 ", 
   RowBox[{"=", "  ", 
    RowBox[{"4", " ", "+", " ", 
     RowBox[{"2", " ", "\[ImaginaryI]"}]}]}]}]}]],
 "   "
}], "Text"],

Cell[TextData[{
 "Similarly, we can parametrize the portion of the parabola  ",
 Cell[BoxData[
  RowBox[{"x", "=", 
   RowBox[{
    SuperscriptBox["y", "2"], "+", 
    RowBox[{"2", "y"}]}]}]]],
 "  joining ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], 
     RowBox[{"-", "1"}]}], ")"}], " ", 
   StyleBox["to",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], " ", 
   RowBox[{"(", 
    RowBox[{"3", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "1"}], ")"}]}]]],
 " by  ",
 Cell[BoxData[
  RowBox[{"y", "=", "t"}]]],
 "  and ",
 Cell[BoxData[
  RowBox[{"x", "=", 
   RowBox[{
    RowBox[{"2", "t"}], "+", "1"}]}]]],
 " and  ",
 Cell[BoxData[
  RowBox[{"x", "=", 
   RowBox[{
    SuperscriptBox["t", "2"], "+", 
    RowBox[{"2", "t"}]}]}]]],
 " so that  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["C", "2"], ":", "  ", 
    RowBox[{"z", 
     RowBox[{"(", "t", ")"}]}]}], "=", 
   RowBox[{
    SuperscriptBox["t", "2"], "+", 
    RowBox[{"2", "t"}], "+", 
    RowBox[{"\[ImaginaryI]", " ", "t"}]}]}]]],
 "   and   ",
 Cell[BoxData[
  RowBox[{"dz", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", "t"}], "+", "2", "+", "\[ImaginaryI]"}], ")"}], " ", 
    "dt"}]}]]],
 "\n\nfor  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"-", "1"}], "\[LessEqual]", "t", "\[LessEqual]", "1"}]]],
 ".\n\nAlong ",
 Cell[BoxData[
  SubscriptBox["C", "2"]]],
 " we have  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", 
     RowBox[{"z", 
      RowBox[{"(", "t", ")"}]}], ")"}]}], "=", 
   RowBox[{
    SuperscriptBox["t", "2"], "+", 
    RowBox[{"2", "t"}], "+", 
    RowBox[{"\[ImaginaryI]", " ", "t"}]}]}]]],
 ".  Theorem 6.1 now gives  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["\[Integral]", 
      SubscriptBox["C", "2"]], " ", 
     RowBox[{"z", " ", 
      RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "=", "  ", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", 
      RowBox[{"-", "1"}], "1"], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["t", "2"], "+", 
        RowBox[{"2", "t"}], "+", 
        RowBox[{"\[ImaginaryI]", " ", "t"}]}], ")"}], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", "t"}], "+", "2", "+", "\[ImaginaryI]"}], ")"}], 
      RowBox[{"\[DifferentialD]", "t"}]}]}]}], " ", 
   "\[IndentingNewLine]"}], "\n", 
  RowBox[{"                 ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", 
       RowBox[{"-", "1"}], "1"], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SuperscriptBox["t", "3"]}], "+", 
         RowBox[{"6", " ", 
          SuperscriptBox["t", "2"]}], "+", 
         RowBox[{"3", "t"}], "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             SuperscriptBox["t", "2"]}], "+", 
            RowBox[{"4", "t"}]}], ")"}]}]}], ")"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], 
    "\n"}]}], "\[IndentingNewLine]", 
  RowBox[{"                 ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      RowBox[{
       SubsuperscriptBox["\[Integral]", 
        RowBox[{"-", "1"}], "1"], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           SuperscriptBox["t", "3"]}], "+", 
          RowBox[{"6", " ", 
           SuperscriptBox["t", "2"]}], "+", 
          RowBox[{"3", "t"}]}], ")"}], 
        RowBox[{"\[DifferentialD]", "t"}]}]}], " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", 
       RowBox[{
        SubsuperscriptBox["\[Integral]", 
         RowBox[{"-", "1"}], "1"], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", 
            SuperscriptBox["t", "2"]}], "+", 
           RowBox[{"4", "t"}]}], ")"}], 
         RowBox[{"\[DifferentialD]", "t"}]}]}]}]}]}], 
    "\n"}]}], "\[IndentingNewLine]", 
  RowBox[{"                 ", 
   RowBox[{"=", "  ", 
    RowBox[{"4", " ", "+", " ", 
     RowBox[{"2", " ", "\[ImaginaryI]"}]}]}]}]}]],
 "  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Explore ",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 StyleBox["Solution 6.9 (a)",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]
}], "Text"],

Cell[TextData[{
 StyleBox["\n(a)",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Use the straight line segment connecting the points  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "1"}], "-", 
     RowBox[{"i", "  ", "and", "  ", 
      SubscriptBox["z", "2"]}]}], "=", 
    RowBox[{"3", "+", "i"}]}]}]]],
 ",  set up the parameterization and compute the contour integral.  Enter the \
function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], "=", "z"}]],
  AspectRatioFixed->True],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", 
     RowBox[{
     "t", ",", "u", ",", "U", ",", "v", ",", "V", ",", "w", ",", "W", ",", 
      "z"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "f", ",", "U1", ",", "U2", ",", "V1", ",", "V2", ",", "W1", ",", "W2", 
      ",", "z1", ",", "z2"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", "z"}], " ", ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"z1", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{
      RowBox[{"2", "t"}], " ", "+", " ", "1", " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", "t"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"w", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{
       RowBox[{"f", "[", 
        RowBox[{"z1", "[", "t", "]"}], "]"}], " ", 
       RowBox[{
        RowBox[{"z1", "'"}], "[", "t", "]"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"u", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"Re", "[", 
       RowBox[{"w", "[", "t", "]"}], "]"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"v", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"Im", "[", 
       RowBox[{"w", "[", "t", "]"}], "]"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<           f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<          \!\(\*SubscriptBox[\(z\), \(1\)]\)[t] = \>\"", ",", 
      RowBox[{"z1", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<       f[\!\(\*SubscriptBox[\(z\), \(1\)]\)[t]] = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"z1", "[", "t", "]"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<         \!\(\*SubscriptBox[\(z\), \(1\)]\)'[t] = \>\"", ",", 
      RowBox[{
       RowBox[{"z1", "'"}], "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<f[\!\(\*SubscriptBox[\(z\), \(1\)]\)[t]] \!\(\*SubscriptBox[\(z\), \
\(1\)]\)'[t] = \>\"", ",", 
      RowBox[{"w", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<           u[t] = \>\"", ",", 
      RowBox[{"u", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<           v[t] = \>\"", ",", 
      RowBox[{"v", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39928835215625*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Method (i).",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  The integral can be computed using the real and imaginary parts."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"U1", " ", "=", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", 
       RowBox[{"-", "1"}], "1"], 
      RowBox[{
       RowBox[{"u", "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"V1", " ", "=", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", 
       RowBox[{"-", "1"}], "1"], 
      RowBox[{
       RowBox[{"v", "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"W1", " ", "=", " ", 
     RowBox[{"U1", " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", "V1"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"U", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"u", "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"V", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"v", "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"reint", " ", "=", " ", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"u", "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"imint", " ", "=", " ", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"v", "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"P1", "[", "t_", "]"}], "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Re", "[", 
         RowBox[{"z1", "[", "t", "]"}], "]"}], ",", 
        RowBox[{"Im", "[", 
         RowBox[{"z1", "[", "t", "]"}], "]"}]}], "}"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<u[t] = \>\"", ",", 
      RowBox[{"u", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<v[t] = \>\"", ",", 
      RowBox[{"v", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\[Integral]u[t]\[DifferentialD]t + \[ImaginaryI] \[Integral]v[t]\
\[DifferentialD]t = \>\"", ",", "reint", ",", "\"\< + \[ImaginaryI] (\>\"", 
      ",", "imint", ",", "\"\<)\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<U[t] = \>\"", ",", 
      RowBox[{"U", "[", "t", "]"}], ",", "\"\<,     V[t] = \>\"", ",", 
      RowBox[{"V", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<U[1] = \>\"", ",", 
      RowBox[{"U", "[", "1", "]"}], ",", "\"\<,     V[1] = \>\"", ",", 
      RowBox[{"V", "[", "1", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<U[-1] = \>\"", ",", 
      RowBox[{"U", "[", 
       RowBox[{"-", "1"}], "]"}], ",", "\"\<,   V[-1] = \>\"", ",", 
      RowBox[{"V", "[", 
       RowBox[{"-", "1"}], "]"}]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-1\), \(1\)]\)u[t]\
\[DifferentialD]t + \[ImaginaryI]\!\(\*SubsuperscriptBox[\(\[Integral]\), \
\(-1\), \(1\)]\)v[t]\[DifferentialD]t = U[1]-U[-1] + \
\[ImaginaryI](V[1]-V[-1])\>\"", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-1\), \(1\)]\)u[t]\
\[DifferentialD]t + \[ImaginaryI]\!\(\*SubsuperscriptBox[\(\[Integral]\), \
\(-1\), \(1\)]\)v[t]\[DifferentialD]t = \>\"", ",", 
      RowBox[{
       RowBox[{"U", "[", "1", "]"}], "-", 
       RowBox[{"U", "[", 
        RowBox[{"-", "1"}], "]"}]}], ",", "\"\< + \[ImaginaryI] (\>\"", ",", 
      RowBox[{
       RowBox[{"V", "[", "1", "]"}], "-", 
       RowBox[{"V", "[", 
        RowBox[{"-", "1"}], "]"}]}], ",", "\"\<)\>\""}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-1\), \(1\)]\)u[t]\
\[DifferentialD]t + \[ImaginaryI] \!\(\*SubsuperscriptBox[\(\[Integral]\), \
\(-1\), \(1\)]\)v[t]\[DifferentialD]t = \>\"", ",", "W1"}], "]"}], ";"}], " ",
    "\n", 
   RowBox[{"ParametricPlot", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{"P1", "[", "t", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["2", "3"]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "3", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(\[Integral]\), \(C\)]\) \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\< \[DifferentialD]z = \>\"", ",",
       "W1"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<C: \!\(\*SubscriptBox[\(z\), \(1\)]\)[t] = \>\"", ",", 
      RowBox[{"z1", "[", "t", "]"}], ",", 
      "\"\<,  for  -1 \[LessEqual] t \[LessEqual] 1.\>\""}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39928835584375*^9, 3.399288358453125*^9}, {
  3.399881578109375*^9, 3.399881578328125*^9}, {3.399882255890625*^9, 
  3.399882258*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Method (ii).",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  The integral can be computed using a complex integrand."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"W", "[", "t_", "]"}], " ", "=", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"w", "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"W1", " ", "=", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", 
       RowBox[{"-", "1"}], "1"], 
      RowBox[{
       RowBox[{"w", "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"P1", "[", "t_", "]"}], "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Re", "[", 
         RowBox[{"z1", "[", "t", "]"}], "]"}], ",", 
        RowBox[{"Im", "[", 
         RowBox[{"z1", "[", "t", "]"}], "]"}]}], "}"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w[t] = \>\"", ",", 
      RowBox[{"w", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<W[t] = \[Integral]w[t]\[DifferentialD]t = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"W", "[", "t", "]"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<W[1] = \>\"", ",", 
      RowBox[{"W", "[", "1", "]"}], ",", "\"\<,  W[-1] = \>\"", ",", 
      RowBox[{"W", "[", 
       RowBox[{"-", "1"}], "]"}]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-1\), \(1\)]\)w[t]\
\[DifferentialD]t = W[1]-W[-1] = \>\"", ",", 
      RowBox[{"W", "[", "1", "]"}], ",", "\"\< - (\>\"", ",", 
      RowBox[{"W", "[", 
       RowBox[{"-", "1"}], "]"}], ",", "\"\<)\>\""}], "]"}], ";"}], " ", "\n",
    
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-1\), \(1\)]\)w[t]\
\[DifferentialD]t = \>\"", ",", "W1"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"ParametricPlot", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{"P1", "[", "t", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["2", "3"]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "3", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(\[Integral]\), \(C\)]\) \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\< \[DifferentialD]z = \>\"", ",",
       "W1"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<C: \!\(\*SubscriptBox[\(z\), \(1\)]\)[t] = \>\"", ",", 
      RowBox[{"z1", "[", "t", "]"}], ",", 
      "\"\<,  for  -1 \[LessEqual] t \[LessEqual] 1.\>\""}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399288363578125*^9, 3.399288366796875*^9}, {
  3.3998815845*^9, 3.3998815846875*^9}, {3.399882263671875*^9, 
  3.399882264078125*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Explore ",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 StyleBox["Solution 6.9 (b)",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]
}], "Text"],

Cell[TextData[{
 StyleBox["(b)",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Use the portion of a parabola connecting the points  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "1"}], "-", 
     RowBox[{"i", "  ", "and", "  ", 
      SubscriptBox["z", "2"]}]}], "=", 
    RowBox[{"3", "+", "i"}]}]}]]],
 ",  set up the parameterization and compute the contour integral."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"z2", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{
      SuperscriptBox["t", "2"], " ", "+", " ", 
      RowBox[{"2", "t"}], " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", "t"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"w", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{
       RowBox[{"f", "[", 
        RowBox[{"z2", "[", "t", "]"}], "]"}], " ", 
       RowBox[{
        RowBox[{"z2", "'"}], "[", "t", "]"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"u", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"Re", "[", 
       RowBox[{"w", "[", "t", "]"}], "]"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"v", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"Im", "[", 
       RowBox[{"w", "[", "t", "]"}], "]"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<          \!\(\*SubscriptBox[\(z\), \(2\)]\)[t] = \>\"", ",", 
      RowBox[{"z2", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<       f[\!\(\*SubscriptBox[\(z\), \(2\)]\)[t]] = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"z2", "[", "t", "]"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<         \!\(\*SubscriptBox[\(z\), \(2\)]\)'[t] = \>\"", ",", 
      RowBox[{
       RowBox[{"z2", "'"}], "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<f[\!\(\*SubscriptBox[\(z\), \(2\)]\)[t]] \!\(\*SubscriptBox[\(z\), \
\(2\)]\)'[t] = \>\"", ",", 
      RowBox[{"w", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<           u[t] = \>\"", ",", 
      RowBox[{"u", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<           v[t] = \>\"", ",", 
      RowBox[{"v", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399288372234375*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Method (i).",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  The integral can be computed using the real and imaginary parts."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"U2", " ", "=", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", 
       RowBox[{"-", "1"}], "1"], 
      RowBox[{
       RowBox[{"u", "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"V2", " ", "=", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", 
       RowBox[{"-", "1"}], "1"], 
      RowBox[{
       RowBox[{"v", "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"W2", " ", "=", " ", 
     RowBox[{"U2", " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", "V2"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"U", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"u", "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"V", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"v", "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"reint", " ", "=", " ", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"u", "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"imint", " ", "=", " ", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"v", "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"P2", "[", "t_", "]"}], "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Re", "[", 
         RowBox[{"z2", "[", "t", "]"}], "]"}], ",", 
        RowBox[{"Im", "[", 
         RowBox[{"z2", "[", "t", "]"}], "]"}]}], "}"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<u[t] = \>\"", ",", 
      RowBox[{"u", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<v[t] = \>\"", ",", 
      RowBox[{"v", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\[Integral]u[t]\[DifferentialD]t + \[ImaginaryI] \[Integral]v[t]\
\[DifferentialD]t = \>\"", ",", "reint", ",", "\"\< + \[ImaginaryI] (\>\"", 
      ",", "imint", ",", "\"\<)\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<U[t] = \>\"", ",", 
      RowBox[{"U", "[", "t", "]"}], ",", "\"\<,     V[t] = \>\"", ",", 
      RowBox[{"V", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<U[1] = \>\"", ",", 
      RowBox[{"U", "[", "1", "]"}], ",", "\"\<,     V[1] = \>\"", ",", 
      RowBox[{"V", "[", "1", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<U[-1] = \>\"", ",", 
      RowBox[{"U", "[", 
       RowBox[{"-", "1"}], "]"}], ",", "\"\<,   V[-1] = \>\"", ",", 
      RowBox[{"V", "[", 
       RowBox[{"-", "1"}], "]"}]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-1\), \(1\)]\)u[t]\
\[DifferentialD]t + \[ImaginaryI]\!\(\*SubsuperscriptBox[\(\[Integral]\), \
\(-1\), \(1\)]\)v[t]\[DifferentialD]t = U[1]-U[-1] + \
\[ImaginaryI](V[1]-V[-1])\>\"", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-1\), \(1\)]\)u[t]\
\[DifferentialD]t + \[ImaginaryI]\!\(\*SubsuperscriptBox[\(\[Integral]\), \
\(-1\), \(1\)]\)v[t]\[DifferentialD]t = \>\"", ",", 
      RowBox[{
       RowBox[{"U", "[", "1", "]"}], "-", 
       RowBox[{"U", "[", 
        RowBox[{"-", "1"}], "]"}]}], ",", "\"\< + \[ImaginaryI] (\>\"", ",", 
      RowBox[{
       RowBox[{"V", "[", "1", "]"}], "-", 
       RowBox[{"V", "[", 
        RowBox[{"-", "1"}], "]"}]}], ",", "\"\<)\>\""}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-1\), \(1\)]\)u[t]\
\[DifferentialD]t + \[ImaginaryI] \!\(\*SubsuperscriptBox[\(\[Integral]\), \
\(-1\), \(1\)]\)v[t]\[DifferentialD]t = \>\"", ",", "W2"}], "]"}], ";"}], " ",
    "\n", 
   RowBox[{"ParametricPlot", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{"P2", "[", "t", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["2", "3"]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "3", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Blue"}]}], "]"}], "\[IndentingNewLine]",
    
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(\[Integral]\), \(C\)]\) \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\< \[DifferentialD]z = \>\"", ",",
       "W2"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<C: \!\(\*SubscriptBox[\(z\), \(2\)]\)[t] = \>\"", ",", 
      RowBox[{"z2", "[", "t", "]"}], ",", 
      "\"\<,  for  -1 \[LessEqual] t \[LessEqual] 1.\>\""}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3992883756875*^9, 3.399288378625*^9}, {
  3.39988159140625*^9, 3.399881591609375*^9}, {3.399882231328125*^9, 
  3.39988223175*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Method (ii).",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  The integral can be computed using a complex integrand."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"W", "[", "t_", "]"}], " ", "=", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"w", "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"W2", " ", "=", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", 
       RowBox[{"-", "1"}], "1"], 
      RowBox[{
       RowBox[{"w", "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"P2", "[", "t_", "]"}], "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Re", "[", 
         RowBox[{"z2", "[", "t", "]"}], "]"}], ",", 
        RowBox[{"Im", "[", 
         RowBox[{"z2", "[", "t", "]"}], "]"}]}], "}"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w[t] = \>\"", ",", 
      RowBox[{"w", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<W[t] = \[Integral]w[t]\[DifferentialD]t = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"W", "[", "t", "]"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<W[1] = \>\"", ",", 
      RowBox[{"W", "[", "1", "]"}], ",", "\"\<,  W[-1] = \>\"", ",", 
      RowBox[{"W", "[", 
       RowBox[{"-", "1"}], "]"}]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-1\), \(1\)]\)w[t]\
\[DifferentialD]t = W[1]-W[-1] = \>\"", ",", 
      RowBox[{"W", "[", "1", "]"}], ",", "\"\< - (\>\"", ",", 
      RowBox[{"W", "[", 
       RowBox[{"-", "1"}], "]"}], ",", "\"\<)\>\""}], "]"}], ";"}], " ", "\n",
    
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(\[Integral]\), \(C\)]\) \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\< \[DifferentialD]z = \>\"", ",",
       "W2"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{"ParametricPlot", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{"P2", "[", "t", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["2", "3"]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "3", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Blue"}]}], "]"}], "\[IndentingNewLine]",
    
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(\[Integral]\), \(C\)]\) \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\< \[DifferentialD]z = \>\"", ",",
       "W2"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<C: \!\(\*SubscriptBox[\(z\), \(2\)]\)[t] = \>\"", ",", 
      RowBox[{"z2", "[", "t", "]"}], ",", 
      "\"\<,  for  -1 \[LessEqual] t \[LessEqual] 1.\>\""}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399288384484375*^9, 3.399288388109375*^9}, {
  3.399881596875*^9, 3.39988159709375*^9}, {3.39988223878125*^9, 
  3.399882239171875*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "Which is the same as the value along the other path because  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   SuperscriptBox["z", "2"]}]]],
 "  is an analytic function"
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"P1", "[", "t_", "]"}], "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Re", "[", 
         RowBox[{"z1", "[", "t", "]"}], "]"}], ",", 
        RowBox[{"Im", "[", 
         RowBox[{"z1", "[", "t", "]"}], "]"}]}], "}"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"ParametricPlot", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{"P1", "[", "t", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["2", "3"]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "3", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(\[Integral]\), \(C\)]\) \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\< \[DifferentialD]z = \>\"", ",",
       "W1"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<C: \!\(\*SubscriptBox[\(z\), \(1\)]\)[t] = \>\"", ",", 
      RowBox[{"z1", "[", "t", "]"}], ",", 
      "\"\<,  for  -1 \[LessEqual] t \[LessEqual] 1.\>\""}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39928839178125*^9, 3.3992883939375*^9}, {3.399881603*^9,
   3.399881603234375*^9}, {3.399882271609375*^9, 3.3998822720625*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Extra Example 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Evaluate the contour integrals  of  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   SuperscriptBox["z", "2"]}]]],
 "  starting at the points   ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "1"}], "-", 
     RowBox[{"i", "  ", "and", "  ", 
      SubscriptBox["z", "2"]}]}], "=", 
    RowBox[{"3", "+", "i"}]}]}]]],
 ".  \n",
 StyleBox["(a)",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Use the line segment joining the points.  \n",
 StyleBox["(b)",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Use a portion of a parabola joining the points.\n",
 StyleBox["Remark.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 " The example in the text used the function ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", "z"}]]],
 "  which is difficult for hand computations but it is not a challenge for ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", hence we choose to use the function ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   SuperscriptBox["z", "2"]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Explore ",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 StyleBox["Solution for Extra Example 1 (a)",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]
}], "Text"],

Cell[TextData[{
 StyleBox["(a)",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Use the straight line segment connecting the points  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "1"}], "-", 
     RowBox[{"i", "  ", "and", "  ", 
      SubscriptBox["z", "2"]}]}], "=", 
    RowBox[{"3", "+", "i"}]}]}]]],
 ",  set up the parameterization and compute the contour integral.  Enter the \
function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], "=", 
   SuperscriptBox["z", "2"]}]],
  AspectRatioFixed->True],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", 
     RowBox[{
     "t", ",", "u", ",", "U", ",", "v", ",", "V", ",", "w", ",", "W", ",", 
      "z"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "f", ",", "U1", ",", "U2", ",", "V1", ",", "V2", ",", "W1", ",", "W2", 
      ",", "z1", ",", "z2"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     SuperscriptBox["z", "2"]}], " ", ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"z1", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{
      RowBox[{"2", "t"}], " ", "+", " ", "1", " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", "t"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"w", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{
       RowBox[{"f", "[", 
        RowBox[{"z1", "[", "t", "]"}], "]"}], " ", 
       RowBox[{
        RowBox[{"z1", "'"}], "[", "t", "]"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"u", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"Re", "[", 
       RowBox[{"w", "[", "t", "]"}], "]"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"v", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"Im", "[", 
       RowBox[{"w", "[", "t", "]"}], "]"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<           f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<          \!\(\*SubscriptBox[\(z\), \(1\)]\)[t] = \>\"", ",", 
      RowBox[{"z1", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<       f[\!\(\*SubscriptBox[\(z\), \(1\)]\)[t]] = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"z1", "[", "t", "]"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<         \!\(\*SubscriptBox[\(z\), \(1\)]\)'[t] = \>\"", ",", 
      RowBox[{
       RowBox[{"z1", "'"}], "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<f[\!\(\*SubscriptBox[\(z\), \(1\)]\)[t]] \!\(\*SubscriptBox[\(z\), \
\(1\)]\)'[t] = \>\"", ",", 
      RowBox[{"w", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<           u[t] = \>\"", ",", 
      RowBox[{"u", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<           v[t] = \>\"", ",", 
      RowBox[{"v", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39928840040625*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Method (i).",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  The integral can be computed using the real and imaginary parts."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"U1", " ", "=", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", 
       RowBox[{"-", "1"}], "1"], 
      RowBox[{
       RowBox[{"u", "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"V1", " ", "=", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", 
       RowBox[{"-", "1"}], "1"], 
      RowBox[{
       RowBox[{"v", "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"W1", " ", "=", " ", 
     RowBox[{"U1", " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", "V1"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"U", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"u", "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"V", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"v", "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"reint", " ", "=", " ", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"u", "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"imint", " ", "=", " ", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"v", "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"P1", "[", "t_", "]"}], "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Re", "[", 
         RowBox[{"z1", "[", "t", "]"}], "]"}], ",", 
        RowBox[{"Im", "[", 
         RowBox[{"z1", "[", "t", "]"}], "]"}]}], "}"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<u[t] = \>\"", ",", 
      RowBox[{"u", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<v[t] = \>\"", ",", 
      RowBox[{"v", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\[Integral]u[t]\[DifferentialD]t + \[ImaginaryI] \[Integral]v[t]\
\[DifferentialD]t = \>\"", ",", "reint", ",", "\"\< + \[ImaginaryI] (\>\"", 
      ",", "imint", ",", "\"\<)\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<U[t] = \>\"", ",", 
      RowBox[{"U", "[", "t", "]"}], ",", "\"\<,     V[t] = \>\"", ",", 
      RowBox[{"V", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<U[1] = \>\"", ",", 
      RowBox[{"U", "[", "1", "]"}], ",", "\"\<,     V[1] = \>\"", ",", 
      RowBox[{"V", "[", "1", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<U[-1] = \>\"", ",", 
      RowBox[{"U", "[", 
       RowBox[{"-", "1"}], "]"}], ",", "\"\<,   V[-1] = \>\"", ",", 
      RowBox[{"V", "[", 
       RowBox[{"-", "1"}], "]"}]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-1\), \(1\)]\)u[t]\
\[DifferentialD]t + \[ImaginaryI]\!\(\*SubsuperscriptBox[\(\[Integral]\), \
\(-1\), \(1\)]\)v[t]\[DifferentialD]t = U[1]-U[-1] + \
\[ImaginaryI](V[1]-V[-1])\>\"", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-1\), \(1\)]\)u[t]\
\[DifferentialD]t + \[ImaginaryI]\!\(\*SubsuperscriptBox[\(\[Integral]\), \
\(-1\), \(1\)]\)v[t]\[DifferentialD]t = \>\"", ",", 
      RowBox[{
       RowBox[{"U", "[", "1", "]"}], "-", 
       RowBox[{"U", "[", 
        RowBox[{"-", "1"}], "]"}]}], ",", "\"\< + \[ImaginaryI] (\>\"", ",", 
      RowBox[{
       RowBox[{"V", "[", "1", "]"}], "-", 
       RowBox[{"V", "[", 
        RowBox[{"-", "1"}], "]"}]}], ",", "\"\<)\>\""}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-1\), \(1\)]\)u[t]\
\[DifferentialD]t + \[ImaginaryI] \!\(\*SubsuperscriptBox[\(\[Integral]\), \
\(-1\), \(1\)]\)v[t]\[DifferentialD]t = \>\"", ",", "W1"}], "]"}], ";"}], " ",
    "\n", 
   RowBox[{"ParametricPlot", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{"P1", "[", "t", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["2", "3"]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "3", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(\[Integral]\), \(C\)]\) \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\< \[DifferentialD]z = \>\"", ",",
       "W1"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<C: \!\(\*SubscriptBox[\(z\), \(1\)]\)[t] = \>\"", ",", 
      RowBox[{"z1", "[", "t", "]"}], ",", 
      "\"\<,  for  -1 \[LessEqual] t \[LessEqual] 1.\>\""}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399288404109375*^9, 3.399288406140625*^9}, {
  3.3998816085625*^9, 3.399881608734375*^9}, {3.3998822985625*^9, 
  3.3998822995*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Method (ii).",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  The integral can be computed using a complex integrand."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"W", "[", "t_", "]"}], " ", "=", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"w", "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"W1", " ", "=", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", 
       RowBox[{"-", "1"}], "1"], 
      RowBox[{
       RowBox[{"w", "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"P1", "[", "t_", "]"}], "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Re", "[", 
         RowBox[{"z1", "[", "t", "]"}], "]"}], ",", 
        RowBox[{"Im", "[", 
         RowBox[{"z1", "[", "t", "]"}], "]"}]}], "}"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w[t] = \>\"", ",", 
      RowBox[{"w", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<W[t] = \[Integral]w[t]\[DifferentialD]t = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"W", "[", "t", "]"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<W[1] = \>\"", ",", 
      RowBox[{"W", "[", "1", "]"}], ",", "\"\<,  W[-1] = \>\"", ",", 
      RowBox[{"W", "[", 
       RowBox[{"-", "1"}], "]"}]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-1\), \(1\)]\)w[t]\
\[DifferentialD]t = W[1]-W[-1] = \>\"", ",", 
      RowBox[{"W", "[", "1", "]"}], ",", "\"\< - (\>\"", ",", 
      RowBox[{"W", "[", 
       RowBox[{"-", "1"}], "]"}], ",", "\"\<)\>\""}], "]"}], ";"}], " ", "\n",
    
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-1\), \(1\)]\)w[t]\
\[DifferentialD]t = \>\"", ",", "W1"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"ParametricPlot", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{"P1", "[", "t", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["2", "3"]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "3", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(\[Integral]\), \(C\)]\) \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\< \[DifferentialD]z = \>\"", ",",
       "W1"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<C: \!\(\*SubscriptBox[\(z\), \(1\)]\)[t] = \>\"", ",", 
      RowBox[{"z1", "[", "t", "]"}], ",", 
      "\"\<,  for  -1 \[LessEqual] t \[LessEqual] 1.\>\""}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3992884089375*^9, 3.39928841190625*^9}, {
  3.3998816135625*^9, 3.399881613734375*^9}, {3.39988230440625*^9, 
  3.399882304953125*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Explore ",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 StyleBox["Solution for Extra Example 1 (b)",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]
}], "Text"],

Cell[TextData[{
 StyleBox["(b)",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Use the portion of a parabola connecting the points  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "1"}], "-", 
     RowBox[{"i", "  ", "and", "  ", 
      SubscriptBox["z", "2"]}]}], "=", 
    RowBox[{"3", "+", "i"}]}]}]]],
 ",  set up the parameterization and compute the contour integral."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"z2", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{
      SuperscriptBox["t", "2"], " ", "+", " ", 
      RowBox[{"2", "t"}], " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", "t"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"w", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{
       RowBox[{"f", "[", 
        RowBox[{"z2", "[", "t", "]"}], "]"}], " ", 
       RowBox[{
        RowBox[{"z2", "'"}], "[", "t", "]"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"u", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"Re", "[", 
       RowBox[{"w", "[", "t", "]"}], "]"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"v", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"Im", "[", 
       RowBox[{"w", "[", "t", "]"}], "]"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<          \!\(\*SubscriptBox[\(z\), \(2\)]\)[t] = \>\"", ",", 
      RowBox[{"z2", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<       f[\!\(\*SubscriptBox[\(z\), \(2\)]\)[t]] = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"z2", "[", "t", "]"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<         \!\(\*SubscriptBox[\(z\), \(2\)]\)'[t] = \>\"", ",", 
      RowBox[{
       RowBox[{"z2", "'"}], "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<f[\!\(\*SubscriptBox[\(z\), \(2\)]\)[t]] \!\(\*SubscriptBox[\(z\), \
\(2\)]\)'[t] = \>\"", ",", 
      RowBox[{"w", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<           u[t] = \>\"", ",", 
      RowBox[{"u", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<           v[t] = \>\"", ",", 
      RowBox[{"v", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399288417484375*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Method (i).",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  The integral can be computed using the real and imaginary parts."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"U2", " ", "=", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", 
       RowBox[{"-", "1"}], "1"], 
      RowBox[{
       RowBox[{"u", "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"V2", " ", "=", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", 
       RowBox[{"-", "1"}], "1"], 
      RowBox[{
       RowBox[{"v", "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"W2", " ", "=", " ", 
     RowBox[{"U2", " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", "V2"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"U", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"u", "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"V", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"v", "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"reint", " ", "=", " ", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"u", "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"imint", " ", "=", " ", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"v", "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"P2", "[", "t_", "]"}], "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Re", "[", 
         RowBox[{"z2", "[", "t", "]"}], "]"}], ",", 
        RowBox[{"Im", "[", 
         RowBox[{"z2", "[", "t", "]"}], "]"}]}], "}"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<u[t] = \>\"", ",", 
      RowBox[{"u", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<v[t] = \>\"", ",", 
      RowBox[{"v", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\[Integral]u[t]\[DifferentialD]t + \[ImaginaryI] \[Integral]v[t]\
\[DifferentialD]t = \>\"", ",", "reint", ",", "\"\< + \[ImaginaryI] (\>\"", 
      ",", "imint", ",", "\"\<)\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<U[t] = \>\"", ",", 
      RowBox[{"U", "[", "t", "]"}], ",", "\"\<,     V[t] = \>\"", ",", 
      RowBox[{"V", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<U[1] = \>\"", ",", 
      RowBox[{"U", "[", "1", "]"}], ",", "\"\<,     V[1] = \>\"", ",", 
      RowBox[{"V", "[", "1", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<U[-1] = \>\"", ",", 
      RowBox[{"U", "[", 
       RowBox[{"-", "1"}], "]"}], ",", "\"\<,   V[-1] = \>\"", ",", 
      RowBox[{"V", "[", 
       RowBox[{"-", "1"}], "]"}]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-1\), \(1\)]\)u[t]\
\[DifferentialD]t + \[ImaginaryI]\!\(\*SubsuperscriptBox[\(\[Integral]\), \
\(-1\), \(1\)]\)v[t]\[DifferentialD]t = U[1]-U[-1] + \
\[ImaginaryI](V[1]-V[-1])\>\"", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-1\), \(1\)]\)u[t]\
\[DifferentialD]t + \[ImaginaryI]\!\(\*SubsuperscriptBox[\(\[Integral]\), \
\(-1\), \(1\)]\)v[t]\[DifferentialD]t = \>\"", ",", 
      RowBox[{
       RowBox[{"U", "[", "1", "]"}], "-", 
       RowBox[{"U", "[", 
        RowBox[{"-", "1"}], "]"}]}], ",", "\"\< + \[ImaginaryI] (\>\"", ",", 
      RowBox[{
       RowBox[{"V", "[", "1", "]"}], "-", 
       RowBox[{"V", "[", 
        RowBox[{"-", "1"}], "]"}]}], ",", "\"\<)\>\""}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-1\), \(1\)]\)u[t]\
\[DifferentialD]t + \[ImaginaryI] \!\(\*SubsuperscriptBox[\(\[Integral]\), \
\(-1\), \(1\)]\)v[t]\[DifferentialD]t = \>\"", ",", "W2"}], "]"}], ";"}], " ",
    "\n", 
   RowBox[{"ParametricPlot", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{"P2", "[", "t", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["2", "3"]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "3", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Blue"}]}], "]"}], "\[IndentingNewLine]",
    
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(\[Integral]\), \(C\)]\) \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\< \[DifferentialD]z = \>\"", ",",
       "W2"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<C: \!\(\*SubscriptBox[\(z\), \(2\)]\)[t] = \>\"", ",", 
      RowBox[{"z2", "[", "t", "]"}], ",", 
      "\"\<,  for  -1 \[LessEqual] t \[LessEqual] 1.\>\""}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39928842096875*^9, 3.399288423140625*^9}, {
  3.3998816184375*^9, 3.399881618625*^9}, {3.39988231475*^9, 
  3.39988234484375*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Method (ii).",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  The integral can be computed using a complex integrand."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"W", "[", "t_", "]"}], " ", "=", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"w", "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"W2", " ", "=", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", 
       RowBox[{"-", "1"}], "1"], 
      RowBox[{
       RowBox[{"w", "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"P2", "[", "t_", "]"}], "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Re", "[", 
         RowBox[{"z2", "[", "t", "]"}], "]"}], ",", 
        RowBox[{"Im", "[", 
         RowBox[{"z2", "[", "t", "]"}], "]"}]}], "}"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w[t] = \>\"", ",", 
      RowBox[{"w", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<W[t] = \[Integral]w[t]\[DifferentialD]t = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"W", "[", "t", "]"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<W[1] = \>\"", ",", 
      RowBox[{"W", "[", "1", "]"}], ",", "\"\<,  W[-1] = \>\"", ",", 
      RowBox[{"W", "[", 
       RowBox[{"-", "1"}], "]"}]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-1\), \(1\)]\)w[t]\
\[DifferentialD]t = W[1]-W[-1] = \>\"", ",", 
      RowBox[{"W", "[", "1", "]"}], ",", "\"\< - (\>\"", ",", 
      RowBox[{"W", "[", 
       RowBox[{"-", "1"}], "]"}], ",", "\"\<)\>\""}], "]"}], ";"}], " ", "\n",
    
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(\[Integral]\), \(C\)]\) \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\<\[DifferentialD]z = \>\"", ",", 
      "W2"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{"ParametricPlot", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{"P2", "[", "t", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["2", "3"]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "3", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Blue"}]}], "]"}], "\[IndentingNewLine]",
    
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(\[Integral]\), \(C\)]\) \
\!\(\*SuperscriptBox[\(z\), \(2\)]\) \[DifferentialD]z = \>\"", ",", "W2"}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<C: \!\(\*SubscriptBox[\(z\), \(2\)]\)[t] = \>\"", ",", 
      RowBox[{"z2", "[", "t", "]"}], ",", 
      "\"\<,  for  -1 \[LessEqual] t \[LessEqual] 1.\>\""}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399288427734375*^9, 3.399288429859375*^9}, {
  3.39988162359375*^9, 3.399881623828125*^9}, {3.39988233965625*^9, 
  3.399882340015625*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "Which is the same as the value along the other path because  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   SuperscriptBox["z", "2"]}]]],
 "  is an analytic function"
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"P1", "[", "t_", "]"}], "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Re", "[", 
         RowBox[{"z1", "[", "t", "]"}], "]"}], ",", 
        RowBox[{"Im", "[", 
         RowBox[{"z1", "[", "t", "]"}], "]"}]}], "}"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"ParametricPlot", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{"P1", "[", "t", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["2", "3"]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "3", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(\[Integral]\), \(C\)]\) \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\< \[DifferentialD]z = \>\"", ",",
       "W1"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<C: \!\(\*SubscriptBox[\(z\), \(1\)]\)[t] = \>\"", ",", 
      RowBox[{"z1", "[", "t", "]"}], ",", 
      "\"\<,  for  -1 \[LessEqual] t \[LessEqual] 1.\>\""}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3992884331875*^9, 3.399288435296875*^9}, {
  3.39988162834375*^9, 3.399881628546875*^9}, {3.39988235234375*^9, 
  3.39988235284375*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Extra Example 2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Evaluate the contour integrals  of  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   OverscriptBox[
    RowBox[{" ", "z"}], "_"]}]]],
 "  starting at the points   ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "1"}], "-", 
     RowBox[{"i", "  ", "and", "  ", 
      SubscriptBox["z", "2"]}]}], "=", 
    RowBox[{"3", "+", "i"}]}]}]]],
 ".  \n",
 StyleBox["(a)",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Use the line segment joining the points.  \n",
 StyleBox["(b)",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Use a portion of a parabola joining the points.\n",
 StyleBox["Remark.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  This example illustrates the situation when f(z) is not analytic."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Explore ",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 StyleBox["Solution for Extra Example 2 (a)",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]
}], "Text"],

Cell[TextData[{
 StyleBox["(a)",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Use the straight line segment connecting the points  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "1"}], "-", 
     RowBox[{"i", "  ", "and", "  ", 
      SubscriptBox["z", "2"]}]}], "=", 
    RowBox[{"3", "+", "i"}]}]}]]],
 ",  set up the parameterization and compute the contour integral.  Enter the \
function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   OverscriptBox[
    RowBox[{" ", "z"}], "_"]}]],
  AspectRatioFixed->True],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", 
     RowBox[{
     "t", ",", "u", ",", "U", ",", "v", ",", "V", ",", "w", ",", "W", ",", 
      "z"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "f", ",", "U1", ",", "U2", ",", "V1", ",", "V2", ",", "W1", ",", "W2", 
      ",", "z1", ",", "z2"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"Conjugate", "[", "z", "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"TagSet", "[", 
     RowBox[{"t", ",", 
      RowBox[{"Im", "[", "t", "]"}], ",", "0"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"z1", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{
      RowBox[{"2", "t"}], " ", "+", " ", "1", " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", "t"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"w", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{
       RowBox[{"f", "[", 
        RowBox[{"z1", "[", "t", "]"}], "]"}], " ", 
       RowBox[{
        RowBox[{"z1", "'"}], "[", "t", "]"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"u", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"Re", "[", 
       RowBox[{"w", "[", "t", "]"}], "]"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"v", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"Im", "[", 
       RowBox[{"w", "[", "t", "]"}], "]"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<           f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<        f[x+\[ImaginaryI]y] = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", "+", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<          \!\(\*SubscriptBox[\(z\), \(1\)]\)[t] = \>\"", ",", 
      RowBox[{"z1", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<       f[\!\(\*SubscriptBox[\(z\), \(1\)]\)[t]] = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", " ", 
       RowBox[{"f", "[", 
        RowBox[{"z1", "[", "t", "]"}], "]"}], " ", "]"}]}], "]"}], ";"}], " ",
    "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<         \!\(\*SubscriptBox[\(z\), \(1\)]\)'[t] = \>\"", ",", 
      RowBox[{
       RowBox[{"z1", "'"}], "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<f[\!\(\*SubscriptBox[\(z\), \(1\)]\)[t]] \!\(\*SubscriptBox[\(z\), \
\(1\)]\)'[t] = \>\"", ",", 
      RowBox[{"w", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<           u[t] = \>\"", ",", 
      RowBox[{"u", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<           v[t] = \>\"", ",", 
      RowBox[{"v", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399288440796875*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Method (i).",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  The integral can be computed using the real and imaginary parts."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"U1", " ", "=", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", 
       RowBox[{"-", "1"}], "1"], 
      RowBox[{
       RowBox[{"u", "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"V1", " ", "=", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", 
       RowBox[{"-", "1"}], "1"], 
      RowBox[{
       RowBox[{"v", "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"W1", " ", "=", " ", 
     RowBox[{"U1", " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", "V1"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"U", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"u", "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"V", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"v", "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"reint", " ", "=", " ", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"u", "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"imint", " ", "=", " ", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"v", "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"P1", "[", "t_", "]"}], "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Re", "[", 
         RowBox[{"z1", "[", "t", "]"}], "]"}], ",", 
        RowBox[{"Im", "[", 
         RowBox[{"z1", "[", "t", "]"}], "]"}]}], "}"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<u[t] = \>\"", ",", 
      RowBox[{"u", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<v[t] = \>\"", ",", 
      RowBox[{"v", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\[Integral]u[t]\[DifferentialD]t + \[ImaginaryI] \[Integral]v[t]\
\[DifferentialD]t = \>\"", ",", "reint", ",", "\"\< + \[ImaginaryI] (\>\"", 
      ",", "imint", ",", "\"\<)\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<U[t] = \>\"", ",", 
      RowBox[{"U", "[", "t", "]"}], ",", "\"\<,     V[t] = \>\"", ",", 
      RowBox[{"V", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<U[1] = \>\"", ",", 
      RowBox[{"U", "[", "1", "]"}], ",", "\"\<,     V[1] = \>\"", ",", 
      RowBox[{"V", "[", "1", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<U[-1] = \>\"", ",", 
      RowBox[{"U", "[", 
       RowBox[{"-", "1"}], "]"}], ",", "\"\<,   V[-1] = \>\"", ",", 
      RowBox[{"V", "[", 
       RowBox[{"-", "1"}], "]"}]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-1\), \(1\)]\)u[t]\
\[DifferentialD]t + \[ImaginaryI]\!\(\*SubsuperscriptBox[\(\[Integral]\), \
\(-1\), \(1\)]\)v[t]\[DifferentialD]t = U[1]-U[-1] + \
\[ImaginaryI](V[1]-V[-1])\>\"", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-1\), \(1\)]\)u[t]\
\[DifferentialD]t + \[ImaginaryI]\!\(\*SubsuperscriptBox[\(\[Integral]\), \
\(-1\), \(1\)]\)v[t]\[DifferentialD]t = \>\"", ",", 
      RowBox[{
       RowBox[{"U", "[", "1", "]"}], "-", 
       RowBox[{"U", "[", 
        RowBox[{"-", "1"}], "]"}]}], ",", "\"\< + \[ImaginaryI] (\>\"", ",", 
      RowBox[{
       RowBox[{"V", "[", "1", "]"}], "-", 
       RowBox[{"V", "[", 
        RowBox[{"-", "1"}], "]"}]}], ",", "\"\<)\>\""}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-1\), \(1\)]\)u[t]\
\[DifferentialD]t + \[ImaginaryI] \!\(\*SubsuperscriptBox[\(\[Integral]\), \
\(-1\), \(1\)]\)v[t]\[DifferentialD]t = \>\"", ",", "W1"}], "]"}], ";"}], " ",
    "\n", 
   RowBox[{"ParametricPlot", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{"P1", "[", "t", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["2", "3"]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "3", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(\[Integral]\), \(C\)]\) \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\< \[DifferentialD]z = \>\"", ",",
       "W1"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<C: \!\(\*SubscriptBox[\(z\), \(1\)]\)[t] = \>\"", ",", 
      RowBox[{"z1", "[", "t", "]"}], ",", 
      "\"\<,  for  -1 \[LessEqual] t \[LessEqual] 1.\>\""}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399288444734375*^9, 3.39928844675*^9}, {
  3.399881634046875*^9, 3.399881634234375*^9}, {3.399882366*^9, 
  3.399882366921875*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Method (ii).",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  The integral can be computed using a complex integrand."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"W", "[", "t_", "]"}], " ", "=", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"w", "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"W1", " ", "=", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", 
       RowBox[{"-", "1"}], "1"], 
      RowBox[{
       RowBox[{"w", "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"P1", "[", "t_", "]"}], "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Re", "[", 
         RowBox[{"z1", "[", "t", "]"}], "]"}], ",", 
        RowBox[{"Im", "[", 
         RowBox[{"z1", "[", "t", "]"}], "]"}]}], "}"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w[t] = \>\"", ",", 
      RowBox[{"w", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<W[t] = \[Integral]w[t]\[DifferentialD]t = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"W", "[", "t", "]"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<W[1] = \>\"", ",", 
      RowBox[{"W", "[", "1", "]"}], ",", "\"\<,  W[-1] = \>\"", ",", 
      RowBox[{"W", "[", 
       RowBox[{"-", "1"}], "]"}]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-1\), \(1\)]\)w[t]\
\[DifferentialD]t = W[1]-W[-1] = \>\"", ",", 
      RowBox[{"W", "[", "1", "]"}], ",", "\"\< - (\>\"", ",", 
      RowBox[{"W", "[", 
       RowBox[{"-", "1"}], "]"}], ",", "\"\<)\>\""}], "]"}], ";"}], " ", "\n",
    
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-1\), \(1\)]\)w[t]\
\[DifferentialD]t = \>\"", ",", "W1"}], "]"}], ";"}], " ", "\n", 
   RowBox[{"ParametricPlot", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{"P1", "[", "t", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["2", "3"]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "3", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(\[Integral]\), \(C\)]\) \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\< \[DifferentialD]z = \>\"", ",",
       "W1"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<C: \!\(\*SubscriptBox[\(z\), \(1\)]\)[t] = \>\"", ",", 
      RowBox[{"z1", "[", "t", "]"}], ",", 
      "\"\<,  for  -1 \[LessEqual] t \[LessEqual] 1.\>\""}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39928845096875*^9, 3.399288452546875*^9}, {
  3.399881639921875*^9, 3.39988164015625*^9}, {3.399882371734375*^9, 
  3.399882372484375*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Explore ",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 StyleBox["Solution for Extra Example 2 (b)",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]
}], "Text"],

Cell[TextData[{
 StyleBox["(b)",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Use the portion of a parabola connecting the points  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "1"}], "-", 
     RowBox[{"i", "  ", "and", "  ", 
      SubscriptBox["z", "2"]}]}], "=", 
    RowBox[{"3", "+", "i"}]}]}]]],
 ",  set up the parameterization and compute the contour integral."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"TagSet", "[", 
     RowBox[{"t", ",", 
      RowBox[{"Im", "[", "t", "]"}], ",", "0"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"z2", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{
      SuperscriptBox["t", "2"], " ", "+", " ", 
      RowBox[{"2", "t"}], " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", "t"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"w", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{
       RowBox[{"f", "[", 
        RowBox[{"z2", "[", "t", "]"}], "]"}], " ", 
       RowBox[{
        RowBox[{"z2", "'"}], "[", "t", "]"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"u", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"Re", "[", 
       RowBox[{"w", "[", "t", "]"}], "]"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"v", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"Im", "[", 
       RowBox[{"w", "[", "t", "]"}], "]"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<          \!\(\*SubscriptBox[\(z\), \(2\)]\)[t] = \>\"", ",", 
      RowBox[{"z2", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<       f[\!\(\*SubscriptBox[\(z\), \(2\)]\)[t]] = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", " ", 
       RowBox[{"f", "[", 
        RowBox[{"z2", "[", "t", "]"}], "]"}], " ", "]"}]}], "]"}], ";"}], " ",
    "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<         \!\(\*SubscriptBox[\(z\), \(2\)]\)'[t] = \>\"", ",", 
      RowBox[{
       RowBox[{"z2", "'"}], "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<f[\!\(\*SubscriptBox[\(z\), \(2\)]\)[t]] \!\(\*SubscriptBox[\(z\), \
\(2\)]\)'[t] = \>\"", ",", 
      RowBox[{"w", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<           u[t] = \>\"", ",", 
      RowBox[{"u", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<           v[t] = \>\"", ",", 
      RowBox[{"v", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399288459859375*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Method (i).",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  The integral can be computed using the real and imaginary parts."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"U2", " ", "=", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", 
       RowBox[{"-", "1"}], "1"], 
      RowBox[{
       RowBox[{"u", "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"V2", " ", "=", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", 
       RowBox[{"-", "1"}], "1"], 
      RowBox[{
       RowBox[{"v", "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"W2", " ", "=", " ", 
     RowBox[{"U2", " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", "V2"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"U", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"u", "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"V", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"v", "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"reint", " ", "=", " ", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"u", "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"imint", " ", "=", " ", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"v", "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"P2", "[", "t_", "]"}], "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Re", "[", 
         RowBox[{"z2", "[", "t", "]"}], "]"}], ",", 
        RowBox[{"Im", "[", 
         RowBox[{"z2", "[", "t", "]"}], "]"}]}], "}"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<u[t] = \>\"", ",", 
      RowBox[{"u", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<v[t] = \>\"", ",", 
      RowBox[{"v", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\[Integral]u[t]\[DifferentialD]t + \[ImaginaryI] \[Integral]v[t]\
\[DifferentialD]t = \>\"", ",", "reint", ",", "\"\< + \[ImaginaryI] (\>\"", 
      ",", "imint", ",", "\"\<)\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<U[t] = \>\"", ",", 
      RowBox[{"U", "[", "t", "]"}], ",", "\"\<,     V[t] = \>\"", ",", 
      RowBox[{"V", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<U[1] = \>\"", ",", 
      RowBox[{"U", "[", "1", "]"}], ",", "\"\<,     V[1] = \>\"", ",", 
      RowBox[{"V", "[", "1", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<U[-1] = \>\"", ",", 
      RowBox[{"U", "[", 
       RowBox[{"-", "1"}], "]"}], ",", "\"\<,   V[-1] = \>\"", ",", 
      RowBox[{"V", "[", 
       RowBox[{"-", "1"}], "]"}]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-1\), \(1\)]\)u[t]\
\[DifferentialD]t + \[ImaginaryI]\!\(\*SubsuperscriptBox[\(\[Integral]\), \
\(-1\), \(1\)]\)v[t]\[DifferentialD]t = U[1]-U[-1] + \
\[ImaginaryI](V[1]-V[-1])\>\"", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-1\), \(1\)]\)u[t]\
\[DifferentialD]t + \[ImaginaryI]\!\(\*SubsuperscriptBox[\(\[Integral]\), \
\(-1\), \(1\)]\)v[t]\[DifferentialD]t = \>\"", ",", 
      RowBox[{
       RowBox[{"U", "[", "1", "]"}], "-", 
       RowBox[{"U", "[", 
        RowBox[{"-", "1"}], "]"}]}], ",", "\"\< + \[ImaginaryI] (\>\"", ",", 
      RowBox[{
       RowBox[{"V", "[", "1", "]"}], "-", 
       RowBox[{"V", "[", 
        RowBox[{"-", "1"}], "]"}]}], ",", "\"\<)\>\""}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-1\), \(1\)]\)u[t]\
\[DifferentialD]t + \[ImaginaryI] \!\(\*SubsuperscriptBox[\(\[Integral]\), \
\(-1\), \(1\)]\)v[t]\[DifferentialD]t = \>\"", ",", "W2"}], "]"}], ";"}], " ",
    "\n", 
   RowBox[{"ParametricPlot", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{"P2", "[", "t", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["2", "3"]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "3", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Blue"}]}], "]"}], "\[IndentingNewLine]",
    
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(\[Integral]\), \(C\)]\) \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\< \[DifferentialD]z = \>\"", ",",
       "W2"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<C: \!\(\*SubscriptBox[\(z\), \(2\)]\)[t] = \>\"", ",", 
      RowBox[{"z2", "[", "t", "]"}], ",", 
      "\"\<,  for  -1 \[LessEqual] t \[LessEqual] 1.\>\""}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399288462875*^9, 3.399288465578125*^9}, {
  3.399881645703125*^9, 3.399881645890625*^9}, {3.39988237784375*^9, 
  3.399882378234375*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Method (ii).",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  The integral can be computed using a complex integrand."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"W", "[", "t_", "]"}], " ", "=", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"w", "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"W2", " ", "=", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", 
       RowBox[{"-", "1"}], "1"], 
      RowBox[{
       RowBox[{"w", "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"P2", "[", "t_", "]"}], "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Re", "[", 
         RowBox[{"z2", "[", "t", "]"}], "]"}], ",", 
        RowBox[{"Im", "[", 
         RowBox[{"z2", "[", "t", "]"}], "]"}]}], "}"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w[t] = \>\"", ",", 
      RowBox[{"w", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<W[t] = \[Integral]w[t]\[DifferentialD]t = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"W", "[", "t", "]"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<W[1] = \>\"", ",", 
      RowBox[{"W", "[", "1", "]"}], ",", "\"\<,  W[-1] = \>\"", ",", 
      RowBox[{"W", "[", 
       RowBox[{"-", "1"}], "]"}]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-1\), \(1\)]\)w[t]\
\[DifferentialD]t = W[1]-W[-1] = \>\"", ",", 
      RowBox[{"W", "[", "1", "]"}], ",", "\"\< - (\>\"", ",", 
      RowBox[{"W", "[", 
       RowBox[{"-", "1"}], "]"}], ",", "\"\<)\>\""}], "]"}], ";"}], " ", "\n",
    
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-1\), \(1\)]\)w[t]\
\[DifferentialD]t = \>\"", ",", "W2"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"ParametricPlot", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{"P2", "[", "t", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["2", "3"]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "3", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Blue"}]}], "]"}], "\[IndentingNewLine]",
    
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(\[Integral]\), \(C\)]\) \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\< \[DifferentialD]z = \>\"", ",",
       "W2"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<C: \!\(\*SubscriptBox[\(z\), \(2\)]\)[t] = \>\"", ",", 
      RowBox[{"z2", "[", "t", "]"}], ",", 
      "\"\<,  for  -1 \[LessEqual] t \[LessEqual] 1.\>\""}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39928847084375*^9, 3.399288474*^9}, {3.3998816505625*^9,
   3.399881650734375*^9}, {3.399882383*^9, 3.39988238340625*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "Which is ",
 StyleBox["different",
  FontColor->RGBColor[1, 0, 1]],
 " from the value for the straight line path because  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   OverscriptBox[
    RowBox[{" ", "z"}], "_"]}]]],
 "  is ",
 StyleBox["not",
  FontColor->RGBColor[1, 0, 1]],
 " an analytic function."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"P1", "[", "t_", "]"}], "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Re", "[", 
         RowBox[{"z1", "[", "t", "]"}], "]"}], ",", 
        RowBox[{"Im", "[", 
         RowBox[{"z1", "[", "t", "]"}], "]"}]}], "}"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"ParametricPlot", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{"P1", "[", "t", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["2", "3"]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "3", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(\[Integral]\), \(C\)]\) \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\< \[DifferentialD]z = \>\"", ",",
       "W1"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<C: \!\(\*SubscriptBox[\(z\), \(1\)]\)[t] = \>\"", ",", 
      RowBox[{"z1", "[", "t", "]"}], ",", 
      "\"\<c  for  -1 \[LessEqual] t \[LessEqual] 1.\>\""}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399288476671875*^9, 3.399288479609375*^9}, {
  3.399881655671875*^9, 3.39988165584375*^9}, {3.39988238959375*^9, 
  3.399882390125*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell["\<\
\tIn Example 6.9, the value of the two integrals is the same.  This outcome \
doesn't hold in general, as Example 6.10 shows. \
\>", "Text"],

Cell[TextData[{
 StyleBox["Example 6.10.  (a)",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "   Show that   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["\[Integral]", 
     SubscriptBox["C", "1"]], " ", 
    RowBox[{
     OverscriptBox[
      RowBox[{" ", "z"}], "_"], " ", 
     RowBox[{"\[DifferentialD]", "z"}]}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"-", "\[Pi]"}], " ", "\[ImaginaryI]"}]}]]],
 "   but that   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["\[Integral]", 
     SubscriptBox["C", "2"]], " ", 
    RowBox[{
     OverscriptBox[
      RowBox[{" ", "z"}], "_"], " ", 
     RowBox[{"\[DifferentialD]", "z"}]}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"-", "4"}], " ", "\[ImaginaryI]"}]}]]],
 ",  \n\nwhere ",
 Cell[BoxData[
  SubscriptBox["C", "1"]]],
 " is the semicircular path from ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"-", "1"}], " ", 
   StyleBox["to",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], " ", "1"}]]],
 ", in the upper half plane, and ",
 Cell[BoxData[
  SubscriptBox["C", "2"]]],
 " is the polygonal path from ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"-", "1"}], "  ", 
    StyleBox["to",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]]}], " ", "-", "1", "+", 
   RowBox[{"\[ImaginaryI]", "  ", 
    StyleBox["to",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], 
    StyleBox[
     RowBox[{
      StyleBox[" ",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], " "}]], "1"}], "+", 
   RowBox[{"\[ImaginaryI]", "  ", 
    StyleBox["to",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], 
    StyleBox[
     RowBox[{
      StyleBox[" ",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], " "}]], "1"}]}]]],
 ", respectively, shown in Figure 6.9.  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["\t\t\t",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 Cell[GraphicsData["CompressedBitmap", "\<\
eJztXWvQXdVZ3jm375KQfEFoIAQJSbglKQlgCuGWqVIbdTCtlT8yLWQqmKqQ
FmgTJBDAFNKqDfzQSqvDoHYYmNGMU6wzxRH9YTuOCbFpGahKYy6QQC5fW2qt
t9muZ633WefZe6+9v9spo6Nn5nznnLXf9a7nva7r3t+NG+/ZdNsdG+/5yIc3
Ln7vXRs/uukjH7578U9uvssVtWdl2aw/ybLsjxdnHfc9d1/lz+O5e2XdfM+e
PfkVV1yBsnznzp35q6++mu1quDbmr3XyU6dO5TfccEM+f/58XOv64p6vctNN
N/kquITvzz///BLjiFrghMvg7C5l1/tr2Wz/0fYk9sq6ibJtVkY2+HVLgq6X
KLswUXe+teSE82hxzVA7MXFtyEty++23R174fOKJJ/Jnn302W2o8qST8MpFG
7RJIHbsCLFfVl9eJ9KFE3SERacuWLfhMinSG0EGU8Cv8hc3Iry11qaLz68UZ
SUAaxt8WilJCfDBRg1wAznSaXZCoe6aVQVDYBr9aUhe0qNv2lgqCTUKIYbsE
ONRNYDsamwcrODLMju80u5UPmyFBAnT0dUjpSAlSuLkWEDujnoOASoaLowxO
MubJ0QLI8QZ5Q7VCeLmy0OrphVZBAt9DtSVLlnhWWo2yMxwYqa5Oy+yXItc0
Aau0LKrwG81IBNm1oZhC2AT4gMbp0dGAsmoSwAIt9Q3tuO8tEJrBjZVFWi+y
oCLtMzj/3EajozWgx28oTWiDbocqFqVucXVdra8F7zDzZgF9j24eX1aP/kbT
AZFZGIgDx3lRNbhkmcV/UifkTpOwPLQ9CV31Y9a9DfRQISeWdBkSjCfsWANq
b3y3TFvfwIJoiLJs2o+obHXGVDe1UM0IS3Th38AQVbugzusKUPAb5eVm6syA
7zD+kmJeoqv1faUbjY2XxaQFSDuyR5Zhf0MN5L6nzn2aVh9VTZnpWsBv8Qq3
AwTzr4x9u2RYTwMnilWHU1XzIJtvuZwWNRjAmXmaWUYBq+7RBPQcsn5fQaQ1
/nat5+FQgYTnzNsyvdA0RIvfEMxSaquhhZalGQYMI8Fo2VtT4H7qG4mxxVe9
hYe0fnQeayKmUrUmXuwgwGFdrWcNVbwCbZiTxtEBtFHo7kWm/iApZdjRlNoi
DvA0PXRLLPqq6lVUZVmDrmO+X3An7fZVCkimZdVx2UhMSnwJ/5JrjVS0N1Gc
sn5PtKOiQfvAWcpmwc9Gk37G6qhi5HT8MjqQOmks39A74SlUOcOJw46qzKEv
Az08hEO5ar4ZrbSuHsqYc7zoPOaYYp5hLfMJmRm1ULUTyaaVZ/qRzTzRzysj
MX+rgdN5ph17NOUNq5iDVejVSVM5j4ouZZWkk3NSUZU5jNbMYJ5Pyrj1Oqu6
kdH8RK3/pEQLw3gYsWwOlk0tsxQTsg3RIj0Hin1nSoumqqEccTDSK3QLYoG2
+B1D0HFoC1MIRl+ziG0JtqKbdWJDhQCuppemsFTxmE1THiZmmMDDai2fsnKY
wGXlLi9nQuD4nNMltYxpo+AF1YxSVYdmFBvTZnMMug6TEcR2fWhyklXTRCdW
MU7DCTdMRTin+OUers964kyAF+eatNlUMoG6mfDkrENsUlXGhPFfbSgd/xwi
l8to5ZnEvyk6jn+bhLdrOvAvd+GM8ZZPKm2fHizuYmyge4eD8QU7y6hkEghq
lZWKlRTfpjAXbU/gPoMKc44d2M1w7SmLyi6ymmmkd01L7F77GPqjYVnrKtXr
xPJpjRqKxnTXJ5MOYA/muZmmA2p5+umgOCNMWG0GY4Kp5IQmD59JTrAFp2Dv
lLqnlxh0ZCf5HUorZEwd1puRppwb6s2uwTXVEYAGU7MrDTo12FaBchpoarCV
l8pUBV1D0MhQAQMlL9brab2q6aeeIsDeZR6iwtDERpVJxy2mjdDT6DzE1tma
0FTNXm0CazZ1ZrbfKVvSi8o6Stn2bcggmHRZN5wcacwkg0Dx2ODRUSHbauKh
qrE5QuTB0T/41qkCw3PXjq5/6CzENK2Xtae3Fhlz0mDJs6qxlLLh1LJLV5U0
WTebrCeXMgxXAvou0tUw9J+aDTjZgwvUL1z0Yhl1bhJxxQzWkTFHXArG/Ldr
jHRg6K5zgb6hapxM6i4jr/edZbSw6qz1KLW1wSa57ZIi100k7kZKeWEBDjSl
Van6sCyGkYVDYSiD5hQOdMwNp/7S47zCJpRmba4H68Zc2e4TZZ+EjZl9qq4V
VkpTOw1hFBooYbCJ5zOjWldVFA1rFtDdTjYVWMyZtGZsk52sUIWroKmwRLVS
gpHZT/Sw6NTteAYAS5ShbC4bjVXYKkEjPtgiE5STXXNIXRSrNYMuZkcvqjFP
wgt70Qv5KuSioSYL2Y57zEMcCfb9NowOoSdD398Ls1EJu6eJ8hDqMwvYMjyb
wCX4C5op7nh24mzPJiehyumpKtEEKGMfAROVd1u4CyorWdzniQPGVtAgcsdc
PXahlPHoBPee8ckM5XfcwG62x8dwgDa5b0gnlUSWnNDQB4AdTUeP7UVxVbmu
jFwUIKTnXp5prGXKTJg4KlP3hEvzzLI5mXKqXtSO84iwGYqetHhUIzX4rE87
/USuO5SOtw4V2Adwc7I7FaX0D6aETW3gnl9wBFUEt3r1N0PNNtBpbccLHNtK
V+jXC22GHZde3KjVfk7EbYrRapbpRLextrjrqamx1ulmR47l3JawR3ZRUJPu
CHMZcTTEmWNcv9db7JI/kCjj8ZiJRlzvTSBoWmVg76F7QxONvFPHp5Yn6PRM
k/UfyS5+eVF57HKi8kwcehH3tjVv0Etj6uzEy4byncbJttT8r5FE2VkJ4ZZY
i7rJKKzXJ4A36ZwR2xdmqCKM2sAyddh+mI4hzrTmuWFRamRFkIXaYJ+Sl3IT
Z8A8eAL/10xh+ueQgFlV0z6NYLmqYAQte4fZsNRtLLWWyx2VXf4puywC6GWq
X9eGe6J+nbFX1O/AcFZviWlJGiP1LyksW2AqIW4ZCVL5o1KNO/7qL1S+bofw
pAz7Ln+oKqx/sx8C8d8lWOtIiLYOZf28x91RPXikv5Gyfy+g91Lt/r/zfaH/
6Bb6VagNWfRjdk229+O52V9tuPZrDTwvCc2eY1bT2L7HyjQH3Jkouy9Rd/n/
Rrbz8OFHjqXzTXgZ/ccTLDeWWAYG4a/OfEIrvl7qfOzbr7N3Wdm6det82Qsv
vJBdM8mmrrMyV8eXb9++Pdb9/+b/ZzV/tv/oxIG7pfUrEwjWGinPY1mrd6SL
r0/gWJtubEVRE2DEkWpKE1dbGQ+Soo+/M1GWQnBNog3TxM8nmjqRYLHp7SA/
DR+tfHx8/D2Jij9rZQcOHMjtld2YKPuZRAMbEnRh5GN3VnTyffv25bfccks+
b948kHHoNf5v/5HvPngyf3T/kXz7vkP5rpdez7/65nfXJgBeZVX2nfyeJwM5
qqG6YzMWpHM1XL0nn3wyAllvCADOgc3PO+88XB9tQOCaSLn8Wqny9LeOe3K8
P/vKUVTh3SlsZNeuXVB2GLPGAagr8fBWrVrlBmTI2m1fg3A5T0Ejhgk83d+2
x0m6lBczwkBn4MDd/wUv8ATFXBMEKrEexBtm8+bNKJttl3XlHy875f9j/nI3
3717d75hw4bIAaofnSR6xpuq9yorO/r9f6/U/fMj47HuaTSD0yT0zPbhXo4f
j+HUoJ8VzMHlcqgAgphvts0i4Av+QdKqVruGC1iJa03CIrQS6Mp1VR9zjQ6e
wD6d3uE8xfuSC6HCBkR5JspRNBYTVpl4kAE6hmWdeB1jqYFKx5xIPMZkymQS
DbGuOZuYrO01XRaPoQJ1EUtFvFmQbhbEm+XlMwN6MKgMP3SMwlq5Y7By5Upv
B/hk15LCvX/zSgXkhx55PNKtMbqxsTEPcvXq1c5+oQx0rNvD3zG7cO211+bD
wxzF4W/HM4QhIa0zAJfAOG2RU4v4vcJMhQyJxABPdCanJIsXL44IR/B3OAF9
raFxkD1rV8nZRoh/4f5HI/HckpyZ12aAPmfOnPzmm2/2QJyTdC0AEtCzWX5v
iOnLnD6bj79sdd2mu2MLd5o8KCto8hxxcwvhmAS5jIZV+JVWRnM7d87OrGvt
nroLZ4nXgYsTNAa4thaCKmuLcdCwGadrXNavX+9dEJi7/m87f2TPtypu9odf
3Rfp1hgdbfXYY485NwtloCvXBT/WnWt0rk6UqG0GRAKn54HeeV6MJ12SuFQy
H8yM1CAiLVu2LDY3MkmR1pZg3Xrrrc79QtlDew9W6j79lb2x7mlG99xzz3nv
C34Y/kJFjle+Y8eOfP/+/akFFkvnzIsQynJdxlyOlpiI6FhujBFRsY9Bn/Ov
//lfniLVu7IMNOyfKNELR79dyuU979Dsm/CGu7mUwFwoG1HZ5VaGdA03Qyoj
fPwu52o01wS/qXtN1cWgh3UD/CHv6gof4sBf4FcpGcwSo6ZnkFJ7Pp1Ve5mW
ILeeJjlJYJkODDisqXaiXa8x1EWMIxqcU9i1TtzrsJPRa6wKFEWBEUgQcnSS
kDn+rw4VJ647V9rXURj6+nlpyKbnOSWP748OuvmBt36Q//4/vJFv23vIvQ/C
tFn9kLrrTf/sgRNGfwj17dbkttcKOjL8mmeuAURIljz7ARewTbw4CqIrI8HO
Flxs44uHT3lcqYH21UL/m19/3dM/9Y9vePoxozfe/teY0SdwObfEtoatXLbz
l7/9/WgQRkl1QtqPEmesbJmVkX3/TESbC1v+l99Po5WBnY55bUJGes2TTi40
5Bqsb2iWF8WE6HjenHw4naRMW5bDNZNtnik+m9UShgxqwa4JBrkMEsZZygd2
JZ/6hYY+HzehGCwQy6K8VKsMtqc9xh0DBsJLbljeEPcdP0QXAw5aH5i02ZS6
EYbEJCANFkbHLxhItFxVi6QY9R8dMIxStDTB0GgZFIyz7RLXOXCpCQPotr0Y
6AaNgdNFyJfCcKWozPcXL3qVDRZGRweBcIymoceXDo/7nhRtf2zAMDQKXSg0
wfjk147EwB4UjIV2idnLDVmSGfRdBnf/qX/xdDCKC61Bw2DSQAg2wfj0/tcM
xkFocLAwitHqpEzNB9Yk3GjH147cNSAkYem6F+2CoMELgzWH6IoEIq7M6fgA
7y+8ejwbLKyi1E7/LfhNChPLdEWQMD7vxqiEMajgpto0qv7URuGOPAWRsy9o
Fmu5Or9AC4OGuMjMxDT4wL6DsZ9swqerbD9MfEzTYFGY6KbAXebLhn0vC17o
QndabD5ifY1T6rTc77MvH43YOO7nnWm6hCjPLslODzIwnSCOLYLibFdXJlfX
umyvMHD42zffom9MS5TPvBRU4jqS+NQnPXmGT2yen6FeHFzSLBRNrk02wWfi
wCde4OW+Tws+LfnMgeOm4eJxQNvkONckk2mvf3/5tfHoxVXPLg7R3HdOrtRQ
d1gZSLlUUZbCXWuU4sF9h30TT3zzWOGcCnbu+mfo+8f6RLIfNaROkojUuXlK
qMuM1PTNCLjbSLnZ5Lr6KMBX3viu9y4MiFICXG0soRB0eGDpJsbDVsw7ju2c
K08s6tPH9JEVPDtjvnaeccFMm6Id/N4PLmsQTdaQoHyKprscFA3DBDNrg2hd
359QNIz5nKjx3JDeHlY+eqlHJ/WZYyXh/FDS2P/OK8dSwq0WJVM4Z5CPWzhZ
9Mc3BHN2bFq/gPVVJuQxysSDzoEyNMEnk/Blh+/NBRcbPoyQwBUAnBOlUgBF
YXK3zT+Kon03RXFcm/Y8OaRQcZx4lAbk3PvumUxy1M6vDuFsdkGUsPD0G994
jbr0CzyrEvJwO0uBO2V+wtoDm7I8Ttx6eYZihlJ5zJsL9xhRqCFDwCPUdmrX
5DnfrvoFrhcDV9dbp0Th8rssZsK1tlqxZs7ffvlo6rxBmDENF6TeYRMDfjo2
XooW8kJAF8/5cYRtUXlpA0j1eQeYIDVdf/HQqXqQI95iCAPM8emNyKEEAYtz
UZ5dOw6KLVbM3UIutfXTeAZTgb8zoUYH4d5EaLuc2wQcprR+RsdI/jdsh/xE
4FyhRX4y4EsNuM4jbJU97mQp8JUJ1ToPui8YcfpDOj33yuPRekcy+YU1PVuB
LMJw7FKIVzRIOGPY3Orh7SL6hBee9MavsLhit+cVze6+r0jAXi6wGX/0qG0z
hT1qoYlEztP2fO4Xj0I6CxjqCw01OeDt4mJ5AvUlEgcalBhE3D9T1HMMB58Y
ZF2Qv5ehALXaPnr1SxJ4L26gf2CmeG2aclFDGxcnMNXRg+X2AWGi3DLbjZgu
SmCq0ysWYR4cECb6jkyFYhsXJjBd0ED/0IAwhY9eSm6ULUvAWpYIXHJ9eECw
VtTAwndXtjQBi4leMyYt/usDgrVSYGmKgxoc2yUJWOw4++OcQ3HWsWNAsC61
NnQ2QJLzE5gWmxiw4G99IwyNMe76VEi/nxwQrFXWDIYc6igwomuG3YhOLs9O
oA1z2WFPB+P+rqt+vx1mgDaxweoM8siAUK8WWJzxB7Zd3SvyUiESFyYg8/YM
8AAd6mHRCNNKnlQA9L8+9h1P+eiAsF9e4whY0Gr5IXVboztuEFWxt+N5zO08
H+TKHnJ1/znAy3YOCLOuS5b1rR2yhX7Ep5h1oezxl4oLh1gDKx6p6MSb7ewJ
pVsGJAoPMcBL1eG37T0Yp+Emhqc8MyGKbpYx6bvYZHXMK3h61E7aurHN1gEJ
wDV9AIQPPRzAU5WfcTNENn5GAjvlsZVx73ahbseZoa8Ph/D0HxL20LhNamKs
PeAS3J8dHvf+8yMJ4CxDQkRd7Hm0jYOdQ44x1R9etrlY2L/veqASxRMcTuVc
Dh+Ovn3YnxRBNzI/IdGY1MXUz9W3ZdeebwoS8WXZKQz1h+I9uVjI4g3kPFTS
GbiQajawCUkKf2fnr7jUCSGx26brA+xDkVIhCKaApyWUwDLwhZBQgh765eEf
9kRI1YxNvfHWnnGc6d37hWfBeY1ssejX5QA3Kffo6henOvFwDeifOXDc9LLO
rtIlP/31IwjFjoUTvBIiwLaOwUhCei5KaifkDMBcTi/Qszw8Vor5Mw9my3M0
o6ifMFepJDpZY1wUqNFFFs8vc0lddcFOFAxhVbj1OWYHWXoveIFl0jDSz368
FMKw9ZCJCojgACwtW/yDRszf8iuvu94jefpLX2YvCb1CYSBuofKQKb7kd8wc
envnsGjTbi6P94/Jwod1CZ2oNUuN3DjT+bzd2QB5FybUd465HofK8A6gh+ud
ZWrU8Wp5sc3JZ2p8jzgNGjRVzjZNnnvZGt/oBz/3jEuCRY2gQQd/QYNG9A4e
akRWwfoa2XvQlu8O5Z//5rFF3ijDvhUW4/3w3x/On/qnN/O/Ovod7IYvMNs5
M/qW79x6n9NMKMPCvlVzreBvG5x9gO458ZbrzgIdUk6RrlvQ1PawAMfb839a
bMUYg6LhbU5tnYTaQr8yFJ2Se3UWyT4eGSJ8Bg2eOPJgKYeCy7uNv+Pr6a67
bbNLNdRhwasMcOpWpQvEOijDOT22pludg2mNM11EBp+ZtF3Cn62lTvQuTPgy
51/wI5jAeS5dsBoibd2Sj2MyCAn1w7Acw8iEO3my1x4Ac6PojndUdxqk5ppZ
fK6Gvwv/XrsqU904ftUBI+8S1nMFlseTaZV5QXcgi3mheBCTgsrooCwowpd3
hKQE5eIK//ECXFfXlXlKeat1IRxq6hIgpyeLxAlhXsA+t6H3gA1RF73HIotM
qKq8guCuX6JSdeJ9LmbGdkKwi8335L9TFJ5gb5HzFwl8m4oq5Co1Ro0pFa6I
fpH1t9SxXtzAm3cN6kHwlBQNtyWShW0RzYSFnP2dKgtaRP+TSI1F/jIReysS
nDk04H+5wa+lRcA6kE819QULpNRt9voQFgaNPjWR0ZKCxiXB1C36I8EN3E99
QpT9UxIKkMqwTws5faEeZMX5lydwpp4BMlrBByb2vCji4x2pfBoVfrVmjLkY
QynFTg6wunoJMHcKZgqYQx8NzOlrWAOrwQM+V2Lm3hM9mYCK5aM/QMxbkXR/
iglLVTdZecrHCCIsfZAKrToAB9e7GKm1qeuenNWCS2YOjtFXSnTT9w1Z1Bqk
8jQ1Tl95+qgYU977jBQ3zgAgbu3DS8D633a73x814FYHvdyu4H4Z3rIleP1v
NIVmxsfHU/86z+A7qcMSdvZ+/zESoYEPbjjFd9xrxzvMdu/enaVwvkO0wCx4
ofHkrbjgwfv2tm7d6u8lwvcNGzbEQZWC5CCXTzfDr/MVbrj1y+IM98bqPdXU
1lNGWnrAA5lrFuS2nd7qjffY2Fg8AKj3+y8VB5cHQnDcaf9PTnH/nF3CzVfM
DwRN04HiD8Q1OZ18t5Vtlxu3WRf8WJf21odEXFNsnppXFnqj9utGJ3ftRzrU
Jd0vFtkqOfWFWxFJfszo5Fb+SKfNG9sPmDnok3zDB9+0a+oAeDva7Je0etFH
nJ78yIzCqDVvK1ZDBAnXE1asYBxma4tpiHZF2uAQkPbCjaKTeJwGowWSlMjJ
CbcMkhw3v7HFEjk4Iebw66SVwbUt7WQl7OCElKLk+M2HExg5h81MXvhFMExw
Qu5/TPBoqPdZdY49MWE+mSj7FSUPT6vjf7Nzl0+ki39ZzVpMpCcTZZuK5Axt
Jdeyksr1346eTJSVVM7hrpJrWcmTS7fzn0gXlypxgI6XQ30iXVyo1PXjHn2g
Mua4xxuuBbgxEXCdRW9flCdIxkQwEZ0lgvfbJWjRFlUiOR8jp2wnorutyBYu
hsuKQnvzY5OkM7Ye+oAfnpbN+m+Eup2b\
\>"], "Graphics",
  ImageSize->{430, 173},
  ImageMargins->0],
 StyleBox["\n\t\t\t",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Figure 6.9",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/contourintegral/\
ContourIntegralMod/Images/mat0609.gif"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 "  The two contours ",
 Cell[BoxData[
  SubscriptBox["C", "1"]]],
 " and ",
 Cell[BoxData[
  SubscriptBox["C", "2"]]],
 " joining  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"-", "1"}], "  ", 
   StyleBox["to",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "  ", "1"}]]],
 ".  "
}], "Text",
 CellChangeTimes->{{3.3992951936875*^9, 3.399295205890625*^9}, {
  3.399308317140625*^9, 3.399308320046875*^9}}],

Cell[TextData[{
 "Solution.  We parametrize the semicircle ",
 Cell[BoxData[
  SubscriptBox["C", "1"]]],
 " as \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["C", "1"], ":", " ", 
    RowBox[{"z", 
     RowBox[{"(", "t", ")"}]}]}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", " ", "cos"}], " ", "t"}], "+", 
    RowBox[{"\[ImaginaryI]", " ", "sin", " ", "t"}]}]}]]],
 "   and   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[DifferentialD]", "z"}], "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"sin", " ", "t"}], "+", 
      RowBox[{"\[ImaginaryI]", " ", "cos", " ", "t"}]}], ")"}], 
    RowBox[{"\[DifferentialD]", "t"}]}]}]]],
 ",  \n\nfor  ",
 Cell[BoxData[
  RowBox[{"0", "\[LessEqual]", "t", "\[LessEqual]", "\[Pi]"}]]],
 ".  \n\nApplying Theorem 6.1, we have  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   OverscriptBox[
    RowBox[{" ", "z"}], "_"]}]]],
 ",  so  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", 
      RowBox[{"z", 
       RowBox[{"(", "t", ")"}]}], ")"}]}], " ", "=", " ", 
    RowBox[{
     OverscriptBox[
      RowBox[{" ", 
       RowBox[{"z", 
        RowBox[{"(", "t", ")"}]}]}], "_"], "  ", "=", "  ", 
     OverscriptBox[
      RowBox[{" ", 
       RowBox[{
        RowBox[{
         RowBox[{"-", " ", "cos"}], " ", "t"}], "+", 
        RowBox[{"\[ImaginaryI]", " ", "sin", " ", "t"}]}]}], "_"]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                   ", 
   RowBox[{"=", 
    RowBox[{
     RowBox[{
      RowBox[{"-", " ", "cos"}], " ", "t"}], " ", "-", " ", 
     RowBox[{"\[ImaginaryI]", " ", "sin", " ", "t"}]}]}]}]}]],
 "    \n\t\t\t\n\t\t\tand \n\t\t\t\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["\[Integral]", 
      SubscriptBox["C", "1"]], " ", 
     RowBox[{
      OverscriptBox[
       RowBox[{" ", "z"}], "_"], " ", 
      RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "=", "  ", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", "0", "\[Pi]"], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", " ", "cos"}], " ", "t"}], "-", 
        RowBox[{"\[ImaginaryI]", " ", "sin", " ", "t"}]}], ")"}], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"sin", " ", "t"}], "+", 
        RowBox[{"\[ImaginaryI]", " ", "cos", " ", "t"}]}], ")"}], 
      RowBox[{"\[DifferentialD]", "t"}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                  ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", "\[Pi]"], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", " ", "\[ImaginaryI]"}], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["cos", "2"], "t"}], "+", 
           RowBox[{
            SuperscriptBox["sin", "2"], "t"}]}], ")"}]}], ")"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], " ", 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                  ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{
      RowBox[{"-", " ", "\[ImaginaryI]"}], 
      RowBox[{
       SubsuperscriptBox["\[Integral]", "0", "\[Pi]"], 
       RowBox[{
        RowBox[{"(", "1", ")"}], 
        RowBox[{"\[DifferentialD]", "t"}]}]}]}], "  ", "=", "  ", 
     RowBox[{
      RowBox[{"-", " ", "\[Pi]"}], " ", "\[ImaginaryI]", " "}]}]}]}]}]],
 "  "
}], "Text"],

Cell[TextData[{
 "We parametrize ",
 Cell[BoxData[
  SubscriptBox["C", "2"]]],
 " in three parts, one for each line segment:\n\n\t\t\t",
 Cell[BoxData[GridBox[{
    {
     RowBox[{
      RowBox[{
       RowBox[{
        SubscriptBox["z", "1"], 
        RowBox[{"(", "t", ")"}]}], " ", "=", " ", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"\[ImaginaryI]", " ", "t"}]}]}], 
      StyleBox[",",
       FontFamily->"Times New Roman"], 
      StyleBox["             ",
       FontFamily->"Times New Roman"]}], 
     RowBox[{
      RowBox[{
       RowBox[{"\[DifferentialD]", "z"}], "=", 
       RowBox[{"\[ImaginaryI]", 
        RowBox[{"\[DifferentialD]", "t"}]}]}], 
      StyleBox[",",
       FontFamily->"Times New Roman"], 
      StyleBox["     ",
       FontFamily->"Times New Roman"]}], 
     StyleBox["and",
      FontFamily->"Times New Roman"], 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"f", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["z", "1"], 
           RowBox[{"(", "t", ")"}]}], ")"}]}], " ", "=", " ", 
        RowBox[{
         RowBox[{"-", "1"}], "-", 
         RowBox[{"\[ImaginaryI]", " ", "t"}]}]}], 
       StyleBox[";",
        FontFamily->"Times New Roman"]}], 
      StyleBox["             ",
       FontFamily->"Times New Roman"]}]},
    {
     RowBox[{
      RowBox[{
       RowBox[{
        SubscriptBox["z", "2"], 
        RowBox[{"(", "t", ")"}]}], " ", "=", " ", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"2", "t"}], "+", "\[ImaginaryI]"}]}], 
      StyleBox[",",
       FontFamily->"Times New Roman"], 
      StyleBox["   ",
       FontFamily->"Times New Roman"]}], 
     RowBox[{
      RowBox[{
       RowBox[{"\[DifferentialD]", "z"}], "=", 
       RowBox[{"2", 
        RowBox[{"\[DifferentialD]", "t"}]}]}], 
      StyleBox[",",
       FontFamily->"Times New Roman"], 
      StyleBox["     ",
       FontFamily->"Times New Roman"]}], 
     StyleBox["and",
      FontFamily->"Times New Roman"], 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"f", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["z", "2"], 
           RowBox[{"(", "t", ")"}]}], ")"}]}], " ", "=", " ", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"2", "t"}], "-", "\[ImaginaryI]"}]}], 
       StyleBox[";",
        FontFamily->"Times New Roman"]}], "  "}]},
    {
     RowBox[{
      RowBox[{
       RowBox[{
        SubscriptBox["z", "3"], 
        RowBox[{"(", "t", ")"}]}], " ", "=", " ", 
       RowBox[{"1", "+", 
        RowBox[{"\[ImaginaryI]", 
         RowBox[{"(", 
          RowBox[{"1", "-", "t"}], ")"}]}]}]}], 
      StyleBox[",",
       FontFamily->"Times New Roman"]}], 
     RowBox[{
      RowBox[{
       RowBox[{"\[DifferentialD]", "z"}], "=", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], 
        RowBox[{"\[DifferentialD]", "t"}]}]}], 
      StyleBox[",",
       FontFamily->"Times New Roman"], 
      StyleBox[" ",
       FontFamily->"Times New Roman"]}], 
     StyleBox["and",
      FontFamily->"Times New Roman"], 
     RowBox[{
      RowBox[{
       RowBox[{"f", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["z", "3"], 
          RowBox[{"(", "t", ")"}]}], ")"}]}], " ", "=", " ", 
       RowBox[{"1", "-", 
        RowBox[{"\[ImaginaryI]", 
         RowBox[{"(", 
          RowBox[{"1", "-", "t"}], ")"}]}]}]}], 
      StyleBox[",",
       FontFamily->"Times New Roman"]}]}
   }]]],
 "  \n\nwhere  ",
 Cell[BoxData[
  RowBox[{"0", "\[LessEqual]", "t", "\[LessEqual]", "1"}]]],
 "  in each case.  Integrating over these three line segments we obtain  \n\n\
\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[Integral]", "0", "1"], " ", 
    RowBox[{
     SubscriptBox["z", "1"], 
     RowBox[{"(", "t", ")"}], 
     SubsuperscriptBox["z", "1", "'"], 
     RowBox[{"(", "t", ")"}], 
     RowBox[{"\[DifferentialD]", "t"}]}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     SubsuperscriptBox["\[Integral]", "0", "1"], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "-", 
        RowBox[{"\[ImaginaryI]", " ", "t"}]}], ")"}], 
      RowBox[{"(", "\[ImaginaryI]", ")"}], 
      RowBox[{"\[DifferentialD]", "t"}]}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", "1"], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"t", "-", "\[ImaginaryI]"}], ")"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}], " ", "=", " ", 
     RowBox[{
      FractionBox["1", "2"], "-", "\[ImaginaryI]"}]}]}]}]]],
 ", \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[Integral]", "0", "1"], " ", 
    RowBox[{
     SubscriptBox["z", "2"], 
     RowBox[{"(", "t", ")"}], 
     SubsuperscriptBox["z", "2", "'"], 
     RowBox[{"(", "t", ")"}], 
     RowBox[{"\[DifferentialD]", "t"}]}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     SubsuperscriptBox["\[Integral]", "0", "1"], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"2", "t"}], "-", "\[ImaginaryI]"}], ")"}], 
      RowBox[{"(", "2", ")"}], 
      RowBox[{"\[DifferentialD]", "t"}]}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", "1"], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "2"}], "+", 
         RowBox[{"4", " ", "t"}], "-", 
         RowBox[{"2", " ", "\[ImaginaryI]"}]}], ")"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}], " ", "=", " ", 
     RowBox[{
      RowBox[{"-", "2"}], " ", "\[ImaginaryI]"}]}]}]}]]],
 ", \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[Integral]", "0", "1"], " ", 
    RowBox[{
     SubscriptBox["z", "3"], 
     RowBox[{"(", "t", ")"}], 
     SubsuperscriptBox["z", "3", "'"], 
     RowBox[{"(", "t", ")"}], 
     RowBox[{"\[DifferentialD]", "t"}]}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     SubsuperscriptBox["\[Integral]", "0", "1"], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"\[ImaginaryI]", 
         RowBox[{"(", 
          RowBox[{"1", "-", "t"}], ")"}]}]}], ")"}], 
      RowBox[{"(", 
       RowBox[{"-", "\[ImaginaryI]"}], ")"}], 
      RowBox[{"\[DifferentialD]", "t"}]}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", "1"], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "t", "-", "\[ImaginaryI]"}], ")"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}], " ", "=", " ", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "2"]}], "-", "\[ImaginaryI]"}]}]}]}]]],
 ". \n\nWe get our answer by adding the three integrals along the three \
segments:  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["\[Integral]", 
      SubscriptBox["C", "2"]], " ", 
     RowBox[{
      OverscriptBox[
       RowBox[{" ", "z"}], "_"], " ", 
      RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", "1"], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"t", "-", "\[ImaginaryI]"}], ")"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}], "+", " ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", "1"], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "2"}], "+", 
         RowBox[{"4", " ", "t"}], "-", 
         RowBox[{"2", " ", "\[ImaginaryI]"}]}], ")"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}], " ", "+", "  ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", "1"], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "t", "-", "\[ImaginaryI]"}], ")"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                  ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], "-", "\[ImaginaryI]", "  ", "-", "  ", 
      RowBox[{"2", " ", "\[ImaginaryI]"}], "  ", "-", 
      FractionBox["1", "2"], "-", "\[ImaginaryI]"}], "   ", "=", "  ", 
     RowBox[{
      RowBox[{"-", " ", "4"}], " ", "\[ImaginaryI]"}]}]}]}]}]],
 "  \n\nNote that the value of the contour integral along ",
 Cell[BoxData[
  SubscriptBox["C", "1"]]],
 " isn't the same as the value of the contour integral along ",
 Cell[BoxData[
  SubscriptBox["C", "2"]]],
 ", although both integrals have the same initial and terminal points."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Explore ",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 StyleBox["Solution 6.10 (a)",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]
}], "Text"],

Cell[TextData[{
 StyleBox["(a)",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Use the semicircular path from -1 to 1 in the upper half plane,  set up \
the parameterization and compute the contour integral.  Enter the function  \
",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   OverscriptBox[
    RowBox[{" ", "z"}], "_"]}]],
  AspectRatioFixed->True],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "f", ",", "t", ",", "u", ",", "v", ",", "w", ",", "W", ",", "W1", ",", 
      "z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"Conjugate", "[", "z", "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<   f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[x+\[ImaginaryI]y] = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", "+", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"TagSet", "[", 
     RowBox[{"t", ",", 
      RowBox[{"Im", "[", "t", "]"}], ",", "0"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"z", "[", "t_", "]"}], " ", "=", "  ", 
     RowBox[{
      RowBox[{"-", " ", 
       RowBox[{"Cos", "[", "t", "]"}]}], " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"Sin", "[", "t", "]"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"w", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{
       RowBox[{"f", "[", 
        RowBox[{"z", "[", "t", "]"}], "]"}], " ", 
       RowBox[{
        RowBox[{"z", "'"}], "[", "t", "]"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"u", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"Re", "[", 
       RowBox[{"w", "[", "t", "]"}], "]"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"v", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"Im", "[", 
       RowBox[{"w", "[", "t", "]"}], "]"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<   f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[x+\[ImaginaryI]y] = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", "+", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<   z[t] = \>\"", ",", 
      RowBox[{"z", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z[t]] = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"f", "[", 
        RowBox[{"z", "[", "t", "]"}], "]"}], "]"}]}], "]"}], ";"}], " ", "\n",
    
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  z'[t] = \>\"", ",", 
      RowBox[{
       RowBox[{"z", "'"}], "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w[t] = f[z[t]] z'[t] = \>\"", ",", 
      RowBox[{"w", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"w", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"Simplify", "[", 
      RowBox[{"w", "[", "t", "]"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w[t] = f[z[t]] z'[t] = \>\"", ",", 
      RowBox[{"w", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399288486890625*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Method.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  The integral can be computed using a complex integrand."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"W", "[", "t_", "]"}], " ", "=", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"w", "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"W1", " ", "=", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", "\[Pi]"], 
      RowBox[{
       RowBox[{"w", "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<W[t] = \[Integral]w[t]\[DifferentialD]t = \>\"", ",", 
      RowBox[{"W", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<W[\[Pi]] = \>\"", ",", 
      RowBox[{"W", "[", "\[Pi]", "]"}], ",", "\"\<,  W[0] = \>\"", ",", 
      RowBox[{"W", "[", "0", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(0\), \(\[Pi]\)]\)w[t]\
\[DifferentialD]t = W[\[Pi]]-W[0] = \>\"", ",", 
      RowBox[{
       RowBox[{"W", "[", "\[Pi]", "]"}], "-", 
       RowBox[{"W", "[", "0", "]"}]}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(0\), \(\[Pi]\)]\)w[t]\
\[DifferentialD]t = \>\"", ",", "W1"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"V", "[", "t_", "]"}], "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Re", "[", 
         RowBox[{"z", "[", "t", "]"}], "]"}], ",", 
        RowBox[{"Im", "[", 
         RowBox[{"z", "[", "t", "]"}], "]"}]}], "}"}], "]"}]}], ";"}], " ", 
   "\n", 
   RowBox[{"ParametricPlot", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{"V", "[", "t", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.03"}], ",", "1.03"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["1", "2"]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "1", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Magenta"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(\[Integral]\), SubscriptBox[\(C\), \(1\)]]\) \
\>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\< \[DifferentialD]z = \>\"", ",",
       "W1"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(C\), \(1\)]\): z[t] = \>\"", ",", 
      RowBox[{"z", "[", "t", "]"}], ",", 
      "\"\<,  for  0 \[LessEqual] t \[LessEqual] \[Pi].\>\""}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399288490421875*^9, 3.399288513640625*^9}, {
  3.399881660390625*^9, 3.399881660578125*^9}, {3.399882396640625*^9, 
  3.399882425390625*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Explore ",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 StyleBox["Solution 6.10 (b)",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]
}], "Text"],

Cell[TextData[{
 StyleBox["(b)",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Use the polygonal path from -1 to -1+i to 1+i to 1,  set up the \
parameterization and compute the contour integral. First, find a \
parameterization of the polygonal path  ",
 Cell[BoxData[
  SubscriptBox["C", "1"]]],
 "  from -1 to 1 consisting of the three line segments:\nLine segment 1 from \
-1 to -1+i,\nLine segment 2 from -1+i to 1+i,\nLine segment 3 from 1+i to 1."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "t", ",", "V1", ",", "V2", ",", "V3", ",", "x0", ",", "x1", ",", "y0", 
      ",", "y1", ",", "z1", ",", "Z", ",", "Z1"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"z0", " ", "=", " ", 
     RowBox[{"-", " ", "1"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"z1", " ", "=", " ", 
     RowBox[{
      RowBox[{"-", " ", "1"}], " ", "+", " ", "\[ImaginaryI]"}]}], ";"}], " ",
    "\n", 
   RowBox[{
    RowBox[{"x0", " ", "=", " ", 
     RowBox[{"Re", "[", "z0", "]"}]}], ";", " ", 
    RowBox[{"y0", " ", "=", " ", 
     RowBox[{"Im", "[", "z0", "]"}]}], ";", " ", 
    RowBox[{"x1", " ", "=", " ", 
     RowBox[{"Re", "[", "z1", "]"}]}], ";", " ", 
    RowBox[{"y1", " ", "=", " ", 
     RowBox[{"Im", "[", "z1", "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"Z1", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"x0", " ", "+", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"x1", "-", "x0"}], ")"}], "t"}], " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", 
       RowBox[{"(", 
        RowBox[{"y0", " ", "+", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"y1", "-", "y0"}], ")"}], "t"}]}], ")"}]}]}]}], ";"}], " ",
    "\n", 
   RowBox[{
    RowBox[{"z0", " ", "=", " ", 
     RowBox[{
      RowBox[{"-", " ", "1"}], " ", "+", " ", "\[ImaginaryI]"}]}], ";"}], " ",
    "\n", 
   RowBox[{
    RowBox[{"z1", " ", "=", " ", 
     RowBox[{"1", " ", "+", " ", "\[ImaginaryI]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"x0", " ", "=", " ", 
     RowBox[{"Re", "[", "z0", "]"}]}], ";", " ", 
    RowBox[{"y0", " ", "=", " ", 
     RowBox[{"Im", "[", "z0", "]"}]}], ";", " ", 
    RowBox[{"x1", " ", "=", " ", 
     RowBox[{"Re", "[", "z1", "]"}]}], ";", " ", 
    RowBox[{"y1", " ", "=", " ", 
     RowBox[{"Im", "[", "z1", "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"Z2", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"x0", " ", "+", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"x1", "-", "x0"}], ")"}], "t"}], " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", 
       RowBox[{"(", 
        RowBox[{"y0", " ", "+", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"y1", "-", "y0"}], ")"}], "t"}]}], ")"}]}]}]}], ";"}], " ",
    "\n", 
   RowBox[{
    RowBox[{"z0", " ", "=", " ", 
     RowBox[{"1", " ", "+", " ", "\[ImaginaryI]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"z1", " ", "=", " ", "1"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"x0", " ", "=", " ", 
     RowBox[{"Re", "[", "z0", "]"}]}], ";", " ", 
    RowBox[{"y0", " ", "=", " ", 
     RowBox[{"Im", "[", "z0", "]"}]}], ";", " ", 
    RowBox[{"x1", " ", "=", " ", 
     RowBox[{"Re", "[", "z1", "]"}]}], ";", " ", 
    RowBox[{"y1", " ", "=", " ", 
     RowBox[{"Im", "[", "z1", "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"Z3", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"x0", " ", "+", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"x1", "-", "x0"}], ")"}], "t"}], " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", 
       RowBox[{"(", 
        RowBox[{"y0", " ", "+", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"y1", "-", "y0"}], ")"}], "t"}]}], ")"}]}]}]}], ";"}], " ",
    "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(Z\), \(1\)]\)[t] = \>\"", ",", 
      RowBox[{"Z1", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(Z\), \(2\)]\)[t] = \>\"", ",", 
      RowBox[{"Z2", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(Z\), \(3\)]\)[t] = \>\"", ",", 
      RowBox[{"Z3", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399288526125*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Method.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  The integral can be computed using a three complex integrands."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Wset", " ", "=", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"f", "[", 
         RowBox[{"Z1", "[", "t", "]"}], "]"}], 
        RowBox[{
         RowBox[{"Z1", "'"}], "[", "t", "]"}]}], ",", 
       RowBox[{
        RowBox[{"f", "[", 
         RowBox[{"Z2", "[", "t", "]"}], "]"}], 
        RowBox[{
         RowBox[{"Z2", "'"}], "[", "t", "]"}]}], ",", 
       RowBox[{
        RowBox[{"f", "[", 
         RowBox[{"Z3", "[", "t", "]"}], "]"}], 
        RowBox[{
         RowBox[{"Z3", "'"}], "[", "t", "]"}]}]}], "}"}]}], ";"}], " ", "\n", 
   
   RowBox[{
    RowBox[{"funset", " ", "=", " ", 
     RowBox[{"MapAll", "[", 
      RowBox[{"ComplexExpand", ",", "Wset"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Wint", " ", "=", 
     RowBox[{"\[Integral]", 
      RowBox[{"funset", 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"val", " ", "=", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", "1"], 
      RowBox[{"funset", 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"val2", " ", "=", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{"val", " ", ",", 
       RowBox[{"List", "\[Rule]", "Plus"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<{\!\(\*SubscriptBox[\(w\), \(1\)]\)[t],\!\(\*SubscriptBox[\(w\), \
\(2\)]\)[t],\!\(\*SubscriptBox[\(w\), \(3\)]\)[t]}\>\"", "]"}], " ", ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<= {f[\!\(\*SubscriptBox[\(Z\), \
\(1\)]\)[t]]\!\(\*SubscriptBox[\(Z\), \
\(1\)]\)'[t],f[\!\(\*SubscriptBox[\(Z\), \
\(2\)]\)[t]]\!\(\*SubscriptBox[\(Z\), \
\(2\)]\)'[t],f[\!\(\*SubscriptBox[\(Z\), \
\(3\)]\)[t]]\!\(\*SubscriptBox[\(Z\), \(3\)]\)'[t]}\>\"", "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<= \>\"", ",", "funset"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\[Integral]{\!\(\*SubscriptBox[\(w\), \
\(1\)]\)[t],\!\(\*SubscriptBox[\(w\), \(2\)]\)[t],\!\(\*SubscriptBox[\(w\), \
\(3\)]\)[t]}\[DifferentialD]t = \>\"", " ", ",", "Wint"}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(0\), \
\(1\)]\){\!\(\*SubscriptBox[\(w\), \(1\)]\)[t],\!\(\*SubscriptBox[\(w\), \
\(2\)]\)[t],\!\(\*SubscriptBox[\(w\), \(3\)]\)[t]}\[DifferentialD]t = \>\"", 
      ",", "val"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(0\), \(1\)]\)w[t]\
\[DifferentialD]t =\!\(\*SubsuperscriptBox[\(\[Integral]\), \(0\), \(1\)]\)\!\
\(\*SubscriptBox[\(w\), \(1\)]\)[t]\[DifferentialD]t \
+\!\(\*SubsuperscriptBox[\(\[Integral]\), \(0\), \
\(1\)]\)\!\(\*SubscriptBox[\(w\), \(2\)]\)[t]\[DifferentialD]t \
+\!\(\*SubsuperscriptBox[\(\[Integral]\), \(0\), \
\(1\)]\)\!\(\*SubscriptBox[\(w\), \(3\)]\)[t]\[DifferentialD]t\>\"", "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(0\), \(1\)]\)w[t]\
\[DifferentialD]t = (\>\"", ",", 
      SubscriptBox["val", 
       RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], ",", 
      "\"\<) + (\>\"", ",", 
      SubscriptBox["val", 
       RowBox[{"\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]], ",", 
      "\"\<) + (\>\"", ",", 
      SubscriptBox["val", 
       RowBox[{"\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}]], ",", 
      "\"\<)\>\""}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(0\), \(1\)]\)w[t]\
\[DifferentialD]t = \>\"", ",", "val2"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"V1", "[", "t_", "]"}], "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Re", "[", 
         RowBox[{"Z1", "[", "t", "]"}], "]"}], ",", 
        RowBox[{"Im", "[", 
         RowBox[{"Z1", "[", "t", "]"}], "]"}]}], "}"}], "]"}]}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"V2", "[", "t_", "]"}], "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Re", "[", 
         RowBox[{"Z2", "[", "t", "]"}], "]"}], ",", 
        RowBox[{"Im", "[", 
         RowBox[{"Z2", "[", "t", "]"}], "]"}]}], "}"}], "]"}]}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"V3", "[", "t_", "]"}], "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Re", "[", 
         RowBox[{"Z3", "[", "t", "]"}], "]"}], ",", 
        RowBox[{"Im", "[", 
         RowBox[{"Z3", "[", "t", "]"}], "]"}]}], "}"}], "]"}]}], ";"}], " ", 
   "\n", 
   RowBox[{"ParametricPlot", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"V1", "[", "t", "]"}], ",", 
        RowBox[{"V2", "[", "t", "]"}], ",", 
        RowBox[{"V3", "[", "t", "]"}]}], "}"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "1"}], "}"}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "3", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Red", ",", "Blue", ",", "Green"}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(\[Integral]\), SubscriptBox[\(C\), \(2\)]]\) \
\>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\< \[DifferentialD]z = \>\"", ",",
       "W2"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(C\), \(2\)]\): \!\(\*SubscriptBox[\(Z\), \
\(1\)]\)[t] = \>\"", ",", 
      RowBox[{"Z1", "[", "t", "]"}], ",", 
      "\"\<,      for  0 \[LessEqual] t \[LessEqual] 1.\>\""}], "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<    \!\(\*SubscriptBox[\(Z\), \(2\)]\)[t] = \>\"", ",", 
      RowBox[{"Z2", "[", "t", "]"}], ",", 
      "\"\<, for  0 \[LessEqual] t \[LessEqual] 1.\>\""}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<    \!\(\*SubscriptBox[\(Z\), \(3\)]\)[t] = \>\"", ",", 
      RowBox[{"Z3", "[", "t", "]"}], ",", 
      "\"\<,  for  0 \[LessEqual] t \[LessEqual] 1.\>\""}], "]"}], ";"}], " ",
    "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399288530140625*^9, 3.399288534109375*^9}, {
  3.399881665625*^9, 3.3998816658125*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "Which is ",
 StyleBox["different",
  FontColor->RGBColor[1, 0, 1]],
 " from the value for the other path because  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   OverscriptBox[
    RowBox[{" ", "z"}], "_"]}]]],
 "  is ",
 StyleBox["not",
  FontColor->RGBColor[1, 0, 1]],
 " an analytic function."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"V", "[", "t_", "]"}], "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Re", "[", 
         RowBox[{"z", "[", "t", "]"}], "]"}], ",", 
        RowBox[{"Im", "[", 
         RowBox[{"z", "[", "t", "]"}], "]"}]}], "}"}], "]"}]}], ";"}], " ", 
   "\n", 
   RowBox[{"ParametricPlot", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{"V", "[", "t", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.02"}], ",", "1.02"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["1", "2"]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "1", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Magenta"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(\[Integral]\), SubscriptBox[\(C\), \(1\)]]\) \
\>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\< \[DifferentialD]z = \>\"", ",",
       "W1"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(C\), \(1\)]\): z[t] = \>\"", ",", 
      RowBox[{"z", "[", "t", "]"}], ",", 
      "\"\<,  for  0 \[LessEqual] t \[LessEqual] \[Pi].\>\""}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399288542453125*^9, 3.39928855571875*^9}, {
  3.39988167028125*^9, 3.399881670453125*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 "\t Contour integrals have properties that are similar to those of integrals \
of a complex function of a real variable, which you studied in Section 6.1.  \
If ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " is given by Equation ",
 StyleBox["(6-10)",
  FontColor->RGBColor[0, 0, 1]],
 ", then the integral for the opposite contour ",
 StyleBox["-C",
  FontFamily->"Courier New"],
 " is  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["\[Integral]", 
     RowBox[{"-", "C"}]], " ", 
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}], " ", 
     RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "=", "  ", 
   RowBox[{
    SubsuperscriptBox["\[Integral]", 
     RowBox[{"-", "b"}], 
     RowBox[{"-", "a"}]], " ", 
    RowBox[{"f", 
     RowBox[{"(", 
      RowBox[{"z", 
       RowBox[{"(", 
        RowBox[{"-", "\[Tau]"}], ")"}]}], ")"}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", " ", 
        RowBox[{"z", "'"}]}], 
       RowBox[{"(", 
        RowBox[{"-", "\[Tau]"}], ")"}]}], ")"}], 
     RowBox[{"\[DifferentialD]", "\[Tau]"}]}]}]}]]],
 "\n\n    Using the change of variable  ",
 Cell[BoxData[
  RowBox[{"t", "=", 
   RowBox[{"-", "\[Tau]"}]}]]],
 "  in this last equation and the property that  ",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{
    RowBox[{
     SubsuperscriptBox["\[Integral]", "a", "b"], " ", 
     RowBox[{"f", 
      RowBox[{"(", "t", ")"}], 
      RowBox[{"\[DifferentialD]", "t"}]}]}], " ", "=", " ", 
    RowBox[{"-", " ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "b", "a"], " ", 
      RowBox[{"f", 
       RowBox[{"(", "t", ")"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}]}]}]]],
 ",  we obtain  \n    \n",
 StyleBox["(6-17)",
  FontColor->RGBColor[0, 0, 1]],
 "    \t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["\[Integral]", 
     RowBox[{"-", "C"}]], " ", 
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}], " ", 
     RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "=", "  ", 
   RowBox[{"-", 
    RowBox[{
     SubscriptBox["\[Integral]", "C"], " ", 
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}], " ", 
      RowBox[{"\[DifferentialD]", "z"}]}]}]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "\tIf two functions ",
 StyleBox["f",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["g",
  FontFamily->"Courier New"],
 " can be integrated over the same path of integration ",
 StyleBox["C",
  FontFamily->"Courier New"],
 ", then their sum can be integrated over ",
 StyleBox["C",
  FontFamily->"Courier New"],
 ", and we have the familiar result  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["\[Integral]", "C"], " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"f", 
        RowBox[{"(", "z", ")"}]}], "+", 
       RowBox[{"g", 
        RowBox[{"(", "z", ")"}]}]}], ")"}], " ", 
     RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Integral]", "C"], " ", 
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}], " ", 
      RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "+", "  ", 
    RowBox[{
     SubscriptBox["\[Integral]", "C"], " ", 
     RowBox[{"g", 
      RowBox[{"(", "z", ")"}], " ", 
      RowBox[{"\[DifferentialD]", "z"}]}]}]}]}]]],
 ".  \n"
}], "Text"],

Cell[TextData[{
 "\tConstant multiples also behave as we would expect: \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["\[Integral]", "C"], " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"a", "+", 
       RowBox[{"\[ImaginaryI]", " ", "b"}]}], ")"}], "f", 
     RowBox[{"(", "z", ")"}], " ", 
     RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"a", "+", 
      RowBox[{"\[ImaginaryI]", " ", "b"}]}], ")"}], 
    RowBox[{
     SubscriptBox["\[Integral]", "C"], " ", 
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}], " ", 
      RowBox[{"\[DifferentialD]", "z"}]}]}]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "\tIf two contours ",
 Cell[BoxData[
  SubscriptBox["C", "1"]]],
 " and ",
 Cell[BoxData[
  SubscriptBox["C", "2"]]],
 " are placed end to end so that the terminal point of ",
 Cell[BoxData[
  SubscriptBox["C", "1"]]],
 " coincides with the initial point of ",
 Cell[BoxData[
  SubscriptBox["C", "2"]]],
 ", then the contour ",
 Cell[BoxData[
  RowBox[{"C", "=", 
   RowBox[{
    SubscriptBox["C", "1"], "+", 
    SubscriptBox["C", "2"]}]}]]],
 " is a continuation of ",
 Cell[BoxData[
  SubscriptBox["C", "1"]]],
 ", and  \n\n",
 StyleBox["(6-18)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["\[Integral]", 
     RowBox[{
      SubscriptBox["C", "1"], "+", 
      SubscriptBox["C", "2"]}]], 
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}], " ", 
     RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Integral]", 
      SubscriptBox["C", "1"]], 
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}], " ", 
      RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "+", "  ", 
    RowBox[{
     SubscriptBox["\[Integral]", 
      SubscriptBox["C", "2"]], 
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}], " ", 
      RowBox[{"\[DifferentialD]", "z"}]}]}]}]}]]],
 ". "
}], "Text"],

Cell[TextData[{
 "\tIf the contour ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " has two parametrizations  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"C", ":", " ", 
    RowBox[{
     SubscriptBox["z", "1"], 
     RowBox[{"(", "t", ")"}]}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     SubscriptBox["x", "1"], 
     RowBox[{"(", "t", ")"}]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["y", "1"], 
     RowBox[{"(", "t", ")"}]}]}]}]]],
 "   for   ",
 Cell[BoxData[
  RowBox[{"a", "\[LessEqual]", "t", "\[LessEqual]", "b"}]]],
 ",   and \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"C", ":", " ", 
    RowBox[{
     SubscriptBox["z", "2"], 
     RowBox[{"(", "\[Tau]", ")"}]}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     SubscriptBox["x", "2"], 
     RowBox[{"(", "\[Tau]", ")"}]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["y", "2"], 
     RowBox[{"(", "\[Tau]", ")"}]}]}]}]]],
 "   for   ",
 Cell[BoxData[
  RowBox[{"c", "\[LessEqual]", "\[Tau]", "\[LessEqual]", "d"}]]],
 ",   \n\nand there exists a differentiable function  ",
 Cell[BoxData[
  RowBox[{"\[Tau]", " ", "=", " ", 
   RowBox[{"\[Phi]", 
    RowBox[{"(", "t", ")"}]}]}]]],
 "  such that  \n\n",
 StyleBox["(6-19)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{"c", "=", " ", 
   RowBox[{"\[Phi]", 
    RowBox[{"(", "a", ")"}]}]}]]],
 ",    ",
 Cell[BoxData[
  RowBox[{"d", "=", " ", 
   RowBox[{"\[Phi]", 
    RowBox[{"(", "b", ")"}]}]}]]],
 ",    and    ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"\[Phi]", "'"}], 
    RowBox[{"(", "t", ")"}]}], ">", "0"}]]],
 "    for   ",
 Cell[BoxData[
  RowBox[{"a", "\[LessEqual]", "t", "\[LessEqual]", "b"}]]],
 ",\n\nthen we say that ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "2"], 
   RowBox[{"(", "\[Tau]", ")"}]}]]],
 " is a reparametrization of the contour ",
 StyleBox["C",
  FontFamily->"Courier New"],
 ".  If ",
 StyleBox["f",
  FontFamily->"Courier New"],
 " is continuous on ",
 StyleBox["C",
  FontFamily->"Courier New"],
 ", then we have  \n\n",
 StyleBox["(6-20)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[Integral]", "a", "b"], " ", 
    RowBox[{"f", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["z", "1"], 
       RowBox[{"(", "t", ")"}]}], ")"}], 
     SubsuperscriptBox["z", "1", "'"], 
     RowBox[{"(", "t", ")"}], 
     RowBox[{"\[DifferentialD]", "t"}]}]}], "  ", "=", "  ", 
   RowBox[{
    SubsuperscriptBox["\[Integral]", "c", "d"], " ", 
    RowBox[{"f", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["z", "2"], 
       RowBox[{"(", "\[Tau]", ")"}]}], ")"}], 
     SubsuperscriptBox["z", "2", "'"], 
     RowBox[{"(", "\[Tau]", ")"}], 
     RowBox[{"\[DifferentialD]", "\[Tau]"}]}]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "\tEquation ",
 StyleBox["(6-20)",
  FontColor->RGBColor[0, 0, 1]],
 " shows that the value of a contour integral is invariant under a change in \
the parametric representation of its contour if the reparametrization \
satisfies Equations ",
 StyleBox["(6-19)",
  FontColor->RGBColor[0, 0, 1]],
 ". "
}], "Text"],

Cell["\<\
\tWe now give two important inequalities relating to complex integrals.\
\>", "Text"],

Cell[TextData[{
 StyleBox["Theorem 6.2 (Absolute Value Inequality).",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  If  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "t", ")"}]}], "=", 
   RowBox[{
    RowBox[{"u", 
     RowBox[{"(", "t", ")"}]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", "v", 
     RowBox[{"(", "t", ")"}]}]}]}]]],
 " is a continuous function of the real parameter ",
 StyleBox["t",
  FontFamily->"Courier New"],
 ", then  \n\n",
 StyleBox["(6-21)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{"|", 
   RowBox[{
    SubsuperscriptBox["\[Integral]", "a", "b"], " ", 
    RowBox[{"f", 
     RowBox[{"(", "t", ")"}], 
     RowBox[{"\[DifferentialD]", "t"}]}]}], "|", "  ", 
   RowBox[{"\[LessEqual]", "  ", 
    SubsuperscriptBox["\[Integral]", "a", "b"]}], " ", "|", 
   RowBox[{"f", 
    RowBox[{"(", "t", ")"}]}], "|", 
   RowBox[{"\[DifferentialD]", "t"}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 6.2 is in the book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
 StyleBox["Theorem 6.3 (ML - Inequality).",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  If  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    RowBox[{"u", 
     RowBox[{"(", 
      RowBox[{"x", ",", "y"}], ")"}]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", "v", 
     RowBox[{"(", 
      RowBox[{"x", ",", "y"}], ")"}]}]}]}]]],
 " is continuous on the contour ",
 StyleBox["C",
  FontFamily->"Courier New"],
 ", then  \n\n",
 StyleBox["(6-23)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["\[Integral]", "C"], " ", 
   RowBox[{"|", 
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "|", " ", 
    RowBox[{
     RowBox[{"\[DifferentialD]", "z"}], " ", "\[LessEqual]", " ", 
     RowBox[{"M", " ", "L"}]}]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 6.3 is in the book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 6.11.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Use Inequality ",
 StyleBox["(6-23)",
  FontColor->RGBColor[0, 0, 1]],
 " to show that  ",
 Cell[BoxData[
  RowBox[{"|", 
   RowBox[{
    SubscriptBox["\[Integral]", "C"], " ", 
    RowBox[{
     FractionBox["1", 
      RowBox[{
       SuperscriptBox["z", "2"], "+", "1"}]], " ", 
     RowBox[{"\[DifferentialD]", "z"}]}]}], "|", 
   RowBox[{"\[LessEqual]", 
    FractionBox["1", 
     RowBox[{"2", 
      SqrtBox["5"]}]]}]}]]],
 ", \nwhere ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " is the straight-line segment from  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"2", "  ", 
    StyleBox["to",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], "  ", "2"}], "+", "\[ImaginaryI]"}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "Solution.  Here  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", 
    RowBox[{
     SuperscriptBox["z", "2"], "+", "1"}], "|"}], "=", 
   RowBox[{"|", 
    RowBox[{
     RowBox[{"z", "-", "\[ImaginaryI]"}], "||", 
     RowBox[{"z", "+", "\[ImaginaryI]"}]}], "|"}]}]]],
 ",  and the terms  ",
 Cell[BoxData[
  RowBox[{"|", 
   RowBox[{"z", "-", "\[ImaginaryI]"}], "|", " ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], " ", "|", 
   RowBox[{"z", "+", "\[ImaginaryI]"}], "|"}]]],
 "  represent the distance from the point ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " to the points ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[ImaginaryI]", " ", 
    StyleBox["and",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]]}], " ", "-", "\[ImaginaryI]"}]]],
 ", respectively.  Referring to Figure 6.10 and using a geometric argument, \
we get \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"|", 
   RowBox[{"z", "-", "\[ImaginaryI]"}], "|", 
   RowBox[{"\[GreaterEqual]", 
    RowBox[{"2", "   ", 
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]]}]}], " ", "|", 
   RowBox[{"z", "+", "\[ImaginaryI]"}], "|", 
   RowBox[{"\[GreaterEqual]", 
    SqrtBox["5"]}]}]]],
 ",   for ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " on ",
 StyleBox["C",
  FontFamily->"Courier New"],
 "."
}], "Text"],

Cell[TextData[{
 "\t\t\t",
 Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
  ImageSize->{272, 262},
  ImageMargins->0],
 StyleBox["\n\t\t\t",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Figure 6.10",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/contourintegral/\
ContourIntegralMod/Images/mat0610.gif"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 "  The distances ",
 Cell[BoxData[
  RowBox[{"|", 
   RowBox[{"z", "-", "\[ImaginaryI]"}], "|", "  ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], " ", "|", 
   RowBox[{"z", "+", "\[ImaginaryI]"}], "|"}]]],
 "  for ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " on ",
 StyleBox["C",
  FontFamily->"Courier New"],
 "."
}], "Text",
 CellChangeTimes->{{3.39929522484375*^9, 3.399295237125*^9}}],

Cell[TextData[{
 "Thus we have  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", 
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "|"}], " ", "=", " ", 
   RowBox[{
    RowBox[{"|", 
     FractionBox["1", 
      RowBox[{
       SuperscriptBox["z", "2"], "+", "1"}]], "|"}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      FractionBox["1", 
       RowBox[{"|", 
        RowBox[{
         RowBox[{"z", "-", "\[ImaginaryI]"}], "||", 
         RowBox[{"z", "+", "\[ImaginaryI]"}]}], "|"}]], "  ", "\[LessEqual]", 
      
      FractionBox["1", 
       RowBox[{"2", 
        SqrtBox["5"]}]]}], " ", "=", " ", "M"}]}]}]]],
 ".\n\nBecause ",
 StyleBox["L",
  FontFamily->"Courier New"],
 ", the length of ",
 StyleBox["C",
  FontFamily->"Courier New"],
 ", equals ",
 StyleBox["1",
  FontFamily->"Courier New"],
 ", Inequality ",
 StyleBox["(6-23)",
  FontColor->RGBColor[0, 0, 1]],
 " implies that  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", 
    RowBox[{
     SubscriptBox["\[Integral]", "C"], " ", 
     RowBox[{
      FractionBox["1", 
       RowBox[{
        SuperscriptBox["z", "2"], "+", "1"}]], " ", 
      RowBox[{"\[DifferentialD]", "z"}]}]}], "|", 
    RowBox[{"\[LessEqual]", " ", 
     RowBox[{"M", " ", "L"}], "\[LessEqual]", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"2", 
        SqrtBox["5"]}]], "\[Cross]", "1"}]}]}], " ", "=", " ", 
   FractionBox["1", 
    RowBox[{"2", 
     SqrtBox["5"]}]]}]]],
 "."
}], "Text"],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[{
 StyleBox[ButtonBox["Complex Integral",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/ComplexIntegralBib.html"], 
    None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0, 1]],
 "  "
}], "Text"],

Cell[TextData[{
 StyleBox[ButtonBox["Contour Integrals",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/ContourIntegralBib.html"], 
    None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0, 1]],
 "  "
}], "Text"],

Cell[TextData[{
 StyleBox[ButtonBox["Green's Theorem",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/GreenTheoremBib.html"], 
    None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0, 1]],
 "  "
}], "Text"],

Cell[TextData[{
 StyleBox[ButtonBox["Cauchy-Goursat Theorem",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/CauchyGoursatBib.html"], 
    None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0, 1]],
 "  "
}], "Text"],

Cell[TextData[{
 StyleBox[ButtonBox["Cauchy's Integral Formula",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/CauchyIntegraBib.html"], 
    None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0, 1]],
 "  "
}], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/complex.html"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2008 John H. Mathews, Russell W. \
Howell",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/"], None}],
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[0, 1, 0]]], "Text",
 CellChangeTimes->{{3.399288173984375*^9, 3.39928817409375*^9}}]
},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{965, 649},
WindowMargins->{{Automatic, 25}, {Automatic, -4}},
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "CHAPTER 1"->{
  Cell[568, 21, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"],
  Cell[133251, 3488, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"],
  Cell[372504, 10814, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"],
  Cell[374091, 10877, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"CHAPTER 1", 388945, 11296}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"],
Cell[905, 32, 123, 2, 29, "Text"],
Cell[1031, 36, 1375, 46, 73, "Text",
 Evaluatable->False],
Cell[2409, 84, 1097, 36, 119, "Text",
 Evaluatable->False],
Cell[3509, 122, 2343, 94, 101, "Text",
 Evaluatable->False],
Cell[5855, 218, 21295, 358, 397, "Text"],
Cell[27153, 578, 1512, 61, 83, "Text",
 Evaluatable->False],
Cell[28668, 641, 2250, 90, 94, "Text"],
Cell[30921, 733, 8133, 142, 185, "Text"],
Cell[39057, 877, 871, 32, 74, "Text"],
Cell[39931, 911, 1881, 74, 85, "Text"],
Cell[41815, 987, 1633, 62, 173, "Text"],
Cell[43451, 1051, 6499, 119, 138, "Text"],
Cell[49953, 1172, 2488, 90, 119, "Text"],
Cell[52444, 1264, 2009, 74, 47, "Text",
 Evaluatable->False],
Cell[54456, 1340, 7241, 141, 240, "Text"],
Cell[61700, 1483, 2019, 75, 155, "Text"],
Cell[63722, 1560, 1279, 47, 119, "Text"],
Cell[CellGroupData[{
Cell[65026, 1611, 185, 7, 29, "Text"],
Cell[65214, 1620, 76, 0, 29, "Text"],
Cell[65293, 1622, 7529, 222, 632, "Input"],
Cell[72825, 1846, 126, 5, 29, "Text"],
Cell[72954, 1853, 2918, 82, 212, "Input"]
}, Closed]],
Cell[75887, 1938, 4260, 154, 116, "Text"],
Cell[80150, 2094, 7674, 149, 316, "Text"],
Cell[87827, 2245, 1055, 37, 47, "Text"],
Cell[88885, 2284, 1131, 37, 105, "Text",
 Evaluatable->False],
Cell[90019, 2323, 971, 30, 53, "Text"],
Cell[90993, 2355, 943, 33, 35, "Text",
 Evaluatable->False],
Cell[91939, 2390, 4077, 146, 83, "Text"],
Cell[96019, 2538, 5834, 108, 281, "Text"],
Cell[101856, 2648, 3310, 96, 307, "Text"],
Cell[CellGroupData[{
Cell[105191, 2748, 185, 7, 29, "Text"],
Cell[105379, 2757, 365, 12, 47, "Text"],
Cell[105747, 2771, 4834, 136, 740, "Input"],
Cell[110584, 2909, 240, 9, 65, "Text"],
Cell[110827, 2920, 1821, 52, 186, "Input"]
}, Closed]],
Cell[112663, 2975, 1059, 35, 62, "Text"],
Cell[113725, 3012, 11777, 209, 319, "Text"],
Cell[125505, 3223, 5034, 172, 270, "Text"],
Cell[130542, 3397, 824, 21, 69, "Text"],
Cell[131369, 3420, 1114, 42, 87, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[132508, 3466, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[132652, 3472, 596, 14, 65, "Text",
 Evaluatable->False],
Cell[133251, 3488, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"]
}, Closed]],
Cell[133600, 3500, 520, 11, 62, "Text"],
Cell[134123, 3513, 942, 33, 35, "Text",
 Evaluatable->False],
Cell[135068, 3548, 6413, 280, 161, "Text"],
Cell[141484, 3830, 8089, 249, 490, "Text"],
Cell[CellGroupData[{
Cell[149598, 4083, 185, 7, 29, "Text"],
Cell[149786, 4092, 265, 8, 29, "Text"],
Cell[150054, 4102, 3022, 89, 428, "Input"],
Cell[153079, 4193, 169, 5, 29, "Text"],
Cell[153251, 4200, 5478, 149, 591, "Input"],
Cell[158732, 4351, 179, 5, 29, "Text"],
Cell[158914, 4358, 7196, 201, 734, "Input"]
}, Closed]],
Cell[166125, 4562, 594, 24, 32, "Text",
 Evaluatable->False],
Cell[166722, 4588, 4993, 240, 113, "Text"],
Cell[171718, 4830, 2354, 81, 100, "Text"],
Cell[CellGroupData[{
Cell[174097, 4915, 185, 7, 29, "Text"],
Cell[174285, 4924, 279, 9, 36, "Text"],
Cell[174567, 4935, 5172, 146, 587, "Input"]
}, Closed]],
Cell[179754, 5084, 492, 15, 44, "Text"],
Cell[180249, 5101, 1526, 55, 133, "Text"],
Cell[181778, 5158, 5431, 189, 310, "Text"],
Cell[187212, 5349, 4445, 153, 253, "Text"],
Cell[191660, 5504, 2214, 70, 180, "Text"],
Cell[193877, 5576, 307, 7, 47, "Text"],
Cell[194187, 5585, 1678, 61, 54, "Text",
 Evaluatable->False],
Cell[195868, 5648, 11553, 211, 236, "Text"],
Cell[207424, 5861, 5359, 186, 406, "Text"],
Cell[212786, 6049, 4695, 169, 302, "Text"],
Cell[CellGroupData[{
Cell[217506, 6222, 188, 7, 29, "Text"],
Cell[217697, 6231, 634, 23, 65, "Text",
 Evaluatable->False],
Cell[218334, 6256, 3218, 91, 392, "Input"],
Cell[221555, 6349, 177, 5, 29, "Text"],
Cell[221735, 6356, 6448, 177, 677, "Input"],
Cell[228186, 6535, 169, 5, 29, "Text"],
Cell[228358, 6542, 4050, 112, 428, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[232445, 6659, 188, 7, 26, "Text"],
Cell[232636, 6668, 501, 17, 29, "Text",
 Evaluatable->False],
Cell[233140, 6687, 2283, 64, 252, "Input"],
Cell[235426, 6753, 177, 5, 29, "Text"],
Cell[235606, 6760, 6446, 177, 677, "Input"],
Cell[242055, 6939, 169, 5, 29, "Text"],
Cell[242227, 6946, 4092, 111, 427, "Input"],
Cell[246322, 7059, 281, 10, 29, "Text",
 Evaluatable->False],
Cell[246606, 7071, 2205, 59, 187, "Input"]
}, Closed]],
Cell[248826, 7133, 1337, 49, 98, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[250188, 7186, 204, 7, 29, "Text"],
Cell[250395, 7195, 657, 24, 47, "Text",
 Evaluatable->False],
Cell[251055, 7221, 3241, 91, 392, "Input"],
Cell[254299, 7314, 177, 5, 29, "Text"],
Cell[254479, 7321, 6446, 177, 677, "Input"],
Cell[260928, 7500, 169, 5, 29, "Text"],
Cell[261100, 7507, 4051, 112, 428, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[265188, 7624, 204, 7, 26, "Text"],
Cell[265395, 7633, 501, 17, 29, "Text",
 Evaluatable->False],
Cell[265899, 7652, 2283, 64, 252, "Input"],
Cell[268185, 7718, 177, 5, 29, "Text"],
Cell[268365, 7725, 6445, 177, 677, "Input"],
Cell[274813, 7904, 169, 5, 29, "Text"],
Cell[274985, 7911, 4078, 112, 427, "Input"],
Cell[279066, 8025, 281, 10, 29, "Text",
 Evaluatable->False],
Cell[279350, 8037, 2214, 60, 187, "Input"]
}, Closed]],
Cell[281579, 8100, 1001, 36, 80, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[282605, 8140, 204, 7, 29, "Text"],
Cell[282812, 8149, 691, 26, 47, "Text",
 Evaluatable->False],
Cell[283506, 8177, 3732, 105, 432, "Input"],
Cell[287241, 8284, 177, 5, 29, "Text"],
Cell[287421, 8291, 6445, 177, 677, "Input"],
Cell[293869, 8470, 169, 5, 29, "Text"],
Cell[294041, 8477, 4034, 111, 428, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[298112, 8593, 204, 7, 26, "Text"],
Cell[298319, 8602, 501, 17, 29, "Text",
 Evaluatable->False],
Cell[298823, 8621, 2482, 70, 272, "Input"],
Cell[301308, 8693, 177, 5, 29, "Text"],
Cell[301488, 8700, 6452, 177, 677, "Input"],
Cell[307943, 8879, 169, 5, 29, "Text"],
Cell[308115, 8886, 4039, 111, 428, "Input"],
Cell[312157, 8999, 418, 17, 29, "Text",
 Evaluatable->False],
Cell[312578, 9018, 2214, 60, 187, "Input"]
}, Closed]],
Cell[314807, 9081, 150, 3, 26, "Text"],
Cell[314960, 9086, 2777, 100, 72, "Text",
 Evaluatable->False],
Cell[317740, 9188, 9965, 185, 208, "Text"],
Cell[327708, 9375, 3478, 116, 375, "Text"],
Cell[331189, 9493, 8505, 273, 414, "Text"],
Cell[CellGroupData[{
Cell[339719, 9770, 189, 7, 29, "Text"],
Cell[339911, 9779, 469, 17, 29, "Text",
 Evaluatable->False],
Cell[340383, 9798, 3692, 106, 432, "Input"],
Cell[344078, 9906, 164, 5, 29, "Text"],
Cell[344245, 9913, 3633, 99, 387, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[347915, 10017, 189, 7, 26, "Text"],
Cell[348107, 10026, 525, 13, 101, "Text",
 Evaluatable->False],
Cell[348635, 10041, 3972, 112, 372, "Input"],
Cell[352610, 10155, 171, 5, 29, "Text"],
Cell[352784, 10162, 7322, 201, 661, "Input"],
Cell[360109, 10365, 410, 17, 29, "Text",
 Evaluatable->False],
Cell[360522, 10384, 2117, 58, 190, "Input"]
}, Closed]],
Cell[362654, 10445, 2190, 75, 164, "Text"],
Cell[364847, 10522, 1081, 38, 87, "Text"],
Cell[365931, 10562, 670, 22, 69, "Text"],
Cell[366604, 10586, 1295, 50, 90, "Text"],
Cell[367902, 10638, 2829, 106, 249, "Text"],
Cell[370734, 10746, 329, 10, 47, "Text"],
Cell[371066, 10758, 95, 2, 29, "Text"],
Cell[371164, 10762, 998, 36, 69, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[372187, 10802, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[372331, 10808, 170, 4, 29, "Text",
 Evaluatable->False],
Cell[372504, 10814, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"]
}, Closed]],
Cell[372853, 10826, 896, 35, 66, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[373774, 10865, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[373918, 10871, 170, 4, 29, "Text",
 Evaluatable->False],
Cell[374091, 10877, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"]
}, Closed]],
Cell[374440, 10889, 1012, 39, 64, "Text",
 Evaluatable->False],
Cell[375455, 10930, 1814, 64, 93, "Text"],
Cell[377272, 10996, 7494, 143, 297, "Text"],
Cell[384769, 11141, 1459, 56, 172, "Text"],
Cell[386231, 11199, 281, 7, 29, "Text"],
Cell[386515, 11208, 298, 10, 29, "Text"],
Cell[386816, 11220, 299, 10, 29, "Text"],
Cell[387118, 11232, 294, 10, 29, "Text"],
Cell[387415, 11244, 302, 10, 29, "Text"],
Cell[387720, 11256, 305, 10, 29, "Text"],
Cell[388028, 11268, 249, 5, 29, "Text"],
Cell[388280, 11275, 319, 7, 29, "Text"]
}
]
*)

(* End of internal cache information *)
