(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    259276,       7069]
NotebookOptionsPosition[    252867,       6862]
NotebookOutlinePosition[    253844,       6901]
CellTagsIndexPosition[    253770,       6896]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["6.3  The Cauchy-Goursat Theorem",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
 "\tThe Cauchy-Goursat theorem states that within certain domains the \
integral of an analytic function over a simple closed contour is zero.  An \
extension of this theorem allows us to replace integrals over certain \
complicated contours with integrals over contours that are easy to evaluate.  \
We demonstrate how to use the technique of partial fractions with the ",
 StyleBox[ButtonBox["Cauchy",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Cauchy.\
html"], None}],
  FontVariations->{"Underline"->True}],
 StyleBox["-",
  FontSize->14,
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 StyleBox[ButtonBox["Goursat",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Goursat.\
html"], None}],
  FontVariations->{"Underline"->True}],
 " ",
 StyleBox[ButtonBox["theorem",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/CauchyIntegralTheorem.html"], None}],
  FontVariations->{"Underline"->True}],
 " to evaluate certain integrals.  In Section 6.4 we will see that the \
Cauchy-Goursat theorem implies that an analytic function has an \
antiderivative.  To begin, we need to introduce some new concepts."
}], "Text"],

Cell[TextData[{
 "\tRecall from Section 1.6 that each simple closed contour ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " divides the plane into two domains.  One domain is bounded and is called \
the interior of ",
 StyleBox["C",
  FontFamily->"Courier New"],
 ";  the other domain is unbounded and is called the exterior of ",
 StyleBox["C",
  FontFamily->"Courier New"],
 ".  Figure 6.15 illustrates this concept, which is known as the ",
 StyleBox[ButtonBox["Jordan",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Jordan.\
html"], None}],
  FontVariations->{"Underline"->True}],
 " ",
 StyleBox[ButtonBox["curve theorem",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/JordanCurveTheorem.html"], None}],
  FontVariations->{"Underline"->True}],
 "."
}], "Text"],

Cell[TextData[{
 "\t\t\t",
 Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
  ImageSize->{450, 176},
  ImageMargins->0],
 StyleBox["\n\t\t\t",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Figure 6.15",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/cauchygoursat/\
CauchyGoursatMod/Images/mat0615.gif"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 "  The interior and exterior of simple closed contours."
}], "Text",
 CellChangeTimes->{
  3.3992887875625*^9, {3.3992888578125*^9, 3.39928886471875*^9}, 
   3.39928896759375*^9}],

Cell[TextData[{
 "\tRecall also that a domain ",
 StyleBox["D",
  FontFamily->"Courier New"],
 " is a connected open set.  In particular, if  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], "  ", "and", "  ", 
   SubscriptBox["z", "2"]}]]],
 "  are any pair of points in ",
 StyleBox["D",
  FontFamily->"Courier New"],
 ", then they can be joined by a curve that lies entirely in ",
 StyleBox["D",
  FontFamily->"Courier New"],
 ".  A domain ",
 StyleBox["D",
  FontFamily->"Courier New"],
 " is said to be a simply connected domain if the interior of any simple \
closed contour ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " contained in ",
 StyleBox["D",
  FontFamily->"Courier New"],
 " is contained in ",
 StyleBox["D",
  FontFamily->"Courier New"],
 ".  In other words, there are no \"holes\" in a simply connected domain.  A \
domain that is not simply connected is said to be a multiply connected \
domain.  Figure 6.16 illustrates uses of the terms simply connected and \
multiply connected."
}], "Text"],

Cell[TextData[{
 "\t\t\t",
 Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
  ImageSize->{530, 431},
  ImageMargins->0],
 StyleBox["\n\t\t\t",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Figure 6.16",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/cauchygoursat/\
CauchyGoursatMod/Images/mat0616.gif"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 "   Simply connected and multiply connected domains."
}], "Text",
 CellChangeTimes->{{3.399288881234375*^9, 3.399288899828125*^9}, 
   3.3992889656875*^9}],

Cell[TextData[{
 "\tLet the simple closed contour ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " have the parametrization  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"C", ":", " ", 
    RowBox[{"z", 
     RowBox[{"(", "t", ")"}]}]}], "=", " ", 
   RowBox[{
    RowBox[{"x", 
     RowBox[{"(", "t", ")"}]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", "y", 
     RowBox[{"(", "t", ")"}]}]}]}]]],
 "  for ",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{"a", "\[LessEqual]", "t", "\[LessEqual]", "b"}]}]]],
 ".  Recall that if ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " is parametrized so that the interior of ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " is kept on the left as ",
 StyleBox["z(t)",
  FontFamily->"Courier New"],
 " moves around  ",
 StyleBox["C",
  FontFamily->"Courier New"],
 ", then we say that ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " is oriented positively (counterclockwise); otherwise, ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " is oriented negatively (clockwise).  If ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " is positively oriented, then ",
 StyleBox["-C",
  FontFamily->"Courier New"],
 " is negatively oriented.  Figure 6.17 illustrates the concept of positive \
and negative orientation."
}], "Text"],

Cell[TextData[{
 "\t\t\t",
 Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
  ImageSize->{525, 199},
  ImageMargins->0],
 StyleBox["\n\t\t\t",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Figure 6.17",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/cauchygoursat/\
CauchyGoursatMod/Images/mat0617.gif"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 "  Simple closed contours that are positively and negatively oriented."
}], "Text",
 CellChangeTimes->{{3.399288906765625*^9, 3.399288919890625*^9}, 
   3.399288961984375*^9}],

Cell[TextData[{
 ButtonBox["\t",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/GreensTheorem.html"], None}],
 StyleBox[ButtonBox["Green's",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Green.\
html"], None}],
  FontVariations->{"Underline"->True}],
 " ",
 StyleBox[ButtonBox["theorem",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/GreensTheorem.html"], None}],
  FontVariations->{"Underline"->True}],
 " is an important result from the calculus of real variables.  It tells you \
how to evaluate the line integral of real-valued functions."
}], "Text"],

Cell[TextData[{
 " ",
 StyleBox["Theorem 6.4 (",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Greens Theorem",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/GreensTheorem.html"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 StyleBox[").",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Let ",
 StyleBox["C",
  FontFamily->"Courier New"],
 "  be a simple closed contour with positive orientation and let ",
 StyleBox["R",
  FontFamily->"Courier New"],
 " be the domain that forms the interior of ",
 StyleBox["C",
  FontFamily->"Courier New"],
 ".  If P and Q are continuous and have continuous partial derivatives  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["P", "x"], ",", 
   SubscriptBox["P", "y"], ",", 
   SubscriptBox["Q", "x"], ",", 
   RowBox[{"and", "  ", 
    SubscriptBox["Q", "y"]}]}]]],
 "  at all points on ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["R",
  FontFamily->"Courier New"],
 ", then  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["\[Integral]", "C"], " ", 
     RowBox[{"P", 
      RowBox[{"(", 
       RowBox[{"x", ",", "y"}], ")"}], 
      RowBox[{"\[DifferentialD]", "x"}]}]}], "  ", "+", "  ", 
    RowBox[{
     SubscriptBox["\[Integral]", "C"], " ", 
     RowBox[{"Q", 
      RowBox[{"(", 
       RowBox[{"x", ",", "y"}], ")"}], 
      RowBox[{"\[DifferentialD]", "y"}]}]}]}], "  ", "=", "  ", 
   RowBox[{"\[Integral]", 
    RowBox[{
     SubscriptBox["\[Integral]", "R"], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SubscriptBox["Q", "x"], 
         RowBox[{"(", 
          RowBox[{"x", ",", "y"}], ")"}]}], " ", "-", " ", 
        RowBox[{
         SubscriptBox["P", "y"], 
         RowBox[{"(", 
          RowBox[{"x", ",", "y"}], ")"}]}]}], ")"}], 
      RowBox[{"\[DifferentialD]", "x"}], " ", 
      RowBox[{"\[DifferentialD]", "y"}]}]}]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 6.4 is in the book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"]
}, Closed]],

Cell["\tWe are now ready to state the main result of this section.", "Text"],

Cell[TextData[{
 " ",
 StyleBox["Theorem 6.5 (",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Cauchy-Goursat Theorem",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/CauchyIntegralTheorem.html"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 StyleBox[").",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Let  ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 "  be analytic in a simply connected domain ",
 StyleBox["D",
  FontFamily->"Courier New"],
 ".  If ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " is a simple closed contour that lies in ",
 StyleBox["D",
  FontFamily->"Courier New"],
 ", then  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["\[Integral]", "C"], " ", 
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}], 
     RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "=", "  ", "0"}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 6.5 is in the book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 6.12.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Let us recall that  ",
 Cell[BoxData[
  RowBox[{
   StyleBox[
    SuperscriptBox["\[ExponentialE]", "z"],
    FontSize->14], ",", " ", 
   RowBox[{"cos", 
    RowBox[{"(", "z", ")"}]}], ",", " ", 
   RowBox[{"and", "  ", 
    SuperscriptBox["z", "n"]}]}]]],
 "  (where n is a positive integer) are all entire functions and have \
continuous derivatives.  The Cauchy-Goursat theorem implies that, for any \
simple closed contour, \n\n",
 StyleBox["(a)",
  FontColor->RGBColor[0, 0, 1]],
 "   \t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["\[Integral]", "C"], " ", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", "z"], 
     RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "=", "  ", "0"}]]],
 ",  \n\n",
 StyleBox["(b)",
  FontColor->RGBColor[0, 0, 1]],
 "   \t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["\[Integral]", "C"], " ", 
    RowBox[{"cos", 
     RowBox[{"(", "z", ")"}], 
     RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "=", "  ", "0"}]]],
 ",   and  \n\n",
 StyleBox["(c)",
  FontColor->RGBColor[0, 0, 1]],
 "  ",
 Cell[BoxData[
  RowBox[{"\t\t\t ", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Integral]", "C"], " ", 
     RowBox[{
      SuperscriptBox["z", "n"], 
      RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "=", "  ", "0"}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 6.12 (a)",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 StyleBox["For illustration.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]],
 "  We use the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   StyleBox[
    SuperscriptBox["\[ExponentialE]", "z"],
    FontSize->14]}]]],
 ".  Choose the contour",
 " ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " ",
 "to be the unit circle C: |z| = 1 with positive orientation. "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", "z", "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "F", ",", "\[Theta]"}], "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     SuperscriptBox["\[ExponentialE]", "z"]}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"z", "[", "\[Theta]_", "]"}], " ", "=", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]]}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "\[Theta]_", "]"}], " ", "=", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"f", "[", 
        RowBox[{"z", "[", "\[Theta]", "]"}], "]"}], 
       RowBox[{
        RowBox[{"z", "'"}], "[", "\[Theta]", "]"}], 
       RowBox[{"\[DifferentialD]", "\[Theta]"}]}]}]}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"val", " ", "=", " ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", 
       RowBox[{"2", "\[Pi]"}]], 
      RowBox[{
       RowBox[{"f", "[", 
        RowBox[{"z", "[", "\[Theta]", "]"}], "]"}], 
       RowBox[{
        RowBox[{"z", "'"}], "[", "\[Theta]", "]"}], 
       RowBox[{"\[DifferentialD]", "\[Theta]"}]}]}]}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<              f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<              z[\[Theta]] = \>\"", ",", 
      RowBox[{"z", "[", "\[Theta]", "]"}]}], "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<           f[z[\[Theta]]] = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"z", "[", "\[Theta]", "]"}], "]"}]}], "]"}], ";"}], "  ", "\n",
    
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<             z'[\[Theta]] = \>\"", ",", 
      RowBox[{
       RowBox[{"z", "'"}], "[", "\[Theta]", "]"}]}], "]"}], ";"}], "  ", "\n",
    
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<     f[z[\[Theta]]] z'[\[Theta]] = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"z", "[", "\[Theta]", "]"}], "]"}], ",", " ", 
      RowBox[{
       RowBox[{"z", "'"}], "[", "\[Theta]", "]"}]}], "]"}], ";"}], "  ", "\n",
    
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< F[\[Theta]] = \[Integral] f[z[\[Theta]]]z'[\[Theta]] \
\[DifferentialD]\[Theta] = \>\"", ",", 
      RowBox[{"F", "[", "\[Theta]", "]"}]}], "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[2\[Pi]] = \>\"", ",", 
      RowBox[{"F", "[", 
       RowBox[{"2", "\[Pi]"}], "]"}], ",", "\"\<,  and  F[0] = \>\"", ",", 
      RowBox[{"F", "[", "0", "]"}]}], "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderoverscriptBox[\(\[Integral]\), \(0\), \(2  \
\[Pi]\)]\)\>\"", ",", 
      "\"\<f[z[\[Theta]]]z'[\[Theta]]\[DifferentialD]\[Theta] = \>\"", ",", 
      "\"\<\!\(\*UnderoverscriptBox[\(\[Integral]\), \(0\), \(2  \[Pi]\)]\)\>\
\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"z", "[", "\[Theta]", "]"}], "]"}], ",", 
      RowBox[{
       RowBox[{"z", "'"}], "[", "\[Theta]", "]"}], ",", 
      "\"\< \[DifferentialD]\[Theta] = \>\"", ",", 
      RowBox[{"F", "[", 
       RowBox[{"2", "\[Pi]"}], "]"}], ",", "\"\< - \>\"", ",", 
      RowBox[{"F", "[", "0", "]"}], ",", "\"\< = \>\"", ",", 
      RowBox[{
       RowBox[{"F", "[", 
        RowBox[{"2", "\[Pi]"}], "]"}], "-", 
       RowBox[{"F", "[", "0", "]"}]}]}], "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderoverscriptBox[\(\[Integral]\), \(0\), \(2  \
\[Pi]\)]\)\>\"", ",", 
      "\"\<f[z[\[Theta]]]z'[\[Theta]]\[DifferentialD]\[Theta] = \>\"", ",", 
      "val"}], "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"contour", " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", 
        RowBox[{"Circle", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}], ",", "1"}], "]"}]}], "}"}], 
      "]"}]}], ";"}], "  ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{"contour", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          FractionBox[
           RowBox[{"-", "3"}], "2"], ",", 
          FractionBox["3", "2"]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          FractionBox[
           RowBox[{"-", "3"}], "2"], ",", 
          FractionBox["3", "2"]}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          FractionBox[
           RowBox[{"-", "3"}], "2"], ",", 
          FractionBox["3", "2"], ",", 
          FractionBox["1", "2"]}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          FractionBox[
           RowBox[{"-", "3"}], "2"], ",", 
          FractionBox["3", "2"], ",", 
          FractionBox["1", "2"]}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], "\n", 
   RowBox[{"Print", "[", 
    RowBox[{
    "\"\<\!\(\*UnderscriptBox[\(\[ContourIntegral]\), \(C\)]\) \>\"", ",", 
     RowBox[{"f", "[", "z", "]"}], ",", "\"\< \[DifferentialD]z = \>\"", ",", 
     "val"}], "]"}], "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The contour is the unit circle  C: |z| = 1.\>\"", 
     "]"}], ";"}], "  ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399289146875*^9, 3.39928915234375*^9}, {
   3.399882605953125*^9, 3.3998826065625*^9}, 3.400266968359375*^9},
 AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 6.12 (b)",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 StyleBox["For illustration.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]],
 "  We use the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{"Cos", "[", "z", "]"}]}]]],
 ". Choose the contour",
 " ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " ",
 "to be the unit circle C: |z| = 1 with positive orientation. "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", "z", "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "F", ",", "\[Theta]"}], "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"Cos", "[", "z", "]"}]}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"z", "[", "\[Theta]_", "]"}], " ", "=", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]]}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "\[Theta]_", "]"}], " ", "=", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"f", "[", 
        RowBox[{"z", "[", "\[Theta]", "]"}], "]"}], 
       RowBox[{
        RowBox[{"z", "'"}], "[", "\[Theta]", "]"}], 
       RowBox[{"\[DifferentialD]", "\[Theta]"}]}]}]}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"val", " ", "=", " ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", 
       RowBox[{"2", "\[Pi]"}]], 
      RowBox[{
       RowBox[{"f", "[", 
        RowBox[{"z", "[", "\[Theta]", "]"}], "]"}], 
       RowBox[{
        RowBox[{"z", "'"}], "[", "\[Theta]", "]"}], 
       RowBox[{"\[DifferentialD]", "\[Theta]"}]}]}]}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<              f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<              z[\[Theta]] = \>\"", ",", 
      RowBox[{"z", "[", "\[Theta]", "]"}]}], "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<           f[z[\[Theta]]] = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"z", "[", "\[Theta]", "]"}], "]"}]}], "]"}], ";"}], "  ", "\n",
    
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<             z'[\[Theta]] = \>\"", ",", 
      RowBox[{
       RowBox[{"z", "'"}], "[", "\[Theta]", "]"}]}], "]"}], ";"}], "  ", "\n",
    
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<     f[z[\[Theta]]] z'[\[Theta]] = \>\"", ",", 
      RowBox[{
       RowBox[{"f", "[", 
        RowBox[{"z", "[", "\[Theta]", "]"}], "]"}], " ", 
       RowBox[{
        RowBox[{"z", "'"}], "[", "\[Theta]", "]"}]}]}], "]"}], ";"}], "  ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< F[\[Theta]] = \[Integral] f[z[\[Theta]]]z'[\[Theta]] \
\[DifferentialD]\[Theta] = \>\"", ",", 
      RowBox[{"F", "[", "\[Theta]", "]"}]}], "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[2\[Pi]] = \>\"", ",", 
      RowBox[{"F", "[", 
       RowBox[{"2", "\[Pi]"}], "]"}], ",", "\"\<,  and  F[0] = \>\"", ",", 
      RowBox[{"F", "[", "0", "]"}]}], "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderoverscriptBox[\(\[Integral]\), \(0\), \(2  \
\[Pi]\)]\)\>\"", ",", 
      "\"\<f[z[\[Theta]]]z'[\[Theta]]\[DifferentialD]\[Theta] = \>\"", ",", 
      "\"\<\!\(\*UnderoverscriptBox[\(\[Integral]\), \(0\), \(2  \[Pi]\)]\)\>\
\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"z", "[", "\[Theta]", "]"}], "]"}], ",", 
      RowBox[{
       RowBox[{"z", "'"}], "[", "\[Theta]", "]"}], ",", 
      "\"\< \[DifferentialD]\[Theta] = \>\"", ",", 
      RowBox[{"F", "[", 
       RowBox[{"2", "\[Pi]"}], "]"}], ",", "\"\< - \>\"", ",", 
      RowBox[{"F", "[", "0", "]"}], ",", "\"\< = \>\"", ",", 
      RowBox[{
       RowBox[{"F", "[", 
        RowBox[{"2", "\[Pi]"}], "]"}], "-", 
       RowBox[{"F", "[", "0", "]"}]}]}], "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderoverscriptBox[\(\[Integral]\), \(0\), \(2  \
\[Pi]\)]\)\>\"", ",", 
      "\"\<f[z[\[Theta]]]z'[\[Theta]]\[DifferentialD]\[Theta] = \>\"", ",", 
      "val"}], "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"contour", " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", 
        RowBox[{"Circle", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}], ",", "1"}], "]"}]}], "}"}], 
      "]"}]}], ";"}], "  ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{"contour", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          FractionBox[
           RowBox[{"-", "3"}], "2"], ",", 
          FractionBox["3", "2"]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          FractionBox[
           RowBox[{"-", "3"}], "2"], ",", 
          FractionBox["3", "2"]}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          FractionBox[
           RowBox[{"-", "3"}], "2"], ",", 
          FractionBox["3", "2"], ",", 
          FractionBox["1", "2"]}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          FractionBox[
           RowBox[{"-", "3"}], "2"], ",", 
          FractionBox["3", "2"], ",", 
          FractionBox["1", "2"]}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], "\n", 
   RowBox[{"Print", "[", 
    RowBox[{
    "\"\<\!\(\*UnderscriptBox[\(\[ContourIntegral]\), \(C\)]\) \>\"", ",", 
     RowBox[{"f", "[", "z", "]"}], ",", "\"\< \[DifferentialD]z = \>\"", ",", 
     "val"}], "]"}], "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The contour is the unit circle  C: |z| = 1.\>\"", 
     "]"}], ";"}], "  ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399289163171875*^9, 3.399289169234375*^9}, {
   3.399882612734375*^9, 3.399882612921875*^9}, 3.40026696325*^9},
 AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 6.12 (c)",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 StyleBox["For illustration.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]],
 "  We use  n=5  and use the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   StyleBox[
    SuperscriptBox["z", "5"],
    FontSize->14]}]]],
 ".  Choose the contour",
 " ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " ",
 "to be the unit circle C: |z| = 1 with positive orientation. "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", "z", "]"}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "F", ",", "\[Theta]"}], "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     SuperscriptBox["z", "5"]}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"z", "[", "\[Theta]_", "]"}], " ", "=", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]]}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "\[Theta]_", "]"}], " ", "=", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"f", "[", 
        RowBox[{"z", "[", "\[Theta]", "]"}], "]"}], 
       RowBox[{
        RowBox[{"z", "'"}], "[", "\[Theta]", "]"}], 
       RowBox[{"\[DifferentialD]", "\[Theta]"}]}]}]}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"val", " ", "=", " ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", 
       RowBox[{"2", "\[Pi]"}]], 
      RowBox[{
       RowBox[{"f", "[", 
        RowBox[{"z", "[", "\[Theta]", "]"}], "]"}], 
       RowBox[{
        RowBox[{"z", "'"}], "[", "\[Theta]", "]"}], 
       RowBox[{"\[DifferentialD]", "\[Theta]"}]}]}]}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<              f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<              z[\[Theta]] = \>\"", ",", 
      RowBox[{"z", "[", "\[Theta]", "]"}]}], "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<           f[z[\[Theta]]] = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"z", "[", "\[Theta]", "]"}], "]"}]}], "]"}], ";"}], "  ", "\n",
    
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<             z'[\[Theta]] = \>\"", ",", 
      RowBox[{
       RowBox[{"z", "'"}], "[", "\[Theta]", "]"}]}], "]"}], ";"}], "  ", "\n",
    
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<     f[z[\[Theta]]] z'[\[Theta]] = \>\"", ",", 
      RowBox[{
       RowBox[{"f", "[", 
        RowBox[{"z", "[", "\[Theta]", "]"}], "]"}], " ", 
       RowBox[{
        RowBox[{"z", "'"}], "[", "\[Theta]", "]"}]}]}], "]"}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< F[\[Theta]] = \[Integral] f[z[\[Theta]]]z'[\[Theta]] \
\[DifferentialD]\[Theta] = \>\"", ",", 
      RowBox[{"F", "[", "\[Theta]", "]"}]}], "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[2\[Pi]] = \>\"", ",", 
      RowBox[{"F", "[", 
       RowBox[{"2", "\[Pi]"}], "]"}], ",", "\"\<,  and  F[0] = \>\"", ",", 
      RowBox[{"F", "[", "0", "]"}]}], "]"}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderoverscriptBox[\(\[Integral]\), \(0\), \(2  \
\[Pi]\)]\)\>\"", ",", 
      "\"\<f[z[\[Theta]]]z'[\[Theta]]\[DifferentialD]\[Theta] = \>\"", ",", 
      "\"\<\!\(\*UnderoverscriptBox[\(\[Integral]\), \(0\), \(2  \[Pi]\)]\)\>\
\"", ",", 
      RowBox[{
       RowBox[{"f", "[", 
        RowBox[{"z", "[", "\[Theta]", "]"}], "]"}], 
       RowBox[{
        RowBox[{"z", "'"}], "[", "\[Theta]", "]"}]}], ",", 
      "\"\< \[DifferentialD]\[Theta] = \>\"", ",", 
      RowBox[{"F", "[", 
       RowBox[{"2", "\[Pi]"}], "]"}], ",", "\"\< - \>\"", ",", 
      RowBox[{"F", "[", "0", "]"}], ",", "\"\< = \>\"", ",", 
      RowBox[{
       RowBox[{"F", "[", 
        RowBox[{"2", "\[Pi]"}], "]"}], "-", 
       RowBox[{"F", "[", "0", "]"}]}]}], "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderoverscriptBox[\(\[Integral]\), \(0\), \(2  \
\[Pi]\)]\)\>\"", ",", 
      "\"\<f[z[\[Theta]]]z'[\[Theta]]\[DifferentialD]\[Theta] = \>\"", ",", 
      "val"}], "]"}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"contour", " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", 
        RowBox[{"Circle", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}], ",", "1"}], "]"}]}], "}"}], 
      "]"}]}], ";"}], "  ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{"contour", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          FractionBox[
           RowBox[{"-", "3"}], "2"], ",", 
          FractionBox["3", "2"]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          FractionBox[
           RowBox[{"-", "3"}], "2"], ",", 
          FractionBox["3", "2"]}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          FractionBox[
           RowBox[{"-", "3"}], "2"], ",", 
          FractionBox["3", "2"], ",", 
          FractionBox["1", "2"]}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          FractionBox[
           RowBox[{"-", "3"}], "2"], ",", 
          FractionBox["3", "2"], ",", 
          FractionBox["1", "2"]}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Print", "[", 
    RowBox[{
    "\"\<\!\(\*UnderscriptBox[\(\[ContourIntegral]\), \(C\)]\) \>\"", ",", 
     RowBox[{"f", "[", "z", "]"}], ",", "\"\< \[DifferentialD]z = \>\"", ",", 
     "val"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The contour is the unit circle  C: |z| = 1.\>\"", 
     "]"}], ";"}], "  ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399289176125*^9, 3.399289180203125*^9}, {
   3.39988261821875*^9, 3.399882618421875*^9}, 3.4002669583125*^9},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 6.13.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  If ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " is a simple closed contour such that the origin does not lie interior to \
",
 StyleBox["C",
  FontFamily->"Courier New"],
 ", then there is a simply connected domain ",
 StyleBox["D",
  FontFamily->"Courier New"],
 " that contains ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " in which  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   FractionBox["1", 
    SuperscriptBox["z", "n"]]}]]],
 "  is analytic, as is indicated in Figure 6.22.  The Cauchy-Goursat theorem \
implies that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["\[Integral]", "C"], 
    RowBox[{
     FractionBox["1", 
      SuperscriptBox["z", "n"]], 
     RowBox[{"\[DifferentialD]", "z"}]}]}], " ", "=", " ", "0"}]]],
 "."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "\t\t\t",
 Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
  ImageSize->{259, 214},
  ImageMargins->0],
 StyleBox["\n\t\t\t",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Figure 6.22",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/cauchygoursat/\
CauchyGoursatMod/Images/mat0622.gif"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 "  A simple connected domain ",
 StyleBox["D",
  FontFamily->"Courier New"],
 " containing the simple closed contour ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " that does not contain the origin."
}], "Text",
 CellChangeTimes->{{3.399288933484375*^9, 3.399288954453125*^9}}],

Cell[TextData[{
 "\tWe want to be able to replace integrals over certain complicated contours \
with integrals that are easy to evaluate.  If ",
 Cell[BoxData[
  SubscriptBox["C", "1"]]],
 " is a simple closed contour that can be \"continuously deformed'' into \
another simple closed contour ",
 Cell[BoxData[
  SubscriptBox["C", "2"]]],
 " without passing through a point where f is not analytic, then the value of \
the contour integral of f over ",
 Cell[BoxData[
  SubscriptBox["C", "1"]]],
 " is the same as the value of the integral of f over ",
 Cell[BoxData[
  SubscriptBox["C", "2"]]],
 ".  To be precise, we state the following result."
}], "Text"],

Cell[TextData[{
 StyleBox["Theorem 6.6 (Deformation of Contour).",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Let  ",
 Cell[BoxData[
  SubscriptBox["C", "1"]]],
 "  and  ",
 Cell[BoxData[
  SubscriptBox["C", "2"]]],
 "  be two simple closed positively oriented contours such that  ",
 Cell[BoxData[
  SubscriptBox["C", "1"]]],
 "  lies interior to ",
 Cell[BoxData[
  SubscriptBox["C", "2"]]],
 ".  If  ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 "  is analytic in a domain ",
 StyleBox["D",
  FontFamily->"Courier New"],
 " that contains both ",
 Cell[BoxData[
  RowBox[{" ", 
   SubscriptBox["C", "1"]}]]],
 "  and ",
 Cell[BoxData[
  SubscriptBox["C", "2"]]],
 "  and the region between them, as shown in Figure 6.23, then \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["\[Integral]", 
     SubscriptBox["C", "1"]], 
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}], 
     RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "=", "  ", 
   RowBox[{
    SubscriptBox["\[Integral]", 
     SubscriptBox["C", "2"]], 
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}], 
     RowBox[{"\[DifferentialD]", "z"}]}]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "\t\t\t",
 Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
  ImageSize->{340, 242},
  ImageMargins->0],
 StyleBox["\n\t\t\t",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Figure 6.23",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/cauchygoursat/\
CauchyGoursatMod/Images/mat0623.gif"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 "   The domain ",
 StyleBox["D",
  FontFamily->"Courier New"],
 " that contains the simple closed contours ",
 Cell[BoxData[
  SubscriptBox["C", "1"]]],
 " and ",
 Cell[BoxData[
  SubscriptBox["C", "2"]]],
 " and the region between them. "
}], "Text",
 CellChangeTimes->{{3.399288975890625*^9, 3.399288986765625*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 6.6 is in the book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"]
}, Closed]],

Cell["\<\
\tWe now state as a corollary an important result that is implied by the \
deformation of contour theorem.  This result occurs several times in the \
theory to be developed and is an important tool for computations.  You may \
want to compare the proof of Corollary 6.1 with your solution to Exercise 23 \
from Section 6.2.\
\>", "Text"],

Cell[TextData[{
 StyleBox["Corollary 6.1.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Let  ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 "  denote a fixed complex value.  If ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " is a simple closed contour with positive orientation such that  ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 "  lies interior to ",
 StyleBox["C",
  FontFamily->"Courier New"],
 ", then\n\n",
 StyleBox["(i)",
  FontColor->RGBColor[0, 0, 1]],
 "     \t\t\t ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["\[Integral]", "C"], 
    RowBox[{
     FractionBox["1", 
      RowBox[{"z", " ", "-", " ", 
       SubscriptBox["z", "0"]}]], 
     RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "=", "  ", 
   RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]"}]}]]],
 ",   and  \n \n",
 StyleBox["(ii)",
  FontColor->RGBColor[0, 0, 1]],
 "    \t\t\t ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["\[Integral]", "C"], 
    RowBox[{
     FractionBox["1", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", " ", "-", " ", 
         SubscriptBox["z", "0"]}], ")"}], "n"]], 
     RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "=", "  ", "0"}]]],
 ",   where ",
 StyleBox["n",
  FontFamily->"Courier New"],
 " is any integer except ",
 Cell[BoxData[
  RowBox[{"n", "=", "1"}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Corollary 6.1 is in the book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Demonstration for (i).",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 StyleBox["(a)",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "   Show that ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["\[Integral]", "C"], 
    RowBox[{
     FractionBox["1", 
      RowBox[{"z", " ", "-", " ", 
       SubscriptBox["z", "0"]}]], 
     RowBox[{"\[DifferentialD]", "z"}]}]}], "=", 
   RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]"}]}]]],
 ".  \n",
 StyleBox["For illustration.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]],
 "  We use a circle of radius 1 centered at  ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Z", "=", 
     RowBox[{"z", "=", "0"}]}], ";", " ", 
    RowBox[{"Remove", "[", 
     RowBox[{"z", ",", "Z"}], "]"}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "F", ",", "\[Theta]", ",", "z", ",", "Z"}], "]"}], 
    ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox["1", 
      RowBox[{"z", "-", 
       SubscriptBox["Z", "0"]}]]}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"z", "[", "\[Theta]_", "]"}], " ", "=", " ", 
     RowBox[{
      SubscriptBox["Z", "0"], " ", "+", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]]}]}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "\[Theta]_", "]"}], " ", "=", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"f", "[", 
        RowBox[{"z", "[", "\[Theta]", "]"}], "]"}], 
       RowBox[{
        RowBox[{"z", "'"}], "[", "\[Theta]", "]"}], 
       RowBox[{"\[DifferentialD]", "\[Theta]"}]}]}]}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"val", " ", "=", " ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", 
       RowBox[{"2", "\[Pi]"}]], 
      RowBox[{
       RowBox[{"f", "[", 
        RowBox[{"z", "[", "\[Theta]", "]"}], "]"}], 
       RowBox[{
        RowBox[{"z", "'"}], "[", "\[Theta]", "]"}], 
       RowBox[{"\[DifferentialD]", "\[Theta]"}]}]}]}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<              f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<              z[\[Theta]] = \>\"", ",", 
      RowBox[{"z", "[", "\[Theta]", "]"}]}], "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<           f[z[\[Theta]]] = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"z", "[", "\[Theta]", "]"}], "]"}]}], "]"}], ";"}], "  ", "\n",
    
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<             z'[\[Theta]] = \>\"", ",", 
      RowBox[{
       RowBox[{"z", "'"}], "[", "\[Theta]", "]"}]}], "]"}], ";"}], "  ", "\n",
    
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<     f[z[\[Theta]]] z'[\[Theta]] = \>\"", ",", 
      RowBox[{
       RowBox[{"f", "[", 
        RowBox[{"z", "[", "\[Theta]", "]"}], "]"}], " ", 
       RowBox[{
        RowBox[{"z", "'"}], "[", "\[Theta]", "]"}]}]}], "]"}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< F[\[Theta]] = \[Integral] f[z[\[Theta]]]z'[\[Theta]] \
\[DifferentialD]\[Theta] = \>\"", ",", 
      RowBox[{"F", "[", "\[Theta]", "]"}]}], "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[2\[Pi]] = \>\"", ",", 
      RowBox[{"F", "[", 
       RowBox[{"2", "\[Pi]"}], "]"}], ",", "\"\<,  and  F[0] = \>\"", ",", 
      RowBox[{"F", "[", "0", "]"}]}], "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderoverscriptBox[\(\[Integral]\), \(0\), \(2  \
\[Pi]\)]\)\>\"", ",", 
      "\"\<f[z[\[Theta]]]z'[\[Theta]]\[DifferentialD]\[Theta] = \>\"", ",", 
      "\"\<\!\(\*UnderoverscriptBox[\(\[Integral]\), \(0\), \(2  \[Pi]\)]\)\>\
\"", ",", 
      RowBox[{
       RowBox[{"f", "[", 
        RowBox[{"z", "[", "\[Theta]", "]"}], "]"}], 
       RowBox[{
        RowBox[{"z", "'"}], "[", "\[Theta]", "]"}]}], ",", 
      "\"\< \[DifferentialD]\[Theta] = \>\"", ",", 
      RowBox[{"F", "[", 
       RowBox[{"2", "\[Pi]"}], "]"}], ",", "\"\< - \>\"", ",", 
      RowBox[{"F", "[", "0", "]"}], ",", "\"\< = \>\"", ",", 
      RowBox[{
       RowBox[{"F", "[", 
        RowBox[{"2", "\[Pi]"}], "]"}], "-", 
       RowBox[{"F", "[", "0", "]"}]}]}], "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderoverscriptBox[\(\[Integral]\), \(0\), \(2  \
\[Pi]\)]\)\>\"", ",", 
      "\"\<f[z[\[Theta]]]z'[\[Theta]]\[DifferentialD]\[Theta] = \>\"", ",", 
      "val"}], "]"}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dot", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
        RowBox[{"Point", "[", 
         RowBox[{"{", 
          RowBox[{"2", ",", 
           FractionBox["5", "3"]}], "}"}], "]"}]}], "}"}], "]"}]}], ";"}], 
   "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"center", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"StyleForm", "[", 
           RowBox[{
            RowBox[{
            "TraditionalForm", "[", 
             "\"\<\!\(\*SubscriptBox[\(z\), \(0\)]\)\>\"", "]"}], ",", 
            RowBox[{"FontSize", "\[Rule]", "12"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"2", ",", "1.6"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1"}], "}"}]}], "]"}], "}"}], "}"}], "]"}]}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"contour", " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", 
        RowBox[{"Circle", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"2", ",", 
            FractionBox["5", "3"]}], "}"}], ",", "1"}], "]"}]}], "}"}], 
      "]"}]}], ";"}], "  ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{"center", ",", "contour", ",", "dot", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "4"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "3"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", "None"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["3", "4"]}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Print", "[", 
    RowBox[{
    "\"\<\!\(\*UnderscriptBox[\(\[ContourIntegral]\), \(C\)]\) \>\"", ",", 
     RowBox[{"f", "[", "z", "]"}], ",", "\"\< \[DifferentialD]z = \>\"", ",", 
     "val"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The contour is the unit circle C: |z - \!\(\*SubscriptBox[\(z\), \
\(0\)]\)| = 1,\>\"", "]"}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<with positive orientation.\>\"", "]"}], ";"}], 
   "  ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399289193578125*^9, 3.399289197765625*^9}, {
   3.399882623125*^9, 3.399882623296875*^9}, 3.4002669479375*^9},
 AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Demonstration for (ii).",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 StyleBox["(b)",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "   Show that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["\[Integral]", "C"], 
    RowBox[{
     FractionBox["1", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", " ", "-", " ", 
         SubscriptBox["z", "0"]}], ")"}], "n"]], 
     RowBox[{"\[DifferentialD]", "z"}]}]}], "=", "0"}]]],
 ".  \n",
 StyleBox["For illustration.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]],
 "  We use n = 5 and a circle of radius 1 centered at  ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Z", "=", 
     RowBox[{"z", "=", "0"}]}], ";", " ", 
    RowBox[{"Remove", "[", 
     RowBox[{"z", ",", "Z"}], "]"}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "F", ",", "\[Theta]", ",", "z", ",", "Z"}], "]"}], 
    ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox["1", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "-", 
         SubscriptBox["Z", "0"]}], ")"}], "5"]]}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"z", "[", "\[Theta]_", "]"}], " ", "=", " ", 
     RowBox[{
      SubscriptBox["Z", "0"], " ", "+", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]]}]}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "\[Theta]_", "]"}], " ", "=", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"f", "[", 
        RowBox[{"z", "[", "\[Theta]", "]"}], "]"}], 
       RowBox[{
        RowBox[{"z", "'"}], "[", "\[Theta]", "]"}], 
       RowBox[{"\[DifferentialD]", "\[Theta]"}]}]}]}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"val", " ", "=", " ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", 
       RowBox[{"2", "\[Pi]"}]], 
      RowBox[{
       RowBox[{"f", "[", 
        RowBox[{"z", "[", "\[Theta]", "]"}], "]"}], 
       RowBox[{
        RowBox[{"z", "'"}], "[", "\[Theta]", "]"}], 
       RowBox[{"\[DifferentialD]", "\[Theta]"}]}]}]}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<              f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<              z[\[Theta]] = \>\"", ",", 
      RowBox[{"z", "[", "\[Theta]", "]"}]}], "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<           f[z[\[Theta]]] = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"z", "[", "\[Theta]", "]"}], "]"}]}], "]"}], ";"}], "  ", "\n",
    
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<             z'[\[Theta]] = \>\"", ",", 
      RowBox[{
       RowBox[{"z", "'"}], "[", "\[Theta]", "]"}]}], "]"}], ";"}], "  ", "\n",
    
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<     f[z[\[Theta]]] z'[\[Theta]] = \>\"", ",", 
      RowBox[{
       RowBox[{"f", "[", 
        RowBox[{"z", "[", "\[Theta]", "]"}], "]"}], " ", 
       RowBox[{
        RowBox[{"z", "'"}], "[", "\[Theta]", "]"}]}]}], "]"}], ";"}], "  ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< F[\[Theta]] = \[Integral] f[z[\[Theta]]]z'[\[Theta]] \
\[DifferentialD]\[Theta] = \>\"", ",", 
      RowBox[{"F", "[", "\[Theta]", "]"}]}], "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[2\[Pi]] = \>\"", ",", 
      RowBox[{"F", "[", 
       RowBox[{"2", "\[Pi]"}], "]"}], ",", "\"\<,  and  F[0] = \>\"", ",", 
      RowBox[{"F", "[", "0", "]"}]}], "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderoverscriptBox[\(\[Integral]\), \(0\), \(2  \
\[Pi]\)]\)\>\"", ",", 
      "\"\<f[z[\[Theta]]]z'[\[Theta]]\[DifferentialD]\[Theta] = \>\"", ",", 
      "\"\<\!\(\*UnderoverscriptBox[\(\[Integral]\), \(0\), \(2  \[Pi]\)]\)\>\
\"", ",", 
      RowBox[{
       RowBox[{"f", "[", 
        RowBox[{"z", "[", "\[Theta]", "]"}], "]"}], 
       RowBox[{
        RowBox[{"z", "'"}], "[", "\[Theta]", "]"}]}], ",", 
      "\"\< \[DifferentialD]\[Theta] = \>\"", ",", 
      RowBox[{"F", "[", 
       RowBox[{"2", "\[Pi]"}], "]"}], ",", "\"\< - \>\"", ",", 
      RowBox[{"F", "[", "0", "]"}], ",", "\"\< = \>\"", ",", 
      RowBox[{
       RowBox[{"F", "[", 
        RowBox[{"2", "\[Pi]"}], "]"}], "-", 
       RowBox[{"F", "[", "0", "]"}]}]}], "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderoverscriptBox[\(\[Integral]\), \(0\), \(2  \
\[Pi]\)]\)\>\"", ",", 
      "\"\<f[z[\[Theta]]]z'[\[Theta]]\[DifferentialD]\[Theta] = \>\"", ",", 
      "val"}], "]"}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dot", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
        RowBox[{"Point", "[", 
         RowBox[{"{", 
          RowBox[{"2", ",", 
           FractionBox["5", "3"]}], "}"}], "]"}]}], "}"}], "]"}]}], ";"}], 
   "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"center", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"StyleForm", "[", 
           RowBox[{
            RowBox[{
            "TraditionalForm", "[", 
             "\"\<\!\(\*SubscriptBox[\(z\), \(0\)]\)\>\"", "]"}], ",", 
            RowBox[{"FontSize", "\[Rule]", "12"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"2", ",", "1.6"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1"}], "}"}]}], "]"}], "}"}], "}"}], "]"}]}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"contour", " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", 
        RowBox[{"Circle", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"2", ",", 
            FractionBox["5", "3"]}], "}"}], ",", "1"}], "]"}]}], "}"}], 
      "]"}]}], ";"}], "  ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{"center", ",", "contour", ",", "dot", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "4"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "3"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", "None"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["3", "4"]}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Print", "[", 
    RowBox[{
    "\"\<\!\(\*UnderscriptBox[\(\[ContourIntegral]\), \(C\)]\) \>\"", ",", 
     RowBox[{"f", "[", "z", "]"}], ",", "\"\< \[DifferentialD]z = \>\"", ",", 
     "val"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The contour is the unit circle C: |z - \!\(\*SubscriptBox[\(z\), \
\(0\)]\)| = 1,\>\"", "]"}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<with positive orientation.\>\"", "]"}], ";"}], 
   "  ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399289205984375*^9, 3.399289210171875*^9}, {
   3.399882628125*^9, 3.399882628296875*^9}, 3.40026693559375*^9},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 "\tThe deformation of contour theorem is an extension of the Cauchy-Goursat \
theorem to a doubly connected domain in the following sense.  Let ",
 StyleBox["D",
  FontFamily->"Courier New"],
 " be a domain that contains ",
 Cell[BoxData[
  SubscriptBox["C", "1"]]],
 " and ",
 Cell[BoxData[
  SubscriptBox["C", "2"]]],
 " and the region between them, as shown in Figure 6.23.  Then the contour ",
 Cell[BoxData[
  RowBox[{"C", "=", 
   RowBox[{
    SubscriptBox["C", "2"], "-", 
    SubscriptBox["C", "1"]}]}]]],
 " is a parametrization of the boundary of the region ",
 StyleBox["R",
  FontFamily->"Courier New"],
 " that lies between ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["C", "1"], 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], " ", 
   SubscriptBox["C", "2"]}]]],
 " so that the points of ",
 StyleBox["R",
  FontFamily->"Courier New"],
 " lie to the left of ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " as a point ",
 StyleBox["z(t)",
  FontFamily->"Courier New"],
 " moves around ",
 StyleBox["C",
  FontFamily->"Courier New"],
 ".  Hence ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " is a positive orientation of the boundary of ",
 StyleBox["R",
  FontFamily->"Courier New"],
 ", and Theorem 6.6 implies that ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["\[Integral]", "C"], " ", 
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}], 
     RowBox[{"\[DifferentialD]", "z"}]}]}], "=", "0"}]]],
 ".  "
}], "Text"],

Cell["\<\
\tWe can extend Theorem 6.6 to multiply connected domains with more than one \
\"hole.''  The proof, which is left for the reader, involves the introduction \
of several cuts and is similar to the proof of Theorem 6.6.\
\>", "Text"],

Cell[TextData[{
 StyleBox["Theorem 6.7 (Extended Cauchy-Goursat Theorem).",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Let  ",
 Cell[BoxData[
  RowBox[{"C", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   SubscriptBox["C", "1"], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   SubscriptBox["C", "2"], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "...", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   SubscriptBox["C", "n"]}]]],
 "   be simple closed positively oriented contours with the property that  ",
 Cell[BoxData[
  SubscriptBox["C", "k"]]],
 "  lies interior to ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " for   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"k", "=", "1"}], 
   StyleBox[",",
    FontFamily->"Times New Roman"], "2", 
   StyleBox[",",
    FontFamily->"Times New Roman"], "...", 
   StyleBox[",",
    FontFamily->"Times New Roman"], "n"}]]],
 "  and the set of interior to  ",
 Cell[BoxData[
  SubscriptBox["C", "k"]]],
 "  has no points in common with the set interior to  ",
 Cell[BoxData[
  SubscriptBox["C", "j"]]],
 "  if  ",
 Cell[BoxData[
  RowBox[{"k", "\[NotEqual]", "j"}]]],
 ".  Let  ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 "  be analytic on a domain ",
 StyleBox["D",
  FontFamily->"Courier New"],
 " that contains all the contours and the region between ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["C", "1"], "+", 
     SubscriptBox["C", "2"], "+"}], "..."}], "+", 
   SubscriptBox["C", "n"]}]]],
 ",  as shown in Figure 6.26. Then\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["\[Integral]", "C"], " ", 
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}], 
     RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "=", "  ", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"k", "=", "1"}], "n"], 
    RowBox[{
     SubscriptBox["\[Integral]", 
      SubscriptBox["C", "k"]], 
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}], 
      RowBox[{"\[DifferentialD]", "z"}]}]}]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "\t\t\t",
 Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
  ImageSize->{381, 267},
  ImageMargins->0],
 StyleBox["\n\t\t\t",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Figure 6.26",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/cauchygoursat/\
CauchyGoursatMod/Images/mat0626.gif"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 "  The multiply connected domain ",
 StyleBox["D",
  FontFamily->"Courier New"],
 " and the contours  ",
 Cell[BoxData[
  RowBox[{"C", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   SubscriptBox["C", "1"], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   SubscriptBox["C", "2"], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "...", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   SubscriptBox["C", "n"]}]]],
 "  in the statement of the extended Cauchy-Goursat theorem."
}], "Text",
 CellChangeTimes->{{3.3992889934375*^9, 3.399289005015625*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 6.7 is in the book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 6.14.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Show that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["\[Integral]", "C"], 
    RowBox[{
     FractionBox[
      RowBox[{"2", "z"}], 
      RowBox[{
       SuperscriptBox["z", "2"], " ", "+", " ", "2"}]], 
     RowBox[{"\[DifferentialD]", "z"}]}]}], " ", "=", " ", 
   RowBox[{"4", " ", "\[Pi]", " ", "\[ImaginaryI]"}]}]]],
 ",  where",
 " ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " ",
 "is the circle  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"C", ":", 
    RowBox[{"|", "z", "|"}]}], "=", "2"}]]],
 "  taken with positive orientation."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "\t\t\t",
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.5 0.238095 [
[.02381 .4875 -6 -9 ]
[.02381 .4875 6 0 ]
[.2619 .4875 -6 -9 ]
[.2619 .4875 6 0 ]
[.7381 .4875 -3 -9 ]
[.7381 .4875 3 0 ]
[.97619 .4875 -3 -9 ]
[.97619 .4875 3 0 ]
[1.025 .5 0 -6.28125 ]
[1.025 .5 10 6.28125 ]
[.4875 .02381 -12 -4.5 ]
[.4875 .02381 0 4.5 ]
[.4875 .2619 -12 -4.5 ]
[.4875 .2619 0 4.5 ]
[.4875 .7381 -6 -4.5 ]
[.4875 .7381 0 4.5 ]
[.4875 .97619 -6 -4.5 ]
[.4875 .97619 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .5 m
.02381 .50625 L
s
[(-2)] .02381 .4875 0 1 Mshowa
.2619 .5 m
.2619 .50625 L
s
[(-1)] .2619 .4875 0 1 Mshowa
.7381 .5 m
.7381 .50625 L
s
[(1)] .7381 .4875 0 1 Mshowa
.97619 .5 m
.97619 .50625 L
s
[(2)] .97619 .4875 0 1 Mshowa
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .02381 m
.50625 .02381 L
s
[(-2)] .4875 .02381 1 0 Mshowa
.5 .2619 m
.50625 .2619 L
s
[(-1)] .4875 .2619 1 0 Mshowa
.5 .7381 m
.50625 .7381 L
s
[(1)] .4875 .7381 1 0 Mshowa
.5 .97619 m
.50625 .97619 L
s
[(2)] .4875 .97619 1 0 Mshowa
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.03 w
.5 .16328 Mdot
.5 .83672 Mdot
0 g
gsave
.5 .12757 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
70.188 14.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
75.813 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .801 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
70.188 14.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
75.813 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 1 r
.5 Mabswid
newpath
.5 .5 .47619 0 365.73 arc
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{194, 194},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\
eJztWu1SFEcUbdldhagxuoQPgbAiC4IEBWMwKi5IEBFRMTGJqVSlKEsLf6SS
Mj5SnoQXm9B9eu58cLrpgVl0Ladqd6buOfd0T093T8/tu7n9fuf1X9vv377a
bqy92/5n5+2rfxsP/n63Z6qcUErt6l9D6eto79L+7aoo2rv63Zwqytj2rvTv
9YHQT/pU1UDlAFIOqrrpW/p0Qdv/hGFDn05qA/PqIraT4vESEmtxPaNuW3ya
7qj+GXF6AdqKGM7qqy5NZlX6SnhbcGyJoZ/QewXdBH0xVo+GCH1A0A3Q74hh
hNAvCroO+oIUN0row4Kugn5T/C8TekPQFdC/E1IkJOY4Jo7LcJwXwwShjwva
Av26GK4Q+oSgi6DPimGa0K+QSt+G44w4zhDHKUEt/SpRYo6Mt1BMwnTymrZc
Ih7fQyyp4DUi0e19MFZiUgxzhF5zjZ5xUqkbUJwg0FyiJjY7Nu0Q51hSOyve
JOLzpH5s3mD3MUn0rqMo9y0y2Wq+/mb+mCYaeFT7noSvcbIFfktEZ+Hh7iv7
6mfKuyaVsAINl0BFxZML7bxq1OVYczliJKhvXGPFON4iKBpVjRDoljj+QNAp
OA4T6Lbc4x2CYgZRQwS6Sx4Qk0BHw3ydgxaJxF3CmygmsUh4GD6pl8xSMcd+
AjGJe4Q3XkyiRXh41ag+Ai0TiSXCGysmsUx4GGTqawLdb4/EfcLDSFV1eZSr
xHGFOGKkqgsEKkHCPPmaa+r6kXhgAlDnA59IO2XNnP2AeGCuwdKPzRxmdg1d
v64WK4B1CCbL6o2pTp1zyToXuR6xLwm0TiTWCG+omMRDwsP0p84S6FF7JNYJ
b/DYJR4R3gAkzhBooz0SG4SHGV2dJtDjY5f4gkCb7ZF4THh9xy6xSXh4r6ge
Aj35lCWeEF4vJLoJ9PRTlnhKeHVInCLQs88SR5MwURWVOsxy3ayExoleM4ua
F7GVj2lYXiESkINYmIOVMhnA07q9+4sCpI5UVDNlizVto6mKlKAP3H9NKhQr
6MMslp0rrNC6sLBEpoVrmRaOC2fxp2ItnXx5W/16utRqprHjArukA7G7MGi6
wFzb5h+j/m0RsWeERzpdZ0p0p4dVuqvVjq7dk+PpA3pYmVdtsekZ4T9iMwqn
SKGeOrKOFmpjY6Cd7fRx9ITPEu2QCH1xliDRISuADy1Rwsqws5a4HokSvhg6
69PHI1HCl2RnfRJ/9EGKEqItJcR8Sog8dVYIzRMLLCEiWUJclMVpH7ZHwhPg
ZUHoJf3vDOsXFAuNaHsC5aWG9dk+xlJgHT1bD0eR9ey61Al0T26TfSJ7xHoJ
tEIkPDtQJWxilbCVFrqhZ9ZZxsT2pK1Y6B4l+3RLMmoKbng6cy1uEAGrPUCg
VqImNkNW/lyLm+5iBuWeWoH9N2/TB7sPu68cuqfNmocVP0f07Pa5exM/PAOD
pUFNHiTPMzCYlE03OHSewqEzIw6dizFKoKDsj4b0rAW5M0+WyRiBkn6be0Cp
xKhUklqUJQWMNSsRmg80T3g2pagp1WKOrNPC5klTykok+Ty4OZr7xnLFZp3t
Y/tGFpotJjEt1WKOSRKezZGbIUpXiWMiiz6NzChjYHSJrEYYO6nWmiJ01ubW
cU4cnVFvgyINBr3EGJqEfllQvBXoRDxGHC+JI96VGHHGwOijgmLNgvFsDA1C
HxEUK6ck0SEaJvRBQbHaTJYk0UVC7xcUn054Ixr/PkKvC4pvXyy7jOF0fEVf
DueE9xyOpnYmebhG6Gz11CMev0DCVGFAG/6A4QXxYq+NTMZ0UJKy9fg5bi1f
ZvXhcrx3g0+/SSV2YHhJVN8cWGDeSx9vUiXsbxiL/qpP8MsGqgPuRJ34Hxi/
+7Q=\
\>"],
  ImageRangeCache->{{{0, 193}, {193, 0}} -> {-2, -2, 0, 0}}],
 "  "
}], "Text"],

Cell[TextData[{
 "Solution.  Using partial fraction decomposition gives  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   FractionBox[
    RowBox[{"2", "z"}], 
    RowBox[{
     SuperscriptBox["z", "2"], " ", "+", " ", "2"}]], "  ", "=", "  ", 
   RowBox[{
    FractionBox[
     RowBox[{"2", "z"}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"z", " ", "+", " ", 
        RowBox[{"\[ImaginaryI]", " ", 
         SqrtBox["2"]}]}], ")"}], 
      RowBox[{"(", 
       RowBox[{"z", " ", "-", " ", 
        RowBox[{"\[ImaginaryI]", " ", 
         SqrtBox["2"]}]}], ")"}]}]], "  ", "=", "   ", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"z", " ", "+", " ", 
       RowBox[{"\[ImaginaryI]", " ", 
        SqrtBox["2"]}]}]], "+", 
     FractionBox["1", 
      RowBox[{"z", " ", "-", " ", 
       RowBox[{"\[ImaginaryI]", " ", 
        SqrtBox["2"]}]}]]}]}]}]]],
 ",  so    \n\n",
 StyleBox["(6-38)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["\[Integral]", "C"], 
    RowBox[{
     FractionBox[
      RowBox[{"2", "z"}], 
      RowBox[{
       SuperscriptBox["z", "2"], " ", "+", " ", "2"}]], 
     RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Integral]", "C"], 
     RowBox[{
      FractionBox["1", 
       RowBox[{"z", " ", "+", " ", 
        RowBox[{"\[ImaginaryI]", " ", 
         SqrtBox["2"]}]}]], 
      RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "+", "  ", 
    RowBox[{
     SubscriptBox["\[Integral]", "C"], 
     RowBox[{
      FractionBox["1", 
       RowBox[{"z", " ", "-", " ", 
        RowBox[{"\[ImaginaryI]", " ", 
         SqrtBox["2"]}]}]], 
      RowBox[{"\[DifferentialD]", "z"}]}]}]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "\nThe points  ",
 Cell[BoxData[
  RowBox[{"z", " ", "=", " ", 
   RowBox[{
    RowBox[{"\[PlusMinus]", " ", "\[ImaginaryI]"}], " ", 
    SqrtBox["2"]}]}]]],
 "  lie interior to ",
 StyleBox["C",
  FontFamily->"Courier New"],
 ",  so Corollary 6.1 implies that  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["\[Integral]", "C"], 
    RowBox[{
     FractionBox["1", 
      RowBox[{"z", " ", "\[PlusMinus]", " ", 
       RowBox[{"\[ImaginaryI]", " ", 
        SqrtBox["2"]}]}]], 
     RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "=", "  ", 
   RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]"}]}]]],
 ".  \n\nSubstituting these values into Equation ",
 StyleBox["(6-38)",
  FontColor->RGBColor[0, 0, 1]],
 " yields  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["\[Integral]", "C"], 
     RowBox[{
      FractionBox[
       RowBox[{"2", "z"}], 
       RowBox[{
        SuperscriptBox["z", "2"], " ", "+", " ", "2"}]], 
      RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Integral]", "C"], 
      RowBox[{
       FractionBox["1", 
        RowBox[{"z", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", 
          SqrtBox["2"]}]}]], 
       RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "+", "  ", 
     RowBox[{
      SubscriptBox["\[Integral]", "C"], 
      RowBox[{
       FractionBox["1", 
        RowBox[{"z", " ", "-", " ", 
         RowBox[{"\[ImaginaryI]", " ", 
          SqrtBox["2"]}]}]], 
       RowBox[{"\[DifferentialD]", "z"}]}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                      ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]"}], "  ", "+", "  ", 
      RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]"}]}]}], "  ", 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                      ", 
   RowBox[{"=", "  ", 
    RowBox[{"4", "\[Pi]", " ", "\[ImaginaryI]"}]}]}]}]],
 "  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 6.14.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 "Enter the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], "=", 
   FractionBox[
    RowBox[{"2", "z"}], 
    RowBox[{
     SuperscriptBox["z", "2"], " ", "+", " ", "2"}]]}]],
  AspectRatioFixed->True],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", 
     RowBox[{"R", ",", "W", ",", "z", ",", "Z"}], "]"}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "F", ",", "i", ",", "p", ",", "solset"}], "]"}], ";"}],
    "  ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox[
      RowBox[{"2", "z"}], 
      RowBox[{
       SuperscriptBox["z", "2"], " ", "+", " ", "2"}]]}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], "  ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39928922425*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "First, split the function up into partial fractions involving linear terms \
in the denominators. Don't worry about the subroutine.  It splits  ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 "  up into partial fractions.  The result will be an equivalent function \
named F[z].  The list of terms added to form F[z] have singularities in the \
same order in the list of points Z."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"solset", " ", "=", " ", 
     RowBox[{"Sort", "[", 
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Denominator", "[", 
          RowBox[{"f", "[", "z", "]"}], "]"}], "\[Equal]", "0"}], ",", "z"}], 
       "]"}], "]"}]}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Z", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"Length", "[", "solset", "]"}], "}"}]}], "]"}]}], ";"}], "  ",
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"W", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"Length", "[", "solset", "]"}], "}"}]}], "]"}]}], ";"}], "  ",
    "\n", 
   RowBox[{
    RowBox[{"R", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"Length", "[", "solset", "]"}], "}"}]}], "]"}]}], ";"}], "  ",
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "z_", "]"}], " ", "=", " ", "0"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"i", "=", "1"}], ",", 
      RowBox[{"i", "\[LessEqual]", 
       RowBox[{"Length", "[", "solset", "]"}]}], ",", 
      RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        SubscriptBox["Z", 
         RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], " ",
         "=", " ", 
        RowBox[{"ReplaceAll", "[", 
         RowBox[{"z", ",", 
          SubscriptBox["solset", 
           RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]]}], 
         "]"}]}], ";", "   ", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"1", "\[Equal]", "i"}], ",", 
         RowBox[{"p", " ", "=", " ", "1"}]}], "]"}], ";", "  ", 
       "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"1", "<", "i"}], ";", "  ", 
          RowBox[{
           SubscriptBox["Z", 
            RowBox[{"\[LeftDoubleBracket]", 
             RowBox[{"i", "-", "1"}], "\[RightDoubleBracket]"}]], "\[Equal]", 
           
           SubscriptBox["Z", 
            RowBox[{
            "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]]}]}], ",", 
         
         RowBox[{"p", " ", "=", " ", 
          RowBox[{"p", "+", "1"}]}], ",", 
         RowBox[{"p", " ", "=", " ", "1"}]}], "]"}], ";", "  ", 
       "\[IndentingNewLine]", 
       RowBox[{
        SubscriptBox["R", 
         RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], " ",
         "=", " ", 
        RowBox[{"Residue", "[", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"z", "-", 
              SubscriptBox["Z", 
               RowBox[{
               "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]]}], 
             ")"}], 
            RowBox[{"p", "-", "1"}]], 
           RowBox[{"f", "[", "z", "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"z", ",", 
            SubscriptBox["Z", 
             RowBox[{
             "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]]}], 
           "}"}]}], "]"}]}], ";", "  ", "\[IndentingNewLine]", 
       RowBox[{
        SubscriptBox["W", 
         RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], "=",
         " ", 
        FractionBox[
         SubscriptBox["R", 
          RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"z", "-", 
            SubscriptBox["Z", 
             RowBox[{
             "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]]}], ")"}],
           "p"]]}], ";", "  ", "\n", "   ", 
       RowBox[{
        RowBox[{"F", "[", "z_", "]"}], " ", "=", " ", 
        RowBox[{
         RowBox[{"F", "[", "z", "]"}], " ", "+", 
         FractionBox[
          SubscriptBox["R", 
           RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"z", "-", 
             SubscriptBox["Z", 
              RowBox[{
              "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]]}], 
            ")"}], "p"]]}]}], ";"}]}], "  ", "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"i", "=", "1"}], ",", 
      RowBox[{"i", "\[LessEqual]", 
       RowBox[{"Length", "[", 
        RowBox[{"F", "[", "z", "]"}], "]"}]}], ",", 
      RowBox[{"i", "++"}], ",", "\n", "   ", 
      RowBox[{
       RowBox[{"soset", " ", "=", " ", 
        RowBox[{"Solve", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Denominator", "[", 
            SubscriptBox["W", 
             RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], 
            "]"}], "\[Equal]", "0"}], ",", "z"}], "]"}]}], ";", "  ", "\n", 
       "   ", 
       RowBox[{
        SubscriptBox["Z", 
         RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], " ",
         "=", " ", 
        RowBox[{"ReplaceAll", "[", 
         RowBox[{"z", ",", 
          SubscriptBox["soset", 
           RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]]}], 
         "]"}]}], ";", "  ", "\n", "   ", 
       RowBox[{
        SubscriptBox["R", 
         RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], " ",
         "=", " ", 
        RowBox[{"Residue", "[", 
         RowBox[{
          RowBox[{"f", "[", "z", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"z", ",", 
            SubscriptBox["Z", 
             RowBox[{
             "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]]}], 
           "}"}]}], "]"}]}], ";"}]}], "  ", "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"F", "[", "z", "]"}]}], "]"}], ";"}], "  ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399289228046875*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "Determine which singularities lie inside  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"C", ":", 
    RowBox[{"|", "z", "|"}]}], "=", "2"}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["Z", 
       RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], ",", 
      "\"\<,  Is |\>\"", ",", 
      SubscriptBox["Z", 
       RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], ",", 
      "\"\<| < 2 ?  \>\"", ",", 
      RowBox[{
       RowBox[{"N", "[", 
        RowBox[{"Abs", "[", 
         SubscriptBox["Z", 
          RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], 
         "]"}], "]"}], "<", "2"}]}], "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(2\)]\) = \>\"", ",", 
      SubscriptBox["Z", 
       RowBox[{"\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]], ",", 
      "\"\<,   Is |\>\"", ",", 
      SubscriptBox["Z", 
       RowBox[{"\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]], ",", 
      "\"\<| < 2 ?   \>\"", ",", 
      RowBox[{
       RowBox[{"N", "[", 
        RowBox[{"Abs", "[", 
         SubscriptBox["Z", 
          RowBox[{"\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]], 
         "]"}], "]"}], "<", "2"}]}], "]"}], ";"}], "  ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39928923784375*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "Since both singularities lie inside ",
 StyleBox["C",
  FontFamily->"Courier New"],
 ", add the corresponding term in the sum forming F[z] times constant in the \
numerator that term times ",
 Cell[BoxData[
  RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]"}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"val", " ", "=", " ", 
     RowBox[{
      RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", 
       RowBox[{"Numerator", "[", 
        SubscriptBox[
         RowBox[{"F", "[", "z", "]"}], 
         RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], 
        "]"}]}], "+", 
      RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", 
       RowBox[{"Numerator", "[", 
        SubscriptBox[
         RowBox[{"F", "[", "z", "]"}], 
         RowBox[{"\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]], 
        "]"}]}]}]}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dots", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", 
               RowBox[{
               "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], "]"}],
              ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", 
               RowBox[{
               "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], 
              "]"}]}], "}"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", 
               RowBox[{
               "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]], "]"}],
              ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", 
               RowBox[{
               "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]], 
              "]"}]}], "}"}], "]"}]}], "}"}]}], "}"}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"centers", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"StyleForm", "[", 
           RowBox[{
            RowBox[{
            "TraditionalForm", "[", 
             "\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\)\>\"", "]"}], ",", 
            RowBox[{"FontSize", "\[Rule]", "12"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Re", "[", 
             SubscriptBox["Z", 
              RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]],
              "]"}], ",", 
            RowBox[{
             RowBox[{"Im", "[", 
              SubscriptBox["Z", 
               RowBox[{
               "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], "]"}],
              "-", "0.15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}], ",", 
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"StyleForm", "[", 
           RowBox[{
            RowBox[{
            "TraditionalForm", "[", 
             "\"\<\!\(\*SubscriptBox[\(z\), \(2\)]\)\>\"", "]"}], ",", 
            RowBox[{"FontSize", "\[Rule]", "12"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Re", "[", 
             SubscriptBox["Z", 
              RowBox[{"\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]],
              "]"}], ",", 
            RowBox[{
             RowBox[{"Im", "[", 
              SubscriptBox["Z", 
               RowBox[{
               "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]], "]"}],
              "-", "0.15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}]}], "}"}], "]"}]}], 
    ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"contour", " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", 
        RowBox[{"Circle", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}], ",", "2"}], "]"}]}], "}"}], 
      "]"}]}], ";"}], "  ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{"dots", ",", "centers", ",", "contour", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.1"}], ",", "2.1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.1"}], ",", "2.1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(\[ContourIntegral]\), \(C\)]\) (\>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\<) \[DifferentialD]z = \>\"", 
      ",", "\"\<\!\(\*UnderscriptBox[\(\[ContourIntegral]\), \(C\)]\) (\>\"", 
      ",", 
      SubscriptBox["W", 
       RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], ",", 
      "\"\<) \[DifferentialD]z + \>\"", ",", 
      "\"\<\!\(\*UnderscriptBox[\(\[ContourIntegral]\), \(C\)]\) (\>\"", ",", 
      
      SubscriptBox["W", 
       RowBox[{"\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]], ",", 
      "\"\<) \[DifferentialD]z\>\""}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(\[ContourIntegral]\), \(C\)]\) (\>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\<) \[DifferentialD]z = \>\"", 
      ",", "\"\<(\>\"", ",", 
      RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", 
       RowBox[{"Numerator", "[", 
        SubscriptBox[
         RowBox[{"F", "[", "z", "]"}], 
         RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], 
        "]"}]}], ",", "\"\<) + \>\"", ",", "\"\<(\>\"", ",", 
      RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", 
       RowBox[{"Numerator", "[", 
        SubscriptBox[
         RowBox[{"F", "[", "z", "]"}], 
         RowBox[{"\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]], 
        "]"}]}], ",", "\"\<)\>\""}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(\[ContourIntegral]\), \(C\)]\) (\>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\<) \[DifferentialD]z = \>\"", 
      ",", "val"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The contour is the circle  C: |z| = 2,\>\"", "]"}], 
    ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<with positive orientation.\>\"", "]"}], ";"}], 
   "  ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39928924225*^9, 3.39928924840625*^9}, {
  3.399882633625*^9, 3.399882633796875*^9}}]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 6.15.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Show that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["\[Integral]", "C"], 
    RowBox[{
     FractionBox[
      RowBox[{"2", "z"}], 
      RowBox[{
       SuperscriptBox["z", "2"], " ", "+", " ", "2"}]], 
     RowBox[{"\[DifferentialD]", "z"}]}]}], " ", "=", " ", 
   RowBox[{"2", " ", "\[Pi]", " ", "\[ImaginaryI]"}]}]]],
 ",  where",
 " ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " ",
 "is the circle  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"C", ":", 
    RowBox[{"|", 
     RowBox[{"z", "-", "\[ImaginaryI]"}], "|"}]}], "=", "1"}]]],
 "  taken with positive orientation."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "\t\t\t",
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.454545 0.0454545 0.454545 [
[.04545 .03295 -6 -9 ]
[.04545 .03295 6 0 ]
[.95455 .03295 -3 -9 ]
[.95455 .03295 3 0 ]
[1.025 .04545 0 -6.28125 ]
[1.025 .04545 10 6.28125 ]
[.4875 .5 -6 -4.5 ]
[.4875 .5 0 4.5 ]
[.4875 .95455 -6 -4.5 ]
[.4875 .95455 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04545 .04545 m
.04545 .0517 L
s
[(-1)] .04545 .03295 0 1 Mshowa
.95455 .04545 m
.95455 .0517 L
s
[(1)] .95455 .03295 0 1 Mshowa
0 .04545 m
1 .04545 L
s
gsave
1.025 .04545 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .5 m
.50625 .5 L
s
[(1)] .4875 .5 1 0 Mshowa
.5 .95455 m
.50625 .95455 L
s
[(2)] .4875 .95455 1 0 Mshowa
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.03 w
.5 .68828 Mdot
0 g
gsave
.5 .64282 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
70.188 14.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
75.813 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 1 r
.5 Mabswid
newpath
.5 .5 .45455 0 365.73 arc
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{194, 194},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\
eJztmmtTU0cYx49cWsZipYpKKRhE5SL3IqCIgAQCIjjTm23tq4xTlReddqxf
pdPvwxdLs/vfPElOf4kJbCjNmJnknHn+l91zsmf37LN7mH//9tff8u+PXuVH
dt/l/3h79OrPkdzv74qhzgtJkhy770jizgvF0/BznBQKxbPP3KHbRf6yswFB
l/yhM/H04pn7/g2xk9G73aHLAV1AegqxZ82V3aRFrzt0OIBI+4YOiv4zkF7H
hl5aqUXAs8Ln09qaX1Ix9+nRWYc7HLrANQcelKFqi+B+EaA19/uJCxDaU2pC
hXVAez9wNTulFlHoA/UlQ38QfcsdHKfQD/QvjP6N6OsWuAH0a4Yeir5Wqmzh
K6B/aagaS7JqgWGgly0KFtuTcMWuIgPCIatWTvQlK2cU6COGbou+aIE7QB+F
aj2R8GuAyOK2FRCE8xYYB/pdQzdEn7XAJNDHoRZrEs4ARBYTVkAQTllgGuj3
DF0V/R6UQ8Ip4D2QxSRAM2AxDbwVWUwANAsWM1b9IByzwALQ5wxdEv0ulEPC
BeCpyVS0kjRUbUEtTLZqVCloESwWgTcvC2ra98HiPvDmZHELoCWwWAKe/hs9
jylouTmLDEArYLEMPDWy5GbNplltsQK86eYsHgBPT0YyDNBDsHgIPD2E6kYr
nuVq4SoI9eiFMZv6kegWj4Cnp1eDRgp6DBbloScIB0BIA+xj4I01Z7EOPHUK
yQ2ANlpjsQE89SvJdYA2wWITeOpXNNbjsBfd4gnw1DUl/QBttcZiC3jq3ZKr
AGXBIgs89W7JFYC2W2OxDTx1kHrfS0E7Z27RB1CuNRY7wLt55hY54KmnTy4D
tAsWu8AbksXnAO21s8Ue8DR5qJjiliGa4raNxVPghcl3L0D77WyxDzy9TiiB
k4JqZjDaweIZ8AY+WrTA4iJAB+1i4Qc/n+7sOL0ZjWuttPVZtIPzXcfT2ebs
Mik9fO5b3Pl4gD9a/CcW52OcrGMR4bXj//X+VMciwuvoGb4U+6USH6I0SzBr
dLZRc/Q7kXd3lYUnmz1jVEyTEyaqfSfE1k5fVGf4A+hKSkfKwIViak+Ho964
2sV0pa289ybwwwQ+Qg6gRZmIHT0FRZTKriPc1nUX0SbzQNlGhJTG2jqpMGvX
SMIRCSOk7xq1qJNEjJCHjJBQjZDWjZBcbtRiA3ghxR0hSx4h3R9h0aHRBY8I
FtS/a/U4xsoNrd8/Aos660dDAK2CRZ3lrwgraBHW8SKsJmYAanJN03deFQvd
1cI666kRFoYjLE9HWCSPsFQ/VrOC1RbzwNPF4Q6NObCYA55uccN7G2aBF7Yt
NLXDwreasDWjvN2D6HX2dJSdpkA4aah6Caz7BAjHTahOrmKHBtHpDwzCBROO
gfCOoRqbsK3eBuGoCTWY60/0AaLTHoogXDbhLRBmDNWroe67D2SAPmyo3nXV
tfpyh4A+aKjmWLppXj8I9AFDlQXSyOu3ZV0Her+hz0XPWnFXgd5n9G9Fz1mg
p3SGc5pe472Q0M98e/zNrmZSCs3vv3SzmcJLqX3pl10gr8D3oKL51usKfWqW
UaPmQfFd6b5iBaPvpjwVdNzw4Ue7qiMFfgLXNx8sMK1ynzcVJfz7Tgf0Ram1
pbdZNnAlyYV/AEZS864=\
\>"],
  ImageRangeCache->{{{0, 193}, {193, 0}} -> {-1, 0, 0, 0}}],
 "  ",
 StyleBox["\n\t\t\t",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Figure 6.27",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/cauchygoursat/\
CauchyGoursatMod/Images/mat0627.gif"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 "  The circle  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"C", ":", 
    RowBox[{"|", 
     RowBox[{"z", "-", "\[ImaginaryI]"}], "|"}]}], "=", "1"}]]],
 "  and the points  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{
    RowBox[{"\[PlusMinus]", " ", "\[ImaginaryI]"}], " ", 
    SqrtBox["2"]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "Solution.  Using partial fractions again, we have  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["\[Integral]", "C"], 
    RowBox[{
     FractionBox[
      RowBox[{"2", "z"}], 
      RowBox[{
       SuperscriptBox["z", "2"], " ", "+", " ", "2"}]], 
     RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Integral]", "C"], 
     RowBox[{
      FractionBox["1", 
       RowBox[{"z", " ", "+", " ", 
        RowBox[{"\[ImaginaryI]", " ", 
         SqrtBox["2"]}]}]], 
      RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "+", "  ", 
    RowBox[{
     SubscriptBox["\[Integral]", "C"], 
     RowBox[{
      FractionBox["1", 
       RowBox[{"z", " ", "-", " ", 
        RowBox[{"\[ImaginaryI]", " ", 
         SqrtBox["2"]}]}]], 
      RowBox[{"\[DifferentialD]", "z"}]}]}]}]}]]],
 "\n\nIn this case,  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{"\[ImaginaryI]", " ", 
    SqrtBox["2"]}]}]]],
 "  lies interior to ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " but  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{
    RowBox[{"-", " ", "\[ImaginaryI]"}], " ", 
    SqrtBox["2"]}]}]]],
 "  does not, as shown in Figure 6.27.  By Corollary 6.1, the second integral \
on the right side of the above equation has the value  ",
 Cell[BoxData[
  RowBox[{"2", " ", "\[Pi]", " ", "\[ImaginaryI]"}]]],
 ".  The first integral equals zero by the Cauchy-Goursat theorem because the \
function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   FractionBox["1", 
    RowBox[{"z", " ", "+", " ", 
     RowBox[{"\[ImaginaryI]", " ", 
      SqrtBox["2"]}]}]]}]]],
 " is analytic on a simply connected domain that contains ",
 StyleBox["C",
  FontFamily->"Courier New"],
 ".  Thus  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["\[Integral]", "C"], 
     RowBox[{
      FractionBox[
       RowBox[{"2", "z"}], 
       RowBox[{
        SuperscriptBox["z", "2"], " ", "+", " ", "2"}]], 
      RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Integral]", "C"], 
      RowBox[{
       FractionBox["1", 
        RowBox[{"z", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", 
          SqrtBox["2"]}]}]], 
       RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "+", "  ", 
     RowBox[{
      SubscriptBox["\[Integral]", "C"], 
      RowBox[{
       FractionBox["1", 
        RowBox[{"z", " ", "-", " ", 
         RowBox[{"\[ImaginaryI]", " ", 
          SqrtBox["2"]}]}]], 
       RowBox[{"\[DifferentialD]", "z"}]}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                      ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{"0", "  ", "+", "  ", 
      RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]"}]}]}], "  ", 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                      ", 
   RowBox[{"=", "  ", 
    RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]"}]}]}]}]],
 "  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 6.15.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 "Enter the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], "=", 
   FractionBox[
    RowBox[{"2", "z"}], 
    RowBox[{
     SuperscriptBox["z", "2"], " ", "+", " ", "2"}]]}]],
  AspectRatioFixed->True],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", 
     RowBox[{"R", ",", "W", ",", "z", ",", "Z"}], "]"}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "F", ",", "i", ",", "p", ",", "solset"}], "]"}], ";"}],
    "  ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox[
      RowBox[{"2", "z"}], 
      RowBox[{
       SuperscriptBox["z", "2"], " ", "+", " ", "2"}]]}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], "  ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.3992892616875*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "First, split the function up into partial fractions involving linear terms \
in the denominators.  Don't worry about the subroutine.  It splits  ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 "  up into partial fractions.  The result will be an equivalent function \
named F[z].  The list of terms added to form F[z] have singularities in the \
same order in the list of points Z."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"solset", " ", "=", " ", 
     RowBox[{"Sort", "[", 
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Denominator", "[", 
          RowBox[{"f", "[", "z", "]"}], "]"}], "\[Equal]", "0"}], ",", "z"}], 
       "]"}], "]"}]}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Z", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"Length", "[", "solset", "]"}], "}"}]}], "]"}]}], ";"}], "  ",
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"W", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"Length", "[", "solset", "]"}], "}"}]}], "]"}]}], ";"}], "  ",
    "\n", 
   RowBox[{
    RowBox[{"R", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"Length", "[", "solset", "]"}], "}"}]}], "]"}]}], ";"}], "  ",
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "z_", "]"}], " ", "=", " ", "0"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"i", "=", "1"}], ",", 
      RowBox[{"i", "\[LessEqual]", 
       RowBox[{"Length", "[", "solset", "]"}]}], ",", 
      RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        SubscriptBox["Z", 
         RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], " ",
         "=", " ", 
        RowBox[{"ReplaceAll", "[", 
         RowBox[{"z", ",", 
          SubscriptBox["solset", 
           RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]]}], 
         "]"}]}], ";", "   ", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"1", "\[Equal]", "i"}], ",", 
         RowBox[{"p", " ", "=", " ", "1"}]}], "]"}], ";", "  ", 
       "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"1", "<", "i"}], ";", "  ", 
          RowBox[{
           SubscriptBox["Z", 
            RowBox[{"\[LeftDoubleBracket]", 
             RowBox[{"i", "-", "1"}], "\[RightDoubleBracket]"}]], "\[Equal]", 
           
           SubscriptBox["Z", 
            RowBox[{
            "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]]}]}], ",", 
         
         RowBox[{"p", " ", "=", " ", 
          RowBox[{"p", "+", "1"}]}], ",", 
         RowBox[{"p", " ", "=", " ", "1"}]}], "]"}], ";", "  ", 
       "\[IndentingNewLine]", 
       RowBox[{
        SubscriptBox["R", 
         RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], " ",
         "=", " ", 
        RowBox[{"Residue", "[", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"z", "-", 
              SubscriptBox["Z", 
               RowBox[{
               "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]]}], 
             ")"}], 
            RowBox[{"p", "-", "1"}]], 
           RowBox[{"f", "[", "z", "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"z", ",", 
            SubscriptBox["Z", 
             RowBox[{
             "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]]}], 
           "}"}]}], "]"}]}], ";", "  ", "\[IndentingNewLine]", 
       RowBox[{
        SubscriptBox["W", 
         RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], "=",
         " ", 
        FractionBox[
         SubscriptBox["R", 
          RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"z", "-", 
            SubscriptBox["Z", 
             RowBox[{
             "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]]}], ")"}],
           "p"]]}], ";", "  ", "\n", "   ", 
       RowBox[{
        RowBox[{"F", "[", "z_", "]"}], " ", "=", " ", 
        RowBox[{
         RowBox[{"F", "[", "z", "]"}], " ", "+", 
         FractionBox[
          SubscriptBox["R", 
           RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"z", "-", 
             SubscriptBox["Z", 
              RowBox[{
              "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]]}], 
            ")"}], "p"]]}]}], ";"}]}], "  ", "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"i", "=", "1"}], ",", 
      RowBox[{"i", "\[LessEqual]", 
       RowBox[{"Length", "[", 
        RowBox[{"F", "[", "z", "]"}], "]"}]}], ",", 
      RowBox[{"i", "++"}], ",", "\n", "   ", 
      RowBox[{
       RowBox[{"soset", " ", "=", " ", 
        RowBox[{"Solve", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Denominator", "[", 
            SubscriptBox["W", 
             RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], 
            "]"}], "\[Equal]", "0"}], ",", "z"}], "]"}]}], ";", "  ", "\n", 
       "   ", 
       RowBox[{
        SubscriptBox["Z", 
         RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], " ",
         "=", " ", 
        RowBox[{"ReplaceAll", "[", 
         RowBox[{"z", ",", 
          SubscriptBox["soset", 
           RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]]}], 
         "]"}]}], ";", "  ", "\n", "   ", 
       RowBox[{
        SubscriptBox["R", 
         RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], " ",
         "=", " ", 
        RowBox[{"Residue", "[", 
         RowBox[{
          RowBox[{"f", "[", "z", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"z", ",", 
            SubscriptBox["Z", 
             RowBox[{
             "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]]}], 
           "}"}]}], "]"}]}], ";"}]}], "  ", "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"F", "[", "z", "]"}]}], "]"}], ";"}], "  ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399289266109375*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "Determine which singularities lie inside  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"C", ":", 
    RowBox[{"|", 
     RowBox[{"z", "-", "\[ImaginaryI]"}], "|"}]}], "=", "1"}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["Z", 
       RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], ",", 
      "\"\<,  Is |\>\"", ",", 
      SubscriptBox["Z", 
       RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], ",", 
      "\"\< - \[ImaginaryI]| < 1 ?   \>\"", ",", 
      RowBox[{
       RowBox[{"N", "[", 
        RowBox[{"Abs", "[", 
         RowBox[{
          SubscriptBox["Z", 
           RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], 
          "-", " ", "\[ImaginaryI]"}], "]"}], "]"}], "<", "1"}]}], "]"}], 
    ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(2\)]\) = \>\"", ",", 
      SubscriptBox["Z", 
       RowBox[{"\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]], ",", 
      "\"\<,    Is |\>\"", ",", 
      SubscriptBox["Z", 
       RowBox[{"\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]], ",", 
      "\"\< - \[ImaginaryI]| < 1 ?   \>\"", ",", 
      RowBox[{
       RowBox[{"N", "[", 
        RowBox[{"Abs", "[", 
         RowBox[{
          SubscriptBox["Z", 
           RowBox[{"\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]], 
          "-", " ", "\[ImaginaryI]"}], "]"}], "]"}], "<", "1"}]}], "]"}], 
    ";"}], "  ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399289272546875*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "Since only the second singularity lies inside ",
 StyleBox["C",
  FontFamily->"Courier New"],
 ", add the first term in the sum forming F[z] times constant in the \
numerator that term times ",
 Cell[BoxData[
  RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]"}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"val", " ", "=", " ", 
     RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", 
      RowBox[{"Numerator", "[", 
       SubscriptBox[
        RowBox[{"F", "[", "z", "]"}], 
        RowBox[{"\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]], 
       "]"}]}]}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dots", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"Red", ",", 
         RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
         RowBox[{"Point", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Re", "[", 
             SubscriptBox["Z", 
              RowBox[{"\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]],
              "]"}], ",", 
            RowBox[{"Im", "[", 
             SubscriptBox["Z", 
              RowBox[{"\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]],
              "]"}]}], "}"}], "]"}]}], "}"}], "}"}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"centers", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"StyleForm", "[", 
          RowBox[{
           RowBox[{
           "TraditionalForm", "[", 
            "\"\<\!\(\*SubscriptBox[\(z\), \(2\)]\)\>\"", "]"}], ",", 
           RowBox[{"FontSize", "\[Rule]", "12"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Re", "[", 
            SubscriptBox["Z", 
             RowBox[{"\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]], 
            "]"}], ",", 
           RowBox[{
            RowBox[{"Im", "[", 
             SubscriptBox["Z", 
              RowBox[{"\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]],
              "]"}], "-", "0.1"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}], "}"}], "]"}]}], 
    ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"contour", " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", 
        RowBox[{"Circle", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "1"}], "}"}], ",", "1"}], "]"}]}], "}"}], 
      "]"}]}], ";"}], "  ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{"dots", ",", "centers", ",", "contour", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.1"}], ",", "1.1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.1"}], ",", "2.1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(\[ContourIntegral]\), \(C\)]\) (\>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\<) \[DifferentialD]z = \>\"", 
      ",", "\"\<\!\(\*UnderscriptBox[\(\[ContourIntegral]\), \(C\)]\) (\>\"", 
      ",", 
      SubscriptBox["W", 
       RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], ",", 
      "\"\<) \[DifferentialD]z + \>\"", ",", 
      "\"\<\!\(\*UnderscriptBox[\(\[ContourIntegral]\), \(C\)]\) (\>\"", ",", 
      
      SubscriptBox["W", 
       RowBox[{"\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]], ",", 
      "\"\<) \[DifferentialD]z\>\""}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(\[ContourIntegral]\), \(C\)]\) (\>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\<) \[DifferentialD]z = \>\"", 
      ",", "\"\<(\>\"", ",", "0", ",", "\"\<) + \>\"", ",", "\"\<(\>\"", ",", 
      
      RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", 
       RowBox[{"Numerator", "[", 
        SubscriptBox[
         RowBox[{"F", "[", "z", "]"}], 
         RowBox[{"\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]], 
        "]"}]}], ",", "\"\<)\>\""}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"Print", "[", 
    RowBox[{
    "\"\<\!\(\*UnderscriptBox[\(\[ContourIntegral]\), \(C\)]\) (\>\"", ",", 
     RowBox[{"f", "[", "z", "]"}], ",", "\"\<) \[DifferentialD]z = \>\"", ",",
      "val"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The contour is the circle  C: |z-\[ImaginaryI]| = 1,\>\"", "]"}], 
    ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<with positive orientation.\>\"", "]"}], ";"}], 
   "  ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3992892761875*^9, 3.39928927990625*^9}, {
  3.399882638796875*^9, 3.399882638984375*^9}}]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 6.16.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Show that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["\[Integral]", "C"], 
    RowBox[{
     FractionBox[
      RowBox[{"z", " ", "-", " ", "2"}], 
      RowBox[{
       SuperscriptBox["z", "2"], " ", "-", " ", "z"}]], 
     RowBox[{"\[DifferentialD]", "z"}]}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"-", "6"}], " ", "\[Pi]", " ", "\[ImaginaryI]"}]}]]],
 ",  where ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " is the \"figure eight\" contour shown in Figure 6.28. "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "\t\t\t",
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.272727 0.454545 0.309017 0.309017 [
[.72727 .29652 -3 -9 ]
[.72727 .29652 3 0 ]
[1.025 .30902 0 -6.28125 ]
[1.025 .30902 10 6.28125 ]
[.26023 0 -12 -4.5 ]
[.26023 0 0 4.5 ]
[.26023 .61803 -6 -4.5 ]
[.26023 .61803 0 4.5 ]
[.27273 .64303 -5 0 ]
[.27273 .64303 5 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.72727 .30902 m
.72727 .31527 L
s
[(1)] .72727 .29652 0 1 Mshowa
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.27273 0 m
.27898 0 L
s
[(-1)] .26023 0 1 0 Mshowa
.27273 .61803 m
.27898 .61803 L
s
[(1)] .26023 .61803 1 0 Mshowa
.27273 0 m
.27273 .61803 L
s
gsave
.27273 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.03 w
.27273 .30902 Mdot
0 1 1 r
.72727 .30902 Mdot
0 g
gsave
.30455 .37082 -69.4063 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
70.188 14.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
75.813 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.75909 .37082 -69.4063 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
70.188 14.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
75.813 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.38636 .55623 -69.4063 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(C) show
70.188 14.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
75.813 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.61364 .55623 -69.4063 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(C) show
70.188 14.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
75.813 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 1 r
.5 Mabswid
.5 .30902 m
.55777 .2311 L
.61968 .15203 L
.67574 .08865 L
.72684 .04174 L
.75178 .02399 L
.7773 .01027 L
.78928 .00563 L
.79545 .00373 L
.8019 .00215 L
.80745 .00112 L
.81057 .00068 L
.81346 .00037 L
.81481 .00026 L
.81609 .00017 L
.81724 .0001 L
.81848 5e-005 L
.81982 2e-005 L
.82057 0 L
.82125 0 L
.82256 1e-005 L
.8238 3e-005 L
.82502 8e-005 L
.82632 .00015 L
.82754 .00023 L
.82866 .00032 L
.83136 .00061 L
.8339 .00097 L
.83888 .00193 L
.8442 .00335 L
.85342 .00683 L
.86164 .01113 L
.8702 .01695 L
.8779 .02348 L
.89418 .04213 L
.90836 .06517 L
.91978 .0901 L
.92984 .11896 L
.93892 .1539 L
.94564 .18968 L
.94859 .21062 L
.95076 .23009 L
.95244 .24992 L
.95356 .26844 L
.95398 .27818 L
.95417 .28379 L
.9543 .28893 L
.95442 .29435 L
.95446 .29734 L
.9545 .30018 L
Mistroke
.95452 .30279 L
.95454 .30522 L
.95454 .30788 L
.95455 .30937 L
.95454 .31072 L
.95454 .31318 L
.95452 .31547 L
.9545 .31799 L
.95446 .32068 L
.95437 .32618 L
.95425 .33119 L
.95394 .34082 L
.95354 .34991 L
.95231 .36999 L
.95139 .38121 L
.9504 .39149 L
.94577 .42752 L
.94238 .44724 L
.9387 .46512 L
.9298 .49921 L
.91997 .52747 L
.90828 .55303 L
.89368 .57659 L
.87814 .59433 L
.86875 .60218 L
.8598 .60797 L
.8553 .61032 L
.85044 .61248 L
.84616 .61406 L
.84148 .61546 L
.83881 .61612 L
.83636 .61663 L
.83384 .61707 L
.83148 .61741 L
.82872 .61771 L
.82726 .61783 L
.82569 .61792 L
.82433 .61798 L
.82304 .61802 L
.82231 .61803 L
.82163 .61803 L
.82088 .61803 L
.8201 .61802 L
.81878 .61799 L
.81804 .61797 L
.81735 .61794 L
.81609 .61787 L
.81474 .61777 L
.81239 .61756 L
.8098 .61725 L
Mistroke
.80398 .61631 L
.79844 .61509 L
.78831 .61208 L
.77715 .6077 L
.75136 .59377 L
.72572 .57541 L
.67433 .52792 L
.61662 .46227 L
.55907 .38865 L
.5 .30902 L
Mfstroke
1 0 1 r
.5 .30902 m
.44223 .2311 L
.38032 .15203 L
.32426 .08865 L
.27316 .04174 L
.24822 .02399 L
.2227 .01027 L
.21072 .00563 L
.20455 .00373 L
.1981 .00215 L
.19255 .00112 L
.18943 .00068 L
.18654 .00037 L
.18519 .00026 L
.18391 .00017 L
.18276 .0001 L
.18152 5e-005 L
.18018 2e-005 L
.17943 0 L
.17875 0 L
.17744 1e-005 L
.1762 3e-005 L
.17498 8e-005 L
.17368 .00015 L
.17246 .00023 L
.17134 .00032 L
.16864 .00061 L
.1661 .00097 L
.16112 .00193 L
.1558 .00335 L
.14658 .00683 L
.13836 .01113 L
.1298 .01695 L
.1221 .02348 L
.10582 .04213 L
.09164 .06517 L
.08022 .0901 L
.07016 .11896 L
.06108 .1539 L
.05436 .18968 L
.05141 .21062 L
.04924 .23009 L
.04756 .24992 L
.04644 .26844 L
.04602 .27818 L
.04583 .28379 L
.0457 .28893 L
.04558 .29435 L
.04554 .29734 L
.0455 .30018 L
Mistroke
.04548 .30279 L
.04546 .30522 L
.04546 .30788 L
.04545 .30937 L
.04546 .31072 L
.04546 .31318 L
.04548 .31547 L
.0455 .31799 L
.04554 .32068 L
.04563 .32618 L
.04575 .33119 L
.04606 .34082 L
.04646 .34991 L
.04769 .36999 L
.04861 .38121 L
.0496 .39149 L
.05423 .42752 L
.05762 .44724 L
.0613 .46512 L
.0702 .49921 L
.08003 .52747 L
.09172 .55303 L
.10632 .57659 L
.12186 .59433 L
.13125 .60218 L
.1402 .60797 L
.1447 .61032 L
.14956 .61248 L
.15384 .61406 L
.15852 .61546 L
.16119 .61612 L
.16364 .61663 L
.16616 .61707 L
.16852 .61741 L
.17128 .61771 L
.17274 .61783 L
.17431 .61792 L
.17567 .61798 L
.17696 .61802 L
.17769 .61803 L
.17837 .61803 L
.17912 .61803 L
.1799 .61802 L
.18122 .61799 L
.18196 .61797 L
.18265 .61794 L
.18391 .61787 L
.18526 .61777 L
.18761 .61756 L
.1902 .61725 L
Mistroke
.19602 .61631 L
.20156 .61509 L
.21169 .61208 L
.22285 .6077 L
.24864 .59377 L
.27428 .57541 L
.32567 .52792 L
.38338 .46227 L
.44093 .38865 L
.5 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {0, -1, 0, 0}}],
 "  "
}], "Text"],

Cell[TextData[{
 StyleBox["\t\t\t",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Figure 6.28",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/cauchygoursat/\
CauchyGoursatMod/Images/mat0628.gif"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 "  The contour  ",
 Cell[BoxData[
  RowBox[{"C", "=", 
   RowBox[{
    SubscriptBox["C", "1"], "+", 
    SubscriptBox["C", "2"]}]}]]],
 "."
}], "Text"],

Cell[TextData[{
 "Solution.  Again, we use partial fractions to express the integral:  \n\n",
 StyleBox["(6-39)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["\[Integral]", "C"], 
    RowBox[{
     FractionBox[
      RowBox[{"z", " ", "-", " ", "2"}], 
      RowBox[{
       SuperscriptBox["z", "2"], " ", "-", " ", "z"}]], 
     RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Integral]", "C"], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        FractionBox["2", "z"], " ", "-", " ", 
        FractionBox["1", 
         RowBox[{"z", "-", "1"}]]}], ")"}], 
      RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{"2", 
      RowBox[{
       SubscriptBox["\[Integral]", "C"], 
       RowBox[{
        FractionBox["1", "z"], 
        RowBox[{"\[DifferentialD]", "z"}]}]}]}], "  ", "-", "  ", 
     RowBox[{
      SubscriptBox["\[Integral]", "C"], 
      RowBox[{
       FractionBox["1", 
        RowBox[{"z", "-", "1"}]], 
       RowBox[{"\[DifferentialD]", "z"}]}]}]}]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "Using the Cauchy-Goursat theorem, Property ",
 StyleBox["(6-17)",
  FontColor->RGBColor[0, 0, 1]],
 ", and Corollary 6.1 (with ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "0"], "=", "0"}]]],
 "), we compute the value of the first integral on the right side of Equation \
",
 StyleBox["(6-39)",
  FontColor->RGBColor[0, 0, 1]],
 ":  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"2", 
     RowBox[{
      SubscriptBox["\[Integral]", "C"], 
      RowBox[{
       FractionBox["1", "z"], 
       RowBox[{"\[DifferentialD]", "z"}]}]}]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{"2", 
      RowBox[{
       SubscriptBox["\[Integral]", 
        SubscriptBox["C", "1"]], 
       RowBox[{
        FractionBox["1", "z"], 
        RowBox[{"\[DifferentialD]", "z"}]}]}]}], "  ", "+", "  ", 
     RowBox[{"2", 
      RowBox[{
       SubscriptBox["\[Integral]", 
        SubscriptBox["C", "2"]], 
       RowBox[{
        FractionBox["1", "z"], 
        RowBox[{"\[DifferentialD]", "z"}]}]}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                   ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], 
       RowBox[{
        SubscriptBox["\[Integral]", 
         RowBox[{"-", 
          SubscriptBox["C", "1"]}]], 
        RowBox[{
         FractionBox["1", "z"], 
         RowBox[{"\[DifferentialD]", "z"}]}]}]}], "  ", "+", "  ", "0"}]}], 
    "\[IndentingNewLine]", " "}]}], "\[IndentingNewLine]", 
  RowBox[{"                   ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      RowBox[{"-", "2"}], 
      RowBox[{"(", 
       RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]"}], ")"}]}]}], "  ", 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                   ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{"-", " ", "4"}], "\[Pi]", " ", "\[ImaginaryI]"}]}]}]}]],
 "  "
}], "Text"],

Cell[TextData[{
 "Similarly, we find that  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     RowBox[{
      SubscriptBox["\[Integral]", "C"], 
      RowBox[{
       FractionBox["1", 
        RowBox[{"z", "-", "1"}]], 
       RowBox[{"\[DifferentialD]", "z"}]}]}]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{
       SubscriptBox["\[Integral]", 
        SubscriptBox["C", "1"]], 
       RowBox[{
        FractionBox["1", 
         RowBox[{"z", "-", "1"}]], 
        RowBox[{"\[DifferentialD]", "z"}]}]}]}], "  ", "+", "  ", 
     RowBox[{"-", 
      RowBox[{
       SubscriptBox["\[Integral]", 
        SubscriptBox["C", "2"]], 
       RowBox[{
        FractionBox["1", 
         RowBox[{"z", "-", "1"}]], 
        RowBox[{"\[DifferentialD]", "z"}]}]}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                     ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{"0", "  ", "-", " ", 
      RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]"}]}]}], "  ", 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                     ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{"-", " ", "2"}], "\[Pi]", " ", "\[ImaginaryI]"}]}]}]}]],
 "   "
}], "Text"],

Cell[TextData[{
 "If we substitute the results of the last two equations into Equation ",
 StyleBox["(6-39)",
  FontColor->RGBColor[0, 0, 1]],
 " we get  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["\[Integral]", "C"], 
     RowBox[{
      FractionBox[
       RowBox[{"z", " ", "-", " ", "2"}], 
       RowBox[{
        SuperscriptBox["z", "2"], " ", "-", " ", "z"}]], 
      RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{"2", 
      RowBox[{
       SubscriptBox["\[Integral]", "C"], 
       RowBox[{
        FractionBox["1", "z"], 
        RowBox[{"\[DifferentialD]", "z"}]}]}]}], "  ", "-", "  ", 
     RowBox[{
      SubscriptBox["\[Integral]", "C"], 
      RowBox[{
       FractionBox["1", 
        RowBox[{"z", "-", "1"}]], 
       RowBox[{"\[DifferentialD]", "z"}]}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                      ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      RowBox[{
       RowBox[{"-", " ", "4"}], "\[Pi]", " ", "\[ImaginaryI]"}], "  ", "-", 
      "  ", 
      RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]"}]}]}], "  ", 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                      ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{"-", " ", "6"}], "\[Pi]", " ", "\[ImaginaryI]"}]}]}]}]],
 "   "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 6.16.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 "Enter the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], "=", 
   FractionBox[
    RowBox[{"z", " ", "-", " ", "2"}], 
    RowBox[{
     SuperscriptBox["z", "2"], " ", "-", " ", "z"}]]}]],
  AspectRatioFixed->True],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", 
     RowBox[{"R", ",", "W", ",", "z", ",", "Z"}], "]"}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "F", ",", "i", ",", "p", ",", "solset"}], "]"}], ";"}],
    "  ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox[
      RowBox[{"z", " ", "-", " ", "2"}], 
      RowBox[{
       SuperscriptBox["z", "2"], " ", "-", "z"}]]}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], "  ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39928928884375*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "First, split the function up into partial fractions involving linear terms \
in the denominators.  Don't worry about the subroutine. It splits  ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 "  up into partial fractions.  The result will be an equivalent function \
named F[z].  The list of terms added to form F[z] have singularities in the \
same order in the list of points Z."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"solset", " ", "=", " ", 
     RowBox[{"Sort", "[", 
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Denominator", "[", 
          RowBox[{"f", "[", "z", "]"}], "]"}], "\[Equal]", "0"}], ",", "z"}], 
       "]"}], "]"}]}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Z", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"Length", "[", "solset", "]"}], "}"}]}], "]"}]}], ";"}], "  ",
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"W", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"Length", "[", "solset", "]"}], "}"}]}], "]"}]}], ";"}], "  ",
    "\n", 
   RowBox[{
    RowBox[{"R", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"Length", "[", "solset", "]"}], "}"}]}], "]"}]}], ";"}], "  ",
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "z_", "]"}], " ", "=", " ", "0"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"i", "=", "1"}], ",", 
      RowBox[{"i", "\[LessEqual]", 
       RowBox[{"Length", "[", "solset", "]"}]}], ",", 
      RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        SubscriptBox["Z", 
         RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], " ",
         "=", " ", 
        RowBox[{"ReplaceAll", "[", 
         RowBox[{"z", ",", 
          SubscriptBox["solset", 
           RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]]}], 
         "]"}]}], ";", "   ", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"1", "\[Equal]", "i"}], ",", 
         RowBox[{"p", " ", "=", " ", "1"}]}], "]"}], ";", "  ", 
       "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"1", "<", "i"}], ";", "  ", 
          RowBox[{
           SubscriptBox["Z", 
            RowBox[{"\[LeftDoubleBracket]", 
             RowBox[{"i", "-", "1"}], "\[RightDoubleBracket]"}]], "\[Equal]", 
           
           SubscriptBox["Z", 
            RowBox[{
            "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]]}]}], ",", 
         
         RowBox[{"p", " ", "=", " ", 
          RowBox[{"p", "+", "1"}]}], ",", 
         RowBox[{"p", " ", "=", " ", "1"}]}], "]"}], ";", "  ", 
       "\[IndentingNewLine]", 
       RowBox[{
        SubscriptBox["R", 
         RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], " ",
         "=", " ", 
        RowBox[{"Residue", "[", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"z", "-", 
              SubscriptBox["Z", 
               RowBox[{
               "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]]}], 
             ")"}], 
            RowBox[{"p", "-", "1"}]], 
           RowBox[{"f", "[", "z", "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"z", ",", 
            SubscriptBox["Z", 
             RowBox[{
             "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]]}], 
           "}"}]}], "]"}]}], ";", "  ", "\[IndentingNewLine]", 
       RowBox[{
        SubscriptBox["W", 
         RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], "=",
         " ", 
        RowBox[{"Together", "[", 
         FractionBox[
          SubscriptBox["R", 
           RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"z", "-", 
             SubscriptBox["Z", 
              RowBox[{
              "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]]}], 
            ")"}], "p"]], "]"}]}], ";", "  ", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"F", "[", "z_", "]"}], " ", "=", " ", 
        RowBox[{
         RowBox[{"F", "[", "z", "]"}], " ", "+", 
         SubscriptBox["W", 
          RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]]}]}],
        ";"}]}], "  ", "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"i", "=", "1"}], ",", 
      RowBox[{"i", "\[LessEqual]", 
       RowBox[{"Length", "[", 
        RowBox[{"F", "[", "z", "]"}], "]"}]}], ",", 
      RowBox[{"i", "++"}], ",", "\n", "   ", 
      RowBox[{
       RowBox[{"soset", " ", "=", " ", 
        RowBox[{"Solve", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Denominator", "[", 
            SubscriptBox["W", 
             RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], 
            "]"}], "\[Equal]", "0"}], ",", "z"}], "]"}]}], ";", "  ", "\n", 
       "   ", 
       RowBox[{
        SubscriptBox["Z", 
         RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], " ",
         "=", " ", 
        RowBox[{"ReplaceAll", "[", 
         RowBox[{"z", ",", 
          SubscriptBox["soset", 
           RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]]}], 
         "]"}]}], ";", "  ", "\n", "   ", 
       RowBox[{
        SubscriptBox["R", 
         RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], " ",
         "=", " ", 
        RowBox[{"Residue", "[", 
         RowBox[{
          RowBox[{"f", "[", "z", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"z", ",", 
            SubscriptBox["Z", 
             RowBox[{
             "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]]}], 
           "}"}]}], "]"}]}], ";"}]}], "  ", "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"F", "[", "z", "]"}]}], "]"}], ";"}], "  ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39928929278125*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "Determine which singularities corresponds to the contour ",
 Cell[BoxData[
  SubscriptBox["C", "1"]]],
 "  and ",
 Cell[BoxData[
  SubscriptBox["C", "2"]]],
 ".  The first term will correspond to the singularity at ",
 Cell[BoxData[
  RowBox[{"z", "=", "1"}]]],
 " used with contour ",
 Cell[BoxData[
  SubscriptBox["C", "2"]]],
 " and the second term corresponds to the singularity at ",
 Cell[BoxData[
  RowBox[{"z", "=", "0"}]]],
 " used with contour ",
 Cell[BoxData[
  SubscriptBox["C", "1"]]],
 ".  \n\nSince ",
 Cell[BoxData[
  SubscriptBox["C", "2"]]],
 " has positive orientation, we add the first term in the sum forming  F(z)  \
times constant in the numerator of that term times ",
 Cell[BoxData[
  RowBox[{"2", " ", "\[Pi]", " ", "\[ImaginaryI]"}]]],
 ".  And since the ",
 Cell[BoxData[
  SubscriptBox["C", "1"]]],
 " has negative orientation, we subtract the second term in the sum forming  \
F(z)  times constant in the numerator of that term times ",
 Cell[BoxData[
  RowBox[{"2", " ", "\[Pi]", " ", "\[ImaginaryI]"}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"val1", " ", "=", " ", 
     RowBox[{"2", " ", "\[Pi]", " ", "\[ImaginaryI]", " ", 
      RowBox[{"Numerator", "[", 
       FractionBox[
        SubscriptBox["R", 
         RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"z", "-", 
           SubscriptBox["Z", 
            RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]]}],
           ")"}], "p"]], "]"}]}]}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"val2", " ", "=", " ", 
     RowBox[{"2", " ", "\[Pi]", " ", "\[ImaginaryI]", " ", 
      RowBox[{"Numerator", "[", 
       FractionBox[
        SubscriptBox["R", 
         RowBox[{"\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"z", "-", 
           SubscriptBox["Z", 
            RowBox[{"\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]]}],
           ")"}], "p"]], "]"}]}]}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"val", " ", "=", " ", 
     RowBox[{
      RowBox[{"-", "val1"}], "+", "val2"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dots", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", 
               RowBox[{
               "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], "]"}],
              ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", 
               RowBox[{
               "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], 
              "]"}]}], "}"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Cyan", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", 
               RowBox[{
               "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]], "]"}],
              ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", 
               RowBox[{
               "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]], 
              "]"}]}], "}"}], "]"}]}], "}"}]}], "}"}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"contour", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"0.5", "+", 
            RowBox[{"Cos", "[", "t", "]"}]}], ",", 
           RowBox[{"Sin", "[", 
            RowBox[{"2", "t"}], "]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"0.5", "+", 
            RowBox[{"Cos", "[", 
             RowBox[{"t", "+", "\[Pi]"}], "]"}]}], ",", 
           RowBox[{"Sin", "[", 
            RowBox[{"2", 
             RowBox[{"(", 
              RowBox[{"t", "+", "\[Pi]"}], ")"}]}], "]"}]}], "}"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", 
         FractionBox[
          RowBox[{"-", "\[Pi]"}], "2"], ",", 
         FractionBox["\[Pi]", "2"]}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", "Magenta"}], "}"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "1", ",", "1"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}]}], "}"}]}]}], 
      "]"}]}], ";"}], "  ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{"dots", ",", "contour", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.6"}], ",", "1.6"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.0"}], ",", "1.0"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<Left contour \!\(\*SubscriptBox[\(C\), \(1\)]\) , right contour \
\!\(\*SubscriptBox[\(C\), \(2\)]\)\>\"", "]"}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<     \!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["Z", 
       RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], ",", 
      " ", "\"\<             \!\(\*SubscriptBox[\(z\), \(2\)]\) = \>\"", ",", 
      
      SubscriptBox["Z", 
       RowBox[{"\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]]}], " ",
      "]"}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(\[ContourIntegral]\), SubscriptBox[\(C\), \
\(1\)]]\) (\>\"", ",", 
      FractionBox[
       SubscriptBox["R", 
        RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"z", "-", 
          SubscriptBox["Z", 
           RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]]}], 
         ")"}], "p"]], ",", "\"\<) \[DifferentialD]z = \>\"", ",", 
      RowBox[{"-", "val1"}]}], "]"}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The contour \!\(\*SubscriptBox[\(C\), \(1\)]\) has negative \
orientation.\>\"", "]"}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(\[ContourIntegral]\), SubscriptBox[\(C\), \
\(2\)]]\) (\>\"", ",", 
      FractionBox[
       RowBox[{"-", 
        SubscriptBox["R", 
         RowBox[{"\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]]}], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"z", "-", 
          SubscriptBox["Z", 
           RowBox[{"\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]]}], 
         ")"}], "p"]], ",", "\"\<) \[DifferentialD]z = \>\"", ",", 
      RowBox[{"-", "val2"}]}], "]"}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(\[ContourIntegral]\), SubscriptBox[\(C\), \
\(2\)]]\) (\>\"", ",", 
      FractionBox[
       SubscriptBox["R", 
        RowBox[{"\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"z", "-", 
          SubscriptBox["Z", 
           RowBox[{"\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]]}], 
         ")"}], "p"]], ",", "\"\<) \[DifferentialD]z = \>\"", ",", "val2"}], 
     "]"}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(\[ContourIntegral]\), SubscriptBox[\(C\), \
\(2\)]]\) (\>\"", ",", 
      SubscriptBox["W", 
       RowBox[{"\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]], ",", 
      "\"\<) \[DifferentialD]z = \>\"", ",", "val2"}], "]"}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The contour \!\(\*SubscriptBox[\(C\), \(2\)]\) has positive \
orientation.\>\"", "]"}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(\[ContourIntegral]\), \(C\)]\) (\>\"", ",", 
      RowBox[{"F", "[", "z", "]"}], ",", "\"\<) \[DifferentialD]z = -(\>\"", 
      ",", "val1", ",", "\"\<) + (\>\"", ",", "val2", ",", "\"\<)\>\""}], 
     "]"}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(\[ContourIntegral]\), \(C\)]\) (\>\"", ",", 
      RowBox[{"F", "[", "z", "]"}], ",", "\"\<) \[DifferentialD]z = \>\"", 
      ",", "val"}], "]"}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<   \>\"", ",", 
      RowBox[{"F", "[", "z", "]"}], ",", "\"\< = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Therefore\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(\[ContourIntegral]\), \(C\)]\) (\>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\<) \[DifferentialD]z = \>\"", 
      ",", "val"}], "]"}], ";"}], "  ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39928929759375*^9, 3.399289300671875*^9}, {
  3.39988264553125*^9, 3.399882645703125*^9}, {3.400266891390625*^9, 
  3.4002668971875*^9}, {3.400267029375*^9, 3.400267033046875*^9}}]
}, Closed]],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[{
 StyleBox[ButtonBox["Complex Integral",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/ComplexIntegralBib.html"], 
    None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0, 1]],
 "  "
}], "Text"],

Cell[TextData[{
 StyleBox[ButtonBox["Contour Integrals",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/ContourIntegralBib.html"], 
    None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0, 1]],
 "  "
}], "Text"],

Cell[TextData[{
 StyleBox[ButtonBox["Green's Theorem",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/GreenTheoremBib.html"], 
    None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0, 1]],
 "  "
}], "Text"],

Cell[TextData[{
 StyleBox[ButtonBox["Cauchy-Goursat Theorem",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/CauchyGoursatBib.html"], 
    None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0, 1]],
 "  "
}], "Text"],

Cell[TextData[{
 StyleBox[ButtonBox["Cauchy's Integral Formula",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/CauchyIntegraBib.html"], 
    None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0, 1]],
 "  "
}], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/complex.html"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2008 John H. Mathews, Russell W. \
Howell",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/"], None}],
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[0, 1, 0]]], "Text",
 CellChangeTimes->{{3.399289364890625*^9, 3.39928936503125*^9}}]
},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{958, 653},
WindowMargins->{{7, Automatic}, {Automatic, 3}},
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "CHAPTER 1"->{
  Cell[568, 21, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"],
  Cell[62764, 1208, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"],
  Cell[64523, 1275, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"],
  Cell[111726, 2443, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"],
  Cell[114166, 2533, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"],
  Cell[153336, 3519, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"CHAPTER 1", 253207, 6874}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"],
Cell[905, 32, 119, 2, 29, "Text"],
Cell[1027, 36, 1308, 31, 85, "Text"],
Cell[2338, 69, 866, 25, 47, "Text"],
Cell[3207, 96, 14600, 249, 211, "Text"],
Cell[17810, 347, 1025, 32, 83, "Text"],
Cell[18838, 381, 26219, 439, 466, "Text"],
Cell[45060, 822, 1261, 45, 65, "Text"],
Cell[46324, 869, 13360, 228, 234, "Text"],
Cell[59687, 1099, 686, 19, 29, "Text"],
Cell[60376, 1120, 2046, 72, 89, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[62447, 1196, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[62591, 1202, 170, 4, 29, "Text",
 Evaluatable->False],
Cell[62764, 1208, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"]
}, Closed]],
Cell[63113, 1220, 76, 0, 26, "Text"],
Cell[63192, 1222, 989, 37, 69, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[64206, 1263, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[64350, 1269, 170, 4, 29, "Text",
 Evaluatable->False],
Cell[64523, 1275, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"]
}, Closed]],
Cell[64872, 1287, 1458, 53, 164, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[66355, 1344, 113, 2, 29, "Text"],
Cell[66471, 1348, 494, 20, 29, "Text",
 Evaluatable->False],
Cell[66968, 1370, 6055, 165, 642, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[73060, 1540, 113, 2, 26, "Text"],
Cell[73176, 1544, 406, 16, 29, "Text"],
Cell[73585, 1562, 6065, 166, 642, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[79687, 1733, 113, 2, 26, "Text"],
Cell[79803, 1737, 448, 18, 29, "Text"],
Cell[80254, 1757, 6204, 170, 642, "Input"]
}, Closed]],
Cell[86473, 1930, 961, 37, 56, "Text",
 Evaluatable->False],
Cell[87437, 1969, 9646, 170, 249, "Text"],
Cell[97086, 2141, 659, 17, 65, "Text"],
Cell[97748, 2160, 1213, 47, 90, "Text",
 Evaluatable->False],
Cell[98964, 2209, 12420, 218, 277, "Text"],
Cell[CellGroupData[{
Cell[111409, 2431, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[111553, 2437, 170, 4, 29, "Text",
 Evaluatable->False],
Cell[111726, 2443, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"]
}, Closed]],
Cell[112075, 2455, 347, 6, 44, "Text"],
Cell[112425, 2463, 1397, 54, 119, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[113847, 2521, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[113991, 2527, 172, 4, 29, "Text",
 Evaluatable->False],
Cell[114166, 2533, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"]
}, Closed]],
Cell[CellGroupData[{
Cell[114537, 2547, 110, 2, 26, "Text"],
Cell[114650, 2551, 643, 25, 56, "Text",
 Evaluatable->False],
Cell[115296, 2578, 7030, 191, 720, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[122363, 2774, 111, 2, 26, "Text"],
Cell[122477, 2778, 669, 26, 56, "Text",
 Evaluatable->False],
Cell[123149, 2806, 7074, 193, 721, "Input"]
}, Closed]],
Cell[130238, 3002, 1639, 60, 88, "Text"],
Cell[131880, 3064, 242, 4, 47, "Text"],
Cell[132125, 3070, 2819, 104, 110, "Text",
 Evaluatable->False],
Cell[134947, 3176, 18047, 327, 302, "Text"],
Cell[CellGroupData[{
Cell[153019, 3507, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[153163, 3513, 170, 4, 29, "Text",
 Evaluatable->False],
Cell[153336, 3519, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"]
}, Closed]],
Cell[153685, 3531, 719, 29, 34, "Text",
 Evaluatable->False],
Cell[154407, 3562, 8463, 331, 211, "Text"],
Cell[162873, 3895, 1746, 61, 132, "Text"],
Cell[164622, 3958, 2044, 66, 261, "Text"],
Cell[CellGroupData[{
Cell[166691, 4028, 110, 2, 29, "Text"],
Cell[166804, 4032, 262, 11, 37, "Text"],
Cell[167069, 4045, 784, 24, 150, "Input"],
Cell[167856, 4071, 461, 10, 47, "Text",
 Evaluatable->False],
Cell[168320, 4083, 6245, 175, 464, "Input"],
Cell[174568, 4260, 220, 9, 29, "Text",
 Evaluatable->False],
Cell[174791, 4271, 1389, 35, 92, "Input"],
Cell[176183, 4308, 339, 11, 29, "Text",
 Evaluatable->False],
Cell[176525, 4321, 7314, 191, 390, "Input"]
}, Closed]],
Cell[183854, 4515, 757, 30, 34, "Text",
 Evaluatable->False],
Cell[184614, 4547, 6842, 262, 231, "Text"],
Cell[191459, 4811, 3049, 100, 292, "Text"],
Cell[CellGroupData[{
Cell[194533, 4915, 110, 2, 29, "Text"],
Cell[194646, 4919, 262, 11, 37, "Text"],
Cell[194911, 4932, 786, 24, 150, "Input"],
Cell[195700, 4958, 462, 10, 47, "Text",
 Evaluatable->False],
Cell[196165, 4970, 6245, 175, 464, "Input"],
Cell[202413, 5147, 258, 10, 29, "Text",
 Evaluatable->False],
Cell[202674, 5159, 1530, 38, 92, "Input"],
Cell[204207, 5199, 341, 11, 29, "Text",
 Evaluatable->False],
Cell[204551, 5212, 5240, 135, 350, "Input"]
}, Closed]],
Cell[209806, 5350, 651, 23, 34, "Text",
 Evaluatable->False],
Cell[210460, 5375, 15340, 660, 195, "Text"],
Cell[225803, 6037, 494, 18, 29, "Text"],
Cell[226300, 6057, 1144, 39, 73, "Text"],
Cell[227447, 6098, 1925, 65, 193, "Text"],
Cell[229375, 6165, 1244, 41, 148, "Text"],
Cell[230622, 6208, 1380, 44, 149, "Text"],
Cell[CellGroupData[{
Cell[232027, 6256, 110, 2, 29, "Text"],
Cell[232140, 6260, 277, 11, 37, "Text"],
Cell[232420, 6273, 797, 24, 150, "Input"],
Cell[233220, 6299, 461, 10, 47, "Text",
 Evaluatable->False],
Cell[233684, 6311, 6052, 169, 450, "Input"],
Cell[239739, 6482, 1120, 36, 101, "Text",
 Evaluatable->False],
Cell[240862, 6520, 9618, 254, 812, "Input"]
}, Closed]],
Cell[250495, 6777, 281, 7, 26, "Text"],
Cell[250779, 6786, 298, 10, 29, "Text"],
Cell[251080, 6798, 299, 10, 29, "Text"],
Cell[251382, 6810, 294, 10, 29, "Text"],
Cell[251679, 6822, 302, 10, 29, "Text"],
Cell[251984, 6834, 305, 10, 29, "Text"],
Cell[252292, 6846, 249, 5, 29, "Text"],
Cell[252544, 6853, 319, 7, 29, "Text"]
}
]
*)

(* End of internal cache information *)
