(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    177849,       5964]
NotebookOptionsPosition[    170233,       5723]
NotebookOutlinePosition[    171208,       5762]
CellTagsIndexPosition[    171134,       5757]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["6.5  Integral Representations for Analytic Functions",
 
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
 "\tWe now present some major results in the theory of functions of a complex \
variable.  The first result is known as ",
 StyleBox[ButtonBox["Cauchy's",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Cauchy.\
html"], None}],
  FontVariations->{"Underline"->True}],
 " ",
 StyleBox[ButtonBox["integral formula",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/CauchyIntegralFormula.html"], None}],
  FontVariations->{"Underline"->True}],
 " and shows that the value of an analytic function ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " can be represented by a certain contour integral.  The  ",
 Cell[BoxData[
  SuperscriptBox["n", "th"]]],
 "  derivative,  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["f", 
    RowBox[{"(", "n", ")"}]], 
   RowBox[{"(", "z", ")"}]}]]],
 ",  will have a similar representation.  In Chapter 7, we use the Cauchy \
integral formulas to prove ",
 StyleBox[ButtonBox["Taylor's",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Taylor.\
html"], None}],
  FontVariations->{"Underline"->True}],
 " ",
 StyleBox[ButtonBox["theorem",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/TaylorsTheorem.html"], None}],
  FontVariations->{"Underline"->True}],
 " and also establish the power series representation for analytic functions. \
The Cauchy integral formulas are a convenient tool for evaluating certain \
contour integrals."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Theorem 6.10 (",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Cauchy Integral Formula",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/CauchyIntegralFormula.html"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 StyleBox[").",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Let ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " be analytic in the simply connected domain ",
 StyleBox["D",
  FontFamily->"Courier New"],
 ",  and let ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " be a simple closed positively oriented contour that lies in ",
 StyleBox["D",
  FontFamily->"Courier New"],
 ".  If  ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 "  is a point that lies interior to ",
 StyleBox["C",
  FontFamily->"Courier New"],
 ", then   \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}], "  ", "=", "  ", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]"}]], 
    RowBox[{
     SubscriptBox["\[Integral]", "C"], 
     RowBox[{
      FractionBox[
       RowBox[{"f", 
        RowBox[{"(", "z", ")"}]}], 
       RowBox[{"z", " ", "-", " ", 
        SubscriptBox["z", "0"]}]], 
      RowBox[{"\[DifferentialD]", "z"}]}]}]}]}]]],
 ".   "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 6.10 is in the book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 6.21.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Show that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["\[Integral]", "C"], 
    RowBox[{
     FractionBox[
      SuperscriptBox["\[ExponentialE]", "z"], 
      RowBox[{"z", " ", "-", " ", "1"}]], 
     RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "=", "  ", 
   RowBox[{
   "\[ImaginaryI]", " ", "2", " ", "\[Pi]", " ", "\[ExponentialE]"}]}]]],
 ",  where ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " is the circle  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"C", ":", 
    RowBox[{"|", "z", "|"}]}], "=", "2"}]]],
 "  with positive orientation."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "\t\t\t",
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.5 0.238095 [
[.02381 .4875 -6 -9 ]
[.02381 .4875 6 0 ]
[.2619 .4875 -6 -9 ]
[.2619 .4875 6 0 ]
[.7381 .4875 -3 -9 ]
[.7381 .4875 3 0 ]
[.97619 .4875 -3 -9 ]
[.97619 .4875 3 0 ]
[1.025 .5 0 -6.28125 ]
[1.025 .5 10 6.28125 ]
[.4875 .02381 -12 -4.5 ]
[.4875 .02381 0 4.5 ]
[.4875 .2619 -12 -4.5 ]
[.4875 .2619 0 4.5 ]
[.4875 .7381 -6 -4.5 ]
[.4875 .7381 0 4.5 ]
[.4875 .97619 -6 -4.5 ]
[.4875 .97619 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .5 m
.02381 .50625 L
s
[(-2)] .02381 .4875 0 1 Mshowa
.2619 .5 m
.2619 .50625 L
s
[(-1)] .2619 .4875 0 1 Mshowa
.7381 .5 m
.7381 .50625 L
s
[(1)] .7381 .4875 0 1 Mshowa
.97619 .5 m
.97619 .50625 L
s
[(2)] .97619 .4875 0 1 Mshowa
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .02381 m
.50625 .02381 L
s
[(-2)] .4875 .02381 1 0 Mshowa
.5 .2619 m
.50625 .2619 L
s
[(-1)] .4875 .2619 1 0 Mshowa
.5 .7381 m
.50625 .7381 L
s
[(1)] .4875 .7381 1 0 Mshowa
.5 .97619 m
.50625 .97619 L
s
[(2)] .4875 .97619 1 0 Mshowa
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.03 w
.7381 .5 Mdot
0 g
gsave
.7381 .54762 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
70.188 14.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
75.813 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 1 r
.5 Mabswid
newpath
.5 .5 .47619 0 365.73 arc
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{175, 175},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\
eJztmmlPFEEQhltgBQ88AfFAl1NQEFQuRQQRwfuIiV80JsSYaIzRqP+Lnzhu
d/XUzg7PDDOhdwPRSXZnUvXWWz19TXV1v9j68+Xz960/Xz9tVTd/bf388vXT
7+rGj181UfshY8y2/VWNfY5qj/5v20RR7emNu7UbJ6s92d/7XVVP7a3DKtp3
AaVUHdnwJ/Z2ysrfiWDN3jqtgJy0gayiFq+E4n5czqjLu0/CM4p/XI2eCWzJ
3iwm6rZPbRZML3JKDTfFcEEFfQDvUVmksnUxnIv9RBfAsFdp1wQ+C0xkeF5p
V8VwRpkGAH5R33tZ4NPg5woYXlY/S2I4pYIhgFeBdlEMr6vhCBgOqtbDrwET
GQ6r4bwYjqvgKsBHgfa2GF4FFVGMqQNvOKqCawAfB9oZMayXfRIMJ1Tr4UPA
RIbXATclFIOZqkaKyUxX2MQ3gGIKcFKyREerq6aB4gbgpIqlX2KtNlJMp9rG
DIDhTTC8CTjpDeYSqG4BxS3AjQnFxcxuWJjiAqhmgeI24GQUyCSSUs0BBU1K
I+Uo5gA3LBT9oJoHinnAyZAw50C1ABQLgJMhYfpAtViOohdUd4BiEXAyqvBD
chco7gBORpU5C6ql5lDcBZwMTHMGVPeAYglwMkTN6ax+UbEEFDSUJKPmJdp7
YCtzgMQJBZrc0bpo4z5YyGxgToLKTQAu1qEwhUq7XM4B9S6ipXLLFGROZNFm
hlclyVaBYgVwMhmZblA9AIpVwPW3nOIB4GQ+k/A1pVprOcUxUD0EijXA9bWc
4iHgZGI2R0G13nKKI6B61ByKdcD1lKN4BDj5PJguUG38p2g2xQbg5GtrOkG1
+U9TuAWxSVwuVHMBRBX4qo1a9/3y9DFMAglzOOE5Vo1mMaZk+QtnkVnesztd
icrsydVgQhZz+koz7erBXvL+FS1QzGAvFwBlBiZFy0JL2oYarjTUcOx8eM81
XU8fef4zSa8dDZVtEiv17BptSxcsVbfpZrS/x0C2CTjodE2m8K9UsxgBi87k
6Ej2mEo5L1XpRFGy4uoWXSkLewmzRKgdvgDJIf7N90jLuFPritwJBckpNzU4
9b/W1Nj+6B0uj+PmSVp5lySj/FMA2lEtI2WGAziQPEyhPHQAb5SJLOmq6Fd1
HF4s7r2U7ylJn1FvlFUrGQ6MaZNTfm1fhScBor2DFbbue4oAK6IWrstyKPbH
MjfAev1gJR6am4QJkE06WGmxFcD5/F6AFCFlQl06ODO3nJOy3EtaNSdbGzS3
XIosJcvJfzcprU67B/P6mrTgzEn9F92KyNnNCLAhEmBnJwBFgC2qABtlASiK
7vjlbBr2xx0qIsNZ1frN0gD7rQF2fQPsPQfYAS+6+z4DuPFyFHRQZUIoroCq
5DGCqrYyGU6q1h+fCHACo+SZDzqvMgGGOadM6udVyJBOvUjLI+cYUNTPv8h4
SLwFwSk94g2p3ijXMqQOZOgmWiozNei0MtdJj3CCQYBTv/KG1KEvA8WAOpAv
jVSpSyteAribWxyrfMLxuMR5MKzPYRJDyXzn/JwDeI9qJYKVz4dz0wPw06r1
p+CW1f5I/GQoCdGtODk5KBHeYSsgOH3Q3YrOZX9fCoUrQq8VvBXBc7CiOKPh
DGOhdI23eBZXbt5Zx5yjlduFb6/U00cRvAbWD7s6TFvZ60PCw86399qXcUOn
s5MF3sQc+gsZJtUa\
\>"],
  ImageRangeCache->{{{0, 174}, {174, 0}} -> {-2, -2, 0, 0}}],
 "   "
}], "Text"],

Cell[TextData[{
 "Solution.  We have  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   SuperscriptBox["\[ExponentialE]", "z"]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "1", ")"}]}], "=", "\[ExponentialE]"}]]],
 ".  The point  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "0"], "=", "1"}]]],
 "  lies interior to the circle, so Cauchy's integral formula implies that  \n\
\n\t\t\t",
 Cell[BoxData[
  RowBox[{"\[ExponentialE]", " ", "=", " ", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "1", ")"}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      FractionBox["1", 
       RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]"}]], 
      RowBox[{
       SubscriptBox["\[Integral]", "C"], 
       RowBox[{
        FractionBox[
         RowBox[{"f", 
          RowBox[{"(", "z", ")"}]}], 
         RowBox[{"z", " ", "-", " ", 
          SubscriptBox["z", "0"]}]], 
        RowBox[{"\[DifferentialD]", "z"}]}]}]}], " ", "=", " ", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]"}]], 
      RowBox[{
       SubscriptBox["\[Integral]", "C"], 
       RowBox[{
        FractionBox[
         SuperscriptBox["\[ExponentialE]", "z"], 
         RowBox[{"z", " ", "-", " ", "1"}]], 
        RowBox[{"\[DifferentialD]", "z"}]}]}]}]}]}]}]]],
 ",  \n\nand multiplication by  ",
 Cell[BoxData[
  RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]"}]]],
 "  establishes the desired result."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 6.21.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 "Enter the integrand  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"w", "[", "z", "]"}], "=", 
   FractionBox[
    SuperscriptBox["\[ExponentialE]", "z"], 
    RowBox[{"z", " ", "-", " ", "1"}]]}]],
  AspectRatioFixed->True],
 "  and locate the singularities."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", 
     RowBox[{"w", ",", "z", ",", "Z"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "i", ",", "solset", ",", "val"}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"w", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox[
      SuperscriptBox["\[ExponentialE]", "z"], 
      RowBox[{"z", "-", "1"}]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"solset", " ", "=", " ", 
     RowBox[{"Sort", "[", 
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Denominator", "[", 
          RowBox[{"w", "[", "z", "]"}], "]"}], "\[Equal]", "0"}], ",", "z"}], 
       "]"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Z", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"Length", "[", "solset", "]"}], "}"}]}], "]"}]}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"i", "=", "1"}], ",", 
      RowBox[{"i", "\[LessEqual]", 
       RowBox[{"Length", "[", "solset", "]"}]}], ",", 
      RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        SubscriptBox["Z", 
         RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], " ",
         "=", " ", 
        RowBox[{"ReplaceAll", "[", 
         RowBox[{"z", ",", 
          SubscriptBox["solset", 
           RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]]}], 
         "]"}]}], ";"}]}], " ", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w[z] = \>\"", ",", 
      RowBox[{"w", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<The set of singularities is \>\"", ",", "Z"}], "]"}], ";"}],
    " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39930878053125*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "Find the singularity that lie inside  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"C", ":", 
    RowBox[{"|", "z", "|"}]}], "=", "2"}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["Z", 
       RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], ",", 
      "\"\<,    Is |\>\"", ",", 
      SubscriptBox["Z", 
       RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], ",", 
      "\"\<| < 2 ?    \>\"", ",", 
      RowBox[{
       RowBox[{"N", "[", 
        RowBox[{"Abs", "[", 
         SubscriptBox["Z", 
          RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], 
         "]"}], "]"}], "<", "2"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399308785703125*^9},
 AspectRatioFixed->True],

Cell["The function f(z) in the numerator ", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{
      RowBox[{"w", "[", "z", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{"z", " ", "-", " ", 
        SubscriptBox["Z", 
         RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]]}], 
       ")"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w[z] = \>\"", ",", 
      RowBox[{"w", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w[z] = (\>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\<)/(\>\"", ",", 
      RowBox[{"z", " ", "-", " ", 
       SubscriptBox["Z", 
        RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]]}], 
      ",", "\"\<)\>\""}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399308790671875*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "Use Cauchy's Integral Formula to evaluate the integral of  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"w", "[", "z", "]"}], "=", 
   FractionBox[
    SuperscriptBox["\[ExponentialE]", "z"], 
    RowBox[{"z", " ", "-", " ", "1"}]]}]],
  AspectRatioFixed->True],
 " taken over",
 " ",
 StyleBox["C",
  FontFamily->"Courier New"],
 "."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"val", " ", "=", " ", 
     RowBox[{"2", " ", "\[Pi]", " ", "\[ImaginaryI]", " ", 
      RowBox[{"f", "[", 
       SubscriptBox["Z", 
        RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], 
       "]"}]}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w[z] = \>\"", ",", 
      FractionBox["\"\<f[z]\>\"", 
       RowBox[{"z", " ", "-", " ", 
        SubscriptBox["Z", 
         RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]]}]]}],
      "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<   \!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["Z", 
       RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]]}], 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[\!\(\*SubscriptBox[\(z\), \(1\)]\)] = \>\"", ",", " ", 
      RowBox[{"f", "[", 
       SubscriptBox["Z", 
        RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], 
       "]"}]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Use Cauchy's Integral Formula\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<\!\(\*SubscriptBox[\(\[Integral]\), \(C\)]\)\!\(\*FractionBox[\(f \
\((z)\)\), \(z - \*SubscriptBox[\(z\), \(1\)]\)]\)\[DifferentialD]z = 2\[Pi]\
\[ImaginaryI] f(\!\(\*SubscriptBox[\(z\), \(1\)]\))\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(\[Integral]\), \(C\)]\) \>\"", ",", 
      RowBox[{"w", "[", "z", "]"}], ",", 
      "\"\< \[DifferentialD]z = 2\[Pi]\[ImaginaryI] f[\>\"", ",", 
      SubscriptBox["Z", 
       RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], ",", 
      "\"\<] = 2\[Pi]\[ImaginaryI](\>\"", ",", 
      RowBox[{"f", "[", 
       SubscriptBox["Z", 
        RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], 
       "]"}], ",", "\"\<) = \>\"", ",", "val"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399308796703125*^9}],

Cell["Thus, we have found the value of the contour integral.", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"dots", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
        RowBox[{"Point", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Re", "[", 
            SubscriptBox["Z", 
             RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], 
            "]"}], ",", 
           RowBox[{"Im", "[", 
            SubscriptBox["Z", 
             RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], 
            "]"}]}], "}"}], "]"}]}], "}"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"centers", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"StyleForm", "[", 
          RowBox[{
           RowBox[{
           "TraditionalForm", "[", 
            "\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\)\>\"", "]"}], ",", 
           RowBox[{"FontSize", "\[Rule]", "12"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Re", "[", 
            SubscriptBox["Z", 
             RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], 
            "]"}], ",", 
           RowBox[{
            RowBox[{"Im", "[", 
             SubscriptBox["Z", 
              RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]],
              "]"}], "+", "0.2"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}], "}"}], "]"}]}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"contour", " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", 
        RowBox[{"Circle", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}], ",", "2"}], "]"}]}], "}"}], 
      "]"}]}], ";"}], " ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{"dots", ",", "centers", ",", "contour", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.1"}], ",", "2.1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.1"}], ",", "2.1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], "\n", 
   RowBox[{"Print", "[", 
    RowBox[{
    "\"\<\!\(\*UnderscriptBox[\(\[ContourIntegral]\), \(C\)]\) (\>\"", ",", 
     RowBox[{"w", "[", "z", "]"}], ",", "\"\<) \[DifferentialD]z = \>\"", ",",
      "val"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The contour is the circle  C: |z| = 2,\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<with positive orientation.\>\"", "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399308801296875*^9, 3.399308804203125*^9}, {
  3.399883520109375*^9, 3.399883520703125*^9}}]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 6.22.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Show that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["\[Integral]", "C"], 
    RowBox[{
     FractionBox[
      RowBox[{"sin", 
       RowBox[{"(", "z", ")"}]}], 
      RowBox[{
       RowBox[{"4", "z"}], " ", "+", "  ", "\[Pi]"}]], 
     RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"-", " ", "\[ImaginaryI]"}], 
    FractionBox[
     RowBox[{" ", 
      RowBox[{"\[Pi]", 
       SqrtBox["2"]}]}], "4"]}]}]]],
 ",  where",
 " ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " is the circle  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"C", ":", 
    RowBox[{"|", "z", "|"}]}], "=", "1"}]]],
 "  with positive orientation."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "\t\t\t",
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.454545 0.5 0.454545 [
[.143 .4875 -11.4063 -18.1875 ]
[.143 .4875 11.4063 0 ]
[.95455 .4875 -3 -9 ]
[.95455 .4875 3 0 ]
[1.025 .5 0 -6.28125 ]
[1.025 .5 10 6.28125 ]
[.4875 .04545 -12 -4.5 ]
[.4875 .04545 0 4.5 ]
[.4875 .95455 -6 -4.5 ]
[.4875 .95455 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.143 .5 m
.143 .50625 L
s
gsave
.143 .4875 -72.4063 -22.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26.1875 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 15.125 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 9.313 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
71.375 15.125 moveto
(\\200\\200) show
75.625 15.125 moveto
(\\200) show
77.688 15.125 moveto
(\\200) show
72.688 21.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.95455 .5 m
.95455 .50625 L
s
[(1)] .95455 .4875 0 1 Mshowa
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .04545 m
.50625 .04545 L
s
[(-1)] .4875 .04545 1 0 Mshowa
.5 .95455 m
.50625 .95455 L
s
[(1)] .4875 .95455 1 0 Mshowa
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.03 w
.143 .5 Mdot
0 g
gsave
.143 .54545 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
70.188 14.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
75.813 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 1 r
.5 Mabswid
newpath
.5 .5 .45455 0 365.73 arc
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{175, 175},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\
eJzdmllvEzEURt00odAlXUlb0iVdoNA03fd9hwKlIPHAAxWKKqT2AYFKn/lL
/Ymh9p04TXImZIQTRkRKZuL73WOPx/Z4rn2avbn8+i17c3WRTb28zv64vLr4
mTr+fn2X1NiglLrV35TS57m7U+/nvcrlcqpRmT93Z/r72fyqkJhO9CGmDRF/
0RswVZAf6UNCp3+UhN18JrmIlkerxD20bmfC2dSHqE5oqRLRZj3kGtSaPmhN
Lq7PfMvTaXWvxHElL8/1grzHWo9Fvmj9+0GesNYDkc9b/wGQ91vrnshnbcIQ
yJPWuiPyjM0uBfJBa90U+ZQV5axoBBxToFsTxKQtwjg4jlirJ38BJHIcA92y
ICYscwIcx63Vkz8DEjmSbkEQBeYkOBbK48mp7ORIdTEriFEwpQExCboZQYyA
aQoQadBNC4JuewYQ1IxEp4Z96cWIjK1Ez3HI98qKHWdAJ7UizR3rtxgxCzq5
N2oATHPBEEkwzQNiDnTPBfHEt2kWI+ZBJ01d9YNpERALoJOeofrAtASIRdA9
FUQvmJYBsQQ6GSVkQC0xrQBiGXTSMdVjMK0CYgV0o84QPWBaA8Qq6KRvq24w
rQNiDXQpZ4guMG0AYh10w8EQG6CTgUIe4yWmzbojOsC0VRvEJuhkxFPtYNoG
xBboZMRTcTDt1AaxDbpkMMQO6GTQlHlhiWm37ohWMO3VBrELun5niBYw7dcG
sQe6vjAhmsFkWqwh0DM+IKwdEDT72AffXn+saQYxvzJWgD0Ck3SOaBHi7kPT
k4DkeAnCD3sAvgl/rKnUiCPY4d8jGvWvqb/CmZyq/MeUlm68g9Leb/NKghmS
n0xx5NW8hHMEnEPQhR7RBggKLtBbQ8Cs4tX3k4N7aXlEwp9cOkr4YQMWuEZY
Uw++g09AmBnEI7rV0uSbYM3iUd7HHnj/ilNjnjLfM/SnWf9EdcIvsMYKsOK6
a/K/DFMoQ6Q3GbqMVtA9qGc91ahDJmzroIBJQFgfIBxg220ZKZzoIAN5Aygb
KmqUWycgapRVFyAitqFRcMpNzTl4dBZuOj0L6j9rCC8i4GT04H9GhP4VxsHr
XDjeSx0gwhEpcBDyqGPgpQLCQRCqWkSFUJiDaFo4IosOQqR1DNRWQIQjaO0g
+u5gDcDBYoaDJRUHCzsOlpccLHI5QDhYrTODl1nKJMcKK4UOljyHwUTLrdOg
SwdDZEAnU3gX68aFjQPkWNh04K2XO1hyD7jI72BbQcCNDA62TtB2gTFAlG3b
SNsEktP99hyplaQAQa1OhnRpfCZvchy0VnmsYwcbBEda2vcQpnObvURJcOyz
Vpna4dBKsQcaqmWyLffHMBPg2G2tEmKRmjGgbpB3WOuJyM1lme1VTfkzDHO2
WN1bcTSla9IJJKe0qPX4IAhThLhO+CQJAbeYBZS/zjcHjGH8g213t1Uf3tmi
f5GEM6Ce/zHDUi/9Ob+XQ3l4xLOe5ptNaciviitRDb8BcPQ5tg==\
\>"],
  ImageRangeCache->{{{0, 174}, {174, 0}} -> {-1, -1, 0, 0}}],
 "   "
}], "Text"],

Cell[TextData[{
 "Solution.  Here we have  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{"sin", 
    RowBox[{"(", "z", ")"}]}]}]]],
 ".  We manipulate the integral and use Cauchy's integral formula to obtain  \
\n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["\[Integral]", "C"], 
     RowBox[{
      FractionBox[
       RowBox[{"sin", 
        RowBox[{"(", "z", ")"}]}], 
       RowBox[{
        RowBox[{"4", "z"}], " ", "+", "  ", "\[Pi]"}]], 
      RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], 
      RowBox[{
       SubscriptBox["\[Integral]", "C"], 
       RowBox[{
        FractionBox[
         RowBox[{"sin", 
          RowBox[{"(", "z", ")"}]}], 
         RowBox[{"z", " ", "+", " ", 
          FractionBox["\[Pi]", "4"]}]], 
        RowBox[{"\[DifferentialD]", "z"}]}]}]}], "   ", "=", "   ", 
     RowBox[{
      FractionBox["1", "4"], 
      RowBox[{
       SubscriptBox["\[Integral]", "C"], 
       RowBox[{
        FractionBox[
         RowBox[{"sin", 
          RowBox[{"(", "z", ")"}]}], 
         RowBox[{"z", " ", "-", " ", 
          RowBox[{"(", 
           RowBox[{"-", 
            FractionBox["\[Pi]", "4"]}], ")"}]}]], 
        RowBox[{"\[DifferentialD]", "z"}]}]}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                        ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      RowBox[{
       FractionBox["1", "4"], 
       RowBox[{"(", 
        RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]"}], ")"}], "f", 
       RowBox[{"(", 
        RowBox[{"-", 
         FractionBox["\[Pi]", "4"]}], ")"}]}], "  ", "=", "  ", 
      RowBox[{
       FractionBox["1", "4"], 
       RowBox[{"(", 
        RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]"}], ")"}], "sin", 
       RowBox[{"(", 
        RowBox[{"-", 
         FractionBox["\[Pi]", "4"]}], ")"}]}]}]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                        ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"\[Pi]", " ", "\[ImaginaryI]"}], "2"], 
      RowBox[{"(", 
       RowBox[{"-", 
        FractionBox[
         SqrtBox["2"], "2"]}], ")"}]}], "  ", "=", "   ", 
     RowBox[{
      RowBox[{"-", " ", "\[ImaginaryI]"}], 
      FractionBox[
       RowBox[{" ", 
        RowBox[{"\[Pi]", 
         SqrtBox["2"]}]}], "4"]}]}]}]}]}]],
 "  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 6.22.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 "Enter the integrand  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"w", "[", "z", "]"}], "=", 
   FractionBox[
    RowBox[{"Sin", "[", "z", "]"}], 
    RowBox[{
     RowBox[{"4", "z"}], " ", "+", " ", "\[Pi]"}]]}]],
  AspectRatioFixed->True],
 "  and locate the singularities."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", 
     RowBox[{"w", ",", "z", ",", "Z"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "i", ",", "solset", ",", "val"}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"w", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox[
      RowBox[{"Sin", "[", "z", "]"}], 
      RowBox[{
       RowBox[{"4", "z"}], " ", "+", " ", "\[Pi]"}]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"solset", " ", "=", " ", 
     RowBox[{"Sort", "[", 
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Denominator", "[", 
          RowBox[{"w", "[", "z", "]"}], "]"}], "\[Equal]", "0"}], ",", "z"}], 
       "]"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Z", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"Length", "[", "solset", "]"}], "}"}]}], "]"}]}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"i", "=", "1"}], ",", 
      RowBox[{"i", "\[LessEqual]", 
       RowBox[{"Length", "[", "solset", "]"}]}], ",", 
      RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        SubscriptBox["Z", 
         RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], " ",
         "=", " ", 
        RowBox[{"ReplaceAll", "[", 
         RowBox[{"z", ",", 
          SubscriptBox["solset", 
           RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]]}], 
         "]"}]}], ";"}]}], " ", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w[z] = \>\"", ",", 
      RowBox[{"w", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<The set of singularities is \>\"", ",", "Z"}], "]"}], ";"}],
    " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.3993088140625*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "Find the singularity that lie inside  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"C", ":", 
    RowBox[{"|", "z", "|"}]}], "=", "1"}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["Z", 
       RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], ",", 
      "\"\<,    Is |\>\"", ",", 
      SubscriptBox["Z", 
       RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], ",", 
      "\"\<| < 1 ?    \>\"", ",", 
      RowBox[{
       RowBox[{"N", "[", 
        RowBox[{"Abs", "[", 
         SubscriptBox["Z", 
          RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], 
         "]"}], "]"}], "<", "1"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.3993088205625*^9}],

Cell["The integrand f(z) is to be used is", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"Simplify", "[", 
      RowBox[{
       RowBox[{"w", "[", "z", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{"z", " ", "-", " ", 
         SubscriptBox["Z", 
          RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]]}], 
        ")"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w[z] = \>\"", ",", 
      RowBox[{"w", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w[z] = (\>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\<)/(\>\"", ",", 
      RowBox[{"z", " ", "-", " ", 
       SubscriptBox["Z", 
        RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]]}], 
      ",", "\"\<)\>\""}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.3993088248125*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "Use Cauchy's Integral Formula to evaluate the integral of  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"w", "[", "z", "]"}], "=", 
   FractionBox[
    RowBox[{"Sin", "[", "z", "]"}], 
    RowBox[{
     RowBox[{"4", "z"}], " ", "+", " ", "\[Pi]"}]]}]],
  AspectRatioFixed->True],
 " taken over",
 " ",
 StyleBox["C",
  FontFamily->"Courier New"],
 "."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"val", " ", "=", " ", 
     RowBox[{"2", " ", "\[Pi]", " ", "\[ImaginaryI]", " ", 
      RowBox[{"f", "[", 
       SubscriptBox["Z", 
        RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], 
       "]"}]}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w[z] = \>\"", ",", 
      FractionBox["\"\<f[z]\>\"", 
       RowBox[{"z", " ", "-", " ", 
        SubscriptBox["Z", 
         RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]]}]]}],
      "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<   \!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["Z", 
       RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]]}], 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[\!\(\*SubscriptBox[\(z\), \(1\)]\)] = \>\"", ",", " ", 
      RowBox[{"f", "[", 
       SubscriptBox["Z", 
        RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], 
       "]"}]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Use Cauchy's Integral Formula\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<\!\(\*SubscriptBox[\(\[Integral]\), \(C\)]\)\!\(\*FractionBox[\(f \
\((z)\)\), \(z - \*SubscriptBox[\(z\), \(1\)]\)]\)\[DifferentialD]z = 2\[Pi]\
\[ImaginaryI] f(\!\(\*SubscriptBox[\(z\), \(1\)]\))\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(\[Integral]\), \(C\)]\) \>\"", ",", 
      RowBox[{"w", "[", "z", "]"}], ",", 
      "\"\< \[DifferentialD]z = 2\[Pi]\[ImaginaryI] f[\>\"", ",", 
      SubscriptBox["Z", 
       RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], ",", 
      "\"\<] = 2\[Pi]\[ImaginaryI](\>\"", ",", 
      RowBox[{"f", "[", 
       SubscriptBox["Z", 
        RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], 
       "]"}], ",", "\"\<) = \>\"", ",", "val"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399308829234375*^9}],

Cell["Thus, we have found the value of the contour integral.", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"dots", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
        RowBox[{"Point", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Re", "[", 
            SubscriptBox["Z", 
             RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], 
            "]"}], ",", 
           RowBox[{"Im", "[", 
            SubscriptBox["Z", 
             RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], 
            "]"}]}], "}"}], "]"}]}], "}"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"centers", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"StyleForm", "[", 
          RowBox[{
           RowBox[{
           "TraditionalForm", "[", 
            "\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\)\>\"", "]"}], ",", 
           RowBox[{"FontSize", "\[Rule]", "12"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Re", "[", 
            SubscriptBox["Z", 
             RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], 
            "]"}], ",", 
           RowBox[{
            RowBox[{"Im", "[", 
             SubscriptBox["Z", 
              RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]],
              "]"}], "+", "0.1"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}], "}"}], "]"}]}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"contour", " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", 
        RowBox[{"Circle", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}], ",", "1"}], "]"}]}], "}"}], 
      "]"}]}], ";"}], " ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{"dots", ",", "centers", ",", "contour", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.1"}], ",", "1.1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.1"}], ",", "1.1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], "\n", 
   RowBox[{"Print", "[", 
    RowBox[{
    "\"\<\!\(\*UnderscriptBox[\(\[ContourIntegral]\), \(C\)]\) (\>\"", ",", 
     RowBox[{"w", "[", "z", "]"}], ",", "\"\<) \[DifferentialD]z = \>\"", ",",
      "val"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The contour is the circle  C: |z| = 1,\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<with positive orientation.\>\"", "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3993088345625*^9, 3.39930883709375*^9}, {
  3.399883531890625*^9, 3.399883532515625*^9}}]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 6.23.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Show that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["\[Integral]", "C"], 
    RowBox[{
     FractionBox[
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", "\[Pi]", " ", "z"}]], 
      RowBox[{
       RowBox[{"2", 
        SuperscriptBox["z", "2"]}], " ", "-", " ", 
       RowBox[{"5", "z"}], " ", "+", " ", "2"}]], 
     RowBox[{"\[DifferentialD]", "z"}]}]}], " ", "=", " ", 
   FractionBox[
    RowBox[{"2", " ", "\[Pi]"}], "3"]}]]],
 ",  where",
 " ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " ",
 "is the circle  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"C", ":", 
    RowBox[{"|", "z", "|"}]}], "=", "1"}]]],
 "  with positive orientation."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "\t\t\t",
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.454545 0.5 0.454545 [
[.04545 .4875 -6 -9 ]
[.04545 .4875 6 0 ]
[.27273 .4875 -11.4063 -20.125 ]
[.27273 .4875 11.4063 0 ]
[.72727 .4875 -8.09375 -20.125 ]
[.72727 .4875 8.09375 0 ]
[.95455 .4875 -3 -9 ]
[.95455 .4875 3 0 ]
[1.025 .5 0 -6.28125 ]
[1.025 .5 10 6.28125 ]
[.4875 .04545 -12 -4.5 ]
[.4875 .04545 0 4.5 ]
[.4875 .27273 -22.8125 -10.0625 ]
[.4875 .27273 0 10.0625 ]
[.4875 .72727 -16.1875 -10.0625 ]
[.4875 .72727 0 10.0625 ]
[.4875 .95455 -6 -4.5 ]
[.4875 .95455 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04545 .5 m
.04545 .50625 L
s
[(-1)] .04545 .4875 0 1 Mshowa
.27273 .5 m
.27273 .50625 L
s
gsave
.27273 .4875 -72.4063 -24.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.063 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
71.375 17.063 moveto
(\\200\\200) show
75.625 17.063 moveto
(\\200) show
77.688 17.063 moveto
(\\200) show
72.688 23.125 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.72727 .5 m
.72727 .50625 L
s
gsave
.72727 .4875 -69.0938 -24.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
66.063 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
64.750 17.063 moveto
(\\200\\200) show
69.000 17.063 moveto
(\\200) show
71.063 17.063 moveto
(\\200) show
66.063 23.125 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.95455 .5 m
.95455 .50625 L
s
[(1)] .95455 .4875 0 1 Mshowa
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .04545 m
.50625 .04545 L
s
[(-1)] .4875 .04545 1 0 Mshowa
.5 .27273 m
.50625 .27273 L
s
gsave
.4875 .27273 -83.8125 -14.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.063 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
71.375 17.063 moveto
(\\200\\200) show
75.625 17.063 moveto
(\\200) show
77.688 17.063 moveto
(\\200) show
72.688 23.125 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .72727 m
.50625 .72727 L
s
gsave
.4875 .72727 -77.1875 -14.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
66.063 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
64.750 17.063 moveto
(\\200\\200) show
69.000 17.063 moveto
(\\200) show
71.063 17.063 moveto
(\\200) show
66.063 23.125 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .95455 m
.50625 .95455 L
s
[(1)] .4875 .95455 1 0 Mshowa
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.03 w
.72727 .5 Mdot
0 g
gsave
.72727 .54545 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
70.188 14.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
75.813 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 1 r
.5 Mabswid
newpath
.5 .5 .45455 0 365.73 arc
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{175, 175},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\
eJzdmu9TFDcYxyMcgmCpLfaAgrAgagVRRNSiWA9RW9ta25m+6Is6HcbpVF90
2rH+X/6JW5In+9zt3SdxF7KU6c1wt+T5Pp/82CSbfZLn++9e//7n/rs3r/az
r9/u//36zat/sqd/vT1IGj5ljHlv/zJjr/ODS//1o8nz3Awb98/Blf371X2b
E2J6Zn9GrGEoLPoOTBH5E/vTtuk/S0KnyCQfsvJWRdyYur0Qzo79admEiYqI
j9RD6mC27Y/V5JP2KlieT1T3jTjeLeT5NMjPq/WpyLfUfxbkbbXuiXxT/edB
PqvWXZFvaMICyOfU+lDk65pdBvILat0R+TUV5SpaAscMdNuCWNUirIDjklq9
/CqQyPEi6O4I4ooyr4Djilq9/DKQyJF0twTRZa6CY7c8Xk5lJ0dqiw1BLINp
DRCroLshiCUwXQPEGuiuC4Ju+zogqBuJziwG6WXEujaid1wI1qzseAN00irS
3bF9y4gN0Mm9MfNgulkPMQemTUDcBN0Xgvg82DXLiE3QSVc3s2DaAsQt0MnI
MDNgug2ILdBdEsQ0mFwz2YnbnAHYbfCQ+UKm1grDbBzS7oCvDFvzWcVxQ6W9
C77LYSyNpbF62PPB0rZKiEDzfgnuMnGYKTC5keuepNSo2+CRhWH36iE+DXUr
V9FhezVmr0YBew98F8PY+1rNHbDKzCTrhj7TDuR9v1HEOTA9ODrCzWdusUj9
kVpFJlvzMZhoqiLsA/CVCdhMgommr2PEfgW+c0fHPgRfmf9liUvY4IisCevU
Q5wF024ziA7oZpMhJsD0qBnELuhmwgg3SbkJbhFgC2Ctju2DZaEMgrqBrMbB
RK8TlH08rVJWy7VrEM9qOpyVIAYescGbNCilZvQZngnVbajs2Fd6Z6VVfwT7
GGB7oGuHEdPaCd3btXsGXwDsvFqprSMZJCjjERDFx7UujejetMLBiWXF5yf5
Vimfgw8V6TEUKU5xt9s9p6mjL6iVuoUnD+v9MyMeW8qi53W2/rCK5Buo0THl
5j9Hya03rcC2e3MrF4SiHMkqVja5WlWYLChQEcE+OUyX/TAik/IEoh7jWlrp
qTogT/v/yqkjXtk7dP+wXy3jYiKD1pEurFsu+xkNV4MeasEHnc95kHIWPE4f
Z9sd4012L+auqelFuCaMXscTYC9qGSlOnCADmQIGlgIN5XYJ0hrK6jKkDWnn
o6hPmpaj2FrNZcCK3nSKsp3YZUnDiEegiyyH9/7PiJqvbAne+hpCdECX7iX6
ZCAShDUSICgA5ILzwTj3YWB9CAoA1QxSUaSOShvBNhQAJKzsmFSKc0cilhT+
dORgVC0Caygo7DYKgtHtCOzQ0e2gY1/eh4msV0ck2DYghGvOYHQ7AqPdFtrN
JGxkq6WhvSHaIKOlM2EjG2S0nKO9acJGtvNoe/GqdlUah5GNxgTbnQk2XRMg
EuwezxeNmJNjZOc6wRb8YsUBcx10a/UQ66CT3p7iHEP3IAs5dg/B+PMbCY6A
1Dx0kuCYS82DNQmO8tDxFQrJDRwjWtMEktP99o7USzJAUK+TJ093Ezx8xspZ
ZTWDAywYH+/TeYQb3C52OQeOM2rtiJwm2RlwpIlc3hvk/jhmGxyn1Crv6tIy
DjQF8nNqfSZyVy133G+0uMIzfROq+14cXelGbQLJKa2lHj8JwhVh0ib8Igk1
jzzWlH9bdAcMvfwHx0DfV/75QYv+myS8AOrLD2bY72U/L3tyGFzAe+vzotv0
Ry8r1MSc+hfSUD3A\
\>"],
  ImageRangeCache->{{{0, 174}, {174, 0}} -> {-1, -1, 0, 0}}],
 "   "
}], "Text"],

Cell[TextData[{
 "Solution.  We see that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"2", 
     SuperscriptBox["z", "2"]}], "-", 
    RowBox[{"5", "z"}], "+", "2"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "z"}], "-", "1"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"z", "-", "2"}], ")"}]}], " ", "=", " ", 
    RowBox[{"2", 
     RowBox[{"(", 
      RowBox[{"z", "-", 
       FractionBox["1", "2"]}], ")"}], 
     RowBox[{"(", 
      RowBox[{"z", "-", "2"}], ")"}]}]}]}]]],
 ".  The only zero of this expression that lies in the interior of",
 " ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " is ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "0"], "=", 
   FractionBox["1", "2"]}]]],
 ".  \nWe set  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   FractionBox[
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", "\[Pi]", " ", "z"}]], 
    RowBox[{"(", 
     RowBox[{"z", "-", "2"}], ")"}]]}]]],
 "  and use Theorem 6.10 to conclude that  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["\[Integral]", "C"], 
     RowBox[{
      FractionBox[
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Pi]", " ", "z"}]], 
       RowBox[{
        RowBox[{"2", 
         SuperscriptBox["z", "2"]}], " ", "-", " ", 
        RowBox[{"5", "z"}], " ", "+", " ", "2"}]], 
      RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Integral]", "C"], 
      RowBox[{
       FractionBox[
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", "\[Pi]", " ", "z"}]], 
        RowBox[{"2", 
         RowBox[{"(", 
          RowBox[{"z", "-", 
           FractionBox["1", "2"]}], ")"}], 
         RowBox[{"(", 
          RowBox[{"z", "-", "2"}], ")"}]}]], 
       RowBox[{"\[DifferentialD]", "z"}]}]}], " ", "=", "  ", 
     RowBox[{
      FractionBox["1", "2"], 
      RowBox[{
       SubscriptBox["\[Integral]", "C"], 
       RowBox[{
        FractionBox[
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"\[ImaginaryI]", " ", "\[Pi]", " ", "z"}]], 
         RowBox[{"(", 
          RowBox[{"z", "-", "2"}], ")"}]], 
        FractionBox["1", 
         RowBox[{"(", 
          RowBox[{"z", "-", 
           FractionBox["1", "2"]}], ")"}]], 
        RowBox[{"\[DifferentialD]", "z"}]}]}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                                ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      RowBox[{
       FractionBox["1", "2"], 
       RowBox[{
        SubscriptBox["\[Integral]", "C"], " ", 
        RowBox[{
         FractionBox[
          RowBox[{"f", 
           RowBox[{"(", "z", ")"}]}], 
          RowBox[{"(", 
           RowBox[{"z", "-", 
            FractionBox["1", "2"]}], ")"}]], 
         RowBox[{"\[DifferentialD]", "z"}]}]}]}], " ", "=", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]"}], ")"}], "f", 
       RowBox[{"(", 
        FractionBox["1", "2"], ")"}]}]}]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                                ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]"}], ")"}], 
       FractionBox[
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"\[Pi]", "/", "2"}]}]], 
        RowBox[{"(", 
         RowBox[{
          FractionBox["1", "2"], "-", "2"}], ")"}]]}], "  ", "=", "  ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Pi]", " ", "\[ImaginaryI]"}], ")"}], " ", 
       FractionBox["\[ImaginaryI]", 
        RowBox[{"(", 
         RowBox[{"-", 
          FractionBox["3", "2"]}], ")"}]]}]}]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                                ", 
   RowBox[{"=", "  ", 
    FractionBox[
     RowBox[{"2", " ", "\[Pi]"}], "3"]}]}]}]],
 "   "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 6.23.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 "Enter the integrand  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"w", "[", "z", "]"}], "=", 
   FractionBox[
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", "\[Pi]", " ", "z"}]], 
    RowBox[{
     RowBox[{"2", 
      SuperscriptBox["z", "2"]}], " ", "-", " ", 
     RowBox[{"5", "z"}], " ", "+", " ", "2"}]]}]],
  AspectRatioFixed->True],
 "  and locate the singularities."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", 
     RowBox[{"w", ",", "z", ",", "Z"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "i", ",", "solset", ",", "val"}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"w", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox[
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", "\[Pi]", " ", "z"}]], 
      RowBox[{
       RowBox[{"2", 
        SuperscriptBox["z", "2"]}], " ", "-", " ", 
       RowBox[{"5", "z"}], " ", "+", " ", "2"}]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"solset", " ", "=", " ", 
     RowBox[{"Sort", "[", 
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Denominator", "[", 
          RowBox[{"w", "[", "z", "]"}], "]"}], "\[Equal]", "0"}], ",", "z"}], 
       "]"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Z", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"Length", "[", "solset", "]"}], "}"}]}], "]"}]}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"i", "=", "1"}], ",", 
      RowBox[{"i", "\[LessEqual]", 
       RowBox[{"Length", "[", "solset", "]"}]}], ",", 
      RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        SubscriptBox["Z", 
         RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], " ",
         "=", " ", 
        RowBox[{"ReplaceAll", "[", 
         RowBox[{"z", ",", 
          SubscriptBox["solset", 
           RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]]}], 
         "]"}]}], ";"}]}], " ", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w[z] = \>\"", ",", 
      RowBox[{"w", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<The set of singularities is \>\"", ",", "Z"}], "]"}], ";"}],
    " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.3993088803125*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "Find the singularity that lie inside",
 " ",
 StyleBox["C",
  FontFamily->"Courier New"],
 "."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["Z", 
       RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], ",", 
      "\"\<,    Is |\>\"", ",", 
      SubscriptBox["Z", 
       RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], ",", 
      "\"\<| < 1 ?   \>\"", ",", 
      RowBox[{
       RowBox[{"N", "[", 
        RowBox[{"Abs", "[", 
         SubscriptBox["Z", 
          RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], 
         "]"}], "]"}], "<", "1"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(2\)]\) = \>\"", ",", 
      SubscriptBox["Z", 
       RowBox[{"\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]], ",", 
      "\"\<,     Is |\>\"", ",", 
      SubscriptBox["Z", 
       RowBox[{"\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]], ",", 
      "\"\<| < 1 ?    \>\"", ",", 
      RowBox[{
       RowBox[{"N", "[", 
        RowBox[{"Abs", "[", 
         SubscriptBox["Z", 
          RowBox[{"\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]], 
         "]"}], "]"}], "<", "1"}]}], "]"}], ";"}], " ", "\n"}]}]], "Input",
 CellChangeTimes->{3.399308884625*^9}],

Cell[TextData[{
 "Thus,  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   FractionBox["1", "2"]}]]],
 "  the only singularity that lies inside  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"C", ":", 
    RowBox[{"|", "z", "|"}]}], "=", "1"}]]],
 ".  \n\nThe integrand f(z) is to be used is"
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"Simplify", "[", 
      RowBox[{
       RowBox[{"w", "[", "z", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{"z", " ", "-", " ", 
         SubscriptBox["Z", 
          RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]]}], 
        ")"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w[z] = \>\"", ",", 
      RowBox[{"w", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w[z] = (\>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\<)/(\>\"", ",", 
      RowBox[{"z", " ", "-", " ", 
       SubscriptBox["Z", 
        RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]]}], 
      ",", "\"\<)\>\""}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399308889671875*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "Use Cauchy's Integral Formula to evaluate the integral of  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"w", "[", "z", "]"}], "=", 
   FractionBox[
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", "\[Pi]", " ", "z"}]], 
    RowBox[{
     RowBox[{"2", 
      SuperscriptBox["z", "2"]}], " ", "-", " ", 
     RowBox[{"5", "z"}], " ", "+", " ", "2"}]]}]],
  AspectRatioFixed->True],
 " taken over",
 " ",
 StyleBox["C",
  FontFamily->"Courier New"],
 "."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"val", " ", "=", " ", 
     RowBox[{"2", " ", "\[Pi]", " ", "\[ImaginaryI]", " ", 
      RowBox[{"f", "[", 
       SubscriptBox["Z", 
        RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], 
       "]"}]}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w[z] = \>\"", ",", 
      FractionBox["\"\<f[z]\>\"", 
       RowBox[{"z", " ", "-", " ", 
        SubscriptBox["Z", 
         RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]]}]]}],
      "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<   \!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["Z", 
       RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]]}], 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[\!\(\*SubscriptBox[\(z\), \(1\)]\)] = \>\"", ",", " ", 
      RowBox[{"f", "[", 
       SubscriptBox["Z", 
        RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], 
       "]"}]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Use Cauchy's Integral Formula\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<\!\(\*SubscriptBox[\(\[Integral]\), \(C\)]\)\!\(\*FractionBox[\(f \
\((z)\)\), \(z - \*SubscriptBox[\(z\), \(1\)]\)]\)\[DifferentialD]z = 2\[Pi]\
\[ImaginaryI] f(\!\(\*SubscriptBox[\(z\), \(1\)]\))\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(\[Integral]\), \(C\)]\) \>\"", ",", 
      RowBox[{"w", "[", "z", "]"}], ",", 
      "\"\< \[DifferentialD]z = \!\(\*SubscriptBox[\(\[Integral]\), \(C\)]\) \
\>\"", ",", "\"\<(\>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\<)/(\>\"", ",", 
      RowBox[{"z", " ", "-", " ", 
       SubscriptBox["Z", 
        RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]]}], 
      ",", "\"\<)\>\"", ",", "\"\< \[DifferentialD]z\>\""}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(\[Integral]\), \(C\)]\) \>\"", ",", 
      RowBox[{"w", "[", "z", "]"}], ",", 
      "\"\< \[DifferentialD]z = 2\[Pi]\[ImaginaryI] f[\>\"", ",", 
      SubscriptBox["Z", 
       RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], ",", 
      "\"\<] = 2\[Pi]\[ImaginaryI](\>\"", ",", 
      RowBox[{"f", "[", 
       SubscriptBox["Z", 
        RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], 
       "]"}], ",", "\"\<) = \>\"", ",", "val"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399308893765625*^9}],

Cell["Thus, we have found the value of the contour integral.", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"dots", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
        RowBox[{"Point", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Re", "[", 
            SubscriptBox["Z", 
             RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], 
            "]"}], ",", 
           RowBox[{"Im", "[", 
            SubscriptBox["Z", 
             RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], 
            "]"}]}], "}"}], "]"}]}], "}"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"centers", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"StyleForm", "[", 
          RowBox[{
           RowBox[{
           "TraditionalForm", "[", 
            "\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\)\>\"", "]"}], ",", 
           RowBox[{"FontSize", "\[Rule]", "12"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Re", "[", 
            SubscriptBox["Z", 
             RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], 
            "]"}], ",", 
           RowBox[{
            RowBox[{"Im", "[", 
             SubscriptBox["Z", 
              RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]],
              "]"}], "+", "0.1"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}], "}"}], "]"}]}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"contour", " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", 
        RowBox[{"Circle", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}], ",", "1"}], "]"}]}], "}"}], 
      "]"}]}], ";"}], " ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{"dots", ",", "centers", ",", "contour", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.1"}], ",", "1.1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.1"}], ",", "1.1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", 
          FractionBox["1", "2"]}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", 
          FractionBox["1", "2"]}], "]"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], "\n", 
   RowBox[{"Print", "[", 
    RowBox[{
    "\"\<\!\(\*UnderscriptBox[\(\[ContourIntegral]\), \(C\)]\) (\>\"", ",", 
     RowBox[{"w", "[", "z", "]"}], ",", "\"\<) \[DifferentialD]z = \>\"", ",",
      "val"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The contour is the circle  C: |z| = 1,\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<with positive orientation.\>\"", "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3993088980625*^9, 3.39930889959375*^9}, {
  3.39988353771875*^9, 3.399883537921875*^9}}]
}, Closed]],

Cell[TextData[{
 StyleBox["Theorem 6.11 (",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Leibniz's Rule",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/LeibnizIntegralRule.html"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 StyleBox[").",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Let ",
 StyleBox["G",
  FontFamily->"Courier New"],
 " be an open set,  and let  ",
 Cell[BoxData[
  RowBox[{"I", ":", " ", 
   RowBox[{"a", "\[LessEqual]", "t", "\[LessEqual]", "b"}]}]]],
 "  be an interval of real numbers.  Let ",
 Cell[BoxData[
  RowBox[{"g", 
   RowBox[{"(", 
    RowBox[{"z", ",", "t"}], ")"}]}]]],
 " and its partial derivative ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["g", "z"], 
   RowBox[{"(", 
    RowBox[{"z", ",", "t"}], ")"}]}]]],
 " with respect to ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " be continuous functions for all ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " in ",
 StyleBox["G",
  FontFamily->"Courier New"],
 " and all ",
 StyleBox["t",
  FontFamily->"Courier New"],
 " in ",
 StyleBox["I",
  FontFamily->"Courier New"],
 ".  Then  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"  ", 
   RowBox[{
    RowBox[{"F", 
     RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", "a", "b"], " ", 
     RowBox[{"g", 
      RowBox[{"(", 
       RowBox[{"z", ",", "t"}], ")"}], 
      RowBox[{"\[DifferentialD]", "t"}]}]}]}]}]]],
 "   is analytic for z in G, and  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"F", "'"}], 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    SubsuperscriptBox["\[Integral]", "a", "b"], " ", 
    RowBox[{
     SubscriptBox["g", "z"], 
     RowBox[{"(", 
      RowBox[{"z", ",", "t"}], ")"}], 
     RowBox[{"\[DifferentialD]", "t"}]}]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "\tThe proof is presented in some advanced texts.  See, for instance, ",
 ButtonBox["Rolf Nevanlinna",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/\
Nevanlinna.html"], None}],
 " and V. Paatero, ",
 StyleBox["Introduction to Complex Analysis",
  FontSlant->"Italic"],
 " (Reading, Massachusetts: Addison-Wesley Publishing Company, 1969), Section \
9.7."
}], "Text"],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Demonstration for Theorem 6.11.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", 
     RowBox[{"t", ",", "z"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "F"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "z_", "]"}], "=", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "a", "b"], 
      RowBox[{
       RowBox[{"f", "[", 
        RowBox[{"z", ",", "t"}], "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[z] = \>\"", ",", 
      RowBox[{"F", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Rule Leibniz's Rule is\>\"", "]"}], ";"}], " ",
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F'[z] = \>\"", ",", 
      RowBox[{
       RowBox[{"F", "'"}], "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<where\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[PartialD]", "z"], " ", 
       RowBox[{"f", "[", 
        RowBox[{"z", ",", "t"}], "]"}]}], ",", 
      "\"\< = \!\(\*SubscriptBox[\(\[PartialD]\), \(z\)]\) f[z,t]\>\""}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399308911015625*^9}]
}, Closed]],

Cell[TextData[{
 "\tWe now generalize Theorem 6.10 to give an integral representation for the \
",
 Cell[BoxData[
  SuperscriptBox["n", "th"]]],
 " derivative, ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["f", 
    RowBox[{"(", "n", ")"}]], 
   RowBox[{"(", "z", ")"}]}]]],
 ". We use ",
 StyleBox[ButtonBox["Leibniz's",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Leibniz.\
html"], None}],
  FontVariations->{"Underline"->True}],
 " ",
 StyleBox[ButtonBox["rule",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/LeibnizIntegralRule.html"], None}],
  FontVariations->{"Underline"->True}],
 " in the proof and note that this method of proof is a mnemonic device for \
remembering Theorem 6.12."
}], "Text"],

Cell[TextData[{
 StyleBox["Theorem 6.12 (Cauchy's Integral Formulae for Derivatives).",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Let ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", "z", ")"}]}]]],
 " be analytic in the simply connected domain ",
 StyleBox["D",
  FontFamily->"Courier New"],
 ", and let ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " be a simple closed positively oriented contour that lies in ",
 StyleBox["D",
  FontFamily->"Courier New"],
 ".  If ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " is a point that lies interior to ",
 StyleBox["C",
  FontFamily->"Courier New"],
 ", then for any integer ",
 Cell[BoxData[
  RowBox[{"n", "\[GreaterEqual]", "0"}]]],
 ", we have",
 StyleBox["\n\n\t\t\t",
  FontColor->RGBColor[1, 0, 1]],
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["f", 
     RowBox[{"(", "n", ")"}]], 
    RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
   RowBox[{
    FractionBox[
     RowBox[{"n", "!"}], 
     RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]"}]], 
    RowBox[{
     SubscriptBox["\[Integral]", "C"], 
     RowBox[{
      FractionBox[
       RowBox[{"f", 
        RowBox[{"(", "\[Zeta]", ")"}]}], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"\[Zeta]", "-", "z"}], ")"}], 
        RowBox[{"n", "+", "1"}]]], 
      RowBox[{"\[DifferentialD]", "\[Zeta]"}]}]}]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 6.12 is in the book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 6.24.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Let  ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 "  denote a fixed complex value.  Show that, if ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " is a simple closed positively oriented contour such that  ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 "  lies interior to ",
 StyleBox["C",
  FontFamily->"Courier New"],
 ", then  \n\n   \t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["\[Integral]", "C"], 
    RowBox[{
     FractionBox["1", 
      RowBox[{"z", " ", "-", " ", 
       SubscriptBox["z", "0"]}]], 
     RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "=", "  ", 
   RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]"}]}]]],
 ",   and\n",
 StyleBox["(6-50)",
  FontColor->RGBColor[0, 0, 1]],
 "\n   \t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["\[Integral]", "C"], 
    RowBox[{
     FractionBox["1", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", " ", "-", " ", 
         SubscriptBox["z", "0"]}], ")"}], 
       RowBox[{"n", "+", "1"}]]], 
     RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "=", "  ", "0"}]]],
 ",   for any integer  ",
 Cell[BoxData[
  RowBox[{"n", "\[GreaterEqual]", "1"}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "\t\t\t",
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .75 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.25 0 0.25 [
[1.025 0 0 -6.28125 ]
[1.025 0 10 6.28125 ]
[0 .775 -5 0 ]
[0 .775 5 12.5625 ]
[ 0 0 0 0 ]
[ 1 .75 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
0 .75 L
s
gsave
0 .775 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .75 L
0 .75 L
closepath
clip
newpath
gsave
.5 .4 -69.4063 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
70.188 14.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
75.813 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 1 r
.5 Mabswid
newpath
.5 .41667 .25 0 365.73 arc
s
1 0 0 r
.03 w
.5 .41667 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{233.313, 175},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\
eJztmdtS01AUhkOLivGGS71wpqMzDtZqURRPyEGwlKMVLMhRIqLtOKhT8bl8
Dmd8AmG85yli1267oPFfoZusjnFsZrqz+Ne3/50mOzR7Zc7bK+3senvlbS81
WfE+l8rbX1K5T5WqlOxyHOew+vmWcij2q2G9OXR836ekvPtJuwTRTrKm1De3
9te+2SWN1EhfqEVm952EngBEH/cYFEj9OGFM1Ge/k+qkOqloqXVqXRK+ylCR
2nMkuBx9lPFFaulm9i9SREn/g4wXGLrMHcsyPs/QFY7ey/gsQ9c42pHxaYbS
fFhvZDzPeJajLRnPMTTA0aaMTzB0n7M+Z9fkjuMAfwC0VdlijMce4igEHwXu
w0BbtrMYAdqSbDHMhzrOUQj+BLhPAO2lbDEE8BzQFmWLxwDPA21BtngE8Gmg
vZAtHgJ8FmgFO4s5oD2XLdAknbezQLdKQbSFFoPiqYtksSCeH2hxT5yJ6Cq1
bFEE2oxscRfgS9EtlsUZ2y6LAYCvAG2qrRZ3AL4a3WINaHnZ4jbA1/9Fi36A
9wPuBuAm7WyzAY62THTbPmrPEJVozwDXTdvdxAmj3QTdc3ajpQGnMFQW4JkW
hmrmTj1UGp9DdCeextlcfnQ3WJptxcLCA9ozO4tb1CaoZIHOiqWZmWrdZIYm
rKWZmUxnyQxl/6aZ6tdUvQDxmJb/qwWaDa9jYbEJNMsfNwWLDaDF/rlH4RlQ
wSIej9TI4hXQ2ru8UFgnKazWFNaMCitXhfWzwipeoZagUNFQqKsoVHcUakwK
lS6FehuqKaJqZ4jFCMDHgFaULUYBjmxDao9oxKNK64rc8SnoiGZIiIVCefio
ND3I0YaMBwrf8CdYLrDjh1MntNQ+xVCGo5BC/gxDfRy9lXHzT8Ac1VXG38m4
ublpledf4qgk42bm0WrT72V8V8bNle4loSJDMXnf1EnZpVp4X9+8O9+Yj86v
muAC84MTxw32ou3g2Ah/FkPq2Z7GnRF8k9/CF3K6fgP245Ms\
\>"],
  ImageRangeCache->{{{0, 232.313}, {174, 0}} -> {0, 0, 0, 0}}],
 "   "
}], "Text"],

Cell[TextData[{
 "Solution.  We let ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", "1"}]]],
 ".  Then ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["f", 
     RowBox[{"(", "n", ")"}]], 
    RowBox[{"(", "z", ")"}]}], "=", "0"}]]],
 " for ",
 Cell[BoxData[
  RowBox[{"n", "\[GreaterEqual]", "1"}]]],
 ".  Theorem 6.10 implies that the value of the first integral in Equations \
",
 StyleBox["(6-50)",
  FontColor->RGBColor[0, 0, 1]],
 " is\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["\[Integral]", "C"], 
    RowBox[{
     FractionBox["1", 
      RowBox[{"z", " ", "-", " ", 
       SubscriptBox["z", "0"]}]], 
     RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", "f", 
     RowBox[{"(", 
      SubscriptBox["z", "0"], ")"}]}], "  ", "=", "  ", 
    RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]"}]}]}]]],
 ",  \n\nand Theorem 6.12 further implies that  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["\[Integral]", "C"], 
    RowBox[{
     FractionBox["1", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", " ", "-", " ", 
         SubscriptBox["z", "0"]}], ")"}], 
       RowBox[{"n", "+", "1"}]]], 
     RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]"}], 
      RowBox[{"n", "!"}]], 
     SuperscriptBox["f", 
      RowBox[{"(", "n", ")"}]], 
     RowBox[{"(", 
      SubscriptBox["z", "0"], ")"}]}], "  ", "=", "  ", "0"}]}]]],
 ".  \n\nThis result is the same as that proven earlier in Corollary 6.1.  \
Obviously, though, the technique of using Theorems 6.10 and 6.12 is easier."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 6.24 (a).",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 StyleBox["(a)",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "   Show that ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["\[Integral]", "C"], 
    RowBox[{
     FractionBox["1", 
      RowBox[{"z", " ", "-", " ", 
       SubscriptBox["z", "0"]}]], 
     RowBox[{"\[DifferentialD]", "z"}]}]}], "=", 
   RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]"}]}]]],
 ".  Use the Cauchy Integral Formula in the form ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["\[Integral]", "C"], 
    RowBox[{
     FractionBox[
      RowBox[{"f", 
       RowBox[{"(", "z", ")"}]}], 
      RowBox[{"z", " ", "-", " ", 
       SubscriptBox["z", "0"]}]], 
     RowBox[{"\[DifferentialD]", "z"}]}]}], "=", 
   RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", "f", 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}]}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", 
     RowBox[{"z", ",", "w"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", "f", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", "1"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"z0", "=", 
     SubscriptBox["z", "0"]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"w", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox["1", 
      RowBox[{"z", "-", "z0"}]]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[\!\(\*SubscriptBox[\(z\), \(0\)]\)] = \>\"", ",", 
      RowBox[{"f", "[", "z0", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Use Cauchy's Integral Formula\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(\[Integral]\), \(C\)]\)\!\(\*FractionBox[\(f \
\((z)\)\), \(z - \*SubscriptBox[\(z\), \(0\)]\)]\)\[DifferentialD]z = 2\[Pi]\
\[ImaginaryI] f(\!\(\*SubscriptBox[\(z\), \(0\)]\)) = \
2\[Pi]\[ImaginaryI](\>\"", ",", 
      RowBox[{"f", "[", "z0", "]"}], ",", "\"\<)\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(\[Integral]\), \(C\)]\)\!\(\*FractionBox[\(f \
\((z)\)\), \(z - \*SubscriptBox[\(z\), \(0\)]\)]\)\[DifferentialD]z = \>\"", 
      ",", 
      RowBox[{"2", " ", "\[Pi]", " ", "\[ImaginaryI]", " ", 
       RowBox[{"f", "[", "z0", "]"}]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39930892375*^9}],

Cell["Thus, we have found the value of the contour integral.", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"dot", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
        RowBox[{"Point", "[", 
         RowBox[{"{", 
          RowBox[{"2", ",", 
           FractionBox["5", "3"]}], "}"}], "]"}]}], "}"}], "]"}]}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"center", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"StyleForm", "[", 
          RowBox[{
           RowBox[{
           "TraditionalForm", "[", 
            "\"\<\!\(\*SubscriptBox[\(z\), \(0\)]\)\>\"", "]"}], ",", 
           RowBox[{"FontSize", "\[Rule]", "12"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"2", ",", "1.6"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "1"}], "}"}]}], "]"}], "}"}], "]"}]}], ";"}], " ",
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"contour", " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", 
        RowBox[{"Circle", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"2", ",", 
            FractionBox["5", "3"]}], "}"}], ",", "1"}], "]"}]}], "}"}], 
      "]"}]}], ";"}], " ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{"center", ",", "contour", ",", "dot", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "4"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "3"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", "None"}], ",", "\[IndentingNewLine]", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["3", "4"]}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Print", "[", 
    RowBox[{
    "\"\<\!\(\*UnderscriptBox[\(\[ContourIntegral]\), \(C\)]\) \>\"", ",", 
     RowBox[{"w", "[", "z", "]"}], ",", "\"\< \[DifferentialD]z = \>\"", ",", 
     
     RowBox[{"2", " ", "\[Pi]", " ", "\[ImaginaryI]", " ", 
      RowBox[{"f", "[", "z0", "]"}]}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<For illustration,\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<a contour could be the unit circle C: |z - \
\!\(\*SubscriptBox[\(z\), \(0\)]\)| = r,\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<with positive orientation.\>\"", "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39930892809375*^9, 3.399308929984375*^9}, {
  3.399883543078125*^9, 3.399883543265625*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 6.24 (b).",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 StyleBox["(b)",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "   Show that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["\[Integral]", "C"], 
    RowBox[{
     FractionBox["1", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", " ", "-", " ", 
         SubscriptBox["z", "0"]}], ")"}], "m"]], 
     RowBox[{"\[DifferentialD]", "z"}]}]}], "=", "0"}]]],
 ",  when  ",
 Cell[BoxData[
  RowBox[{"m", "\[NotEqual]", "1"}]]],
 "  is an integer. \n",
 StyleBox["Remark.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  If  m  is an integer and  m < 0,  then  m = -n,  where  n  is a positive \
integer and the integrand is  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"z", "-", 
      SubscriptBox["z", "0"]}], ")"}], "n"]}]]],
 "\n which is a polynomial of degree n.  Hence in this case, f(z) would be \
analytic and the Cauchy-Goursat theorem implies that the value of the \
integral is zero.\n \n Now we consider the case when m is a positive integer \
and  m > 1.\n Use the Cauchy's Integral Formulae for Derivatives in the form  \
",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["\[Integral]", "C"], 
    RowBox[{
     FractionBox[
      RowBox[{"f", 
       RowBox[{"(", "z", ")"}]}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "-", 
         SubscriptBox["z", "0"]}], ")"}], 
       RowBox[{"n", "+", "1"}]]], 
     RowBox[{"\[DifferentialD]", "z"}]}]}], "=", 
   RowBox[{
    FractionBox[
     RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]"}], 
     RowBox[{"n", "!"}]], 
    SuperscriptBox["f", 
     RowBox[{"(", "n", ")"}]], 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}]}]]],
 "\n \n",
 StyleBox[" For illustration.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]],
 "  We use m = 5,  and  f(z) = 1.  Then  m = 5 = n + 1 implies that  n = 4."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", 
     RowBox[{"z", ",", "w"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "z0"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", "1"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"n", " ", "=", " ", "4"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"z0", "=", 
     SubscriptBox["z", "0"]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"w", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox["1", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "-", "z0"}], ")"}], 
       RowBox[{"n", "+", "1"}]]]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"fn", "[", "z_", "]"}], "=", 
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{"f", "[", "z", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"z", ",", "n"}], "}"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<n = \>\"", ",", "n"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SuperscriptBox[\(f\), \((n)\)]\)[z] = \>\"", ",", 
      RowBox[{"fn", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  \!\(\*SubscriptBox[\(z\), \(0\)]\) = \>\"", ",", "z0"}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SuperscriptBox[\(f\), \((n)\)]\)[\>\"", ",", "z0", ",", 
      "\"\<] = \>\"", ",", 
      RowBox[{"fn", "[", "z0", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<Use Cauchy's Integral Formulae for Derivatives\>\"", 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(\[Integral]\), \(C\)]\)\!\(\*FractionBox[\(f \
\((z)\)\), SuperscriptBox[\((z - \*SubscriptBox[\(z\), \(0\)])\), \(n + 1\)]]\
\)\[DifferentialD]z = \!\(\*FractionBox[\(2  \[Pi]\\\ \[ImaginaryI]\), \
\(n!\)]\) \!\(\*SuperscriptBox[\(f\), \((n)\)]\)[\>\"", ",", "z0", ",", 
      "\"\<] = \!\(\*FractionBox[\(2  \[Pi]\\\ \[ImaginaryI]\), \
\(n!\)]\)(\>\"", ",", 
      RowBox[{"fn", "[", "z0", "]"}], ",", "\"\<)\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(\[Integral]\), \(C\)]\)\!\(\*FractionBox[\(f \
\((z)\)\), SuperscriptBox[\((z - \*SubscriptBox[\(z\), \(0\)])\), \(n + 1\)]]\
\)\[DifferentialD]z = \>\"", ",", 
      RowBox[{"2", " ", "\[Pi]", " ", "\[ImaginaryI]", " ", 
       RowBox[{"fn", "[", "z0", "]"}]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399308952328125*^9}],

Cell["Thus, we have found the value of the contour integral.", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"dot", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
        RowBox[{"Point", "[", 
         RowBox[{"{", 
          RowBox[{"2", ",", 
           FractionBox["5", "3"]}], "}"}], "]"}]}], "}"}], "]"}]}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"center", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"StyleForm", "[", 
          RowBox[{
           RowBox[{
           "TraditionalForm", "[", 
            "\"\<\!\(\*SubscriptBox[\(z\), \(0\)]\)\>\"", "]"}], ",", 
           RowBox[{"FontSize", "\[Rule]", "12"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"2", ",", "1.6"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "1"}], "}"}]}], "]"}], "}"}], "]"}]}], ";"}], " ",
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"contour", " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", 
        RowBox[{"Circle", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"2", ",", 
            FractionBox["5", "3"]}], "}"}], ",", "1"}], "]"}]}], "}"}], 
      "]"}]}], ";"}], " ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{"center", ",", "contour", ",", "dot", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "4"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "3"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", "None"}], ",", "\[IndentingNewLine]", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["3", "4"]}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Print", "[", 
    RowBox[{
    "\"\<\!\(\*UnderscriptBox[\(\[ContourIntegral]\), \(C\)]\) \>\"", ",", 
     RowBox[{"w", "[", "z", "]"}], ",", "\"\< \[DifferentialD]z = \>\"", ",", 
     
     RowBox[{"2", " ", "\[Pi]", " ", "\[ImaginaryI]", " ", 
      RowBox[{"f", "[", "z0", "]"}]}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<For illustration,\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<a contour could be the unit circle C :|z - \
\!\(\*SubscriptBox[\(z\), \(0\)]\)| = r,\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<with positive orientation.\>\"", "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399308958484375*^9, 3.399308961234375*^9}, {
  3.399883549171875*^9, 3.39988354934375*^9}}]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 6.25.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Show that",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["\[Integral]", "C"], 
    RowBox[{
     FractionBox[
      SuperscriptBox["\[ExponentialE]", 
       SuperscriptBox["z", "2"]], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", " ", "-", " ", "\[ImaginaryI]"}], ")"}], "4"]], 
     RowBox[{"\[DifferentialD]", "z"}]}]}], "=", 
   FractionBox[
    RowBox[{
     RowBox[{"-", " ", "4"}], " ", "\[Pi]"}], 
    RowBox[{"3", " ", "\[ExponentialE]"}]]}]]],
 ",  where",
 " ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " is the circle  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"C", ":", 
    RowBox[{"|", "z", "|"}]}], "=", "2"}]]],
 "  with positive orientation."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "\t\t\t",
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.5 0.238095 [
[.02381 .4875 -6 -9 ]
[.02381 .4875 6 0 ]
[.2619 .4875 -6 -9 ]
[.2619 .4875 6 0 ]
[.7381 .4875 -3 -9 ]
[.7381 .4875 3 0 ]
[.97619 .4875 -3 -9 ]
[.97619 .4875 3 0 ]
[1.025 .5 0 -6.28125 ]
[1.025 .5 10 6.28125 ]
[.4875 .02381 -12 -4.5 ]
[.4875 .02381 0 4.5 ]
[.4875 .2619 -12 -4.5 ]
[.4875 .2619 0 4.5 ]
[.4875 .7381 -6 -4.5 ]
[.4875 .7381 0 4.5 ]
[.4875 .97619 -6 -4.5 ]
[.4875 .97619 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .5 m
.02381 .50625 L
s
[(-2)] .02381 .4875 0 1 Mshowa
.2619 .5 m
.2619 .50625 L
s
[(-1)] .2619 .4875 0 1 Mshowa
.7381 .5 m
.7381 .50625 L
s
[(1)] .7381 .4875 0 1 Mshowa
.97619 .5 m
.97619 .50625 L
s
[(2)] .97619 .4875 0 1 Mshowa
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .02381 m
.50625 .02381 L
s
[(-2)] .4875 .02381 1 0 Mshowa
.5 .2619 m
.50625 .2619 L
s
[(-1)] .4875 .2619 1 0 Mshowa
.5 .7381 m
.50625 .7381 L
s
[(1)] .4875 .7381 1 0 Mshowa
.5 .97619 m
.50625 .97619 L
s
[(2)] .4875 .97619 1 0 Mshowa
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.03 w
.5 .7381 Mdot
0 g
gsave
.5 .7619 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
70.188 14.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
75.813 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 1 r
.5 Mabswid
newpath
.5 .5 .47619 0 365.73 arc
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{175, 175},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\
eJztmttOFEEQhlt2V0BFAQHxgCxyEAQElZMiiojgGY2JNxoTQkz0wmjUJ/FF
eMRxu6und2b4epiR2RWim8BMqv76q6eP1dX9Yvvnp49ftn9+3tmubn7f/vbp
886P6sbX7zVR6ZhSalf/VZV+D2qv9t+uCoLa22vzKCkjq73pv3f7qp7qR1kr
SvuAEqqyH/5EPzq1/K0I1vSjVQvISQvIKs5iSyjuheUM2qz7KNxT/FPO6JnA
lvVDY4IO/daiwfQhnc5wUwwXnaAP4D1OFjjZuhjOh36CC2DY62jXBD4HTGR4
3tGuiuGsYxoA+EX33SsCnwE/g2B42flZFsNpJ7gC8CrQLonhpDMcAcMhp7Xw
a8BEhsPOcEEMx53gKsBHgfaWGF4FFVGMOQfWcNQJrgF8HGhnxbBe9ikwnHBa
C78CTGQ4CbhpoRjyquIUU15X2MTXgWIacFKySEerq2aA4jrgpIqlX2Ktxilm
Em2jBsDwBhjeAJz0BnUJVDeB4ibgxoTiorcbZqa4AKo5oLgFOBkFMokkVPNA
QZPSSD6KecANC0U/qBaAYgFwMiTUOVAtAsUi4GRIqD5QLeWj6AXVbaBYApyM
KlxI7gDFbcDJqFJnQbXcGIo7gJOBqbpBdRcolgEnQ1R1+fpFRRNQ0JCTjJqX
aO+CrcwBEidkaHJDa6KNe2Ahs4E6AyozAZhYh8IUKu1KPgfUu4iWyi1TkDrt
o/WGVznJVoHiPuBkMlIdoHoAFKuA6286xQPAyXwm4WtCtdZ0ipOgeggUa4Dr
azrFQ8DJxKxOgGq96RTtoHrUGIp1wPXko3gEOFkeVBuoNv5TNJpiA3Cy2qpW
UG3+0xRmQ6wiPxOqmQCiCnzVuNasX5Y+hEkgoY5HPIeqUR9jQpa+cRaZ5j27
15Wo1IFcDUVkIaetNFVyHvRPvr/iChQy6J8JgLyBSday0JY2VsOVWA2HzocP
XNP19JHl7456LccqW0V26v4abUkWLFG3yWbUf4+BbBNw0On+AkVrdExE+0nl
4NxtCZz+CZ9Eo2XrNjqcf4HMFK8VnKaUkZqUeljWDtzIejocPeE/xR6KrEtW
ARRHZO09EEUB0dDRCusOPUUBO4Ym7ltSKA7HNrCA/ezR2pg3NklRQLblaKWN
7gPO5r8KSKFRptCkS72515SUnj/tGD/EDXTUVMNTuWwGM2u+tazCZcgUmI5R
/oSxHRR0UGSzw/6kM394iyswHWanOKJs+4LQqnCDVkm6VPWmZB3V2oDfIaX3
qafQt9FxtD1JyHoYUfJVbO1HVWfp/ScuaRUWd00VNbgf/Z6SGn90WmepCjhe
KuCQqwCKrKd1KQd+/WHTBmQ457T2oLOAs9ICTmwLODcu4PQ668n5LODG81HQ
qJ4QikFQ5bwCUHWtTIZTTmuvPhRweyLnfQ26azIBhik3ROp3TciQbqxIyyPn
GFDU767IeIh8BcFHgNYaUr15syiRoRtpKW9az2hlrpMeYQRDAKd+ZQ2pQ18G
igHnQFY0qVKTErwEcDO3GFYJgfCqw3kwrM9hEt/JfGf8nAN4j9NKdC3LiHHT
A/Aup7U32FacfXv4hktxh8PJrT+JPo9rAcEp+2t2myZz+1IoTBF6teCNCJ6D
Fa2ssfuHma78WYtnYeWm3VNMuRa5m/mx5Tx9EMErYH2/r8Oklf69j3jY+/VW
+zJs6GS2McOXqGO/AcasvTI=\
\>"],
  ImageRangeCache->{{{0, 174}, {174, 0}} -> {-2, -2, 0, 0}}],
 "   "
}], "Text"],

Cell[TextData[{
 "Solution.  If we set  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   SuperscriptBox["\[ExponentialE]", 
    SuperscriptBox["z", "2"]]}]]],
 ",  then a straightforward calculation shows that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["f", 
     RowBox[{"(", "3", ")"}]], 
    RowBox[{"(", "z", ")"}]}], " ", "=", "  ", 
   RowBox[{
    RowBox[{"(", " ", 
     RowBox[{
      RowBox[{"12", " ", "z"}], "+", 
      RowBox[{"8", " ", 
       SuperscriptBox["z", "3"]}]}], ")"}], 
    SuperscriptBox["\[ExponentialE]", 
     SuperscriptBox["z", "2"]]}]}]]],
 ".   Using Cauchy's integral formulas with ",
 Cell[BoxData[
  RowBox[{"n", "=", "3"}]]],
 ", we conclude that  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["\[Integral]", "C"], 
     RowBox[{
      FractionBox[
       SuperscriptBox["\[ExponentialE]", 
        SuperscriptBox["z", "2"]], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"z", " ", "-", " ", "\[ImaginaryI]"}], ")"}], "4"]], 
      RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]"}], 
       RowBox[{"3", "!"}]], 
      SuperscriptBox["f", 
       RowBox[{"(", "3", ")"}]], 
      RowBox[{"(", "\[ImaginaryI]", ")"}]}], "  ", "=", "  ", 
     RowBox[{
      FractionBox[
       RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]"}], 
       RowBox[{"3", "!"}]], 
      RowBox[{"(", " ", 
       RowBox[{
        RowBox[{"12", " ", "\[ImaginaryI]"}], "+", 
        RowBox[{"8", " ", 
         SuperscriptBox["\[ImaginaryI]", "3"]}]}], ")"}], 
      SuperscriptBox["\[ExponentialE]", 
       SuperscriptBox["\[ImaginaryI]", "2"]]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                           ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      RowBox[{
       FractionBox[
        RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]"}], 
        RowBox[{"3", "!"}]], 
       RowBox[{"(", " ", 
        RowBox[{
         RowBox[{"12", " ", "\[ImaginaryI]"}], "-", 
         RowBox[{"8", " ", "\[ImaginaryI]"}]}], ")"}], 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", "1"}]]}], "   ", "=", "   ", 
      RowBox[{
       FractionBox[
        RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]"}], 
        RowBox[{"3", "!"}]], 
       FractionBox[
        RowBox[{"4", " ", "\[ImaginaryI]"}], "\[ExponentialE]"]}]}]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                           ", 
   RowBox[{"=", "  ", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"4", " ", "\[Pi]"}], 
      RowBox[{"3", " ", "\[ExponentialE]"}]]}]}]}]}]],
 "  \n"
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 6.25.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 "Enter the integrand  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"w", "[", "z", "]"}], "=", 
   FractionBox[
    SuperscriptBox["\[ExponentialE]", 
     SuperscriptBox["z", "2"]], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"z", " ", "-", " ", "\[ImaginaryI]"}], ")"}], "4"]]}]],
  AspectRatioFixed->True],
 "  and locate the singularities."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", 
     RowBox[{"w", ",", "z", ",", "Z"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "i", ",", "solset", ",", "val"}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"w", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox[
      SuperscriptBox["\[ExponentialE]", 
       SuperscriptBox["z", "2"]], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", " ", "-", " ", "\[ImaginaryI]"}], ")"}], "4"]]}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"solset", " ", "=", " ", 
     RowBox[{"Sort", "[", 
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Denominator", "[", 
          RowBox[{"w", "[", "z", "]"}], "]"}], "\[Equal]", "0"}], ",", "z"}], 
       "]"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Z", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"Length", "[", "solset", "]"}], "}"}]}], "]"}]}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"i", "=", "1"}], ",", 
      RowBox[{"i", "\[LessEqual]", 
       RowBox[{"Length", "[", "solset", "]"}]}], ",", 
      RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        SubscriptBox["Z", 
         RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], " ",
         "=", " ", 
        RowBox[{"ReplaceAll", "[", 
         RowBox[{"z", ",", 
          SubscriptBox["solset", 
           RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]]}], 
         "]"}]}], ";"}]}], " ", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w[z] = \>\"", ",", 
      RowBox[{"w", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<The set of singularities is \>\"", ",", "Z"}], "]"}], ";"}],
    " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39930896884375*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "Find the singularity that lie inside  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"C", ":", 
    RowBox[{"|", "z", "|"}]}], "=", "2"}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["Z", 
       RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], ",", 
      "\"\<,    Is |\>\"", ",", 
      SubscriptBox["Z", 
       RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], ",", 
      "\"\<| < 2 ?    \>\"", ",", 
      RowBox[{
       RowBox[{"N", "[", 
        RowBox[{"Abs", "[", 
         SubscriptBox["Z", 
          RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], 
         "]"}], "]"}], "<", "2"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.3993089736875*^9}],

Cell[TextData[{
 "Since  z = i  is a singularity of order  n = 4 , multiply the integrand by \
",
 Cell[BoxData[
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{"z", "-", "\[ImaginaryI]"}], ")"}], "4"]]],
 " to obtain the function f(z)."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{
      RowBox[{"w", "[", "z", "]"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", " ", "-", " ", 
         SubscriptBox["Z", 
          RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]]}], 
        ")"}], "4"]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w[z] = \>\"", ",", 
      RowBox[{"w", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w[z] = (\>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\<)/(\>\"", ",", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", " ", "-", " ", 
         SubscriptBox["Z", 
          RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]]}], 
        ")"}], "4"], ",", "\"\<)\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399308977578125*^9, 3.3993089800625*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "Use Cauchy's Integral Formula for Derivatives to evaluate the integral of  \
",
 Cell[BoxData[
  RowBox[{
   RowBox[{"w", "[", "z", "]"}], "=", 
   FractionBox[
    SuperscriptBox["\[ExponentialE]", 
     SuperscriptBox["z", "2"]], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"z", " ", "-", " ", "\[ImaginaryI]"}], ")"}], "4"]]}]],
  AspectRatioFixed->True],
 " taken over ",
 StyleBox["C",
  FontFamily->"Courier New"],
 "."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"f3", " ", "=", " ", 
     RowBox[{"Simplify", "[", 
      RowBox[{"Expand", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"f", "'"}], "'"}], "'"}], "[", "z", "]"}], "]"}], "]"}]}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"val", " ", "=", " ", 
     RowBox[{
      FractionBox[
       RowBox[{"2", " ", "\[Pi]", " ", "\[ImaginaryI]"}], 
       RowBox[{"3", "!"}]], " ", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"f", "'"}], "'"}], "'"}], "[", 
       SubscriptBox["Z", 
        RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], 
       "]"}]}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = \>\"", ",", 
      FractionBox["\"\<f[z]\>\"", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"z", " ", "-", " ", 
          SubscriptBox["Z", 
           RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]]}], 
         ")"}], "4"]]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f'''[z] = \>\"", ",", "f3"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<      \!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["Z", 
       RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]]}], 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<f'''[\!\(\*SubscriptBox[\(z\), \(1\)]\)] = \>\"", ",", " ", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"f", "'"}], "'"}], "'"}], "[", 
       SubscriptBox["Z", 
        RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], 
       "]"}]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<       n = 3\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<Use Cauchy's Integral Formulae for Derivatives\>\"", 
     "]"}], ";", " ", 
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(\[Integral]\), \(C\)]\) \>\"", ",", 
      RowBox[{"w", "[", "z", "]"}], ",", 
      "\"\< \[DifferentialD]z = \!\(\*SubscriptBox[\(\[Integral]\), \
\(C\)]\)\!\(\*FractionBox[\(f \((z)\)\), SuperscriptBox[\((z - \
\*SubscriptBox[\(z\), \(1\)])\), \(n + 1\)]]\)\[DifferentialD]z = \
\!\(\*FractionBox[\(2  \[Pi]\\\ \[ImaginaryI]\), \(n!\)]\) \
\!\(\*SuperscriptBox[\(f\), \((n)\)]\)[\!\(\*SubscriptBox[\(z\), \
\(1\)]\)]\>\""}], "]"}]}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(\[Integral]\), \(C\)]\) \>\"", ",", 
      RowBox[{"w", "[", "z", "]"}], ",", 
      "\"\< \[DifferentialD]z = \!\(\*FractionBox[\(2  \[Pi]\\\ \[ImaginaryI]\
\), \(3!\)]\) f'''[\>\"", ",", 
      SubscriptBox["Z", 
       RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], ",", 
      "\"\<] = \!\(\*FractionBox[\(2  \[Pi]\\\ \[ImaginaryI]\), \
\(3!\)]\)(\>\"", ",", 
      RowBox[{
       RowBox[{"f", "'''"}], "[", 
       SubscriptBox["Z", 
        RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], 
       "]"}], ",", "\"\<) = \>\"", ",", "val"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.3993089831875*^9},
 AspectRatioFixed->True],

Cell["Thus, we have found the value of the contour integral.", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"dots", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
        RowBox[{"Point", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Re", "[", 
            SubscriptBox["Z", 
             RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], 
            "]"}], ",", 
           RowBox[{"Im", "[", 
            SubscriptBox["Z", 
             RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], 
            "]"}]}], "}"}], "]"}]}], "}"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"centers", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"StyleForm", "[", 
          RowBox[{
           RowBox[{
           "TraditionalForm", "[", 
            "\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\)\>\"", "]"}], ",", 
           RowBox[{"FontSize", "\[Rule]", "12"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Re", "[", 
            SubscriptBox["Z", 
             RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], 
            "]"}], ",", 
           RowBox[{
            RowBox[{"Im", "[", 
             SubscriptBox["Z", 
              RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]],
              "]"}], "+", "0.1"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}], "}"}], "]"}]}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"contour", " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", 
        RowBox[{"Circle", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}], ",", "2"}], "]"}]}], "}"}], 
      "]"}]}], ";"}], " ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{"dots", ",", "centers", ",", "contour", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.1"}], ",", "2.1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.1"}], ",", "2.1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], "\n", 
   RowBox[{"Print", "[", 
    RowBox[{
    "\"\<\!\(\*UnderscriptBox[\(\[ContourIntegral]\), \(C\)]\) (\>\"", ",", 
     RowBox[{"w", "[", "z", "]"}], ",", "\"\<) \[DifferentialD]z = \>\"", ",",
      "val"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The contour is the circle  C: |z| = 2,\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<with positive orientation.\>\"", "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399308990421875*^9, 3.399308992359375*^9}, {
  3.399883554*^9, 3.399883554234375*^9}}]
}, Closed]],

Cell["\tWe now state two important corollaries of Theorem 6.12. ", "Text"],

Cell[TextData[{
 StyleBox["Corollary 6.2.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  If ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", "z", ")"}]}]]],
 " is analytic in the domain ",
 StyleBox["D",
  FontFamily->"Courier New"],
 ", then all derivatives  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"f", "'"}], 
    RowBox[{"(", "z", ")"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    RowBox[{"f", "''"}], 
    RowBox[{"(", "z", ")"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "...", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]]}]]],
 " ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["f", 
     RowBox[{"(", "n", ")"}]], 
    RowBox[{"(", "z", ")"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "..."}]]],
 "  exists for  ",
 Cell[BoxData[
  RowBox[{"z", "\[Element]", "D"}]]],
 "  (and therefore are analytic in ",
 StyleBox["D",
  FontFamily->"Courier New"],
 ")."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Corollary 6.2 is in the book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
 StyleBox["Remark 6.3.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  This result is interesting, as it illustrates a big difference between \
real and complex functions.  A real function ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", "z", ")"}]}]]],
 " can have the property that ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "'"}], 
   RowBox[{"(", "z", ")"}]}]]],
 " exists everywhere in a domain ",
 StyleBox["D",
  FontFamily->"Courier New"],
 ", but ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "''"}], 
   RowBox[{"(", "z", ")"}]}]]],
 " exists nowhere.  Corollary 6.2 states that if a complex function ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", "z", ")"}]}]]],
 " has the property that ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "'"}], 
   RowBox[{"(", "z", ")"}]}]]],
 "exists everywhere in a domain ",
 StyleBox["D",
  FontFamily->"Courier New"],
 ", then, remarkably, all derivatives of ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", "z", ")"}]}]]],
 " exist in ",
 StyleBox["D",
  FontFamily->"Courier New"],
 ".  "
}], "Text"],

Cell[TextData[{
 StyleBox["Corollary 6.3.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  If ",
 Cell[BoxData[
  RowBox[{"u", 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 " is a harmonic function at each point ",
 Cell[BoxData[
  RowBox[{"(", 
   RowBox[{"x", 
    StyleBox[",",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], "y"}], ")"}]]],
 " in the domain ",
 StyleBox["D",
  FontFamily->"Courier New"],
 ", then all partial derivatives  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["u", "x"], 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 ", ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["u", "y"], 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 ", ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["u", "xx"], 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 ", ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["u", "xy"], 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 ", ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["u", "yy"], 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "..."}]]],
 "  exists and are harmonic functions.  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Corollary 6.3 is in the book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
 StyleBox["Extra Example 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Show that the partial derivatives of  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"u", 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], " ", "=", " ", 
   RowBox[{
    SuperscriptBox["x", "7"], "-", 
    RowBox[{"21", " ", 
     SuperscriptBox["x", "5"], " ", 
     SuperscriptBox["y", "2"]}], "+", 
    RowBox[{"35", " ", 
     SuperscriptBox["x", "3"], " ", 
     SuperscriptBox["y", "4"]}], "-", 
    RowBox[{"7", " ", "x", " ", 
     SuperscriptBox["y", "6"]}]}]}]]],
 " are harmonic functions.  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Extra Solution 1.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"x", ",", "y", ",", "u", ",", "z"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"TagSet", "[", 
     RowBox[{"x", ",", 
      RowBox[{"Im", "[", "x", "]"}], ",", "0"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"TagSet", "[", 
     RowBox[{"y", ",", 
      RowBox[{"Im", "[", "y", "]"}], ",", "0"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"TagSet", "[", 
     RowBox[{"x", ",", 
      RowBox[{"Re", "[", "x", "]"}], ",", "x"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"TagSet", "[", 
     RowBox[{"y", ",", 
      RowBox[{"Re", "[", "y", "]"}], ",", "y"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", 
     SuperscriptBox["z", "7"]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"u", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"Re", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", "+", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<    f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[x+\[ImaginaryI] y] = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"x", "+", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[x+\[ImaginaryI] y] = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", "+", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], " ", "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The real part is u[x,y]\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<u[x,y] = Re[f[z]]\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<u[x,y] = Re[\>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", "+", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], ",", 
      "\"\<]\>\""}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<u[x,y] = \>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<Therefore, u[x,y] is a harmonic function.\>\"", "]"}], 
    ";"}], "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399309005671875*^9, 3.399309008859375*^9}}],

Cell[TextData[{
 "According to Corollary 6.3, all of its partial derivatives  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["u", "x"], 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 ", ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["u", "y"], 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 ", ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["u", "xx"], 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 ", ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["u", "xy"], 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 ", ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["u", "yy"], 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "..."}]]],
 "  exists and are harmonic functions.  \n\nWe can use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to verify Laplace's equation for some of these functions. "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"laplace", "[", "u0_", "]"}], " ", ":=", " ", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", "\[Phi]", "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Apply", "[", 
         RowBox[{"Set", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"\[Phi]", "[", 
             RowBox[{"x_", ",", "y_"}], "]"}], ",", "u0"}], "}"}]}], "]"}], 
        ";", "\[IndentingNewLine]", 
        RowBox[{"Print", "[", 
         RowBox[{"\"\<   \[Phi][x,y] = \>\"", ",", 
          RowBox[{"\[Phi]", "[", 
           RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"Print", "[", 
         RowBox[{
         "\"\<\!\(\*SubscriptBox[\(\[PartialD]\), \(x, x\)]\)\[Phi][x,y] = \>\
\"", ",", 
          RowBox[{
           SubscriptBox["\[PartialD]", 
            RowBox[{"x", ",", "x"}]], 
           RowBox[{"\[Phi]", "[", 
            RowBox[{"x", ",", "y"}], "]"}]}]}], "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"Print", "[", 
         RowBox[{
         "\"\<\!\(\*SubscriptBox[\(\[PartialD]\), \(y, y\)]\)\[Phi][x,y] = \>\
\"", ",", 
          RowBox[{
           SubscriptBox["\[PartialD]", 
            RowBox[{"y", ",", "y"}]], 
           RowBox[{"\[Phi]", "[", 
            RowBox[{"x", ",", "y"}], "]"}]}]}], "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"lap", "=", 
         RowBox[{"FullSimplify", "[", 
          RowBox[{
           RowBox[{
            SubscriptBox["\[PartialD]", 
             RowBox[{"x", ",", "x"}]], 
            RowBox[{"\[Phi]", "[", 
             RowBox[{"x", ",", "y"}], "]"}]}], " ", "+", " ", 
           RowBox[{
            SubscriptBox["\[PartialD]", 
             RowBox[{"y", ",", "y"}]], 
            RowBox[{"\[Phi]", "[", 
             RowBox[{"x", ",", "y"}], "]"}]}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"Print", "[", 
         RowBox[{
         "\"\<\!\(\*SubscriptBox[\(\[PartialD]\), \(x, x\)]\)\[Phi][x,y] + \!\
\(\*SubscriptBox[\(\[PartialD]\), \(y, y\)]\)\[Phi][x,y] = \>\"", ",", 
          "lap"}], " ", "]"}], ";", "  ", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"lap", "\[Equal]", "0"}], ",", 
          RowBox[{
           RowBox[{"Print", "[", 
            RowBox[{"\"\<Therefore, \>\"", ",", 
             RowBox[{"\[Phi]", "[", 
              RowBox[{"x", ",", "y"}], "]"}], ",", "\"\< is harmonic.\>\""}], 
            " ", "]"}], ";"}]}], " ", "]"}], ";"}]}], "  ", "]"}]}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399309012875*^9, 3.399309015078125*^9}, {
  3.39930925115625*^9, 3.399309256109375*^9}},
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<   \[Phi][x,y] = u[x,y] = \>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"laplace", "[", " ", 
     RowBox[{"u", "[", 
      RowBox[{"x", ",", "y"}], "]"}], " ", "]"}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.3993090195625*^9, 3.39930905775*^9}, {3.399309362625*^9,
   3.39930937540625*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<              u[x,y] = \>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<   \[Phi][x,y] = \!\(\*SubscriptBox[\(\[PartialD]\), \(x\)]\)u[x,y] \
= \>\"", ",", 
      RowBox[{
       SubscriptBox["\[PartialD]", "x"], 
       RowBox[{"u", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"laplace", "[", " ", 
     RowBox[{
      SubscriptBox["\[PartialD]", "x"], " ", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], " ", "]"}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.399309022078125*^9, 3.399309060359375*^9}, {
  3.399309389625*^9, 3.399309424921875*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<              u[x,y] = \>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<   \[Phi][x,y] = \!\(\*SubscriptBox[\(\[PartialD]\), \(y\)]\)u[x,y] \
= \>\"", ",", 
      RowBox[{
       SubscriptBox["\[PartialD]", "y"], 
       RowBox[{"u", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"laplace", "[", " ", 
     RowBox[{
      SubscriptBox["\[PartialD]", "y"], " ", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], " ", "]"}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.3993090240625*^9, 3.399309062953125*^9}, {
  3.399309432609375*^9, 3.399309433484375*^9}, {3.39930950853125*^9, 
  3.399309569390625*^9}, {3.3993096205*^9, 3.39930962059375*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<               u[x,y] = \>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<   \[Phi][x,y] = \!\(\*SubscriptBox[\(\[PartialD]\), \(x, \
x\)]\)u[x,y] = \>\"", ",", 
      RowBox[{
       SubscriptBox["\[PartialD]", 
        RowBox[{"x", ",", "x"}]], 
       RowBox[{"u", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"laplace", "[", " ", 
     RowBox[{
      SubscriptBox["\[PartialD]", 
       RowBox[{"x", ",", "x"}]], 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], " ", "]"}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.399309025875*^9, 3.39930902678125*^9}, 
   3.399309066359375*^9, {3.399309533078125*^9, 3.399309596578125*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<               u[x,y] = \>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<   \[Phi][x,y] = \!\(\*SubscriptBox[\(\[PartialD]\), \(x, \
y\)]\)u[x,y] = \>\"", ",", 
      RowBox[{
       SubscriptBox["\[PartialD]", 
        RowBox[{"x", ",", "y"}]], 
       RowBox[{"u", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"laplace", "[", " ", 
     RowBox[{
      SubscriptBox["\[PartialD]", 
       RowBox[{"x", ",", "y"}]], 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39930902775*^9, 3.3993090288125*^9}, {3.39930943625*^9, 
  3.39930943690625*^9}, {3.39930960609375*^9, 3.399309613*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<               u[x,y] = \>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<   \[Phi][x,y] = \!\(\*SubscriptBox[\(\[PartialD]\), \(y, \
y\)]\)u[x,y] = \>\"", ",", 
      RowBox[{
       SubscriptBox["\[PartialD]", 
        RowBox[{"y", ",", "y"}]], 
       RowBox[{"u", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"laplace", "[", " ", 
     RowBox[{
      SubscriptBox["\[PartialD]", 
       RowBox[{"y", ",", "y"}]], 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], " ", "]"}], ";"}]}]}]], "Input",
 CellChangeTimes->{
  3.3993090703125*^9, {3.39930963421875*^9, 3.399309650984375*^9}, {
   3.39930977896875*^9, 3.3993097836875*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<                 u[x,y] = \>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<   \[Phi][x,y] = \!\(\*SubscriptBox[\(\[PartialD]\), \(x, x, \
x\)]\)u[x,y] = \>\"", ",", 
      RowBox[{
       SubscriptBox["\[PartialD]", 
        RowBox[{"x", ",", "x", ",", "x"}]], 
       RowBox[{"u", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"laplace", "[", " ", 
     RowBox[{
      SubscriptBox["\[PartialD]", 
       RowBox[{"x", ",", "x", ",", "x"}]], 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], " ", "]"}], ";"}]}]}]], "Input",
 CellChangeTimes->{
  3.39930907184375*^9, {3.399309439078125*^9, 3.39930943978125*^9}, {
   3.399309656609375*^9, 3.399309669828125*^9}, 3.39930977446875*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<                 u[x,y] = \>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<   \[Phi][x,y] = \!\(\*SubscriptBox[\(\[PartialD]\), \(x, x, \
y\)]\)u[x,y] = \>\"", ",", 
      RowBox[{
       SubscriptBox["\[PartialD]", 
        RowBox[{"x", ",", "x", ",", "y"}]], 
       RowBox[{"u", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"laplace", "[", " ", 
     RowBox[{
      SubscriptBox["\[PartialD]", 
       RowBox[{"x", ",", "x", ",", "y"}]], 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], " ", "]"}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.3993090303125*^9, 3.39930903171875*^9}, 
   3.399309074875*^9, {3.399309441953125*^9, 3.399309442609375*^9}, {
   3.39930967990625*^9, 3.39930968925*^9}, 3.39930976940625*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<                 u[x,y] = \>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<   \[Phi][x,y] = \!\(\*SubscriptBox[\(\[PartialD]\), \(x, y, \
y\)]\)u[x,y] = \>\"", ",", 
      RowBox[{
       SubscriptBox["\[PartialD]", 
        RowBox[{"x", ",", "y", ",", "y"}]], 
       RowBox[{"u", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"laplace", "[", " ", 
     RowBox[{
      SubscriptBox["\[PartialD]", 
       RowBox[{"x", ",", "y", ",", "y"}]], 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], " ", "]"}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.39930903275*^9, 3.399309033765625*^9}, {3.399309084*^9, 
   3.3993090893125*^9}, {3.399309698765625*^9, 3.399309716015625*^9}, 
   3.399309764703125*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<                 u[x,y] = \>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<   \[Phi][x,y] = \!\(\*SubscriptBox[\(\[PartialD]\), \(y, y, \
y\)]\)u[x,y] = \>\"", ",", 
      RowBox[{
       SubscriptBox["\[PartialD]", 
        RowBox[{"y", ",", "y", ",", "y"}]], 
       RowBox[{"u", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"laplace", "[", " ", 
     RowBox[{
      SubscriptBox["\[PartialD]", 
       RowBox[{"y", ",", "y", ",", "y"}]], 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], " ", "]"}], ";"}]}]}]], "Input",
 CellChangeTimes->{
  3.39930909115625*^9, {3.399309445625*^9, 3.399309446328125*^9}, {
   3.3993097020625*^9, 3.3993097608125*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<                  u[x,y] = \>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<   \[Phi][x,y] = \!\(\*SubscriptBox[\(\[PartialD]\), \(x, x, x, \
x\)]\)u[x,y] = \>\"", ",", 
      RowBox[{
       SubscriptBox["\[PartialD]", 
        RowBox[{"x", ",", "x", ",", "x", ",", "x"}]], 
       RowBox[{"u", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"laplace", "[", " ", 
     RowBox[{
      SubscriptBox["\[PartialD]", 
       RowBox[{"x", ",", "x", ",", "x", ",", "x"}]], 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399309038578125*^9, 3.399309039421875*^9}, {
  3.399309448703125*^9, 3.399309449375*^9}, {3.399309745421875*^9, 
  3.399309756671875*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<                  u[x,y] = \>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<   \[Phi][x,y] = \!\(\*SubscriptBox[\(\[PartialD]\), \(x, x, x, \
y\)]\)u[x,y] = \>\"", ",", 
      RowBox[{
       SubscriptBox["\[PartialD]", 
        RowBox[{"x", ",", "x", ",", "x", ",", "y"}]], 
       RowBox[{"u", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"laplace", "[", " ", 
     RowBox[{
      SubscriptBox["\[PartialD]", 
       RowBox[{"x", ",", "x", ",", "x", ",", "y"}]], 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], " ", "]"}], ";"}]}]}]], "Input",
 CellChangeTimes->{
  3.399309041203125*^9, {3.39930945165625*^9, 3.399309452453125*^9}, {
   3.3993097980625*^9, 3.39930980871875*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<                  u[x,y] = \>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<   \[Phi][x,y] = \!\(\*SubscriptBox[\(\[PartialD]\), \(x, x, y, \
y\)]\)u[x,y] = \>\"", ",", 
      RowBox[{
       SubscriptBox["\[PartialD]", 
        RowBox[{"x", ",", "x", ",", "y", ",", "y"}]], 
       RowBox[{"u", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"laplace", "[", " ", 
     RowBox[{
      SubscriptBox["\[PartialD]", 
       RowBox[{"x", ",", "x", ",", "y", ",", "y"}]], 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], " ", "]"}], ";"}]}]}]], "Input",
 CellChangeTimes->{
  3.399309044875*^9, {3.39930945475*^9, 3.39930945540625*^9}, {
   3.3993098181875*^9, 3.399309827265625*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<                  u[x,y] = \>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<   \[Phi][x,y] = \!\(\*SubscriptBox[\(\[PartialD]\), \(x, y, y, \
y\)]\)u[x,y] = \>\"", ",", 
      RowBox[{
       SubscriptBox["\[PartialD]", 
        RowBox[{"x", ",", "y", ",", "y", ",", "y"}]], 
       RowBox[{"u", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"laplace", "[", " ", 
     RowBox[{
      SubscriptBox["\[PartialD]", 
       RowBox[{"x", ",", "y", ",", "y", ",", "y"}]], 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], " ", "]"}], ";"}]}]}]], "Input",
 CellChangeTimes->{
  3.39930909934375*^9, {3.399309457625*^9, 3.399309458296875*^9}, {
   3.3993098365625*^9, 3.39930985075*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<              u[x,y] = \>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<   \[Phi][x,y] = \!\(\*SubscriptBox[\(\[PartialD]\), \(y, y, y, \
y\)]\)u[x,y] = \>\"", ",", 
      RowBox[{
       SubscriptBox["\[PartialD]", 
        RowBox[{"y", ",", "y", ",", "y", ",", "y"}]], 
       RowBox[{"u", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"laplace", "[", " ", 
     RowBox[{
      SubscriptBox["\[PartialD]", 
       RowBox[{"y", ",", "y", ",", "y", ",", "y"}]], 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], " ", "]"}], ";"}]}]}]], "Input",
 CellChangeTimes->{
  3.3993091004375*^9, {3.3993094605*^9, 3.399309461234375*^9}, {
   3.399309857484375*^9, 3.399309867*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<                   u[x,y] = \>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<   \[Phi][x,y] = \!\(\*SubscriptBox[\(\[PartialD]\), \(x, x, x, x, \
x\)]\)u[x,y] = \>\"", ",", 
      RowBox[{
       SubscriptBox["\[PartialD]", 
        RowBox[{"x", ",", "x", ",", "x", ",", "x", ",", "x"}]], 
       RowBox[{"u", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"laplace", "[", " ", 
     RowBox[{
      SubscriptBox["\[PartialD]", 
       RowBox[{"x", ",", "x", ",", "x", ",", "x", ",", "x"}]], 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], " ", "]"}], ";"}]}]}]], "Input",
 CellChangeTimes->{
  3.399309101453125*^9, {3.399309463359375*^9, 3.399309464015625*^9}, {
   3.39930987246875*^9, 3.399309881875*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<                   u[x,y] = \>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<   \[Phi][x,y] = \!\(\*SubscriptBox[\(\[PartialD]\), \(x, x, x, x, \
y\)]\)u[x,y] = \>\"", ",", 
      RowBox[{
       SubscriptBox["\[PartialD]", 
        RowBox[{"x", ",", "x", ",", "x", ",", "x", ",", "y"}]], 
       RowBox[{"u", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"laplace", "[", " ", 
     RowBox[{
      SubscriptBox["\[PartialD]", 
       RowBox[{"x", ",", "x", ",", "x", ",", "x", ",", "y"}]], 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], " ", "]"}], ";"}]}]}]], "Input",
 CellChangeTimes->{
  3.399309102453125*^9, {3.399309466640625*^9, 3.39930946734375*^9}, {
   3.39930988621875*^9, 3.399309896421875*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<                   u[x,y] = \>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<   \[Phi][x,y] = \!\(\*SubscriptBox[\(\[PartialD]\), \(x, x, x, y, \
y\)]\)u[x,y] = \>\"", ",", 
      RowBox[{
       SubscriptBox["\[PartialD]", 
        RowBox[{"x", ",", "x", ",", "x", ",", "y", ",", "y"}]], 
       RowBox[{"u", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"laplace", "[", " ", 
     RowBox[{
      SubscriptBox["\[PartialD]", 
       RowBox[{"x", ",", "x", ",", "x", ",", "y", ",", "y"}]], 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], " ", "]"}], ";"}]}]}]], "Input",
 CellChangeTimes->{
  3.39930910559375*^9, {3.39930947059375*^9, 3.39930947146875*^9}, {
   3.399309901625*^9, 3.399309914046875*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<                   u[x,y] = \>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<   \[Phi][x,y] = \!\(\*SubscriptBox[\(\[PartialD]\), \(x, x, y, y, \
y\)]\)u[x,y] = \>\"", ",", 
      RowBox[{
       SubscriptBox["\[PartialD]", 
        RowBox[{"x", ",", "x", ",", "y", ",", "y", ",", "y"}]], 
       RowBox[{"u", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"laplace", "[", " ", 
     RowBox[{
      SubscriptBox["\[PartialD]", 
       RowBox[{"x", ",", "x", ",", "y", ",", "y", ",", "y"}]], 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], " ", "]"}], ";"}]}]}]], "Input",
 CellChangeTimes->{
  3.399309106953125*^9, {3.39930947421875*^9, 3.399309474875*^9}, {
   3.399309921015625*^9, 3.399309931390625*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<                   u[x,y] = \>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<   \[Phi][x,y] = \!\(\*SubscriptBox[\(\[PartialD]\), \(x, y, y, y, \
y\)]\)u[x,y] = \>\"", ",", 
      RowBox[{
       SubscriptBox["\[PartialD]", 
        RowBox[{"x", ",", "y", ",", "y", ",", "y", ",", "y"}]], 
       RowBox[{"u", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"laplace", "[", " ", 
     RowBox[{
      SubscriptBox["\[PartialD]", 
       RowBox[{"x", ",", "y", ",", "y", ",", "y", ",", "y"}]], 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], " ", "]"}], ";"}]}]}]], "Input",
 CellChangeTimes->{
  3.39930910875*^9, {3.399309476734375*^9, 3.399309477421875*^9}, {
   3.399309937140625*^9, 3.3993099499375*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<                   u[x,y] = \>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<   \[Phi][x,y] = \!\(\*SubscriptBox[\(\[PartialD]\), \(y, y, y, y, \
y\)]\)u[x,y] = \>\"", ",", 
      RowBox[{
       SubscriptBox["\[PartialD]", 
        RowBox[{"y", ",", "y", ",", "y", ",", "y", ",", "y"}]], 
       RowBox[{"u", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"laplace", "[", " ", 
     RowBox[{
      SubscriptBox["\[PartialD]", 
       RowBox[{"y", ",", "y", ",", "y", ",", "y", ",", "y"}]], 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], " ", "]"}], ";"}]}]}]], "Input",
 CellChangeTimes->{
  3.399309110109375*^9, {3.39930948025*^9, 3.39930948084375*^9}, {
   3.399309955375*^9, 3.3993099683125*^9}}]
}, Closed]],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[{
 StyleBox[ButtonBox["Cauchy-Goursat Theorem",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/CauchyGoursatBib.html"], 
    None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0, 1]],
 "  "
}], "Text"],

Cell[TextData[{
 StyleBox[ButtonBox["Cauchy's Integral Formula",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/CauchyIntegraBib.html"], 
    None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0, 1]],
 "  "
}], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/complex.html"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2008 John H. Mathews, Russell W. \
Howell",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/"], None}],
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[0, 1, 0]]], "Text",
 CellChangeTimes->{{3.399308770046875*^9, 3.39930877025*^9}}]
},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{987, 650},
WindowMargins->{{Automatic, 12}, {Automatic, 0}},
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "CHAPTER 1"->{
  Cell[568, 21, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"],
  Cell[4445, 153, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"],
  Cell[80250, 2759, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"],
  Cell[85002, 2927, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"],
  Cell[133739, 4562, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"],
  Cell[138474, 4748, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"CHAPTER 1", 170574, 5735}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"],
Cell[905, 32, 142, 3, 29, "Text"],
Cell[1050, 37, 1628, 46, 83, "Text",
 Evaluatable->False],
Cell[2681, 85, 1421, 52, 92, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[4127, 141, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[4271, 147, 171, 4, 29, "Text",
 Evaluatable->False],
Cell[4445, 153, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"]
}, Closed]],
Cell[4794, 165, 724, 27, 35, "Text",
 Evaluatable->False],
Cell[5521, 194, 6647, 264, 192, "Text"],
Cell[12171, 460, 1487, 50, 112, "Text"],
Cell[CellGroupData[{
Cell[13683, 514, 110, 2, 29, "Text"],
Cell[13796, 518, 284, 10, 38, "Text"],
Cell[14083, 530, 2009, 59, 247, "Input"],
Cell[16095, 591, 216, 9, 29, "Text",
 Evaluatable->False],
Cell[16314, 602, 776, 20, 72, "Input"],
Cell[17093, 624, 97, 2, 29, "Text",
 Evaluatable->False],
Cell[17193, 628, 1234, 35, 152, "Input"],
Cell[18430, 665, 405, 16, 38, "Text",
 Evaluatable->False],
Cell[18838, 683, 2584, 63, 303, "Input"],
Cell[21425, 748, 116, 2, 29, "Text",
 Evaluatable->False],
Cell[21544, 752, 3545, 97, 237, "Input"]
}, Closed]],
Cell[25104, 852, 832, 34, 42, "Text",
 Evaluatable->False],
Cell[25939, 888, 7294, 290, 192, "Text"],
Cell[33236, 1180, 2486, 84, 186, "Text"],
Cell[CellGroupData[{
Cell[35747, 1268, 110, 2, 29, "Text"],
Cell[35860, 1272, 301, 11, 36, "Text"],
Cell[36164, 1285, 2037, 60, 248, "Input"],
Cell[38204, 1347, 216, 9, 29, "Text",
 Evaluatable->False],
Cell[38423, 1358, 749, 19, 72, "Input"],
Cell[39175, 1379, 97, 2, 29, "Text",
 Evaluatable->False],
Cell[39275, 1383, 1277, 36, 152, "Input"],
Cell[40555, 1421, 422, 17, 36, "Text",
 Evaluatable->False],
Cell[40980, 1440, 2584, 63, 303, "Input"],
Cell[43567, 1505, 116, 2, 29, "Text",
 Evaluatable->False],
Cell[43686, 1509, 3542, 97, 237, "Input"]
}, Closed]],
Cell[47243, 1609, 855, 33, 39, "Text",
 Evaluatable->False],
Cell[48101, 1644, 12077, 487, 192, "Text"],
Cell[60181, 2133, 4185, 136, 277, "Text"],
Cell[CellGroupData[{
Cell[64391, 2273, 110, 2, 29, "Text"],
Cell[64504, 2277, 426, 14, 42, "Text"],
Cell[64933, 2293, 2168, 63, 254, "Input"],
Cell[67104, 2358, 170, 8, 29, "Text",
 Evaluatable->False],
Cell[67277, 2368, 1345, 33, 92, "Input"],
Cell[68625, 2403, 336, 13, 71, "Text",
 Evaluatable->False],
Cell[68964, 2418, 1279, 36, 152, "Input"],
Cell[70246, 2456, 547, 20, 42, "Text",
 Evaluatable->False],
Cell[70796, 2478, 3158, 75, 337, "Input"],
Cell[73957, 2555, 116, 2, 29, "Text",
 Evaluatable->False],
Cell[74076, 2559, 3599, 99, 258, "Input"]
}, Closed]],
Cell[77690, 2661, 1940, 74, 124, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[79655, 2739, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[79799, 2745, 448, 12, 47, "Text"],
Cell[80250, 2759, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"]
}, Closed]],
Cell[CellGroupData[{
Cell[80621, 2773, 165, 4, 26, "Text",
 Evaluatable->False],
Cell[80789, 2779, 1617, 48, 247, "Input"]
}, Closed]],
Cell[82421, 2830, 805, 26, 44, "Text"],
Cell[83229, 2858, 1430, 53, 92, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[84684, 2915, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[84828, 2921, 171, 4, 29, "Text",
 Evaluatable->False],
Cell[85002, 2927, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"]
}, Closed]],
Cell[85351, 2939, 1276, 47, 116, "Text"],
Cell[86630, 2988, 5116, 203, 192, "Text"],
Cell[91749, 3193, 1776, 59, 191, "Text"],
Cell[CellGroupData[{
Cell[93550, 3256, 114, 2, 29, "Text"],
Cell[93667, 3260, 863, 31, 38, "Text"],
Cell[94533, 3293, 2049, 54, 321, "Input"],
Cell[96585, 3349, 116, 2, 29, "Text",
 Evaluatable->False],
Cell[96704, 3353, 2890, 79, 306, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[99631, 3437, 114, 2, 26, "Text"],
Cell[99748, 3441, 1960, 65, 173, "Text"],
Cell[101711, 3508, 3345, 90, 455, "Input"],
Cell[105059, 3600, 116, 2, 29, "Text",
 Evaluatable->False],
Cell[105178, 3604, 2890, 79, 306, "Input"]
}, Closed]],
Cell[108083, 3686, 852, 33, 43, "Text",
 Evaluatable->False],
Cell[108938, 3721, 6651, 264, 192, "Text"],
Cell[115592, 3987, 2765, 88, 196, "Text"],
Cell[CellGroupData[{
Cell[118382, 4079, 110, 2, 29, "Text"],
Cell[118495, 4083, 377, 13, 46, "Text"],
Cell[118875, 4098, 2122, 63, 258, "Input"],
Cell[121000, 4163, 216, 9, 29, "Text",
 Evaluatable->False],
Cell[121219, 4174, 749, 19, 72, "Input"],
Cell[121971, 4195, 294, 10, 29, "Text",
 Evaluatable->False],
Cell[122268, 4207, 1357, 39, 155, "Input"],
Cell[123628, 4248, 511, 19, 46, "Text",
 Evaluatable->False],
Cell[124142, 4269, 3806, 101, 384, "Input"],
Cell[127951, 4372, 116, 2, 29, "Text",
 Evaluatable->False],
Cell[128070, 4376, 3539, 97, 237, "Input"]
}, Closed]],
Cell[131624, 4476, 74, 0, 26, "Text"],
Cell[131701, 4478, 1694, 68, 29, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[133420, 4550, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[133564, 4556, 172, 4, 29, "Text",
 Evaluatable->False],
Cell[133739, 4562, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"]
}, Closed]],
Cell[134088, 4574, 1083, 42, 62, "Text"],
Cell[135174, 4618, 2956, 114, 51, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[138155, 4736, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[138299, 4742, 172, 4, 29, "Text",
 Evaluatable->False],
Cell[138474, 4748, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"]
}, Closed]],
Cell[138823, 4760, 669, 23, 26, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[139517, 4787, 113, 2, 29, "Text"],
Cell[139633, 4791, 3132, 88, 412, "Input"],
Cell[142768, 4881, 2255, 84, 67, "Text"],
Cell[145026, 4967, 2818, 73, 212, "Input"],
Cell[147847, 5042, 507, 14, 72, "Input"],
Cell[148357, 5058, 892, 26, 92, "Input"],
Cell[149252, 5086, 981, 27, 92, "Input"],
Cell[150236, 5115, 970, 28, 92, "Input"],
Cell[151209, 5145, 1006, 29, 112, "Input"],
Cell[152218, 5176, 971, 29, 92, "Input"],
Cell[153192, 5207, 1021, 29, 92, "Input"],
Cell[154216, 5238, 1059, 29, 92, "Input"],
Cell[155278, 5269, 1037, 29, 92, "Input"],
Cell[156318, 5300, 994, 29, 92, "Input"],
Cell[157315, 5331, 1073, 30, 112, "Input"],
Cell[158391, 5363, 1022, 29, 92, "Input"],
Cell[159416, 5394, 1016, 29, 92, "Input"],
Cell[160435, 5425, 1016, 29, 92, "Input"],
Cell[161454, 5456, 1009, 29, 92, "Input"],
Cell[162466, 5487, 1046, 29, 92, "Input"],
Cell[163515, 5518, 1048, 29, 92, "Input"],
Cell[164566, 5549, 1044, 29, 92, "Input"],
Cell[165613, 5580, 1046, 29, 92, "Input"],
Cell[166662, 5611, 1044, 29, 92, "Input"],
Cell[167709, 5642, 1040, 29, 92, "Input"]
}, Closed]],
Cell[168764, 5674, 281, 7, 26, "Text"],
Cell[169048, 5683, 302, 10, 29, "Text"],
Cell[169353, 5695, 305, 10, 29, "Text"],
Cell[169661, 5707, 249, 5, 29, "Text"],
Cell[169913, 5714, 316, 7, 29, "Text"]
}
]
*)

(* End of internal cache information *)
