(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    301621,       9572]
NotebookOptionsPosition[    288808,       9180]
NotebookOutlinePosition[    290060,       9228]
CellTagsIndexPosition[    289986,       9223]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["7.4  Singularities, Zeros, and Poles",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
 "\tRecall that the point ",
 Cell[BoxData[
  RowBox[{"z", "=", "\[Alpha]"}]]],
 " is called a ",
 StyleBox[ButtonBox["singular point",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/SingularPointFunction.html"], None}],
  FontVariations->{"Underline"->True}],
 ", or  ",
 StyleBox[ButtonBox["singularity",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/SingularPointFunction.html"], None}],
  FontVariations->{"Underline"->True}],
 " of the complex function ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " if ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " is ",
 StyleBox["not",
  FontColor->RGBColor[1, 0, 1]],
 " analytic at  ",
 Cell[BoxData[
  RowBox[{"z", "=", "\[Alpha]"}]]],
 ",  but every neighborhood  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["D", "R"], 
   RowBox[{"(", "\[Alpha]", ")"}], "  ", "of", "  ", "\[Alpha]"}]]],
 "  contains at least one point at which ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " is analytic.  For example, the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   FractionBox["1", 
    RowBox[{"1", " ", "-", " ", "z"}]]}]]],
 "  is not analytic at  ",
 Cell[BoxData[
  RowBox[{"z", "=", "1"}]]],
 ",  but is analytic for all other values of ",
 StyleBox["z",
  FontFamily->"Courier New"],
 ".  Thus the point  ",
 Cell[BoxData[
  RowBox[{"z", "=", "1"}]]],
 "  is a singular point of ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 ".  As another example,  consider  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"g", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{"Log", 
    RowBox[{"(", "z", ")"}]}]}]]],
 ".  We saw in Section 5.2 that ",
 StyleBox["g(z)",
  FontFamily->"Courier New"],
 " is  analytic for all ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " except at the origin and at all points on the negative real-axis.  Thus, \
the origin and each point on the negative real axis is a singularity of  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"g", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{"Log", 
    RowBox[{"(", "z", ")"}]}]}]]],
 "."
}], "Text",
 Evaluatable->False,
 CellChangeTimes->{3.399381265296875*^9},
 AspectRatioFixed->False],

Cell[TextData[{
 "\tThe point ",
 Cell[BoxData["\[Alpha]"]],
 " is called a ",
 StyleBox[ButtonBox["isolated singularity",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/IsolatedSingularity.html"], None}],
  FontVariations->{"Underline"->True}],
 " of the complex function ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " if  f  is ",
 StyleBox["not",
  FontColor->RGBColor[1, 0, 1]],
 " analytic at  ",
 Cell[BoxData[
  RowBox[{"z", "=", "\[Alpha]"}]]],
 ",  but there exists a real number  ",
 Cell[BoxData[
  RowBox[{"R", ">", "0"}]]],
 "  such that ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " is analytic everywhere in the punctured disk  ",
 Cell[BoxData[
  RowBox[{
   SubsuperscriptBox["D", "R", "*"], 
   RowBox[{"(", "\[Alpha]", ")"}]}]]],
 ".  The function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   FractionBox["1", 
    RowBox[{"1", " ", "-", " ", "z"}]]}]]],
 "  has an isolated singularity at  ",
 Cell[BoxData[
  RowBox[{"z", "=", "1"}]]],
 ".  \n\n\tThe function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"g", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{"Log", 
    RowBox[{"(", "z", ")"}]}]}]]],
 ",  however, the singularity at  ",
 Cell[BoxData[
  RowBox[{"z", "=", "0"}]]],
 "  (or at any point of the negative real axis) that is not isolated, because \
any neighborhood of  contains points on the negative real axis, and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"g", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{"Log", 
    RowBox[{"(", "z", ")"}]}]}]]],
 "  is not analytic at those points.  Functions with isolated singularities \
have a Laurent series because the punctured disk   ",
 Cell[BoxData[
  RowBox[{
   SubsuperscriptBox["D", "R", "*"], 
   RowBox[{"(", "\[Alpha]", ")"}]}]]],
 "  is the same as the annulus  ",
 Cell[BoxData[
  RowBox[{"A", 
   RowBox[{"(", 
    RowBox[{"\[Alpha]", ",", "0", ",", "R"}], ")"}]}]]],
 ".  The logarithm function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"g", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{"Log", 
    RowBox[{"(", "z", ")"}]}]}]]],
 "  does ",
 StyleBox["not",
  FontColor->RGBColor[1, 0, 1]],
 " have a ",
 StyleBox[ButtonBox["Laurent",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Laurent_\
Pierre.html"], None}],
  FontVariations->{"Underline"->True}],
 " series at any point  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{"-", "a"}]}]]],
 "  on the negative real-axis.  We now look at this special case of Laurent's \
theorem in order to classify three types of isolated singularities. "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 StyleBox["Definition 7.5 (",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Removable Singularity",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/RemovableSingularity.html"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 StyleBox[", ",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Pole of order k",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/Pole.html"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 StyleBox[", ",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Essential Singularity",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/EssentialSingularity.html"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 StyleBox[").",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 " Let ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " have an isolated singularity at  ",
 Cell[BoxData["\[Alpha]"]],
 "  with Laurent series expansion  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", 
      RowBox[{"-", "\[Infinity]"}]}], "\[Infinity]"], 
    RowBox[{
     SubscriptBox["c", "n"], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "\[Alpha]"}], ")"}], "n"]}]}]}]]],
 "    valid for    ",
 Cell[BoxData[
  RowBox[{"z", "\[Element]", 
   RowBox[{"A", 
    RowBox[{"(", 
     RowBox[{"\[Alpha]", ",", "0", ",", "R"}], ")"}]}]}]]],
 ".  \n\nThen we distinguish the following types of singularities at  ",
 Cell[BoxData["\[Alpha]"]],
 ".  \n\n",
 StyleBox["(i)",
  FontColor->RGBColor[0, 0, 1]],
 "  \tIf  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["c", "n"], "=", 
    RowBox[{
     RowBox[{"0", "  ", 
      StyleBox["for",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "  ", "n"}], "=", 
     RowBox[{"-", "1"}]}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{"-", "2"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{"-", "3"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "..."}]]],
 ",  then we say that ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " has a ",
 StyleBox[ButtonBox["removable singularity",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/RemovableSingularity.html"], None}],
  FontVariations->{"Underline"->True}],
 " at  ",
 Cell[BoxData["\[Alpha]"]],
 ".  \n\n",
 StyleBox["(ii)",
  FontColor->RGBColor[0, 0, 1]],
 "  \tIf ",
 StyleBox["k",
  FontFamily->"Courier"],
 " is a positive integer such that  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["c", 
    RowBox[{"-", "k"}]], "\[NotEqual]", "0"}]]],
 "  but ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["c", "n"], "=", 
    RowBox[{
     RowBox[{"0", 
      StyleBox[
       RowBox[{"  ", 
        StyleBox["  ",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]]}]], 
      StyleBox["for",
       FontFamily->"Times New Roman"], 
      StyleBox[
       RowBox[{
        StyleBox["  ",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], "  "}]], "n"}], "=", 
     RowBox[{
      RowBox[{"-", "k"}], "-", "1"}]}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    RowBox[{"-", "k"}], "-", "2"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    RowBox[{"-", "k"}], "-", "3"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "..."}]]],
 ",  then we say that ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " has a ",
 StyleBox[ButtonBox["pole of order k",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/Pole.html"], None}],
  FontVariations->{"Underline"->True}],
 " at ",
 Cell[BoxData["\[Alpha]"]],
 ".  \n\n",
 StyleBox["(iii)",
  FontColor->RGBColor[0, 0, 1]],
 "  \tIf ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["c", "n"], "\[NotEqual]", "0"}]]],
 " for infinitely many negative integers ",
 StyleBox["n",
  FontFamily->"Courier New"],
 ", then we say that ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " has an",
 StyleBox[" ",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["essential singularity",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/EssentialSingularity.html"], None}],
  FontVariations->{"Underline"->True}],
 " at  ",
 Cell[BoxData[
  RowBox[{"z", "=", "\[Alpha]"}]]],
 ".  "
}], "Text"],

Cell["\tLet's investigate some examples of these three cases.", "Text"],

Cell[TextData[{
 StyleBox["(i).",
  FontColor->RGBColor[0, 0, 1]],
 "  If ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " has a removable singularity at ",
 Cell[BoxData[
  RowBox[{"z", "=", "\[Alpha]"}]]],
 ", then it has a Laurent series  \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", "0"}], "\[Infinity]"], 
    RowBox[{
     SubscriptBox["c", "n"], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "\[Alpha]"}], ")"}], "n"]}]}]}]]],
 "    valid for    ",
 Cell[BoxData[
  RowBox[{"z", "\[Element]", 
   RowBox[{"A", 
    RowBox[{"(", 
     RowBox[{"\[Alpha]", ",", "0", ",", "R"}], ")"}]}]}]]],
 ".  \n\n\tTheorem 4.17 implies that the power series for ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " defines an analytic function in the disk  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["D", "R"], 
   RowBox[{"(", "\[Alpha]", ")"}]}]]],
 ".  \n\tIf we use this series to define  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "\[Alpha]", ")"}]}], "=", 
   SubscriptBox["c", "0"]}]]],
 ",  then the function ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " becomes analytic at ",
 Cell[BoxData[
  RowBox[{"z", "=", "\[Alpha]"}]]],
 ", removing the singularity.  "
}], "Text"],

Cell[TextData[{
 "\tFor example, consider the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   FractionBox[
    RowBox[{"sin", 
     RowBox[{"(", "z", ")"}]}], "z"]}]],
  AspectRatioFixed->True],
 ".  It is undefined at ",
 Cell[BoxData[
  RowBox[{"z", "=", "0"}]]],
 " and has an isolated singularity at ",
 Cell[BoxData[
  RowBox[{"z", "=", "0"}]]],
 ", as the Laurent series for ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " is  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
    RowBox[{
     FractionBox["1", "z"], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"z", "-", 
        FractionBox[
         SuperscriptBox["z", "3"], 
         RowBox[{"3", "!"}]], "+", 
        FractionBox[
         SuperscriptBox["z", "5"], 
         RowBox[{"5", "!"}]], "-", 
        FractionBox[
         SuperscriptBox["z", "7"], 
         RowBox[{"7", "!"}]], "+", 
        FractionBox[
         SuperscriptBox["z", "9"], 
         RowBox[{"9", "!"}]], "-", 
        FractionBox[
         SuperscriptBox["z", "11"], 
         RowBox[{"11", "!"}]], "+"}], "..."}], ")"}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"             ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{"1", "-", 
      FractionBox[
       SuperscriptBox["z", "2"], 
       RowBox[{"3", "!"}]], "+", 
      FractionBox[
       SuperscriptBox["z", "4"], 
       RowBox[{"5", "!"}]], "-", 
      FractionBox[
       SuperscriptBox["z", "6"], 
       RowBox[{"7", "!"}]], "+", 
      FractionBox[
       SuperscriptBox["z", "8"], 
       RowBox[{"9", "!"}]], "-", 
      FractionBox[
       SuperscriptBox["z", "10"], 
       RowBox[{"11", "!"}]], "+"}], "..."}]}]}]}]],
 "  \n\nvalid for ",
 Cell[BoxData[
  RowBox[{"|", "z", "|", 
   RowBox[{">", "0"}]}]]],
 ".  \n\nWe can remove this singularity if we define  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "0", ")"}]}], "=", "1"}]]],
 ",  for then ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " will be analytic at ",
 Cell[BoxData[
  RowBox[{"z", "=", "0"}]]],
 " in accordance with Theorem 4.17.  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration 1.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "Enter the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], "=", 
   FractionBox[
    RowBox[{"Sin", "[", "z", "]"}], "z"]}]]],
 " and find the first few terms of the Laurent series in the punctured plane  \
",
 Cell[BoxData[
  RowBox[{"0", "<", "z"}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "lim", ",", "S", ",", "z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", 
     FractionBox[
      RowBox[{"Sin", "[", "z", "]"}], "z"]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"S", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{"f", "[", "z", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", "0", ",", "13"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"lim", "=", 
     RowBox[{"Limit", "[", 
      RowBox[{
       RowBox[{"f", "[", "z", "]"}], ",", 
       RowBox[{"z", "\[Rule]", "0"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[0] = \>\"", ",", 
      RowBox[{"f", "[", "0", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[z] = \>\"", ",", 
      RowBox[{"S", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[0] = \>\"", ",", 
      RowBox[{"S", "[", "0", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<From calculus we know that\>\"", "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(lim\), \(x \[Rule] 0\)]\) \>\"", ",", 
      RowBox[{"f", "[", "x", "]"}], ",", "\"\< = \>\"", ",", 
      RowBox[{"Limit", "[", 
       RowBox[{
        RowBox[{"f", "[", "x", "]"}], ",", 
        RowBox[{"x", "\[Rule]", "0"}]}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<Extending to the complex plane, we have\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"S", "[", "z", "]"}], ",", "\"\< + ...\>\""}], "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(lim\), \(z \[Rule] 0\)]\) \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\< = \>\"", ",", "lim"}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{
  3.399381285*^9, {3.400269202984375*^9, 3.400269210234375*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "The Laurent series for f(z) contains only positive powers of z. Hence,  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], "=", 
   FractionBox[
    RowBox[{"Sin", "[", "z", "]"}], "z"]}]]],
 "  has a removable singularity at the origin.\n\nWe can use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to investigate how well the Laurent series is \"converging\" for real \
numbers."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"f", "[", "z", "]"}], ",", 
       RowBox[{"S", "[", "z", "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", 
       RowBox[{"-", "7"}], ",", "7"}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Red", ",", "Blue"}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "7"}], ",", "7"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.25"}], ",", "1.05"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "7"}], ",", "7", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "1", ",", 
          FractionBox["1", "2"]}], "]"}]}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<The function  f[x] = \>\"", ",", 
      RowBox[{"f", "[", "x", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<and series\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[x] = \>\"", ",", 
      RowBox[{"S", "[", "x", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399381291734375*^9, 3.399381296609375*^9}, {
  3.399915339375*^9, 3.399915339578125*^9}, {3.3999652859375*^9, 
  3.39996528675*^9}}],

Cell[TextData[{
 "We can use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to investigate the real and imaginary parts of  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], "=", 
   FractionBox[
    RowBox[{"Sin", "[", "z", "]"}], "z"]}]]],
 " near the removable singularity."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"u", ",", "v"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"u", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], "=", 
     RowBox[{"Together", "[", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{
        RowBox[{"Re", "[", 
         RowBox[{"f", "[", 
          RowBox[{"x", "+", 
           RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], ",", 
        RowBox[{"TargetFunctions", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"Im", ",", "Re"}], "}"}]}]}], "]"}], "]"}]}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"v", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], "=", 
     RowBox[{"Together", "[", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{
        RowBox[{"Im", "[", 
         RowBox[{"f", "[", 
          RowBox[{"x", "+", 
           RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], ",", 
        RowBox[{"TargetFunctions", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"Im", ",", "Re"}], "}"}]}]}], "]"}], "]"}]}], ";"}], " ", 
   "\n", 
   RowBox[{"Plot3D", "[", 
    RowBox[{
     RowBox[{"u", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "0.1"}], ",", "0.1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "0.1"}], ",", "0.1"}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "40"}], ",", 
     RowBox[{"BoxRatios", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], ",", 
     RowBox[{"Mesh", "\[Rule]", "False"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<s\>\""}], "}"}]}], 
     ",", 
     RowBox[{"ViewPoint", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "3"}], ",", "3", ",", "2"}], "}"}]}], ",", 
     RowBox[{"Boxed", "\[Rule]", "False"}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<u[x,y] = \>\"", ",", 
      RowBox[{"Re", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<       = \>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3993813030625*^9, 3.399381306859375*^9}, {
  3.39938140353125*^9, 3.399381404515625*^9}, {3.399915344671875*^9, 
  3.399915344875*^9}, {3.399964232015625*^9, 3.399964285671875*^9}, {
  3.39996433221875*^9, 3.399964340578125*^9}, {3.399964398796875*^9, 
  3.39996439925*^9}, {3.399964463421875*^9, 3.399964471015625*^9}, {
  3.400269141421875*^9, 3.400269146765625*^9}}],

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{"Plot3D", "[", 
    RowBox[{
     RowBox[{"v", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "0.1"}], ",", "0.1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "0.1"}], ",", "0.1"}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "40"}], ",", 
     RowBox[{"BoxRatios", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], ",", 
     RowBox[{"Mesh", "\[Rule]", "False"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<s\>\""}], "}"}]}], 
     ",", 
     RowBox[{"ViewPoint", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "3"}], ",", "3", ",", "2"}], "}"}]}], ",", 
     RowBox[{"Boxed", "\[Rule]", "False"}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<v[x,y] = \>\"", ",", 
      RowBox[{"Im", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<       = \>\"", ",", 
      RowBox[{"v", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3993814190625*^9, 3.399381428765625*^9}, {
  3.399915349671875*^9, 3.399915349859375*^9}, {3.39996435753125*^9, 
  3.39996436209375*^9}, {3.39996440534375*^9, 3.399964405609375*^9}, {
  3.399964466*^9, 3.399964477125*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Plot3D", "[", 
    RowBox[{
     RowBox[{"u", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"31", ",", "31"}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "12"}], ",", "15"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<\>\""}], "}"}]}], ",",
      
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<u[x,y] = \>\"", ",", 
      RowBox[{"Re", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<       = \>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399381444828125*^9, 3.399381447984375*^9}, {
  3.39991535471875*^9, 3.39991535490625*^9}, {3.399964482015625*^9, 
  3.399964483421875*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Plot3D", "[", 
    RowBox[{
     RowBox[{"v", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"31", ",", "31"}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "12"}], ",", "15"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<\>\""}], "}"}]}], ",",
      
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<v[x,y] = \>\"", ",", 
      RowBox[{"Im", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<       = \>\"", ",", 
      RowBox[{"v", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399381455671875*^9, 3.399381458421875*^9}, {
  3.3999153608125*^9, 3.399915361*^9}, {3.399964509515625*^9, 
  3.39996451025*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"u", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "35"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<u[x,y] = \>\"", ",", 
      RowBox[{"Re", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<       = \>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399381461546875*^9, 3.39938146371875*^9}, {
   3.399915365484375*^9, 3.399915365671875*^9}, 3.3999645158125*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"v", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "35"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<v[x,y] = \>\"", ",", 
      RowBox[{"Im", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<       = \>\"", ",", 
      RowBox[{"v", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399381466453125*^9, 3.39938146859375*^9}, {
   3.399915368140625*^9, 3.399915368328125*^9}, 3.399964520640625*^9}]
}, Closed]],

Cell[TextData[{
 "\tAnother example is  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"g", 
    RowBox[{"(", "z", ")"}]}], "=", 
   FractionBox[
    RowBox[{
     RowBox[{"cos", 
      RowBox[{"(", "z", ")"}]}], " ", "-", "  ", "1"}], 
    SuperscriptBox["z", "2"]]}]],
  AspectRatioFixed->True],
 ",  which has an isolated singularity at the point ",
 Cell[BoxData[
  RowBox[{"z", "=", "0"}]]],
 ", as the Laurent series for ",
 StyleBox["g(z)",
  FontFamily->"Courier New"],
 " is \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"g", 
     RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
    RowBox[{
     FractionBox["1", 
      SuperscriptBox["z", "2"]], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          SuperscriptBox["z", "2"], 
          RowBox[{"2", "!"}]]}], "+", 
        FractionBox[
         SuperscriptBox["z", "4"], 
         RowBox[{"4", "!"}]], "-", 
        FractionBox[
         SuperscriptBox["z", "6"], 
         RowBox[{"6", "!"}]], "+", 
        FractionBox[
         SuperscriptBox["z", "8"], 
         RowBox[{"8", "!"}]], "-", 
        FractionBox[
         SuperscriptBox["z", "10"], 
         RowBox[{"10", "!"}]], "+"}], "..."}], ")"}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"            ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", 
        RowBox[{"2", "!"}]]}], "+", 
      FractionBox[
       SuperscriptBox["z", "2"], 
       RowBox[{"4", "!"}]], "-", 
      FractionBox[
       SuperscriptBox["z", "4"], 
       RowBox[{"6", "!"}]], "+", 
      FractionBox[
       SuperscriptBox["z", "6"], 
       RowBox[{"8", "!"}]], "-", 
      FractionBox[
       SuperscriptBox["z", "8"], 
       RowBox[{"10", "!"}]], "+"}], "..."}]}]}]}]],
 " \n\nvalid for ",
 Cell[BoxData[
  RowBox[{"|", "z", "|", 
   RowBox[{">", "0"}]}]]],
 ".  If we define  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "0", ")"}]}], " ", "=", " ", 
   RowBox[{"-", 
    FractionBox["1", "2"]}]}]]],
 ",  then ",
 StyleBox["g(z)",
  FontFamily->"Courier New"],
 " will be analytic for all ",
 StyleBox["z",
  FontFamily->"Courier New"],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration 2.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "Enter the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], "=", 
   FractionBox[
    RowBox[{
     RowBox[{"Cos", "[", "z", "]"}], " ", "-", " ", "1"}], 
    SuperscriptBox["z", "2"]]}]]],
 " and find the first few terms of the Laurent series in the punctured plane  \
",
 Cell[BoxData[
  RowBox[{"0", "<", "z"}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "S", ",", "z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox[
      RowBox[{
       RowBox[{"Cos", "[", "z", "]"}], " ", "-", "1"}], 
      SuperscriptBox["z", "2"]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"S", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{"f", "[", "z", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", "0", ",", "11"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"lim", "=", 
     RowBox[{"Limit", "[", 
      RowBox[{
       RowBox[{"f", "[", "z", "]"}], ",", 
       RowBox[{"z", "\[Rule]", "0"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[0] = \>\"", ",", 
      RowBox[{"f", "[", "0", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[z] = \>\"", ",", 
      RowBox[{"S", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[0] = \>\"", ",", 
      RowBox[{"S", "[", "0", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<From calculus we know that\>\"", "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(lim\), \(x \[Rule] 0\)]\) \>\"", ",", 
      RowBox[{"f", "[", "x", "]"}], ",", "\"\< = \>\"", ",", 
      RowBox[{"Limit", "[", 
       RowBox[{
        RowBox[{"f", "[", "x", "]"}], ",", 
        RowBox[{"x", "\[Rule]", "0"}]}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<Extending to the complex plane, we have\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"S", "[", "z", "]"}], ",", "\"\< + ...\>\""}], "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(lim\), \(z \[Rule] 0\)]\) \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\< = \>\"", ",", "lim"}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{
  3.399381495984375*^9, {3.400269214859375*^9, 3.40026921765625*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "The Laurent series for f(z) contains only positive powers of z. Hence,  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], "=", 
   FractionBox[
    RowBox[{
     RowBox[{"Cos", "[", "z", "]"}], " ", "-", " ", "1"}], 
    SuperscriptBox["z", "2"]]}]]],
 "  has a removable singularity at the origin.\n\nWe can use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to investigate how well the Laurent series is \"converging\" for real \
numbers."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"f", "[", "z", "]"}], ",", 
       RowBox[{"S", "[", "z", "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", 
       RowBox[{"-", "8"}], ",", "8"}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Red", ",", "Blue"}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "8"}], ",", "8"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.55"}], ",", "0.15"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "8"}], ",", "8", ",", "2"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "0.5"}], ",", "0", ",", "0.25"}], "]"}]}], "}"}]}]}], 
    "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<The function  f[x] = \>\"", ",", 
      RowBox[{"f", "[", "x", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<and series\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[x] = \>\"", ",", 
      RowBox[{"S", "[", "x", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399381500546875*^9, 3.399381502390625*^9}, {
  3.3999153740625*^9, 3.399915374515625*^9}, {3.399964528609375*^9, 
  3.39996452953125*^9}}],

Cell[TextData[{
 "We can use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to investigate the real and imaginary parts of  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], "=", 
   FractionBox[
    RowBox[{
     RowBox[{"Cos", "[", "z", "]"}], " ", "-", " ", "1"}], 
    SuperscriptBox["z", "2"]]}]]],
 " near the removable singularity."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"u", ",", "v"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"u", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], "=", 
     RowBox[{"FullSimplify", "[", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{
        RowBox[{"Re", "[", 
         RowBox[{"f", "[", 
          RowBox[{"x", "+", 
           RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], ",", 
        RowBox[{"TargetFunctions", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"Im", ",", "Re"}], "}"}]}]}], "]"}], "]"}]}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"v", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], "=", 
     RowBox[{"FullSimplify", "[", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{
        RowBox[{"Im", "[", 
         RowBox[{"f", "[", 
          RowBox[{"x", "+", 
           RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], ",", 
        RowBox[{"TargetFunctions", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"Im", ",", "Re"}], "}"}]}]}], "]"}], "]"}]}], ";"}], " ", 
   "\n", 
   RowBox[{"Plot3D", "[", 
    RowBox[{
     RowBox[{"u", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "0.1"}], ",", "0.1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "0.1"}], ",", "0.1"}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "40"}], ",", 
     RowBox[{"BoxRatios", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], ",", 
     RowBox[{"Mesh", "\[Rule]", "False"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<s\>\""}], "}"}]}], 
     ",", 
     RowBox[{"ViewPoint", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "3"}], ",", "3", ",", "2"}], "}"}]}], ",", 
     RowBox[{"Boxed", "\[Rule]", "False"}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<u[x,y] = \>\"", ",", 
      RowBox[{"Re", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<= \>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399381505546875*^9, 3.399381511203125*^9}, {
   3.39991538475*^9, 3.3999153849375*^9}, 3.39996453571875*^9, {
   3.400269154359375*^9, 3.4002691590625*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Plot3D", "[", 
    RowBox[{
     RowBox[{"v", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "0.1"}], ",", "0.1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "0.1"}], ",", "0.1"}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "40"}], ",", 
     RowBox[{"BoxRatios", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], ",", 
     RowBox[{"Mesh", "\[Rule]", "False"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<s\>\""}], "}"}]}], 
     ",", 
     RowBox[{"ViewPoint", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "3"}], ",", "3", ",", "2"}], "}"}]}], ",", 
     RowBox[{"Boxed", "\[Rule]", "False"}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<v[x,y] = \>\"", ",", 
      RowBox[{"Im", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<= \>\"", ",", 
      RowBox[{"v", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39938152128125*^9, 3.3993815265*^9}, {
   3.39991538965625*^9, 3.3999153898125*^9}, 3.399964541390625*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Plot3D", "[", 
    RowBox[{
     RowBox[{"u", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"31", ",", "31"}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<\>\""}], "}"}]}], ",",
      
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<u[x,y] = \>\"", ",", 
      RowBox[{"Re", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<= \>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399381530578125*^9, 3.39938153375*^9}, {
   3.399915393796875*^9, 3.39991539396875*^9}, 3.39996454846875*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Plot3D", "[", 
    RowBox[{
     RowBox[{"v", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"31", ",", "31"}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<\>\""}], "}"}]}], ",",
      
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<v[x,y] = \>\"", ",", 
      RowBox[{"Im", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<= \>\"", ",", 
      RowBox[{"v", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399381537109375*^9, 3.399381538640625*^9}, {
   3.3999153995*^9, 3.399915399703125*^9}, 3.399964551421875*^9}],

Cell[BoxData[{
 RowBox[{"ContourPlot", "[", 
  RowBox[{
   RowBox[{"u", "[", 
    RowBox[{"x", ",", "y"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", 
     RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
   RowBox[{"PlotPoints", "\[Rule]", "35"}], ",", 
   RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
   RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Print", "[", 
    RowBox[{"\"\<u[x,y] = \>\"", ",", 
     RowBox[{"Re", "[", 
      RowBox[{"f", "[", 
       RowBox[{"x", " ", "+", " ", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Print", "[", 
    RowBox[{"\"\<= \>\"", ",", 
     RowBox[{"u", "[", 
      RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], 
  " "}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.399381541546875*^9, 3.399381543078125*^9}, {
  3.399915404734375*^9, 3.39991540490625*^9}, {3.399964555921875*^9, 
  3.3999645628125*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"v", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "35"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<v[x,y] = \>\"", ",", 
      RowBox[{"Im", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<= \>\"", ",", 
      RowBox[{"v", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39938154559375*^9, 3.399381547296875*^9}, {
   3.399915409109375*^9, 3.3999154093125*^9}, 3.399964566640625*^9}]
}, Closed]],

Cell[TextData[{
 StyleBox["(ii).",
  FontColor->RGBColor[0, 0, 1]],
 "  If ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " has a pole of order",
 " ",
 StyleBox["k",
  FontFamily->"Courier"],
 " ",
 "at ",
 Cell[BoxData[
  RowBox[{"z", "=", "\[Alpha]"}]]],
 ", the Laurent series for ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " is \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", 
      RowBox[{"-", "k"}]}], "\[Infinity]"], 
    RowBox[{
     SubscriptBox["c", "n"], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "\[Alpha]"}], ")"}], "n"]}]}]}]]],
 "    valid for    ",
 Cell[BoxData[
  RowBox[{"z", "\[Element]", 
   RowBox[{"A", 
    RowBox[{"(", 
     RowBox[{"\[Alpha]", ",", "0", ",", "R"}], ")"}]}]}]]],
 ".  \n\nwhere  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["c", 
    RowBox[{"-", "k"}]], "\[NotEqual]", "0"}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 StyleBox["Extra Example 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 " The following example will help this concept.  Consider the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{"cot", " ", "z"}]}]]],
 ".  The leading term in the Laurent series expansion  ",
 StyleBox["S(z)",
  FontFamily->"Courier New"],
 "  is  ",
 Cell[BoxData[
  FractionBox["1", "z"]]],
 "  and  ",
 StyleBox["S(z)",
  FontFamily->"Courier New"],
 "  goes to ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Infinity]", "  ", "as", "  ", "z"}], "\[Rule]", "0"}]]],
 " in the same manner as  ",
 Cell[BoxData[
  RowBox[{"cot", " ", "z"}]]],
 ". "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "\t\t\t",
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15625 0.309017 0.0309017 [
[.00913 .29652 -8.3125 -12.5625 ]
[.00913 .29652 8.3125 0 ]
[.25456 .29652 -11.4063 -18.1875 ]
[.25456 .29652 11.4063 0 ]
[.74544 .29652 -8.09375 -18.1875 ]
[.74544 .29652 8.09375 0 ]
[.99087 .29652 -5 -12.5625 ]
[.99087 .29652 5 0 ]
[.4875 0 -18 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .15451 -12 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .46353 -6 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .61803 -12 -4.5 ]
[.4875 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.00913 .30902 m
.00913 .31527 L
s
gsave
.00913 .29652 -69.3125 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.625 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
1.000 setlinewidth
grestore
.25456 .30902 m
.25456 .31527 L
s
gsave
.25456 .29652 -72.4063 -22.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26.1875 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 15.125 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 9.313 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
71.375 15.125 moveto
(\\200\\200) show
75.625 15.125 moveto
(\\200) show
77.688 15.125 moveto
(\\200) show
72.688 21.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.74544 .30902 m
.74544 .31527 L
s
gsave
.74544 .29652 -69.0938 -22.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26.1875 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
66.063 9.313 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
64.750 15.125 moveto
(\\200\\200) show
69.000 15.125 moveto
(\\200) show
71.063 15.125 moveto
(\\200) show
66.063 21.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.99087 .30902 m
.99087 .31527 L
s
gsave
.99087 .29652 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
1.000 setlinewidth
grestore
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-10)] .4875 0 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-5)] .4875 .15451 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(5)] .4875 .46353 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(10)] .4875 .61803 1 0 Mshowa
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.51566 .61803 m
.51635 .60332 L
.51884 .5641 L
.52115 .53593 L
.52394 .50912 L
.52657 .48898 L
.53149 .46028 L
.53678 .43785 L
.54251 .41979 L
.55262 .39729 L
.55771 .38885 L
.5633 .38108 L
.57402 .3693 L
.58379 .36101 L
.60351 .34863 L
.62371 .33953 L
.64314 .33274 L
.66382 .32681 L
.68373 .3219 L
.70286 .31765 L
.72324 .31344 L
.74286 .30953 L
.76371 .30539 L
.7838 .30127 L
.80312 .29706 L
.82368 .2921 L
.84348 .28661 L
.86451 .27952 L
.88478 .27072 L
.90428 .25908 L
.91436 .25104 L
.92503 .24008 L
.93495 .2264 L
.94423 .20858 L
.94951 .19502 L
.95452 .17861 L
.95902 .15956 L
.96392 .13168 L
.9666 .11174 L
.96912 .08853 L
.97141 .06226 L
.97383 .02692 L
.97509 .00422 L
s
.97509 .00422 m
.97528 0 L
s
0 0 1 r
.51566 .61803 m
.51635 .60332 L
.51884 .5641 L
.52115 .53593 L
.52394 .50912 L
.52657 .48898 L
.53149 .46028 L
.53678 .43785 L
.54251 .41979 L
.55262 .39729 L
.55771 .38885 L
.5633 .38108 L
.57402 .3693 L
.58379 .36101 L
.60351 .34863 L
.62371 .33953 L
.64314 .33274 L
.66382 .32681 L
.68373 .3219 L
.70286 .31765 L
.72324 .31344 L
.74286 .30953 L
.76371 .30539 L
.7838 .30128 L
.80312 .29708 L
.82368 .29217 L
.84348 .28679 L
.86451 .28003 L
.88478 .27205 L
.90428 .26241 L
.92503 .24914 L
.945 .23215 L
.96421 .21023 L
.98437 .17887 L
s
1 0 0 r
.02476 .61803 m
.02516 .6091 L
.0277 .5678 L
.03039 .53473 L
.03521 .4924 L
.03774 .47587 L
.04046 .46104 L
.04538 .43982 L
.05122 .42093 L
.05657 .40764 L
.0662 .38983 L
.0767 .37596 L
.08668 .36608 L
.09731 .35783 L
.11839 .34576 L
.1387 .33732 L
.15824 .33091 L
.17903 .32524 L
.19905 .32048 L
.2183 .31632 L
.23879 .31215 L
.25852 .30824 L
.27948 .30405 L
.29968 .29984 L
.31912 .29547 L
.33979 .29026 L
.3597 .28439 L
.37883 .2775 L
.39921 .26795 L
.41883 .25498 L
.42899 .24577 L
.43968 .23298 L
.44452 .22567 L
.44969 .21638 L
.459 .19396 L
.4642 .17653 L
.46693 .1652 L
.46982 .151 L
.47236 .13619 L
.47514 .11644 L
.47765 .09442 L
.48004 .06843 L
.48226 .03805 L
s
.48226 .03805 m
.48439 0 L
s
0 0 1 r
.01563 .43916 m
.03521 .40857 L
.05657 .38436 L
.07663 .36769 L
.09593 .35551 L
.11646 .34544 L
.13623 .33774 L
.15724 .33104 L
.17748 .32557 L
.19696 .32093 L
.21767 .31644 L
.23762 .31238 L
.2568 .30857 L
.27723 .3045 L
.29688 .30044 L
.31778 .29578 L
.33791 .29077 L
.35727 .28516 L
.37788 .27788 L
.39772 .26875 L
.40784 .26284 L
.4188 .25501 L
.42938 .24537 L
.43911 .23378 L
.44865 .21839 L
.45407 .20694 L
.45913 .19359 L
.46443 .17564 L
.46944 .15301 L
.47395 .12538 L
.4765 .10514 L
.47885 .0821 L
.48116 .05394 L
.48365 .01471 L
s
.48365 .01471 m
.48435 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\
eJztm/lP1EAUx8tuFxCEXVgQRcQleF/BaDzibQz6i/GI0aiJul6BeHGpoHiC
4vWTiX+If+HamTd9nXa/U9sui6jdQHd25n0/783rdDptd8+Wp0buPSpPjd4p
l05PlMdGRu9MloafTDhV2QbLaihZlvWzZIlyxSmqTcX5qwyIjajxyu/FW06Y
ZEQpI0o/qGlevsk2WXL/2djK+tq+x5OpOJxPrt837mdN2UraWfFmCyM7CT4Q
6Wuzo0TRR8fPcWdtLilGQuI3NveCRXvnFUCsTBEpYrkjvmpNYcfI/4TQ07l8
EbMA0ZYigogvOkI12/VBvASI9vogVFOK+JOIz1qTi8klQ+hRLF/EC4DIE+IT
yEVjMoSlIOKVCGH7OuK8EvUFU+SaEmkLZCZX/HIpnYnYnRkzLJgRU1JDEAv6
rlVRZEw5icERn5oAYhogOgBCNf1diBzQrqgdawNtC2E/gqZmgH0eMdpFwKJo
W2vHZoFWrYg+GNPuxz6LGO0iYFG0arUwb0y7H/s0YrSLgEXRqql/zrg3f4/N
AG0+HnYqIlafXeHeRNicDysBTk0xHmoyYoRqenln3IMIiyPsotJbzbOLaweo
iRBUN5XOiTd5VtoBoHkAPcKKoRD8Kg0fACBHBZOjQF2Yyx4qnQey7caB47c7
Cup2wd3slFeTvwtAs9U4DPx2x4zpsX3+nFKvnlDbp3BeyGGnMadVcoPPtVpG
MyY3RVMeM4hMC5ZKH32Yce0qqwDlQWCgiP9+Ek6DQBBilBwIrd9YcYZ5MMuZ
sFmUBjioNYB4iO02gvDU3V00XaDbL7fAodAL7O4DV6i7yAed7Gl16PW0egyU
gY8+wLsrtlkvPVUgOq9XTUjidYN3h8xvP8Df5uyvA4AQNpouUD56tBHp9tP5
LwHTwxGRazkl680xy7k+50Valbcef3IGox++nv8BdtKkHbuBgLrAnpYuNwKX
wSmRI5VXQUNmLwU3lMrWiNgiY/dS3TnuTQvDdpnSIu3ynIkDhLjOFYEpfAhw
znIAh0h9hSsC6j1AfYZjpGndusgVAfV+oD4pto2i4hSp5YLzlDDREe5rlhuk
CV37wYXUQQZb7gMPajwBjPezMRrnx0Fdk9nzXlP/0d0UxN7D6UfXCiHR8ICo
oAXIbjrQnIqrZH6ABol75F0Cmp0cynXS7DMdRJeBejOn9SapvZ5dA+aD3HqP
zId4FN8A5iVuHSXznVxRBub93P2HZL6Nze8C8z42f0zmW7gisFuRupeNx0i9
yaS+D9TeCdg7cyvOBhNnBHB62JhW19agDlaGD4Cwm4V0maMtDh4D8yK30oWs
td4U5SOg7gS9VZz+YJNTGgOIDoCgtZK1DiDGAaIAEHT7R1sOeIgJgMgDBN0Z
08aDmo3cpMTkeGsPr8mpngKUdkChW54WLeFzfooKCqHaAIoeD6hlBUY9BaiV
AEXPftTKDqOeAVQrQNGTa3WV529yZ3Z9OKLOhmC7ImJRx1uA9g1hi6ApWzsW
HVcIi3K7AmjfEhYda3Z9sCja5wDbDLR03wEe1ijamFh0iObqg0XRTsfDoqkA
RYuwTUD7vq5YNNsg7Ew8bPfSIRoBYm7REF0A8aJ2hDwTyZsX6IkKunc+b4aN
q6GrIyz8jCUmGU3ZWRB6FawIYJNJ+2yEGRG1YbOm7KEb5B/MsJdLjugEiNkU
EYpAjyc+/mOIDoB4tWwR6AHHQor4ZxEFgHidIlJEPRHoa+AV9b2sVFZX2ROx
DfwuoTEZatwow79jyC6hm4y/1VPRF6vq/RuMgGyOQ/J+naB+DCLt1FNFq+EX
1maczQ==\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-3, -10, 0, 0}}],
 "   "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Explore ",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 StyleBox["Solution Extra Example 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "lim", ",", "S", ",", "z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"Cot", "[", "z", "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"S", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{"f", "[", "z", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", "0", ",", "13"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"lim", "=", 
     RowBox[{"Limit", "[", 
      RowBox[{
       RowBox[{"f", "[", "z", "]"}], ",", 
       RowBox[{"z", "\[Rule]", "0"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[z] = \>\"", ",", 
      RowBox[{"S", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"S", "[", "z", "]"}], ",", "\"\< - ...\>\""}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(lim\), \(z \[Rule] 0\)]\) \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\< = \>\"", ",", "lim"}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399381563421875*^9, 3.40026922196875*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "The Laurent series for f(z) involves only ",
 Cell[BoxData[
  FractionBox["1", "z"]]],
 " for negative powers of z. Hence, ",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{
    RowBox[{"f", "[", "z", "]"}], "=", 
    RowBox[{"Cot", "[", "z", "]"}]}]}]]],
 "  has a simple pole at the origin.\n\nWe can use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to investigate how well the Laurent series is \"converging\" for real \
numbers."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{
    RowBox[{"graph1", " ", "=", " ", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"f", "[", "z", "]"}], ",", 
         RowBox[{"S", "[", "z", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"z", ",", "0.01", ",", "3.1"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Red", ",", "Blue"}], "}"}]}]}], "]"}]}], ";"}], "  ", "\n", 
   
   RowBox[{
    RowBox[{"graph2", " ", "=", " ", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"f", "[", "z", "]"}], ",", 
         RowBox[{"S", "[", "z", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"z", ",", 
         RowBox[{"-", "3.1"}], ",", 
         RowBox[{"-", "0.01"}]}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Red", ",", "Blue"}], "}"}]}]}], "]"}]}], ";"}], "  ", "\n", 
   
   RowBox[{"Show", "[", 
    RowBox[{"graph1", ",", "graph2", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "3.2"}], ",", "3.2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "10"}], ",", "10"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "\[Pi]"}], ",", "\[Pi]", ",", 
          FractionBox["\[Pi]", "2"]}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "10"}], ",", "10", ",", "5"}], "]"}]}], "}"}]}]}], 
    "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<The function  f[x] = \>\"", ",", 
      RowBox[{"f", "[", "x", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<and series\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[x] = \>\"", ",", 
      RowBox[{"S", "[", "x", "]"}]}], "]"}], ";"}], " "}]}]], "Input",
 CellChangeTimes->{{3.3993815669375*^9, 3.399381569671875*^9}, {
  3.399915414296875*^9, 3.39991541446875*^9}, {3.400268729125*^9, 
  3.400268737671875*^9}}],

Cell[TextData[{
 "\nWe can use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to investigate the real and imaginary parts of  f[z] = Cot[z]  near the \
pole."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"u", ",", "v"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"u", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"Re", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", "+", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], "]"}]}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"v", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"Im", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", "+", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], "]"}]}], ";"}], 
   " ", "\n", 
   RowBox[{"Plot3D", "[", 
    RowBox[{
     RowBox[{"u", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "0.1"}], ",", "0.1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "0.1"}], ",", "0.1"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.1"}], ",", "0.1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.1"}], ",", "0.1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "30"}], ",", "60"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "40"}], ",", 
     RowBox[{"BoxRatios", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], ",", 
     RowBox[{"Mesh", "\[Rule]", "False"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<\>\""}], "}"}]}], ",",
      
     RowBox[{"ViewPoint", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "3"}], ",", "3", ",", "2"}], "}"}]}], ",", 
     RowBox[{"Boxed", "\[Rule]", "False"}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<u[x,y] = \>\"", ",", 
      RowBox[{"Re", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<       = \>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399381572578125*^9, 3.399381579921875*^9}, {
   3.399915418921875*^9, 3.399915419078125*^9}, 3.39996458915625*^9, {
   3.4002691664375*^9, 3.400269170578125*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Plot3D", "[", 
    RowBox[{
     RowBox[{"v", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "0.1"}], ",", "0.1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "0.1"}], ",", "0.1"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.1"}], ",", "0.1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.1"}], ",", "0.1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "30"}], ",", "60"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "40"}], ",", 
     RowBox[{"BoxRatios", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], ",", 
     RowBox[{"Mesh", "\[Rule]", "False"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<\>\""}], "}"}]}], ",",
      
     RowBox[{"ViewPoint", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "3"}], ",", "3", ",", "2"}], "}"}]}], ",", 
     RowBox[{"Boxed", "\[Rule]", "False"}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<v[x,y] = \>\"", ",", 
      RowBox[{"Im", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<       = \>\"", ",", 
      RowBox[{"v", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39938158365625*^9, 3.399381589125*^9}, {
   3.39991542428125*^9, 3.399915424484375*^9}, 3.39996459578125*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Plot3D", "[", 
    RowBox[{
     RowBox[{"Re", "[", 
      RowBox[{"f", "[", 
       RowBox[{"x", " ", "+", " ", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"31", ",", "31"}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "5"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<\>\""}], "}"}]}], ",",
      
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<u[x,y] = \>\"", ",", 
      RowBox[{"Re", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<       = \>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399381592140625*^9, 3.3993815945*^9}, {
  3.399915429546875*^9, 3.399915429734375*^9}, {3.399964601171875*^9, 
  3.399964602390625*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Plot3D", "[", 
    RowBox[{
     RowBox[{"Im", "[", 
      RowBox[{"f", "[", 
       RowBox[{"x", " ", "+", " ", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"31", ",", "31"}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "5"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<\>\""}], "}"}]}], ",",
      
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<v[x,y] = \>\"", ",", 
      RowBox[{"Im", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<       = \>\"", ",", 
      RowBox[{"v", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39938159778125*^9, 3.399381598953125*^9}, {
  3.399915433765625*^9, 3.39991543396875*^9}, {3.39996460609375*^9, 
  3.399964607078125*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"g1", "=", 
     RowBox[{"ContourPlot", "[", 
      RowBox[{
       RowBox[{"u", "[", 
        RowBox[{"x", ",", "y"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "1"}], ",", 
         RowBox[{"-", "0.00001"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", 
         RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
       RowBox[{"PlotPoints", "\[Rule]", "35"}], ",", 
       RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g2", "=", 
     RowBox[{"ContourPlot", "[", 
      RowBox[{
       RowBox[{"u", "[", 
        RowBox[{"x", ",", "y"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "0.00001", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", 
         RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
       RowBox[{"PlotPoints", "\[Rule]", "35"}], ",", 
       RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"g1", ",", "g2", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}]}], "]"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<u[x,y] = \>\"", ",", 
      RowBox[{"Re", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<       = \>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39938160171875*^9, 3.399381688953125*^9}, {
  3.3999154385*^9, 3.399915438671875*^9}, {3.39996461065625*^9, 
  3.39996461303125*^9}, {3.400268748*^9, 3.400268761359375*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"g1", "=", 
     RowBox[{"ContourPlot", "[", 
      RowBox[{
       RowBox[{"v", "[", 
        RowBox[{"x", ",", "y"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", 
         RowBox[{"-", "1"}], ",", 
         RowBox[{"-", "0.00001"}]}], "}"}], ",", 
       RowBox[{"PlotPoints", "\[Rule]", "35"}], ",", 
       RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g2", "=", 
     RowBox[{"ContourPlot", "[", 
      RowBox[{
       RowBox[{"v", "[", 
        RowBox[{"x", ",", "y"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", "0.00001", ",", "1"}], "}"}], ",", 
       RowBox[{"PlotPoints", "\[Rule]", "35"}], ",", 
       RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"g1", ",", "g2", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}]}], "]"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<v[x,y] = \>\"", ",", 
      RowBox[{"Im", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<       = \>\"", ",", 
      RowBox[{"v", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3993817006875*^9, 3.39938171840625*^9}, {
  3.399915444671875*^9, 3.399915444859375*^9}, {3.39996461821875*^9, 
  3.399964619203125*^9}, {3.40026877225*^9, 3.400268782140625*^9}}]
}, Closed]],

Cell[TextData[{
 "\tFor example,  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
    FractionBox[
     RowBox[{"sin", 
      RowBox[{"(", "z", ")"}]}], 
     SuperscriptBox["z", "3"]]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"            ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      FractionBox["1", 
       SuperscriptBox["z", "3"]], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"z", "-", 
         FractionBox[
          SuperscriptBox["z", "3"], 
          RowBox[{"3", "!"}]], "+", 
         FractionBox[
          SuperscriptBox["z", "5"], 
          RowBox[{"5", "!"}]], "-", 
         FractionBox[
          SuperscriptBox["z", "7"], 
          RowBox[{"7", "!"}]], "+", 
         FractionBox[
          SuperscriptBox["z", "9"], 
          RowBox[{"9", "!"}]], "-", 
         FractionBox[
          SuperscriptBox["z", "11"], 
          RowBox[{"11", "!"}]], "+"}], "..."}], ")"}]}]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"            ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{
      FractionBox["1", 
       SuperscriptBox["z", "2"]], "-", 
      FractionBox["1", 
       RowBox[{"3", "!"}]], "+", 
      FractionBox[
       SuperscriptBox["z", "2"], 
       RowBox[{"5", "!"}]], "-", 
      FractionBox[
       SuperscriptBox["z", "4"], 
       RowBox[{"7", "!"}]], "+", 
      FractionBox[
       SuperscriptBox["z", "6"], 
       RowBox[{"9", "!"}]], "-", 
      FractionBox[
       SuperscriptBox["z", "10"], 
       RowBox[{"11", "!"}]], "+"}], "..."}]}]}]}],
  AspectRatioFixed->True],
 "  \n\nhas a pole of order  ",
 Cell[BoxData[
  RowBox[{"k", "=", "2"}]]],
 "  at  ",
 Cell[BoxData[
  RowBox[{"z", "=", "0"}]]],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration 3.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "Enter the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], "=", 
   FractionBox[
    RowBox[{"Sin", "[", "z", "]"}], 
    SuperscriptBox["z", "3"]]}]]],
 " and find the first few terms of the Laurent series in the punctured plane  \
",
 Cell[BoxData[
  RowBox[{"0", "<", "z"}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "lim", ",", "S", ",", "z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", 
     FractionBox[
      RowBox[{"Sin", "[", "z", "]"}], 
      SuperscriptBox["z", "3"]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"S", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{"f", "[", "z", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", "0", ",", "11"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"lim", "=", 
     RowBox[{"Limit", "[", 
      RowBox[{
       RowBox[{"f", "[", "z", "]"}], ",", 
       RowBox[{"z", "\[Rule]", "0"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[z] = \>\"", ",", 
      RowBox[{"S", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      FractionBox["1", 
       SuperscriptBox["z", "2"]], ",", 
      RowBox[{
       RowBox[{"S", "[", "z", "]"}], "-", 
       FractionBox["1", 
        SuperscriptBox["z", "2"]]}], ",", "\"\< - ...\>\""}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(lim\), \(z \[Rule] 0\)]\) \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\< = \>\"", ",", "lim"}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{
  3.399381735046875*^9, {3.400269227296875*^9, 3.4002692296875*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "The Laurent series for f(z) contains terms down to  ",
 Cell[BoxData[
  FractionBox["1", 
   SuperscriptBox["z", "2"]]]],
 "  for negative powers of z. Hence, ",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{
    RowBox[{"f", "[", "z", "]"}], "=", 
    FractionBox[
     RowBox[{"Sin", "[", "z", "]"}], 
     SuperscriptBox["z", "3"]]}]}]]],
 " has a pole of order 2 at the origin.\n\nWe can use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to investigate how well the Laurent series is \"converging\" for real \
numbers."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"f", "[", "x", "]"}], ",", 
       RowBox[{"S", "[", "x", "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "10"}], ",", "10"}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Red", ",", "Blue"}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "10"}], ",", "10"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "10"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "10"}], ",", "10", ",", "2"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "10", ",", "5"}], "]"}]}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<The function  f[x] = \>\"", ",", 
      RowBox[{"f", "[", "x", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<and series\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[x] = \>\"", ",", 
      RowBox[{"S", "[", "x", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399381738890625*^9, 3.399381740859375*^9}, {
  3.39991544928125*^9, 3.3999154495625*^9}, {3.3999646299375*^9, 
  3.399964630734375*^9}}],

Cell[TextData[{
 "\nWe can use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to investigate the real and imaginary parts of  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], "=", 
   FractionBox[
    RowBox[{"Sin", "[", "z", "]"}], 
    SuperscriptBox["z", "3"]]}]]],
 " near the removable singularity."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"u", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], "=", 
     RowBox[{"FullSimplify", "[", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{
        RowBox[{"Re", "[", 
         RowBox[{"f", "[", 
          RowBox[{"x", "+", 
           RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], ",", 
        RowBox[{"TargetFunctions", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"Im", ",", "Re"}], "}"}]}]}], "]"}], "]"}]}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"v", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], "=", 
     RowBox[{"FullSimplify", "[", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{
        RowBox[{"Im", "[", 
         RowBox[{"f", "[", 
          RowBox[{"x", "+", 
           RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], ",", 
        RowBox[{"TargetFunctions", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"Im", ",", "Re"}], "}"}]}]}], "]"}], "]"}]}], ";"}], " ", 
   "\n", 
   RowBox[{"Plot3D", "[", 
    RowBox[{
     RowBox[{"u", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "0.1"}], ",", "0.1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "0.1"}], ",", "0.1"}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "40"}], ",", 
     RowBox[{"BoxRatios", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], ",", 
     RowBox[{"Mesh", "\[Rule]", "False"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<\>\""}], "}"}]}], ",",
      
     RowBox[{"ViewPoint", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "3"}], ",", "3", ",", "2"}], "}"}]}], ",", 
     RowBox[{"Boxed", "\[Rule]", "False"}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<u[x,y] = \>\"", ",", 
      RowBox[{"Re", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<= \>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399381743984375*^9, 3.399381750125*^9}, {
   3.399915454078125*^9, 3.399915454265625*^9}, 3.39996463628125*^9, {
   3.40026896453125*^9, 3.400268965046875*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Plot3D", "[", 
    RowBox[{
     RowBox[{"v", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "0.1"}], ",", "0.1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "0.1"}], ",", "0.1"}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "40"}], ",", 
     RowBox[{"BoxRatios", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], ",", 
     RowBox[{"Mesh", "\[Rule]", "False"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<\>\""}], "}"}]}], ",",
      
     RowBox[{"ViewPoint", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "3"}], ",", "3", ",", "2"}], "}"}]}], ",", 
     RowBox[{"Boxed", "\[Rule]", "False"}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<v[x,y] = \>\"", ",", 
      RowBox[{"Im", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<= \>\"", ",", 
      RowBox[{"v", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39938175503125*^9, 3.39938175965625*^9}, {
  3.399964640703125*^9, 3.399964649671875*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Plot3D", "[", 
    RowBox[{
     RowBox[{"u", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"31", ",", "31"}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "15"}], ",", "20"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<\>\""}], "}"}]}], ",",
      
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<u[x,y] = \>\"", ",", 
      RowBox[{"Re", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<= \>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399381764109375*^9, 3.399381769*^9}, {3.3999646565*^9, 
  3.39996466165625*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Plot3D", "[", 
    RowBox[{
     RowBox[{"v", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"31", ",", "31"}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "15"}], ",", "20"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<\>\""}], "}"}]}], ",",
      
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<v[x,y] = \>\"", ",", 
      RowBox[{"Im", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<= \>\"", ",", 
      RowBox[{"v", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39938177303125*^9, 3.3993817745*^9}, {
  3.3999646679375*^9, 3.3999646708125*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"u", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "55"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<u[x,y] = \>\"", ",", 
      RowBox[{"Re", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<= \>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399381777484375*^9, 3.399381778734375*^9}, {
  3.399964676546875*^9, 3.399964677890625*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"v", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "54"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<v[x,y] = \>\"", ",", 
      RowBox[{"Im", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<= \>\"", ",", 
      RowBox[{"v", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3993817829375*^9, 3.39938178440625*^9}, {
  3.39996468465625*^9, 3.399964686484375*^9}}]
}, Closed]],

Cell[TextData[{
 "\tIf ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " has a pole of order ",
 StyleBox["1",
  FontFamily->"Courier New"],
 " at ",
 Cell[BoxData[
  RowBox[{"z", "=", "\[Alpha]"}]]],
 ", we say that ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " has a simple pole at ",
 Cell[BoxData[
  RowBox[{"z", "=", "\[Alpha]"}]]],
 ".   "
}], "Text"],

Cell[TextData[{
 "\tFor example,  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"g", 
     RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      FractionBox["1", "z"], 
      SuperscriptBox["\[ExponentialE]", "z"]}], "  ", "=", "  ", 
     RowBox[{
      FractionBox["1", "z"], " ", 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"n", "=", "0"}], "\[Infinity]"], 
       RowBox[{
        FractionBox["1", 
         RowBox[{"n", "!"}]], 
        SuperscriptBox["z", "n"]}]}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"            ", 
   RowBox[{"=", "  ", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", "0"}], "\[Infinity]"], 
     RowBox[{
      FractionBox["1", 
       RowBox[{"n", "!"}]], 
      SuperscriptBox["z", 
       RowBox[{"n", "-", "1"}]]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"            ", 
   RowBox[{"=", " ", 
    RowBox[{
     RowBox[{
      FractionBox["1", "z"], "+", "1", "+", 
      FractionBox["z", 
       RowBox[{"2", "!"}]], "+", 
      FractionBox[
       SuperscriptBox["z", "2"], 
       RowBox[{"3", "!"}]], "+", 
      FractionBox[
       SuperscriptBox["z", "3"], 
       RowBox[{"4", "!"}]], "+", 
      FractionBox[
       SuperscriptBox["z", "4"], 
       RowBox[{"5", "!"}]], "+", 
      FractionBox[
       SuperscriptBox["z", "5"], 
       RowBox[{"6", "!"}]], "+"}], "..."}]}]}]}]],
 "  \n\nhas a simple pole at  ",
 Cell[BoxData[
  RowBox[{"z", "=", "0"}]]],
 ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration 4.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "Enter the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], "=", 
   FractionBox[
    SuperscriptBox["\[ExponentialE]", "z"], "z"]}]]],
 " and find the first few terms of the Laurent series in the punctured plane  \
",
 Cell[BoxData[
  RowBox[{"0", "<", "z"}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "lim", ",", "S", ",", "z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox[
      SuperscriptBox["\[ExponentialE]", "z"], "z"]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"S", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{"f", "[", "z", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", "0", ",", "8"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"lim", "=", 
     RowBox[{"Limit", "[", 
      RowBox[{
       RowBox[{"f", "[", "z", "]"}], ",", 
       RowBox[{"z", "\[Rule]", "0"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[z] = \>\"", ",", 
      RowBox[{"S", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"S", "[", "z", "]"}], ",", "\"\< + ...\>\""}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(lim\), \(z \[Rule] 0\)]\) \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\< = \>\"", ",", "lim"}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{
  3.399381799171875*^9, {3.400269235390625*^9, 3.400269237703125*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "The Laurent series for f(z) involves only ",
 Cell[BoxData[
  FractionBox["1", "z"]]],
 " for negative powers of z. Hence, ",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{
    RowBox[{"f", "[", "z", "]"}], "=", 
    FractionBox[
     SuperscriptBox["\[ExponentialE]", "z"], "z"]}]}]]],
 " has a simple pole at the origin.\n\nWe can use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to investigate how well the Laurent series is \"converging\" for real \
numbers."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{
    RowBox[{"graph1", " ", "=", " ", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"f", "[", "z", "]"}], ",", 
         RowBox[{"S", "[", "z", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"z", ",", "0.01", ",", "6.1"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Red", ",", "Blue"}], "}"}]}]}], "]"}]}], ";"}], "  ", "\n", 
   
   RowBox[{
    RowBox[{"graph2", " ", "=", " ", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"f", "[", "z", "]"}], ",", 
         RowBox[{"S", "[", "z", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"z", ",", 
         RowBox[{"-", "6.1"}], ",", 
         RowBox[{"-", "0.01"}]}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Red", ",", "Blue"}], "}"}]}]}], "]"}]}], ";"}], "  ", "\n", 
   
   RowBox[{"Show", "[", 
    RowBox[{"graph1", ",", "graph2", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "6.1"}], ",", "6.1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "20"}], ",", "50"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "6"}], ",", "6", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "20"}], ",", "50", ",", "10"}], "]"}]}], "}"}]}]}], 
    "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<The function  f[x] = \>\"", ",", 
      RowBox[{"f", "[", "x", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<and series\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[x] = \>\"", ",", 
      RowBox[{"S", "[", "x", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399381802140625*^9, 3.39938180396875*^9}, {
  3.399965205375*^9, 3.3999652055625*^9}, {3.400268790203125*^9, 
  3.400268799703125*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "We can use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to investigate the real and imaginary parts of  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], "=", 
   FractionBox[
    SuperscriptBox["\[ExponentialE]", "z"], "z"]}]],
  AspectRatioFixed->True],
 "  near the pole."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"u", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], "=", 
     RowBox[{"FullSimplify", "[", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{
        RowBox[{"Re", "[", 
         RowBox[{"f", "[", 
          RowBox[{"x", "+", 
           RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], ",", 
        RowBox[{"TargetFunctions", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"Im", ",", "Re"}], "}"}]}]}], "]"}], "]"}]}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"v", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], "=", 
     RowBox[{"FullSimplify", "[", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{
        RowBox[{"Im", "[", 
         RowBox[{"f", "[", 
          RowBox[{"x", "+", 
           RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], ",", 
        RowBox[{"TargetFunctions", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"Im", ",", "Re"}], "}"}]}]}], "]"}], "]"}]}], ";"}], " ", 
   "\n", 
   RowBox[{"Plot3D", "[", 
    RowBox[{
     RowBox[{"u", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "0.1"}], ",", "0.1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "0.1"}], ",", "0.1"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.1"}], ",", "0.1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.1"}], ",", "0.1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "30"}], ",", "60"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "40"}], ",", 
     RowBox[{"BoxRatios", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], ",", 
     RowBox[{"Mesh", "\[Rule]", "False"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<\>\""}], "}"}]}], ",",
      
     RowBox[{"ViewPoint", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "3"}], ",", "3", ",", "2"}], "}"}]}], ",", 
     RowBox[{"Boxed", "\[Rule]", "False"}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<u[x,y] = \>\"", ",", 
      RowBox[{"Re", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<       = \>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3993818104375*^9, 3.399381811734375*^9}, 
   3.39996521153125*^9, {3.4002689756875*^9, 3.400268988859375*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Plot3D", "[", 
    RowBox[{
     RowBox[{"v", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "0.1"}], ",", "0.1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "0.1"}], ",", "0.1"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.1"}], ",", "0.1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.1"}], ",", "0.1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "30"}], ",", "60"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "40"}], ",", 
     RowBox[{"BoxRatios", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], ",", 
     RowBox[{"Mesh", "\[Rule]", "False"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<\>\""}], "}"}]}], ",",
      
     RowBox[{"ViewPoint", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "3"}], ",", "3", ",", "2"}], "}"}]}], ",", 
     RowBox[{"Boxed", "\[Rule]", "False"}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<v[x,y] = \>\"", ",", 
      RowBox[{"Im", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<       = \>\"", ",", 
      RowBox[{"v", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39938181715625*^9, 3.3993818235625*^9}, 
   3.39996521765625*^9, 3.40026899296875*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Plot3D", "[", 
    RowBox[{
     RowBox[{"u", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"31", ",", "31"}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "5"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<\>\""}], "}"}]}], ",",
      
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<u[x,y] = \>\"", ",", 
      RowBox[{"Re", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<       = \>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399381826734375*^9, 3.39938182846875*^9}, 
   3.39996522359375*^9, {3.400268998421875*^9, 3.400268999328125*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Plot3D", "[", 
    RowBox[{
     RowBox[{"v", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"31", ",", "31"}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "5"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<\>\""}], "}"}]}], ",",
      
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<v[x,y] = \>\"", ",", 
      RowBox[{"Im", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<       = \>\"", ",", 
      RowBox[{"v", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399381831703125*^9, 3.399381832796875*^9}, 
   3.399965228328125*^9, {3.400269001875*^9, 3.400269002734375*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"g1", "=", 
     RowBox[{"ContourPlot", "[", 
      RowBox[{
       RowBox[{"u", "[", 
        RowBox[{"x", ",", "y"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "1"}], ",", 
         RowBox[{"-", "0.00001"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", 
         RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
       RowBox[{"PlotPoints", "\[Rule]", "35"}], ",", 
       RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g2", "=", 
     RowBox[{"ContourPlot", "[", 
      RowBox[{
       RowBox[{"u", "[", 
        RowBox[{"x", ",", "y"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "0.00001", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", 
         RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
       RowBox[{"PlotPoints", "\[Rule]", "35"}], ",", 
       RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"g1", ",", "g2", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}]}], "]"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<u[x,y] = \>\"", ",", 
      RowBox[{"Re", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<       = \>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399381835984375*^9, 3.399381854875*^9}, 
   3.399965232421875*^9, {3.400268805796875*^9, 3.40026881653125*^9}, {
   3.400269005765625*^9, 3.40026900740625*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"g1", "=", 
     RowBox[{"ContourPlot", "[", 
      RowBox[{
       RowBox[{"v", "[", 
        RowBox[{"x", ",", "y"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", 
         RowBox[{"-", "1"}], ",", 
         RowBox[{"-", "0.00001"}]}], "}"}], ",", 
       RowBox[{"PlotPoints", "\[Rule]", "35"}], ",", 
       RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g2", "=", 
     RowBox[{"ContourPlot", "[", 
      RowBox[{
       RowBox[{"v", "[", 
        RowBox[{"x", ",", "y"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", "0.00001", ",", "1"}], "}"}], ",", 
       RowBox[{"PlotPoints", "\[Rule]", "35"}], ",", 
       RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"g1", ",", "g2", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}]}], "]"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<u[x,y] = \>\"", ",", 
      RowBox[{"Im", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<       = \>\"", ",", 
      RowBox[{"v", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3993818654375*^9, 3.39938187328125*^9}, 
   3.39996523728125*^9, {3.40026881928125*^9, 3.4002688276875*^9}, {
   3.400269009875*^9, 3.400269010796875*^9}}]
}, Closed]],

Cell[TextData[{
 StyleBox["(iii).",
  FontColor->RGBColor[0, 0, 1]],
 "  If infinitely many negative powers of ",
 Cell[BoxData[
  RowBox[{"(", 
   RowBox[{"z", "-", "\[Alpha]"}], ")"}]]],
 " occur in the Laurent series, then",
 " ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " ",
 "has an essential singularity at ",
 Cell[BoxData[
  RowBox[{"z", "=", "\[Alpha]"}]]],
 ".  For example,  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
    RowBox[{
     SuperscriptBox["z", "2"], "sin", 
     RowBox[{"(", 
      FractionBox["1", "z"], ")"}]}]}], "\[IndentingNewLine]"}], "\n", 
  RowBox[{"          ", 
   RowBox[{"=", "  ", 
    RowBox[{
     SuperscriptBox["z", "2"], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        FractionBox["1", "z"], "-", 
        FractionBox[
         SuperscriptBox[
          RowBox[{"(", 
           FractionBox["1", "z"], ")"}], "3"], 
         RowBox[{"3", "!"}]], "+", 
        FractionBox[
         SuperscriptBox[
          RowBox[{"(", 
           FractionBox["1", "z"], ")"}], "5"], 
         RowBox[{"5", "!"}]], "-", 
        FractionBox[
         SuperscriptBox[
          RowBox[{"(", 
           FractionBox["1", "z"], ")"}], "7"], 
         RowBox[{"7", "!"}]], "+", 
        FractionBox[
         SuperscriptBox[
          RowBox[{"(", 
           FractionBox["1", "z"], ")"}], "9"], 
         RowBox[{"9", "!"}]], "-", 
        FractionBox[
         SuperscriptBox[
          RowBox[{"(", 
           FractionBox["1", "z"], ")"}], "11"], 
         RowBox[{"11", "!"}]], "+"}], "..."}], ")"}]}]}], 
   "\n"}], "\[IndentingNewLine]", 
  RowBox[{"          ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{"z", "-", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"3", "!"}]], 
       SuperscriptBox["z", 
        RowBox[{"-", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"5", "!"}]], 
       SuperscriptBox["z", "3"]}], "-", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"7", "!"}]], 
       SuperscriptBox["z", 
        RowBox[{"-", "5"}]]}], "+", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"9", "!"}]], 
       SuperscriptBox["z", 
        RowBox[{"-", "7"}]]}], "-", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"11", "!"}]], 
       SuperscriptBox["z", 
        RowBox[{"-", "9"}]]}], "+"}], "..."}]}]}]}],
  AspectRatioFixed->True],
 "  \n\nhas an essential singularity at the origin.  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration 5.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "Enter the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], "=", 
   RowBox[{
    SuperscriptBox["z", "2"], " ", 
    RowBox[{"Sin", "[", 
     FractionBox["1", "z"], "]"}]}]}]]],
 " and find the first few terms of the Laurent series in the punctured plane  \
",
 Cell[BoxData[
  RowBox[{
   RowBox[{"0", "<"}], "|", "z", "|"}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"g", ",", "h", ",", "p", ",", "S", ",", "z"}], "]"}], ";"}], " ",
    "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"g", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"Sin", "[", "z", "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"S", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{"Sin", "[", "z", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", "0", ",", "17"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"h", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"S", "[", 
      FractionBox["1", "z"], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{
      SuperscriptBox["z", "2"], " ", 
      RowBox[{"g", "[", 
       FractionBox["1", "z"], "]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"p", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"Simplify", "[", 
      RowBox[{
       SuperscriptBox["z", "2"], " ", 
       RowBox[{"h", "[", "z", "]"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"lim0", "=", 
     RowBox[{"Limit", "[", 
      RowBox[{
       RowBox[{"f", "[", "z", "]"}], ",", 
       RowBox[{"z", "\[Rule]", "0"}], ",", 
       RowBox[{"Direction", "\[Rule]", 
        RowBox[{"-", "1"}]}]}], "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"lim1", "=", 
     RowBox[{"Limit", "[", 
      RowBox[{
       RowBox[{"f", "[", "z", "]"}], ",", 
       RowBox[{"z", "\[Rule]", "0"}], ",", 
       RowBox[{"Direction", "\[Rule]", 
        RowBox[{"-", "\[ImaginaryI]"}]}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"lim2", "=", 
     RowBox[{"Limit", "[", 
      RowBox[{
       RowBox[{"f", "[", "z", "]"}], ",", 
       RowBox[{"z", "\[Rule]", "0"}], ",", 
       RowBox[{"Direction", "\[Rule]", "1"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"lim3", "=", 
     RowBox[{"Limit", "[", 
      RowBox[{
       RowBox[{"f", "[", "z", "]"}], ",", 
       RowBox[{"z", "\[Rule]", "0"}], ",", 
       RowBox[{"Direction", "\[Rule]", "\[ImaginaryI]"}]}], "]"}]}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<p[z] = \>\"", ",", 
      RowBox[{"p", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = ... + \>\"", ",", 
      RowBox[{"p", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(lim\), \(z \[Rule] \*SuperscriptBox[\(0\), \
\(+\)]\)]\) \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\< = \>\"", ",", "lim0"}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(lim\), \(z \[Rule] \*SuperscriptBox[\(\
\[ImaginaryI]0\), \(+\)]\)]\) \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\< = \>\"", ",", "lim1"}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(lim\), \(z \[Rule] \*SuperscriptBox[\(0\), \
\(-\)]\)]\) \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\< = \>\"", ",", "lim2"}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(lim\), \(z \[Rule] \*SuperscriptBox[\(\
\[ImaginaryI]0\), \(-\)]\)]\) \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\< = \>\"", ",", "lim3"}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{
  3.3993818904375*^9, {3.40026924259375*^9, 3.4002692448125*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "The Laurent series for f(z) has \"infinitely many\" negative powers of z. \
Hence, ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    SuperscriptBox["z", "2"], " ", "sin", 
    RowBox[{"(", 
     FractionBox["1", "z"], ")"}]}]}]]],
 " has an essential singularity at the origin. \n\nWe can use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to investigate how well the Laurent series is \"converging\" for real \
numbers."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{
    RowBox[{"graph1", " ", "=", " ", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"f", "[", "z", "]"}], ",", 
         RowBox[{"p", "[", "z", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"z", ",", "0.0001", ",", "0.5"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Red", ",", "Blue"}], "}"}]}]}], "]"}]}], ";"}], "  ", "\n", 
   
   RowBox[{
    RowBox[{"graph2", " ", "=", " ", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"f", "[", "z", "]"}], ",", 
         RowBox[{"p", "[", "z", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"z", ",", 
         RowBox[{"-", "0.5"}], ",", 
         RowBox[{"-", "0.0001"}]}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Red", ",", "Blue"}], "}"}]}]}], "]"}]}], ";"}], "  ", "\n", 
   
   RowBox[{"Show", "[", 
    RowBox[{"graph1", ",", "graph2", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.5"}], ",", "0.5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.1"}], ",", "0.1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "0.5"}], ",", "0.5", ",", "0.5"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "0.1"}], ",", "0.1", ",", "0.1"}], "]"}]}], "}"}]}]}], 
    "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<The function  f[x] = \>\"", ",", 
      RowBox[{"f", "[", "x", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<and series\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[x] = \>\"", ",", 
      RowBox[{"p", "[", "x", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39938189471875*^9, 3.39938189671875*^9}, 
   3.399965241984375*^9, {3.400268835609375*^9, 3.400268846046875*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "We can use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to investigate the real and imaginary parts of  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], "=", 
   FractionBox[
    SuperscriptBox["\[ExponentialE]", "z"], "z"]}]],
  AspectRatioFixed->True],
 "  near the pole."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"u", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], "=", 
     RowBox[{"FullSimplify", "[", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{
        RowBox[{"Re", "[", 
         RowBox[{"f", "[", 
          RowBox[{"x", "+", 
           RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], ",", 
        RowBox[{"TargetFunctions", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"Im", ",", "Re"}], "}"}]}]}], "]"}], "]"}]}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"v", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], "=", 
     RowBox[{"FullSimplify", "[", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{
        RowBox[{"Im", "[", 
         RowBox[{"f", "[", 
          RowBox[{"x", "+", 
           RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], ",", 
        RowBox[{"TargetFunctions", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"Im", ",", "Re"}], "}"}]}]}], "]"}], "]"}]}], ";"}], " ", 
   "\n", 
   RowBox[{"Plot3D", "[", 
    RowBox[{
     RowBox[{"u", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "0.1"}], ",", "0.1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "0.1"}], ",", "0.1"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.1"}], ",", "0.1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.1"}], ",", "0.1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "30"}], ",", "60"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "40"}], ",", 
     RowBox[{"BoxRatios", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], ",", 
     RowBox[{"Mesh", "\[Rule]", "False"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<\>\""}], "}"}]}], ",",
      
     RowBox[{"ViewPoint", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "3"}], ",", "3", ",", "2"}], "}"}]}], ",", 
     RowBox[{"Boxed", "\[Rule]", "False"}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<u[x,y] = \>\"", ",", 
      RowBox[{"Re", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<= \>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3993818994375*^9, 3.399381904203125*^9}, 
   3.3999652464375*^9, 3.4002689029375*^9, 3.4002690198125*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Plot3D", "[", 
    RowBox[{
     RowBox[{"v", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "0.1"}], ",", "0.1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "0.1"}], ",", "0.1"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.1"}], ",", "0.1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.1"}], ",", "0.1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "30"}], ",", "60"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "40"}], ",", 
     RowBox[{"BoxRatios", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], ",", 
     RowBox[{"Mesh", "\[Rule]", "False"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<\>\""}], "}"}]}], ",",
      
     RowBox[{"ViewPoint", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "3"}], ",", "3", ",", "2"}], "}"}]}], ",", 
     RowBox[{"Boxed", "\[Rule]", "False"}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<v[x,y] = \>\"", ",", 
      RowBox[{"Im", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<= \>\"", ",", 
      RowBox[{"v", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399381912171875*^9, 3.39938191771875*^9}, 
   3.39996525240625*^9, {3.4002689078125*^9, 3.40026891209375*^9}, {
   3.400269025515625*^9, 3.400269027296875*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Plot3D", "[", 
    RowBox[{
     RowBox[{"Re", "[", 
      RowBox[{"f", "[", 
       RowBox[{"x", " ", "+", " ", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "0.1"}], ",", "0.099999"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "0.1"}], ",", "0.099999"}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"41", ",", "41"}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.1"}], ",", "0.1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.1"}], ",", "0.1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "5"}], ",", "5"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<\>\""}], "}"}]}], ",",
      
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<u[x,y] = \>\"", ",", 
      RowBox[{"Re", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<= \>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3993819223125*^9, 3.399381925640625*^9}, 
   3.39996525675*^9, {3.400268916703125*^9, 3.400268924609375*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Plot3D", "[", 
    RowBox[{
     RowBox[{"Im", "[", 
      RowBox[{"f", "[", 
       RowBox[{"x", " ", "+", " ", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "0.1"}], ",", "0.099999"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "0.1"}], ",", "0.099999"}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"41", ",", "41"}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.1"}], ",", "0.1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.1"}], ",", "0.1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "5"}], ",", "5"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<\>\""}], "}"}]}], ",",
      
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<v[x,y] = \>\"", ",", 
      RowBox[{"Im", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<= \>\"", ",", 
      RowBox[{"v", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399381933171875*^9, 3.399381934796875*^9}, 
   3.3999652608125*^9, {3.400268929078125*^9, 3.400268931734375*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"g1", "=", 
     RowBox[{"ContourPlot", "[", 
      RowBox[{
       RowBox[{"u", "[", 
        RowBox[{"x", ",", "y"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "0.5"}], ",", 
         RowBox[{"-", "0.00001"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", 
         RowBox[{"-", "0.5"}], ",", "0.5"}], "}"}], ",", 
       RowBox[{"PlotPoints", "\[Rule]", "55"}], ",", 
       RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g2", "=", 
     RowBox[{"ContourPlot", "[", 
      RowBox[{
       RowBox[{"Re", "[", 
        RowBox[{"f", "[", 
         RowBox[{"x", " ", "+", " ", 
          RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "0.00001", ",", "0.5"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", 
         RowBox[{"-", "0.5"}], ",", "0.5"}], "}"}], ",", 
       RowBox[{"PlotPoints", "\[Rule]", "55"}], ",", 
       RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"g1", ",", "g2", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.52"}], ",", "0.52"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.52"}], ",", "0.52"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}]}], "]"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<u[x,y] = \>\"", ",", 
      RowBox[{"Re", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<= \>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3993819433125*^9, 3.399381955625*^9}, 
   3.399965266828125*^9, {3.40026885359375*^9, 3.400268869265625*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"g1", "=", 
     RowBox[{"ContourPlot", "[", 
      RowBox[{
       RowBox[{"v", "[", 
        RowBox[{"x", ",", "y"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "0.5"}], ",", 
         RowBox[{"-", "0.00001"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", 
         RowBox[{"-", "0.5"}], ",", "0.5"}], "}"}], ",", 
       RowBox[{"PlotPoints", "\[Rule]", "55"}], ",", 
       RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g2", "=", 
     RowBox[{"ContourPlot", "[", 
      RowBox[{
       RowBox[{"Im", "[", 
        RowBox[{"f", "[", 
         RowBox[{"x", " ", "+", " ", 
          RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "0.00001", ",", "0.5"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", 
         RowBox[{"-", "0.5"}], ",", "0.5"}], "}"}], ",", 
       RowBox[{"PlotPoints", "\[Rule]", "55"}], ",", 
       RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"g1", ",", "g2", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.52"}], ",", "0.52"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.52"}], ",", "0.52"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}]}], "]"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<v[x,y] = \>\"", ",", 
      RowBox[{"Im", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<= \>\"", ",", 
      RowBox[{"v", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39938197309375*^9, 3.3993819746875*^9}, 
   3.399965272109375*^9, {3.4002688724375*^9, 3.400268885796875*^9}}]
}, Closed]],

Cell[TextData[{
 StyleBox["Definition 7.6 (",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Zero of order k",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/Multiplicity.html"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 StyleBox[").",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  A function ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " analytic in  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["D", "r"], 
   RowBox[{"(", "\[Alpha]", ")"}]}]]],
 "  has a ",
 StyleBox[ButtonBox["zero of order k",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/Multiplicity.html"], None}],
  FontFamily->"Times New Roman",
  FontVariations->{"Underline"->True}],
 " at the point  ",
 Cell[BoxData[
  RowBox[{"z", "=", "\[Alpha]"}]]],
 "  if and only if  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["f", 
      RowBox[{"(", "n", ")"}]], 
     RowBox[{"(", "\[Alpha]", ")"}]}], "=", 
    RowBox[{
     RowBox[{"0", "  ", "for", "  ", "n"}], "=", "0"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "1", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "2", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "...", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{"k", "-", "1"}]}]]],
 ",  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["f", 
     RowBox[{"(", "k", ")"}]], 
    RowBox[{"(", "\[Alpha]", ")"}]}], "\[NotEqual]", "0"}]]],
 ".\n\nA zero of order one is sometimes called a simple zero.  "
}], "Text"],

Cell[TextData[{
 StyleBox["Theorem 7.10.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  A function ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", "z", ")"}]}]]],
 " analytic in ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["D", "R"], 
   RowBox[{"(", "\[Alpha]", ")"}]}]]],
 " has a zero of order ",
 StyleBox["k",
  FontFamily->"Courier"],
 " at the point ",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{"z", "=", "\[Alpha]"}]}]]],
 "  iff its Taylor series given by ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", "0"}], "\[Infinity]"], 
    RowBox[{
     SubscriptBox["c", "n"], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "\[Alpha]"}], ")"}], "n"]}]}]}]]],
 " has \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["c", "0"], " ", "=", " ", 
   RowBox[{
    SubscriptBox["c", "1"], " ", "=", " ", 
    RowBox[{"...", "=", " ", 
     RowBox[{
      SubscriptBox["c", 
       RowBox[{"k", "-", "1"}]], " ", "=", " ", 
      RowBox[{
       RowBox[{"0", "   ", "and", "   ", 
        SubscriptBox["c", "k"]}], "\[NotEqual]", "0"}]}]}]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 7.10 is in the book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 7.10.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  From Theorem 7.10 we see that the function\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"z", " ", "sin", 
     RowBox[{"(", 
      SuperscriptBox["z", "2"], ")"}]}], "  ", "=", "    ", 
    RowBox[{
     RowBox[{
      SuperscriptBox["z", "3"], "-", 
      FractionBox[
       SuperscriptBox["z", "7"], 
       RowBox[{"3", "!"}]], "+", 
      FractionBox[
       SuperscriptBox["z", "11"], 
       RowBox[{"5", "!"}]], "-", 
      FractionBox[
       SuperscriptBox["z", "15"], 
       RowBox[{"7", "!"}]], "+"}], "..."}]}]}]],
  AspectRatioFixed->True],
 "   \n\nhas a zero of order ",
 Cell[BoxData[
  RowBox[{"k", "=", "3"}]]],
 " at ",
 Cell[BoxData[
  RowBox[{"z", "=", "0"}]]],
 ".  Definition 7.6 confirms this fact because   \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"    ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"f", "'"}], 
       RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
      RowBox[{
       RowBox[{"2", " ", 
        SuperscriptBox["z", "2"], " ", "Cos", " ", 
        SuperscriptBox["z", "2"]}], " ", "+", " ", 
       RowBox[{"Sin", " ", 
        SuperscriptBox["z", "2"]}]}]}], "\n"}], "\[IndentingNewLine]", "  ", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"f", "''"}], 
       RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
      RowBox[{
       RowBox[{"6", " ", "z", " ", "Cos", " ", 
        SuperscriptBox["z", "2"]}], " ", "-", " ", 
       RowBox[{"4", " ", 
        SuperscriptBox["z", "3"], " ", "Sin", " ", 
        SuperscriptBox["z", "2"]}]}]}], "\n"}], "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"f", "'''"}], 
      RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
     RowBox[{
      RowBox[{"6", " ", "Cos", " ", 
       SuperscriptBox["z", "2"]}], " ", "-", " ", 
      RowBox[{"8", " ", 
       SuperscriptBox["z", "4"], " ", "Cos", " ", 
       SuperscriptBox["z", "2"]}], " ", "-", " ", 
      RowBox[{"24", " ", 
       SuperscriptBox["z", "2"], " ", "Sin", " ", 
       SuperscriptBox["z", "2"]}]}]}]}]}]]],
 "  \n\nThen,  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "0", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "''"}], 
     RowBox[{"(", "0", ")"}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"f", "''"}], 
      RowBox[{"(", "0", ")"}]}], " ", "=", " ", "0"}]}]}]]],
 ",  but  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"f", "'''"}], 
    RowBox[{"(", "0", ")"}]}], "  ", "=", "  ", 
   RowBox[{"6", "  ", "\[NotEqual]", " ", "0"}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 7.10.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "Enter the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], "=", 
   RowBox[{"z", " ", "sin", 
    RowBox[{"(", 
     SuperscriptBox["z", "2"], ")"}]}]}]]],
 "  and find the first few terms of the Maclaurin series.  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "f", ",", "i", ",", "L", ",", "m", ",", "p", ",", "S", ",", "z"}], "]"}],
     ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"z", " ", 
      RowBox[{"Sin", "[", 
       SuperscriptBox["z", "2"], "]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"S", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{"f", "[", "z", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", "0", ",", "23"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"L", " ", "=", " ", 
     RowBox[{"CoefficientList", "[", 
      RowBox[{
       RowBox[{"S", "[", "z", "]"}], ",", "z"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"i", "=", "1"}], ";", "  ", 
    RowBox[{"m", " ", "=", " ", 
     RowBox[{"Length", "[", "L", "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"While", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"L", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "==", "0"}], " ", "&&", " ", 
       RowBox[{"i", "<", "m"}]}], ",", "\n", "  ", 
      RowBox[{
       RowBox[{"term", " ", "=", " ", 
        SuperscriptBox["z", "i"]}], ";", "  ", 
       RowBox[{"i", "=", 
        RowBox[{"i", "+", "1"}]}]}]}], "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"fact", " ", "=", " ", 
     RowBox[{"Simplify", "[", 
      FractionBox[
       RowBox[{"S", "[", "z", "]"}], "term"], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"p", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"term", " ", "fact"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[z] = \>\"", ",", 
      RowBox[{"S", "[", "z", "]"}], ",", "\"\< + ...\>\""}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<p[z] = \>\"", ",", "term", " ", ",", "\"\<(\>\"", ",", "fact", ",", 
      "\"\< + ...)\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{
  3.399382000546875*^9, {3.400269249328125*^9, 3.40026925146875*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "Thus, ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{"z", " ", "sin", 
    RowBox[{"(", 
     SuperscriptBox["z", "2"], ")"}]}]}]],
  AspectRatioFixed->True],
 " has a zero of order k = 3 at z = 0."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["Investigate the graph for real variables.", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"f", "[", "x", "]"}], ",", 
       RowBox[{"S", "[", "x", "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "3"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "4"}], ",", "4", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Red", ",", "Blue"}], "}"}]}]}], "]"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[x] = \>\"", ",", 
      RowBox[{"f", "[", "x", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[z] = \>\"", ",", 
      RowBox[{"S", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399382004140625*^9, 3.39938200728125*^9}, {
  3.39996547765625*^9, 3.39996547796875*^9}}],

Cell[TextData[{
 "We can use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to investigate the real and imaginary parts and the absolute value of ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], "=", 
   RowBox[{"z", " ", "sin", 
    RowBox[{"(", 
     SuperscriptBox["z", "2"], ")"}]}]}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"u", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], "=", 
     RowBox[{"FullSimplify", "[", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{
        RowBox[{"Re", "[", 
         RowBox[{"f", "[", 
          RowBox[{"x", "+", 
           RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], ",", 
        RowBox[{"TargetFunctions", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"Im", ",", "Re"}], "}"}]}]}], "]"}], "]"}]}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"v", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], "=", 
     RowBox[{"FullSimplify", "[", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{
        RowBox[{"Im", "[", 
         RowBox[{"f", "[", 
          RowBox[{"x", "+", 
           RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], ",", 
        RowBox[{"TargetFunctions", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"Im", ",", "Re"}], "}"}]}]}], "]"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"w", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], "=", 
     RowBox[{"FullSimplify", "[", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{
        RowBox[{"Abs", "[", 
         RowBox[{"f", "[", 
          RowBox[{"x", "+", 
           RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], ",", 
        RowBox[{"TargetFunctions", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"Im", ",", "Re"}], "}"}]}]}], "]"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"Plot3D", "[", 
    RowBox[{
     RowBox[{"u", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"21", ",", "21"}], "}"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "4"}], ",", "4"}], "}"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<\>\""}], "}"}]}], ",",
      
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<u[x,y] = \>\"", ",", 
      RowBox[{"Re", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<= \>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39938200978125*^9, 3.39938201315625*^9}, {
  3.399965482125*^9, 3.39996548234375*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Plot3D", "[", 
    RowBox[{
     RowBox[{"v", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"21", ",", "21"}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "4"}], ",", "4"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<\>\""}], "}"}]}], ",",
      
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<v[x,y] = \>\"", ",", 
      RowBox[{"Im", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<= \>\"", ",", 
      RowBox[{"v", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399382021078125*^9, 3.39938202265625*^9}, {
  3.399965484734375*^9, 3.399965500421875*^9}, {3.40026903990625*^9, 
  3.400269040921875*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Plot3D", "[", 
    RowBox[{
     RowBox[{"w", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"21", ",", "21"}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "5"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<\>\""}], "}"}]}], ",",
      
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w[x,y] = \>\"", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<= \>\"", ",", 
      RowBox[{"w", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3993820256875*^9, 3.39938202696875*^9}, {
  3.3999654873125*^9, 3.39996550278125*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"Re", "[", 
      RowBox[{"f", "[", 
       RowBox[{"x", " ", "+", " ", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "35"}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<u[x,y] = \>\"", ",", 
      RowBox[{"Re", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<= \>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399382029296875*^9, 3.3993820305625*^9}, {
  3.3999654893125*^9, 3.39996550496875*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"Im", "[", 
      RowBox[{"f", "[", 
       RowBox[{"x", " ", "+", " ", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "35"}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<v[x,y] = \>\"", ",", 
      RowBox[{"Im", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<= \>\"", ",", 
      RowBox[{"v", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399382033171875*^9, 3.399382034453125*^9}, {
  3.399965491578125*^9, 3.399965506125*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"Abs", "[", 
      RowBox[{"f", "[", 
       RowBox[{"x", " ", "+", " ", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "35"}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w[x,y] = \>\"", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<= \>\"", ",", 
      RowBox[{"w", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39938203690625*^9, 3.399382039046875*^9}, {
  3.39996549465625*^9, 3.3999655076875*^9}}]
}, Closed]],

Cell[TextData[{
 StyleBox["Theorem 7.11.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Suppose ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " is analytic in ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["D", "R"], 
   RowBox[{"(", "\[Alpha]", ")"}]}]]],
 ".  Then ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " has a zero of order ",
 StyleBox["k",
  FontFamily->"Courier New"],
 " at the point ",
 Cell[BoxData[
  RowBox[{"z", "=", "\[Alpha]"}]]],
 " if and only if it can be expressed in the form \n\n",
 StyleBox["(7-35)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"z", "-", "\[Alpha]"}], ")"}], "k"], "g", 
    RowBox[{"(", "z", ")"}]}]}]]],
 ", \n\nwhere ",
 StyleBox["g(z)",
  FontFamily->"Courier New"],
 " is analytic at ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{
    RowBox[{"\[Alpha]", "  ", "and", "  ", "g", 
     RowBox[{"(", "\[Alpha]", ")"}]}], "\[NotEqual]", "0"}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 7.11 is in the book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"]
}, Closed]],

Cell["\<\
\tAn immediate consequence of Theorem 7.11 is Corollary 7.4.  The proof is \
left as an exercise. \
\>", "Text"],

Cell[TextData[{
 StyleBox["Corollary 7.4.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  If ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["g(z)",
  FontFamily->"Courier New"],
 " are analytic at  ",
 Cell[BoxData[
  RowBox[{"z", "=", "\[Alpha]"}]]],
 ",  and have zeros of orders  ",
 StyleBox["m",
  FontFamily->"Courier New"],
 "  and  ",
 StyleBox["n",
  FontFamily->"Courier New"],
 ",  respectively at  ",
 Cell[BoxData[
  RowBox[{"z", "=", "\[Alpha]"}]]],
 ",  then their product  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"h", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}], "g", 
    RowBox[{"(", "z", ")"}]}]}]]],
 "  has a zero of order  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"m", "+", 
    RowBox[{"n", "  ", "at", "  ", "z"}]}], "=", "\[Alpha]"}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Corollary 7.4 is an exercise in the book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 7.11.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Let ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    SuperscriptBox["z", "3"], " ", "sin", " ", "z"}]}]],
  AspectRatioFixed->True],
 ".  Then ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " can be factored as the product of  ",
 Cell[BoxData[
  SuperscriptBox["z", "3"]],
  AspectRatioFixed->True],
 "  and  ",
 Cell[BoxData[
  RowBox[{"sin", " ", "z"}]],
  AspectRatioFixed->True],
 ",  which have zeros of orders ",
 Cell[BoxData[
  RowBox[{"m", "=", "3"}]]],
 " and ",
 Cell[BoxData[
  RowBox[{"n", "=", "1"}]]],
 ", respectively, at ",
 Cell[BoxData[
  RowBox[{"z", "=", "0"}]]],
 ".  \nHence  ",
 Cell[BoxData[
  RowBox[{"z", "=", "0"}]]],
 " is a zero of order 4 of  ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 "."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 7.11.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "Enter the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], "=", 
   RowBox[{
    SuperscriptBox["z", "3"], " ", 
    RowBox[{"Sin", "[", "z", "]"}]}]}]]],
 " and find the first few terms of the Maclaurin series.  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "f", ",", "i", ",", "L", ",", "m", ",", "p", ",", "S", ",", "z"}], "]"}],
     ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{
      SuperscriptBox["z", "3"], " ", 
      RowBox[{"Sin", "[", "z", "]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"S", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{"f", "[", "z", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", "0", ",", "16"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"L", " ", "=", " ", 
     RowBox[{"CoefficientList", "[", 
      RowBox[{
       RowBox[{"S", "[", "z", "]"}], ",", "z"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"i", "=", "1"}], ";", "  ", 
    RowBox[{"m", " ", "=", " ", 
     RowBox[{"Length", "[", "L", "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"While", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"L", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], "==",
         "0"}], " ", "&&", " ", 
       RowBox[{"i", "<", "m"}]}], ",", "\n", "   ", 
      RowBox[{
       RowBox[{"term", " ", "=", " ", 
        SuperscriptBox["z", "i"]}], ";", "  ", 
       RowBox[{"i", "=", 
        RowBox[{"i", "+", "1"}]}]}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"fact", " ", "=", " ", 
     RowBox[{"Simplify", "[", 
      FractionBox[
       RowBox[{"S", "[", "z", "]"}], "term"], " ", "]"}]}], ";"}], " ", "\n", 
   
   RowBox[{
    RowBox[{
     RowBox[{"p", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"term", " ", "fact"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[z] = \>\"", ",", 
      RowBox[{"S", "[", "z", "]"}], ",", "\"\< + ...\>\""}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<p[z] = \>\"", ",", "term", " ", ",", "\"\<(\>\"", ",", "fact", ",", 
      "\"\< + ...)\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{
  3.3993820566875*^9, 3.39996552909375*^9, {3.4002692561875*^9, 
   3.400269258765625*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "Thus, ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    SuperscriptBox["z", "3"], " ", "sin", 
    RowBox[{"(", "z", ")"}]}]}]],
  AspectRatioFixed->True],
 " has a zero of order k = 4 at z = 0.\n\nInvestigate the graph for real \
variables."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"f", "[", "x", "]"}], ",", 
       RowBox[{"S", "[", "x", "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "3.3"}], ",", "3.3"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "3.3"}], ",", "3.3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "10"}], ",", "10"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "\[Pi]"}], ",", "\[Pi]", ",", 
          FractionBox["\[Pi]", "2"]}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "10"}], ",", "10", ",", "5"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Red", ",", "Blue"}], "}"}]}]}], "]"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[x] = \>\"", ",", 
      RowBox[{"f", "[", "x", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[z] = \>\"", ",", 
      RowBox[{"S", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399382059890625*^9, 3.399382062953125*^9}, 
   3.399965542109375*^9}],

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"f", "[", "x", "]"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "3.3"}], ",", "3.3"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "3.3"}], ",", "3.3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "10"}], ",", "10"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "\[Pi]"}], ",", "\[Pi]", ",", 
          FractionBox["\[Pi]", "2"]}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "10"}], ",", "10", ",", "5"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", "Red", "}"}]}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y = f[x] = \>\"", ",", 
      RowBox[{"f", "[", "x", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"S", "[", "x", "]"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "3.3"}], ",", "3.3"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "3.3"}], ",", "3.3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "10"}], ",", "10"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "\[Pi]"}], ",", "\[Pi]", ",", 
          FractionBox["\[Pi]", "2"]}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "10"}], ",", "10", ",", "5"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", "Blue", "}"}]}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[z] = \>\"", ",", 
      RowBox[{"S", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399382065390625*^9, 3.3993820703125*^9}, 
   3.399965545390625*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "We can use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to investigate the real and imaginary parts and the absolute value of ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    SuperscriptBox["z", "3"], " ", "sin", 
    RowBox[{"(", "z", ")"}]}]}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"u", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], "=", 
     RowBox[{"FullSimplify", "[", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{
        RowBox[{"Re", "[", 
         RowBox[{"f", "[", 
          RowBox[{"x", "+", 
           RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], ",", 
        RowBox[{"TargetFunctions", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"Im", ",", "Re"}], "}"}]}]}], "]"}], "]"}]}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"v", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], "=", 
     RowBox[{"FullSimplify", "[", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{
        RowBox[{"Im", "[", 
         RowBox[{"f", "[", 
          RowBox[{"x", "+", 
           RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], ",", 
        RowBox[{"TargetFunctions", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"Im", ",", "Re"}], "}"}]}]}], "]"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"w", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], "=", 
     RowBox[{"FullSimplify", "[", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{
        RowBox[{"Abs", "[", 
         RowBox[{"f", "[", 
          RowBox[{"x", "+", 
           RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], ",", 
        RowBox[{"TargetFunctions", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"Im", ",", "Re"}], "}"}]}]}], "]"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"Plot3D", "[", 
    RowBox[{
     RowBox[{"Re", "[", 
      RowBox[{"f", "[", 
       RowBox[{"x", " ", "+", " ", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"21", ",", "21"}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "4"}], ",", "1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<\>\""}], "}"}]}], ",",
      
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<u[x,y] = \>\"", ",", 
      RowBox[{"Re", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<= \>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39938207378125*^9, 3.39938207615625*^9}, {
  3.399965551515625*^9, 3.399965554546875*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Plot3D", "[", 
    RowBox[{
     RowBox[{"Im", "[", 
      RowBox[{"f", "[", 
       RowBox[{"x", " ", "+", " ", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"21", ",", "21"}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<\>\""}], "}"}]}], ",",
      
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<v[x,y] = \>\"", ",", 
      RowBox[{"Im", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<= \>\"", ",", 
      RowBox[{"v", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399382079703125*^9, 3.399382081*^9}, {3.399965559375*^9,
   3.39996556115625*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Plot3D", "[", 
    RowBox[{
     RowBox[{"Abs", "[", 
      RowBox[{"f", "[", 
       RowBox[{"x", " ", "+", " ", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"21", ",", "21"}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "5"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<\>\""}], "}"}]}], ",",
      
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w[x,y] = \>\"", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<= \>\"", ",", 
      RowBox[{"w", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399382083421875*^9, 3.399382084796875*^9}, {
  3.399965564859375*^9, 3.399965566359375*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"Re", "[", 
      RowBox[{"f", "[", 
       RowBox[{"x", " ", "+", " ", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "35"}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<u[x,y] = \>\"", ",", 
      RowBox[{"Re", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<= \>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3993820868125*^9, 3.399382088203125*^9}, {
  3.39996556975*^9, 3.399965571609375*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"Im", "[", 
      RowBox[{"f", "[", 
       RowBox[{"x", " ", "+", " ", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "35"}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<v[x,y] = \>\"", ",", 
      RowBox[{"Im", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<= \>\"", ",", 
      RowBox[{"v", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39938209084375*^9, 3.399382092328125*^9}, {
  3.399965575234375*^9, 3.399965576*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"Abs", "[", 
      RowBox[{"f", "[", 
       RowBox[{"x", " ", "+", " ", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "35"}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w[x,y] = \>\"", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<= \>\"", ",", 
      RowBox[{"w", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399382094921875*^9, 3.399382096578125*^9}, {
  3.39996557946875*^9, 3.399965580703125*^9}}]
}, Closed]],

Cell["\tTheorem 7.12 gives a useful way to characterize a pole.  ", "Text"],

Cell[TextData[{
 StyleBox["Theorem 7.12.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  A function ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " analytic in the punctured disk ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox[
    SubscriptBox["D", "R"], "*"], 
   RowBox[{"(", "\[Alpha]", ")"}]}]]],
 " has a pole of order k at ",
 Cell[BoxData[
  RowBox[{"z", "=", "\[Alpha]"}]]],
 " if and only if it can be expressed in the form \n\t\t\t\n",
 StyleBox["(7-37)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   FractionBox[
    RowBox[{"h", 
     RowBox[{"(", "z", ")"}]}], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"z", " ", "-", " ", "\[Alpha]"}], ")"}], "k"]]}]]],
 ", \n\nwhere the function ",
 StyleBox["h(z)",
  FontFamily->"Courier New"],
 " is analytic at the point ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{
    RowBox[{"\[Alpha]", "  ", "and", "  ", "h", 
     RowBox[{"(", "\[Alpha]", ")"}]}], "\[NotEqual]", "0"}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 7.12 is in the book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"]
}, Closed]],

Cell["\<\
\tCorollaries 7.5-7.8 are useful in determining the order of a zero or a \
pole.  The proofs follow easily from Theorems 7.10 and 7.12 and are left as \
exercises.\
\>", "Text"],

Cell[TextData[{
 StyleBox["Corollary 7.5.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["  ",
  FontWeight->"Bold"],
 "If ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " is analytic and has a zero of order ",
 StyleBox["k",
  FontFamily->"Courier"],
 " at the point  ",
 Cell[BoxData[
  RowBox[{"z", "=", "\[Alpha]"}]]],
 ",  then  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"g", 
    RowBox[{"(", "z", ")"}]}], "=", 
   FractionBox["1", 
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}]]}]]],
 "  has a pole of order ",
 StyleBox["k",
  FontFamily->"Courier"],
 " at  ",
 Cell[BoxData[
  RowBox[{"z", "=", "\[Alpha]"}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Corollary 7.5 is an exercise in the book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
 StyleBox["Corollary 7.6. ",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "If  ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " has a pole of order ",
 StyleBox["k",
  FontFamily->"Courier"],
 " at the point ",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{"z", "=", "\[Alpha]"}]}]]],
 ", then ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"g", 
    RowBox[{"(", "z", ")"}]}], "=", 
   FractionBox["1", 
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}]]}]]],
 " has a removable singularity at ",
 Cell[BoxData[
  RowBox[{"z", "=", "\[Alpha]"}]]],
 ".  If we define ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"g", 
    RowBox[{"(", "\[Alpha]", ")"}]}], "=", "0"}]]],
 ",  then ",
 StyleBox["g(z)",
  FontFamily->"Courier New"],
 "  has a zero of order ",
 StyleBox["k",
  FontFamily->"Courier"],
 " at ",
 Cell[BoxData[
  RowBox[{"z", "=", "\[Alpha]"}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Corollary 7.6 is an exercise in the book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
 StyleBox["Corollary 7.7.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  If ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["g(z)",
  FontFamily->"Courier New"],
 " have poles of orders  ",
 StyleBox["m",
  FontFamily->"Courier New"],
 "  and  ",
 StyleBox["n",
  FontFamily->"Courier New"],
 ",  respectively at the point  ",
 Cell[BoxData[
  RowBox[{"z", "=", "\[Alpha]"}]]],
 ", then their product  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"h", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}], "g", 
    RowBox[{"(", "z", ")"}]}]}]]],
 "  has a pole of order  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"m", "+", 
    RowBox[{"n", "  ", "at", "  ", "z"}]}], "=", "\[Alpha]"}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Corollary 7.7 is an exercise in the book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
 StyleBox["Corollary 7.8.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Let ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["g(z)",
  FontFamily->"Courier New"],
 " be analytic with  zeros of orders  ",
 StyleBox["m",
  FontFamily->"Courier New"],
 "  and  ",
 StyleBox["n",
  FontFamily->"Courier New"],
 ",  respectively at  ",
 Cell[BoxData[
  RowBox[{"z", "=", "\[Alpha]"}]]],
 ".  Then their quotient ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"h", 
    RowBox[{"(", "z", ")"}]}], "=", 
   FractionBox[
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], 
    RowBox[{"g", 
     RowBox[{"(", "z", ")"}]}]]}]]],
 "  has the following behavior:\n\n",
 StyleBox["(i)",
  FontColor->RGBColor[0, 0, 1]],
 "  If  ",
 Cell[BoxData[
  RowBox[{"m", ">", "n"}]]],
 ",  then ",
 StyleBox["h(z)",
  FontFamily->"Courier New"],
 " has a removable singularity at  ",
 Cell[BoxData[
  RowBox[{"z", "=", "\[Alpha]"}]]],
 ".   If we define  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"h", 
    RowBox[{"(", "\[Alpha]", ")"}]}], "=", "0"}]]],
 ",  then ",
 StyleBox["h(z)",
  FontFamily->"Courier New"],
 " has a zero of order  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"m", "-", 
    RowBox[{"n", "  ", "at", "  ", "z"}]}], "=", "\[Alpha]"}]]],
 ". \n\n",
 StyleBox["(ii)",
  FontColor->RGBColor[0, 0, 1]],
 "  If  ",
 Cell[BoxData[
  RowBox[{"m", "<", "n"}]]],
 ",  then ",
 StyleBox["h(z)",
  FontFamily->"Courier New"],
 " has a pole of order  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"n", "-", 
    RowBox[{"m", "  ", "at", "  ", "z"}]}], "=", "\[Alpha]"}]]],
 ". \n\n",
 StyleBox["(iii)",
  FontColor->RGBColor[0, 0, 1]],
 "  If  ",
 Cell[BoxData[
  RowBox[{"m", "=", "n"}]]],
 ",  then ",
 StyleBox["h(z)",
  FontFamily->"Courier New"],
 " has a removable singularity  at  ",
 Cell[BoxData[
  RowBox[{"z", "=", "\[Alpha]"}]]],
 ",  and can be defined so that ",
 StyleBox["h(z)",
  FontFamily->"Courier New"],
 " is analytic at  ",
 Cell[BoxData[
  RowBox[{"z", "=", "\[Alpha]"}]]],
 ",  by  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"h", 
    RowBox[{"(", "\[Alpha]", ")"}]}], "=", 
   RowBox[{
    UnderscriptBox["lim", 
     RowBox[{"z", " ", "\[Rule]", " ", "\[Alpha]"}]], "  ", 
    RowBox[{"h", 
     RowBox[{"(", "z", ")"}]}]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Corollary 7.8 is an exercise in the book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 7.12.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Locate the zeros and poles of  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"h", 
    RowBox[{"(", "z", ")"}]}], "=", 
   FractionBox[
    RowBox[{"tan", " ", "z"}], "z"]}]],
  AspectRatioFixed->True],
 ",  and determine their order. "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "Solution.  In Section 5.4 we saw that the zeros of  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{"sin", " ", "z"}]}]],
  AspectRatioFixed->True],
 "  occur at the points  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{"n", " ", "\[Pi]"}]}]]],
 ",  where ",
 StyleBox["n",
  FontFamily->"Courier New"],
 " is an integer.  Because  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"f", "'"}], 
    RowBox[{"(", 
     RowBox[{"n", " ", "\[Pi]"}], ")"}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"cos", " ", "n", " ", "\[Pi]"}], "  ", "\[NotEqual]", "  ", 
    "0"}]}]]],
 ",  the zeros of ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " are simple.  Similarly, the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"g", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{"z", " ", "cos", " ", "z"}]}]],
  AspectRatioFixed->True],
 "  has simple zeros at the points ",
 Cell[BoxData[
  RowBox[{"z", "=", "0"}]]],
 " and  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"n", "+", 
      FractionBox["1", "2"]}], ")"}], "\[Pi]"}]}]]],
 ",  where ",
 StyleBox["n",
  FontFamily->"Courier New"],
 " is an integer.  From the information given, we find that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"h", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   FractionBox[
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], 
    RowBox[{"g", 
     RowBox[{"(", "z", ")"}]}]]}]]],
 "  behaves as follows:\n\n\t\t i.    ",
 StyleBox["h(z)",
  FontFamily->"Courier New"],
 "  has simple zeros at  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{"n", " ", "\[Pi]"}]}]]],
 ",  where  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"n", "=", 
    RowBox[{"\[PlusMinus]", "1"}]}], ",", 
   RowBox[{"\[PlusMinus]", "2"}], ",", "..."}]]],
 ";\n\n\t\t ii.   ",
 StyleBox["h(z)",
  FontFamily->"Courier New"],
 "  has simple poles at  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"n", "+", 
      FractionBox["1", "2"]}], ")"}], "\[Pi]"}]}]]],
 ",  where ",
 StyleBox["n",
  FontFamily->"Courier New"],
 " is an integer;  and\n\n\t\t iii.  ",
 StyleBox["h(z)",
  FontFamily->"Courier New"],
 "  is analytic at ",
 Cell[BoxData[
  RowBox[{"z", "=", "0"}]]],
 " if we define  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"h", 
    RowBox[{"(", "0", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"z", "\[Rule]", "0"}]], 
     RowBox[{"h", 
      RowBox[{"(", "z", ")"}]}]}], " ", "=", " ", "1"}]}]]],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 7.12.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "Enter the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"h", "[", "z", "]"}], "=", 
   FractionBox[
    RowBox[{"Tan", "[", "z", "]"}], "z"]}]]],
 " and find the first few terms of the Maclaurin series.  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"h", ",", "i", ",", "S", ",", "z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"h", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox[
      RowBox[{"Tan", "[", "z", "]"}], "z"]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"S", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{"h", "[", "z", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", "0", ",", "13"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<h[z] = \>\"", ",", 
      RowBox[{"h", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[z] = \>\"", ",", 
      RowBox[{"S", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<h[z] = \>\"", ",", 
      RowBox[{"S", "[", "z", "]"}], ",", "\"\< + ...\>\""}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{
  3.39938211228125*^9, {3.4002692643125*^9, 3.400269266578125*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "Thus, ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"h", 
    RowBox[{"(", "z", ")"}]}], "=", 
   FractionBox[
    RowBox[{"Tan", "[", "z", "]"}], "z"]}]],
  AspectRatioFixed->True],
 " has a removable singularity at z = 0.\n\nNow look for the zeros of  h[x]."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  h[z] = \>\"", ",", 
      RowBox[{"h", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"k", "=", 
       RowBox[{"-", "5"}]}], ",", 
      RowBox[{"k", "\[LessEqual]", 
       RowBox[{"-", "1"}]}], ",", 
      RowBox[{"k", "++"}], ",", "\n", "   ", 
      RowBox[{"Print", "[", 
       RowBox[{"\"\<h[\>\"", ",", "k", ",", "\"\< \[Pi]] = \>\"", ",", 
        RowBox[{"h", "[", 
         RowBox[{"k", " ", "\[Pi]"}], "]"}]}], "]"}]}], " ", "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"k", "=", "1"}], ",", 
      RowBox[{"k", "\[LessEqual]", "5"}], ",", 
      RowBox[{"k", "++"}], ",", "\n", "   ", 
      RowBox[{"Print", "[", 
       RowBox[{"\"\<h[\>\"", ",", "k", ",", "\"\< \[Pi]] = \>\"", ",", 
        RowBox[{"h", "[", 
         RowBox[{"k", " ", "\[Pi]"}], "]"}]}], "]"}]}], " ", "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.3993821154375*^9},
 AspectRatioFixed->True],

Cell["Or we could consider the following method of investigation.", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<h[x] = \>\"", ",", 
      RowBox[{"h", "[", "x", "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<h[n \[Pi]] = \>\"", ",", 
      RowBox[{"h", "[", 
       RowBox[{"n", " ", "\[Pi]"}], "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<h[n \[Pi]] = \>\"", ",", 
      RowBox[{"Simplify", "[", 
       RowBox[{
        RowBox[{"h", "[", 
         RowBox[{"n", " ", "\[Pi]"}], "]"}], ",", 
        RowBox[{"Element", "[", 
         RowBox[{"n", ",", "Integers"}], "]"}]}], "]"}]}], " ", "]"}], ";"}], 
   " "}]}]], "Input",
 CellChangeTimes->{3.39938211815625*^9}],

Cell[TextData[{
 "\nThus, ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"h", 
    RowBox[{"(", "z", ")"}]}], "=", 
   FractionBox[
    RowBox[{"Tan", "[", "z", "]"}], "z"]}]],
  AspectRatioFixed->True],
 " has simple zeros at  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"z", "=", 
    RowBox[{
     RowBox[{"n", " ", "\[Pi]", "  ", "for", "  ", "n"}], "=", 
     RowBox[{"\[PlusMinus]", "1"}]}]}], ",", 
   RowBox[{"\[PlusMinus]", "2"}], ",", "..."}]]],
 ".  \n\nNow consider the other singular points."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<    h[z] = \>\"", ",", 
      RowBox[{"h", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"i", "=", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"i", "<=", "5"}], ",", 
      RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{"\"\<h[\>\"", ",", 
        FractionBox[
         RowBox[{
          RowBox[{"2", "i"}], "-", "1"}], "2"], ",", "\"\< \[Pi]] = \>\"", 
        ",", "\[IndentingNewLine]", 
        RowBox[{"Limit", "[", 
         RowBox[{
          RowBox[{"h", "[", "z", "]"}], ",", 
          RowBox[{"z", "\[Rule]", 
           FractionBox[
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", "i"}], "-", "1"}], ")"}], "\[Pi]"}], "2"]}]}], 
         "]"}]}], " ", "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39938212109375*^9}],

Cell["Or we could consider the following method of investigation.", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<h[x] = \>\"", ",", 
      RowBox[{"h", "[", "x", "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<h[(2n+1) \!\(\*FractionBox[\(\[Pi]\), \(2\)]\)] = \>\"", ",", 
      RowBox[{"h", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", "n"}], "+", "1"}], ")"}], " ", 
        FractionBox["\[Pi]", "2"]}], "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<h[(2n+1) \!\(\*FractionBox[\(\[Pi]\), \(2\)]\)] = \>\"", ",", 
      RowBox[{"Simplify", "[", 
       RowBox[{
        RowBox[{"h", "[", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", "n"}], "+", "1"}], ")"}], " ", 
          FractionBox["\[Pi]", "2"]}], "]"}], ",", 
        RowBox[{"Element", "[", 
         RowBox[{"n", ",", "Integers"}], "]"}]}], "]"}]}], " ", "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399382125859375*^9, 3.3993821266875*^9}}],

Cell[TextData[{
 "Hence,  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"h", 
    RowBox[{"(", "z", ")"}]}], "=", 
   FractionBox[
    RowBox[{"Tan", "[", "z", "]"}], "z"]}]],
  AspectRatioFixed->True],
 " has simple poles at  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", "n"}], "-", "1"}], ")"}], "\[Pi]"}], "2"]}]]],
 "  where n is an integer."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["Investigate the graph for real variables.", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"h", "[", "x", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{
        RowBox[{"-", "3"}], "\[Pi]"}], ",", 
       RowBox[{"3", "\[Pi]"}]}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "3"}], "\[Pi]"}], ",", 
          RowBox[{"3", "\[Pi]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "10"}], ",", "10"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          FractionBox[
           RowBox[{
            RowBox[{"-", "7"}], "\[Pi]"}], "2"], ",", 
          FractionBox[
           RowBox[{"7", "\[Pi]"}], "2"], ",", "\[Pi]"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "10"}], ",", "10", ",", "5"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Blue"}]}], "]"}], "\[IndentingNewLine]",
    
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<h[x] = \>\"", ",", 
      RowBox[{"h", "[", "x", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399382143234375*^9, 3.3993821565*^9}, {3.399964717*^9, 
  3.399964722*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "We can use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to investigate the real part, imaginary part and absolute value of  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"h", 
    RowBox[{"(", "z", ")"}]}], "=", 
   FractionBox[
    RowBox[{"Tan", "[", "z", "]"}], "z"]}]]],
 "."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"u", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], "=", 
     RowBox[{"FullSimplify", "[", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{
        RowBox[{"Re", "[", 
         RowBox[{"h", "[", 
          RowBox[{"x", "+", 
           RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], ",", 
        RowBox[{"TargetFunctions", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"Im", ",", "Re"}], "}"}]}]}], "]"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"v", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], "=", 
     RowBox[{"FullSimplify", "[", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{
        RowBox[{"Im", "[", 
         RowBox[{"h", "[", 
          RowBox[{"x", "+", 
           RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], ",", 
        RowBox[{"TargetFunctions", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"Im", ",", "Re"}], "}"}]}]}], "]"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"w", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], "=", 
     RowBox[{"FullSimplify", "[", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{
        RowBox[{"Abs", "[", 
         RowBox[{"h", "[", 
          RowBox[{"x", "+", 
           RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], ",", 
        RowBox[{"TargetFunctions", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"Im", ",", "Re"}], "}"}]}]}], "]"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"Plot3D", "[", 
    RowBox[{
     RowBox[{"u", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "6"}], ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "6"}], ",", "6"}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"41", ",", "41"}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "6"}], ",", "6"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "6"}], ",", "6"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0.15"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"ViewPoint", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"4", ",", "4", ",", "1"}], "}"}]}], ",", 
     RowBox[{"ClippingStyle", "\[Rule]", 
      RowBox[{"{", "None", "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<\>\""}], "}"}]}], ",",
      
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Re[\>\"", ",", 
      RowBox[{"h", "[", "z", "]"}], ",", "\"\<] = \>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399382160609375*^9, 3.399382224359375*^9}, {
  3.399964726671875*^9, 3.399964735578125*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Plot3D", "[", 
    RowBox[{
     RowBox[{"u", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "6"}], ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "6"}], ",", "6"}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"41", ",", "41"}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "6"}], ",", "6"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "6"}], ",", "6"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "2"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"ViewPoint", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"4", ",", "4", ",", "1"}], "}"}]}], ",", 
     RowBox[{"ClippingStyle", "\[Rule]", "None"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<\>\""}], "}"}]}], ",",
      
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Re[\>\"", ",", 
      RowBox[{"h", "[", "z", "]"}], ",", "\"\<] = \>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3993822104375*^9, 3.399382234609375*^9}, 
   3.399382301296875*^9, {3.399964741234375*^9, 3.399964744609375*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Plot3D", "[", 
    RowBox[{
     RowBox[{"v", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "6"}], ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "6"}], ",", "6"}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"41", ",", "41"}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "6"}], ",", "6"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "6"}], ",", "6"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.15"}], ",", "0.15"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"ViewPoint", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"4", ",", "2", ",", "2"}], "}"}]}], ",", 
     RowBox[{"ClippingStyle", "\[Rule]", "None"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<\>\""}], "}"}]}], ",",
      
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Im[\>\"", ",", 
      RowBox[{"h", "[", "z", "]"}], ",", "\"\<] = \>\"", ",", 
      RowBox[{"v", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399382239203125*^9, 3.399382248609375*^9}, 
   3.399382306953125*^9, {3.39996474659375*^9, 3.3999647504375*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Plot3D", "[", 
    RowBox[{
     RowBox[{"v", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "6"}], ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "6"}], ",", "6"}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"41", ",", "41"}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "6"}], ",", "6"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "6"}], ",", "6"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"ViewPoint", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"4", ",", "2", ",", "2"}], "}"}]}], ",", 
     RowBox[{"ClippingStyle", "\[Rule]", "None"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<\>\""}], "}"}]}], ",",
      
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Im[\>\"", ",", 
      RowBox[{"h", "[", "z", "]"}], ",", "\"\<] = \>\"", ",", 
      RowBox[{"v", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399382253046875*^9, 3.399382259375*^9}, 
   3.39938231228125*^9, {3.399964763265625*^9, 3.3999647681875*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Plot3D", "[", 
    RowBox[{
     RowBox[{"w", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "6"}], ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "6"}], ",", "6"}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"41", ",", "41"}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "6"}], ",", "6"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "6"}], ",", "6"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0.2"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"ViewPoint", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"4", ",", "4", ",", "1"}], "}"}]}], ",", 
     RowBox[{"ClippingStyle", "\[Rule]", "None"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<\>\""}], "}"}]}], ",",
      
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Abs[\>\"", ",", 
      RowBox[{"h", "[", "z", "]"}], ",", "\"\<] = \>\"", ",", 
      RowBox[{"w", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399382264078125*^9, 3.399382269546875*^9}, 
   3.399382317015625*^9, {3.39996477425*^9, 3.399964776796875*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Plot3D", "[", 
    RowBox[{
     RowBox[{"w", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "6"}], ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "6"}], ",", "6"}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"41", ",", "41"}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "6"}], ",", "6"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "6"}], ",", "6"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "2"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"ViewPoint", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"4", ",", "4", ",", "1"}], "}"}]}], ",", 
     RowBox[{"ClippingStyle", "\[Rule]", "None"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<\>\""}], "}"}]}], ",",
      
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Abs[\>\"", ",", 
      RowBox[{"h", "[", "z", "]"}], ",", "\"\<] = \>\"", ",", 
      RowBox[{"w", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39938227534375*^9, 3.39938228065625*^9}, 
   3.39938232225*^9, {3.3999647825*^9, 3.39996478525*^9}}]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 7.13.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Locate the poles of ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"g", 
    RowBox[{"(", "z", ")"}]}], "=", 
   FractionBox["1", 
    RowBox[{
     RowBox[{"5", 
      SuperscriptBox["z", "4"]}], " ", "+", " ", 
     RowBox[{"26", 
      SuperscriptBox["z", "2"]}], " ", "+", " ", "5"}]]}]],
  AspectRatioFixed->True],
 ", and specify their order. "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{403, 239},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 "Solution.  The roots of the quadratic equation  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"5", 
     SuperscriptBox["z", "2"]}], " ", "+", " ", 
    RowBox[{"26", "z"}], " ", "+", " ", "5"}], " ", "=", " ", "0"}]],
  AspectRatioFixed->True],
 "  occur at the points ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "5"}], "  ", 
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", "z"}], "=", 
    RowBox[{"-", 
     FractionBox["1", "5"]}]}]}]]],
 ".  If we replace ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " with ",
 Cell[BoxData[
  SuperscriptBox["z", "2"]],
  AspectRatioFixed->True],
 " in this equation, the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"5", 
     SuperscriptBox["z", "4"]}], " ", "+", " ", 
    RowBox[{"26", 
     SuperscriptBox["z", "2"]}], " ", "+", " ", "5"}]}]],
  AspectRatioFixed->True],
 "  has simple zeros at the points  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"\[PlusMinus]", "\[ImaginaryI]"}], 
     SqrtBox["5"], "  ", 
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", "z"}], "=", 
    RowBox[{"\[PlusMinus]", 
     FractionBox["\[ImaginaryI]", 
      SqrtBox["5"]]}]}]}]]],
 ".  Corollary 7.5 implies that ",
 StyleBox["g(z)",
  FontFamily->"Courier New"],
 "  has simple poles at  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"\[PlusMinus]", "\[ImaginaryI]"}], 
     SqrtBox["5"], "  ", 
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", "z"}], "=", 
    RowBox[{"\[PlusMinus]", 
     FractionBox["\[ImaginaryI]", 
      SqrtBox["5"]]}]}]}]]],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 7.13.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "Enter the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"g", "[", "z", "]"}], "=", 
   FractionBox["1", 
    RowBox[{
     RowBox[{"5", 
      SuperscriptBox["z", "4"]}], " ", "+", " ", 
     RowBox[{"26", 
      SuperscriptBox["z", "2"]}], " ", "+", " ", "5"}]]}]]],
 " and find roots of the polynomial in the denominator.  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"g", ",", "solset", ",", "z", ",", "Z"}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"g", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox["1", 
      RowBox[{
       RowBox[{"5", 
        SuperscriptBox["z", "4"]}], " ", "+", " ", 
       RowBox[{"26", 
        SuperscriptBox["z", "2"]}], " ", "+", " ", "5"}]]}], ";"}], " ", "\n",
    
   RowBox[{
    RowBox[{"solset", " ", "=", " ", 
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Denominator", "[", 
         RowBox[{"g", "[", "z", "]"}], "]"}], "==", "0"}], ",", "z"}], 
      "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<g[z] = \>\"", ",", 
      RowBox[{"g", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The poles are located at:\>\"", "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "solset", "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{
  3.399382340875*^9, {3.400269272890625*^9, 3.400269277125*^9}},
 AspectRatioFixed->True],

Cell["Evaluate g[z] at the poles.  ", "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "1"], " ", "=", " ", 
     SubscriptBox["solset", 
      RowBox[{"\[LeftDoubleBracket]", 
       RowBox[{"1", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "2"], " ", "=", " ", 
     SubscriptBox["solset", 
      RowBox[{"\[LeftDoubleBracket]", 
       RowBox[{"2", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "3"], " ", "=", " ", 
     SubscriptBox["solset", 
      RowBox[{"\[LeftDoubleBracket]", 
       RowBox[{"3", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "4"], " ", "=", " ", 
     SubscriptBox["solset", 
      RowBox[{"\[LeftDoubleBracket]", 
       RowBox[{"4", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<g[z] = \>\"", ",", 
      RowBox[{"g", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<g[\>\"", ",", 
      SubscriptBox["Z", "1"], ",", "\"\<] = \>\"", ",", 
      RowBox[{"Limit", "[", 
       RowBox[{
        RowBox[{"g", "[", "z", "]"}], ",", 
        RowBox[{"z", "\[Rule]", 
         SubscriptBox["Z", "1"]}]}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<g[\>\"", ",", 
      SubscriptBox["Z", "2"], ",", "\"\<] = \>\"", ",", 
      RowBox[{"Limit", "[", 
       RowBox[{
        RowBox[{"g", "[", "z", "]"}], ",", 
        RowBox[{"z", "\[Rule]", 
         SubscriptBox["Z", "2"]}]}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<g[\>\"", ",", 
      SubscriptBox["Z", "3"], ",", "\"\<] = \>\"", ",", 
      RowBox[{"Limit", "[", 
       RowBox[{
        RowBox[{"g", "[", "z", "]"}], ",", 
        RowBox[{"z", "\[Rule]", 
         SubscriptBox["Z", "3"]}]}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<g[\>\"", ",", 
      SubscriptBox["Z", "4"], ",", "\"\<] = \>\"", ",", 
      RowBox[{"Limit", "[", 
       RowBox[{
        RowBox[{"g", "[", "z", "]"}], ",", 
        RowBox[{"z", "\[Rule]", 
         SubscriptBox["Z", "4"]}]}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399382345640625*^9}],

Cell[TextData[{
 "Thus ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"g", 
    RowBox[{"(", "z", ")"}]}], "=", 
   FractionBox["1", 
    RowBox[{
     RowBox[{"5", 
      SuperscriptBox["z", "4"]}], " ", "+", " ", 
     RowBox[{"26", 
      SuperscriptBox["z", "2"]}], " ", "+", " ", "5"}]]}]],
  AspectRatioFixed->True],
 " has four simple poles.\n\nWe can use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to investigate the absolute value of  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"g", 
    RowBox[{"(", "z", ")"}]}], "=", 
   FractionBox["1", 
    RowBox[{
     RowBox[{"5", 
      SuperscriptBox["z", "4"]}], " ", "+", " ", 
     RowBox[{"26", 
      SuperscriptBox["z", "2"]}], " ", "+", " ", "5"}]]}]]],
 "."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"u", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], "=", 
     RowBox[{"FullSimplify", "[", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{
        RowBox[{"Re", "[", 
         RowBox[{"g", "[", 
          RowBox[{"x", "+", 
           RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], ",", 
        RowBox[{"TargetFunctions", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"Im", ",", "Re"}], "}"}]}]}], "]"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"v", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], "=", 
     RowBox[{"FullSimplify", "[", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{
        RowBox[{"Im", "[", 
         RowBox[{"g", "[", 
          RowBox[{"x", "+", 
           RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], ",", 
        RowBox[{"TargetFunctions", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"Im", ",", "Re"}], "}"}]}]}], "]"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"w", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], "=", 
     RowBox[{"FullSimplify", "[", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{
        RowBox[{"Abs", "[", 
         RowBox[{"g", "[", 
          RowBox[{"x", "+", 
           RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], ",", 
        RowBox[{"TargetFunctions", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"Im", ",", "Re"}], "}"}]}]}], "]"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"Plot3D", "[", 
    RowBox[{
     RowBox[{"u", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"41", ",", "41"}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.05"}], ",", "0.4"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"ClippingStyle", "\[Rule]", "None"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<\>\""}], "}"}]}], ",",
      
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<u[x,y] = \>\"", ",", 
      RowBox[{"Re", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<= \>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39938234959375*^9, 3.39938236196875*^9}, {
  3.399964798421875*^9, 3.399964804375*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"u", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "75"}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<u[x,y] = \>\"", ",", 
      RowBox[{"Re", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<= \>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39938236759375*^9, 3.39938237040625*^9}, {
  3.39996481240625*^9, 3.39996481396875*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Plot3D", "[", 
    RowBox[{
     RowBox[{"u", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "55"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0.4"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"BoxRatios", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], ",", 
     RowBox[{"Mesh", "\[Rule]", "False"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<\>\""}], "}"}]}], ",",
      
     RowBox[{"ViewPoint", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "3"}], ",", "3", ",", "2"}], "}"}]}], ",", 
     RowBox[{"Boxed", "\[Rule]", "False"}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<u[x,y] = \>\"", ",", 
      RowBox[{"Re", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<= \>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399382377859375*^9, 3.39938238425*^9}, {
  3.39996482046875*^9, 3.399964829953125*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Plot3D", "[", 
    RowBox[{
     RowBox[{"v", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"41", ",", "41"}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.05"}], ",", "0.4"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"ClippingStyle", "\[Rule]", "None"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<\>\""}], "}"}]}], ",",
      
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<v[x,y] = \>\"", ",", 
      RowBox[{"Im", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<= \>\"", ",", 
      RowBox[{"v", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399382387984375*^9, 3.399382396609375*^9}, {
  3.399964834703125*^9, 3.399964837421875*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"v", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "75"}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<v[x,y] = \>\"", ",", 
      RowBox[{"Im", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<= \>\"", ",", 
      RowBox[{"v", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39938240053125*^9, 3.399382401859375*^9}, {
  3.39996484134375*^9, 3.39996484309375*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Plot3D", "[", 
    RowBox[{
     RowBox[{"v", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "55"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0.4"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"BoxRatios", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], ",", 
     RowBox[{"Mesh", "\[Rule]", "False"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<\>\""}], "}"}]}], ",",
      
     RowBox[{"ViewPoint", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "3"}], ",", "3", ",", "2"}], "}"}]}], ",", 
     RowBox[{"Boxed", "\[Rule]", "False"}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<v[x,y] = \>\"", ",", 
      RowBox[{"Im", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<= \>\"", ",", 
      RowBox[{"v", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399382408046875*^9, 3.399382413484375*^9}, {
   3.39996485096875*^9, 3.39996485309375*^9}, 3.399965705140625*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Plot3D", "[", 
    RowBox[{
     RowBox[{"w", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"41", ",", "41"}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0.4"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"ClippingStyle", "\[Rule]", "None"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<\>\""}], "}"}]}], ",",
      
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w[x,y] = \>\"", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<= \>\"", ",", 
      RowBox[{"w", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39938241678125*^9, 3.39938243996875*^9}, {
  3.39996485725*^9, 3.39996485928125*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"w", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "75"}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w[x,y] = \>\"", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<= \>\"", ",", 
      RowBox[{"w", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399382446015625*^9, 3.399382447390625*^9}, {
  3.399964863984375*^9, 3.399964865921875*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Plot3D", "[", 
    RowBox[{
     RowBox[{"w", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "55"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0.4"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"BoxRatios", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], ",", 
     RowBox[{"Mesh", "\[Rule]", "False"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<\>\""}], "}"}]}], ",",
      
     RowBox[{"ViewPoint", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "3"}], ",", "3", ",", "2"}], "}"}]}], ",", 
     RowBox[{"Boxed", "\[Rule]", "False"}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w[x,y] = \>\"", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<= \>\"", ",", 
      RowBox[{"w", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39938245734375*^9, 3.399382462890625*^9}, {
  3.39996487590625*^9, 3.399964881640625*^9}}]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 7.14.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Locate the zeros and poles of ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"g", 
    RowBox[{"(", "z", ")"}]}], "=", 
   FractionBox[
    RowBox[{"\[Pi]", " ", "cot", 
     RowBox[{"(", 
      RowBox[{"\[Pi]", " ", "z"}], ")"}]}], 
    SuperscriptBox["z", "2"]]}]],
  AspectRatioFixed->True],
 ", and determine their order."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "Solution. The function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    SuperscriptBox["z", "2"], " ", "sin", " ", "\[Pi]", " ", "z"}]}]],
  AspectRatioFixed->True],
 "  has a zero of order  ",
 Cell[BoxData[
  RowBox[{"k", "=", "3"}]]],
 "  at  ",
 Cell[BoxData[
  RowBox[{"z", "=", "0"}]]],
 "  and simple zeros at the points  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"z", "=", 
    RowBox[{"\[PlusMinus]", "1"}]}], ",", 
   RowBox[{"\[PlusMinus]", "2"}], ",", "..."}]]],
 ".  Corollary 7.5 implies that ",
 StyleBox["g(z)",
  FontFamily->"Courier New"],
 " has a pole of order 3 at the point  ",
 Cell[BoxData[
  RowBox[{"z", "=", "0"}]]],
 "  and simple poles at the points  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"z", "=", 
    RowBox[{"\[PlusMinus]", "1"}]}], ",", 
   RowBox[{"\[PlusMinus]", "2"}], ",", "..."}]]],
 ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 7.14.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "Enter the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"g", "[", "z", "]"}], "=", 
   FractionBox[
    RowBox[{"\[Pi]", " ", 
     RowBox[{"Cot", "[", 
      RowBox[{"\[Pi]", " ", "z"}], "]"}]}], 
    SuperscriptBox["z", "2"]]}]]],
 " and find roots of the polynomial in the denominator.  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"g", ",", "S", ",", "z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"g", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox[
      RowBox[{"\[Pi]", " ", 
       RowBox[{"Cot", "[", 
        RowBox[{"\[Pi]", " ", "z"}], "]"}]}], 
      SuperscriptBox["z", "2"]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"S", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{"g", "[", "z", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", "0", ",", "9"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<g[z] = \>\"", ",", 
      RowBox[{"g", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[z] = \>\"", ",", 
      RowBox[{"S", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<g[z] = \>\"", ",", 
      RowBox[{"S", "[", "z", "]"}], ",", "\"\< + ...\>\""}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{
  3.399382480875*^9, {3.400269281546875*^9, 3.400269284046875*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "Thus ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"g", 
    RowBox[{"(", "z", ")"}]}], "=", 
   FractionBox[
    RowBox[{"\[Pi]", " ", "cot", 
     RowBox[{"(", 
      RowBox[{"\[Pi]", " ", "z"}], ")"}]}], 
    SuperscriptBox["z", "2"]]}]],
  AspectRatioFixed->True],
 ", has a pole of order  n = 3  at  z = 0.\n\nNow consider the other \
singularities."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<g[z] = \>\"", ",", 
      RowBox[{"g", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"k", "=", 
       RowBox[{"-", "5"}]}], ",", 
      RowBox[{"k", "\[LessEqual]", 
       RowBox[{"-", "1"}]}], ",", 
      RowBox[{"k", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Print", "[", 
        RowBox[{"\"\<g[\>\"", ",", "k", ",", "\"\<] = \>\"", ",", 
         RowBox[{"Limit", "[", 
          RowBox[{
           RowBox[{"g", "[", "z", "]"}], ",", 
           RowBox[{"z", "\[Rule]", "k"}]}], "]"}]}], "]"}], ";"}]}], "  ", 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"k", "=", "1"}], ",", 
      RowBox[{"k", "\[LessEqual]", "5"}], ",", 
      RowBox[{"k", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Print", "[", 
        RowBox[{"\"\<g[\>\"", ",", "k", ",", "\"\<] = \>\"", ",", 
         RowBox[{"Limit", "[", 
          RowBox[{
           RowBox[{"g", "[", "z", "]"}], ",", 
           RowBox[{"z", "\[Rule]", "k"}]}], "]"}]}], "]"}], ";"}]}], "  ", 
     "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399382484328125*^9}],

Cell["Or we could consider the following method of investigation.", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<g[x] = \>\"", ",", 
      RowBox[{"g", "[", "x", "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<g[n] = \>\"", ",", 
      RowBox[{"g", "[", "n", "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<g[n] = \>\"", ",", 
      RowBox[{"Simplify", "[", 
       RowBox[{
        RowBox[{"g", "[", "n", "]"}], ",", 
        RowBox[{"Element", "[", 
         RowBox[{"n", ",", "Integers"}], "]"}]}], "]"}]}], " ", "]"}], ";"}], 
   " "}]}]], "Input",
 CellChangeTimes->{3.399382487296875*^9}],

Cell[TextData[{
 "\nThus ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"g", 
    RowBox[{"(", "z", ")"}]}], "=", 
   FractionBox[
    RowBox[{"\[Pi]", " ", "cot", 
     RowBox[{"(", 
      RowBox[{"\[Pi]", " ", "z"}], ")"}]}], 
    SuperscriptBox["z", "2"]]}]],
  AspectRatioFixed->True],
 " has simple poles at ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"z", "=", 
    RowBox[{"\[PlusMinus]", "1"}]}], ",", 
   RowBox[{"\[PlusMinus]", "2"}], ",", " ", "..."}]]],
 ".  ",
 "\n",
 "\nInvestigate the graph for real variables."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"g", "[", "x", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "10"}], ",", "10"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "3", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "10"}], ",", "10", ",", "5"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Blue"}]}], "]"}], "\[IndentingNewLine]",
    
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<The function y = g[x] = \>\"", ",", 
      RowBox[{"g", "[", "x", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399382491359375*^9, 3.39938250009375*^9}, {
  3.399964896125*^9, 3.3999648963125*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "We can use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to investigate the real part, imaginary part, and absolute value of  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"g", 
    RowBox[{"(", "z", ")"}]}], "=", 
   FractionBox[
    RowBox[{"\[Pi]", " ", "cot", 
     RowBox[{"(", 
      RowBox[{"\[Pi]", " ", "z"}], ")"}]}], 
    SuperscriptBox["z", "2"]]}]]],
 "."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"u", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], "=", 
     RowBox[{"FullSimplify", "[", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{
        RowBox[{"Re", "[", 
         RowBox[{"g", "[", 
          RowBox[{"x", "+", 
           RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], ",", 
        RowBox[{"TargetFunctions", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"Im", ",", "Re"}], "}"}]}]}], "]"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"v", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], "=", 
     RowBox[{"FullSimplify", "[", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{
        RowBox[{"Im", "[", 
         RowBox[{"g", "[", 
          RowBox[{"x", "+", 
           RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], ",", 
        RowBox[{"TargetFunctions", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"Im", ",", "Re"}], "}"}]}]}], "]"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"w", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], "=", 
     RowBox[{"FullSimplify", "[", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{
        RowBox[{"Abs", "[", 
         RowBox[{"g", "[", 
          RowBox[{"x", "+", 
           RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], ",", 
        RowBox[{"TargetFunctions", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"Im", ",", "Re"}], "}"}]}]}], "]"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"Plot3D", "[", 
    RowBox[{
     RowBox[{"Re", "[", 
      RowBox[{"g", "[", 
       RowBox[{"x", " ", "+", " ", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotPoints", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"41", ",", "41"}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.5"}], ",", "0.5"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"ClippingStyle", "\[Rule]", "None"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<\>\""}], "}"}]}], ",",
      
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<u[x,y] = \>\"", ",", 
      RowBox[{"Re", "[", 
       RowBox[{"g", "[", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<= \>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399382504359375*^9, 3.3993825118125*^9}, {
  3.399964899875*^9, 3.399964903265625*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"u", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "3"}], ",", "3.01"}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "75"}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<u[x,y] = \>\"", ",", 
      RowBox[{"Re", "[", 
       RowBox[{"g", "[", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<= \>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399382517484375*^9, 3.39938251915625*^9}, {
  3.399964913984375*^9, 3.399964915234375*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Plot3D", "[", 
    RowBox[{
     RowBox[{"Re", "[", 
      RowBox[{"g", "[", 
       RowBox[{"x", " ", "+", " ", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "55"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "5"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"BoxRatios", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], ",", 
     RowBox[{"Mesh", "\[Rule]", "False"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<\>\""}], "}"}]}], ",",
      
     RowBox[{"ViewPoint", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "3"}], ",", "3", ",", "2"}], "}"}]}], ",", 
     RowBox[{"Boxed", "\[Rule]", "False"}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<u[x,y] = \>\"", ",", 
      RowBox[{"Re", "[", 
       RowBox[{"g", "[", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<= \>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399382531625*^9, 3.39938253784375*^9}, {
  3.39996491875*^9, 3.39996492128125*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Plot3D", "[", 
    RowBox[{
     RowBox[{"Im", "[", 
      RowBox[{"g", "[", 
       RowBox[{"x", " ", "+", " ", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"41", ",", "41"}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.5"}], ",", "0.5"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"ClippingStyle", "\[Rule]", "None"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<\>\""}], "}"}]}], ",",
      
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<v[x,y] = \>\"", ",", 
      RowBox[{"Im", "[", 
       RowBox[{"g", "[", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<= \>\"", ",", 
      RowBox[{"v", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399382539546875*^9, 3.399382547203125*^9}, {
  3.39996492890625*^9, 3.399964933578125*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"v", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "3"}], ",", "3.01"}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "75"}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<v[x,y] = \>\"", ",", 
      RowBox[{"Im", "[", 
       RowBox[{"g", "[", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<= \>\"", ",", 
      RowBox[{"v", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39938255053125*^9, 3.399382551875*^9}, {
  3.399964938609375*^9, 3.399964940015625*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Plot3D", "[", 
    RowBox[{
     RowBox[{"Im", "[", 
      RowBox[{"g", "[", 
       RowBox[{"x", " ", "+", " ", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "55"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "5"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"BoxRatios", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], ",", 
     RowBox[{"Mesh", "\[Rule]", "False"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<\>\""}], "}"}]}], ",",
      
     RowBox[{"ViewPoint", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "3"}], ",", "3", ",", "2"}], "}"}]}], ",", 
     RowBox[{"Boxed", "\[Rule]", "False"}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<v[x,y] = \>\"", ",", 
      RowBox[{"Im", "[", 
       RowBox[{"g", "[", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<= \>\"", ",", 
      RowBox[{"v", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399382560921875*^9, 3.3993825655625*^9}, {
  3.399964949703125*^9, 3.39996495259375*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Plot3D", "[", 
    RowBox[{
     RowBox[{"Abs", "[", 
      RowBox[{"g", "[", 
       RowBox[{"x", " ", "+", " ", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"41", ",", "41"}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "5"}], "}"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"ViewPoint", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"4", ",", "4", ",", "1"}], "}"}]}], ",", 
     RowBox[{"ClippingStyle", "\[Rule]", "None"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<\>\""}], "}"}]}], ",",
      
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w[x,y] = \>\"", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{"g", "[", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<= \>\"", ",", 
      RowBox[{"w", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39938256959375*^9, 3.399382577078125*^9}, {
  3.399964957890625*^9, 3.39996495959375*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"w", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "3"}], ",", "3.01"}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "75"}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w[x,y] = \>\"", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{"g", "[", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<= \>\"", ",", 
      RowBox[{"w", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399382580484375*^9, 3.399382581671875*^9}, {
  3.39996496409375*^9, 3.399964965625*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Plot3D", "[", 
    RowBox[{
     RowBox[{"Abs", "[", 
      RowBox[{"g", "[", 
       RowBox[{"x", " ", "+", " ", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "55"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "5"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"BoxRatios", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], ",", 
     RowBox[{"Mesh", "\[Rule]", "False"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<\>\""}], "}"}]}], ",",
      
     RowBox[{"ViewPoint", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "3"}], ",", "3", ",", "2"}], "}"}]}], ",", 
     RowBox[{"Boxed", "\[Rule]", "False"}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w[x,y] = \>\"", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{"g", "[", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<= \>\"", ",", 
      RowBox[{"w", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39938259703125*^9, 3.39938260159375*^9}, {
  3.399964981046875*^9, 3.39996498203125*^9}}]
}, Closed]],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[{
 StyleBox[ButtonBox["Laurent Series",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/LaurentSeriesBib.html"], 
    None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0, 1]],
 "  "
}], "Text"],

Cell[TextData[{
 StyleBox[ButtonBox["Poles and Singularity",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/PoleBib.html"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0, 1]],
 "  "
}], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/complex.html"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2008 John H. Mathews, Russell W. \
Howell",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/"], None}],
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[0, 1, 0]]], "Text",
 CellChangeTimes->{{3.3993225564375*^9, 3.39932255653125*^9}}]
},
CellGrouping->Manual,
WindowSize->{932, 638},
WindowMargins->{{28, Automatic}, {Automatic, 0}},
CellLabelAutoDelete->True,
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "CHAPTER 1"->{
  Cell[568, 21, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"],
  Cell[144083, 4757, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"],
  Cell[164139, 5412, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"],
  Cell[165862, 5483, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"],
  Cell[186737, 6161, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"],
  Cell[188344, 6227, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"],
  Cell[189988, 6297, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"],
  Cell[191524, 6360, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"],
  Cell[194569, 6487, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"CHAPTER 1", 289148, 9192}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"],
Cell[905, 32, 124, 2, 29, "Text"],
Cell[1032, 36, 2268, 80, 90, "Text",
 Evaluatable->False],
Cell[3303, 118, 2734, 93, 144, "Text",
 Evaluatable->False],
Cell[6040, 213, 6130, 221, 209, "Text"],
Cell[12173, 436, 71, 0, 29, "Text"],
Cell[12247, 438, 1355, 49, 119, "Text"],
Cell[13605, 489, 2211, 81, 199, "Text"],
Cell[CellGroupData[{
Cell[15841, 574, 149, 4, 29, "Text",
 Evaluatable->False],
Cell[15993, 580, 360, 14, 35, "Text",
 Evaluatable->False],
Cell[16356, 596, 2967, 85, 426, "Input"],
Cell[19326, 683, 475, 14, 71, "Text",
 Evaluatable->False],
Cell[19804, 699, 1646, 48, 173, "Input"],
Cell[21453, 749, 309, 11, 35, "Text"],
Cell[21765, 762, 2907, 79, 192, "Input"],
Cell[24675, 843, 1654, 44, 132, "Input"],
Cell[26332, 889, 1714, 50, 132, "Input"],
Cell[28049, 941, 1704, 50, 132, "Input"],
Cell[29756, 993, 1172, 32, 112, "Input"],
Cell[30931, 1027, 1174, 32, 112, "Input"]
}, Closed]],
Cell[32120, 1062, 2213, 84, 168, "Text"],
Cell[CellGroupData[{
Cell[34358, 1150, 149, 4, 29, "Text",
 Evaluatable->False],
Cell[34510, 1156, 422, 16, 36, "Text",
 Evaluatable->False],
Cell[34935, 1174, 3010, 86, 428, "Input"],
Cell[37948, 1262, 537, 16, 72, "Text",
 Evaluatable->False],
Cell[38488, 1280, 1655, 48, 152, "Input"],
Cell[40146, 1330, 371, 13, 36, "Text"],
Cell[40520, 1345, 2678, 76, 192, "Input"],
Cell[43201, 1423, 1531, 42, 132, "Input"],
Cell[44735, 1467, 1305, 37, 112, "Input"],
Cell[46043, 1506, 1306, 37, 112, "Input"],
Cell[47352, 1545, 1128, 33, 92, "Input"],
Cell[48483, 1580, 1165, 32, 112, "Input"]
}, Closed]],
Cell[49663, 1615, 1003, 43, 98, "Text"],
Cell[50669, 1660, 771, 29, 53, "Text",
 Evaluatable->False],
Cell[51443, 1691, 9905, 468, 195, "Text"],
Cell[CellGroupData[{
Cell[61373, 2163, 244, 9, 29, "Text",
 Evaluatable->False],
Cell[61620, 2174, 1930, 55, 282, "Input"],
Cell[63553, 2231, 514, 17, 71, "Text",
 Evaluatable->False],
Cell[64070, 2250, 2303, 68, 164, "Input"],
Cell[66376, 2320, 178, 6, 47, "Text"],
Cell[66557, 2328, 2705, 78, 192, "Input"],
Cell[69265, 2408, 1920, 54, 132, "Input"],
Cell[71188, 2464, 1794, 52, 132, "Input"],
Cell[72985, 2518, 1796, 52, 132, "Input"],
Cell[74784, 2572, 2193, 62, 152, "Input"],
Cell[76980, 2636, 2209, 62, 152, "Input"]
}, Closed]],
Cell[79204, 2701, 1810, 65, 199, "Text"],
Cell[CellGroupData[{
Cell[81039, 2770, 149, 4, 29, "Text",
 Evaluatable->False],
Cell[81191, 2776, 386, 15, 36, "Text",
 Evaluatable->False],
Cell[81580, 2793, 2147, 63, 314, "Input"],
Cell[83730, 2858, 604, 20, 72, "Text",
 Evaluatable->False],
Cell[84337, 2880, 1597, 46, 152, "Input"],
Cell[85937, 2928, 337, 12, 54, "Text"],
Cell[86277, 2942, 2574, 73, 172, "Input"],
Cell[88854, 3017, 1514, 42, 132, "Input"],
Cell[90371, 3061, 1648, 49, 132, "Input"],
Cell[92022, 3112, 1650, 49, 132, "Input"],
Cell[93675, 3163, 1145, 32, 112, "Input"],
Cell[94823, 3197, 1141, 32, 112, "Input"]
}, Closed]],
Cell[95979, 3232, 369, 17, 26, "Text"],
Cell[96351, 3251, 1569, 55, 197, "Text"],
Cell[CellGroupData[{
Cell[97945, 3310, 149, 4, 29, "Text",
 Evaluatable->False],
Cell[98097, 3316, 368, 14, 37, "Text",
 Evaluatable->False],
Cell[98468, 3332, 1990, 57, 297, "Input"],
Cell[100461, 3391, 545, 18, 73, "Text",
 Evaluatable->False],
Cell[101009, 3411, 2315, 69, 172, "Input"],
Cell[103327, 3482, 327, 12, 37, "Text"],
Cell[103657, 3496, 2911, 84, 172, "Input"],
Cell[106571, 3582, 1897, 54, 132, "Input"],
Cell[108471, 3638, 1686, 49, 132, "Input"],
Cell[110160, 3689, 1690, 49, 132, "Input"],
Cell[111853, 3740, 2190, 62, 152, "Input"],
Cell[114046, 3804, 2185, 62, 152, "Input"]
}, Closed]],
Cell[116246, 3869, 2513, 89, 214, "Text"],
Cell[CellGroupData[{
Cell[118784, 3962, 149, 4, 29, "Text",
 Evaluatable->False],
Cell[118936, 3968, 436, 17, 35, "Text",
 Evaluatable->False],
Cell[119375, 3987, 4649, 135, 585, "Input"],
Cell[124027, 4124, 554, 18, 71, "Text",
 Evaluatable->False],
Cell[124584, 4144, 2308, 68, 172, "Input"],
Cell[126895, 4214, 327, 12, 37, "Text"],
Cell[127225, 4228, 2899, 84, 172, "Input"],
Cell[130127, 4314, 1964, 55, 132, "Input"],
Cell[132094, 4371, 1786, 51, 132, "Input"],
Cell[133883, 4424, 1790, 51, 132, "Input"],
Cell[135676, 4477, 2245, 63, 152, "Input"],
Cell[137924, 4542, 2246, 63, 152, "Input"]
}, Closed]],
Cell[140185, 4608, 2300, 82, 98, "Text"],
Cell[142488, 4692, 1252, 49, 65, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[143765, 4745, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[143909, 4751, 171, 4, 29, "Text",
 Evaluatable->False],
Cell[144083, 4757, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"]
}, Closed]],
Cell[144432, 4769, 2765, 94, 257, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[147222, 4867, 157, 4, 29, "Text",
 Evaluatable->False],
Cell[147382, 4873, 316, 11, 32, "Text",
 Evaluatable->False],
Cell[147701, 4886, 2604, 77, 353, "Input"],
Cell[150308, 4965, 321, 13, 32, "Text",
 Evaluatable->False],
Cell[150632, 4980, 103, 2, 29, "Text",
 Evaluatable->False],
Cell[150738, 4984, 1477, 45, 132, "Input"],
Cell[152218, 5031, 331, 12, 32, "Text"],
Cell[152552, 5045, 3224, 95, 212, "Input"],
Cell[155779, 5142, 1705, 50, 132, "Input"],
Cell[157487, 5194, 1627, 48, 132, "Input"],
Cell[159117, 5244, 1173, 33, 112, "Input"],
Cell[160293, 5279, 1175, 33, 112, "Input"],
Cell[161471, 5314, 1176, 33, 112, "Input"]
}, Closed]],
Cell[162662, 5350, 1134, 46, 98, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[163821, 5400, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[163965, 5406, 171, 4, 29, "Text",
 Evaluatable->False],
Cell[164139, 5412, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"]
}, Closed]],
Cell[164488, 5424, 122, 3, 26, "Text"],
Cell[164613, 5429, 902, 38, 47, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[165540, 5471, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[165684, 5477, 175, 4, 29, "Text",
 Evaluatable->False],
Cell[165862, 5483, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"]
}, Closed]],
Cell[166211, 5495, 945, 41, 44, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[167181, 5540, 157, 4, 29, "Text",
 Evaluatable->False],
Cell[167341, 5546, 314, 11, 29, "Text",
 Evaluatable->False],
Cell[167658, 5559, 2652, 79, 350, "Input"],
Cell[170313, 5640, 367, 14, 65, "Text",
 Evaluatable->False],
Cell[170683, 5656, 1510, 46, 151, "Input"],
Cell[172196, 5704, 2387, 71, 210, "Input"],
Cell[174586, 5777, 345, 13, 29, "Text"],
Cell[174934, 5792, 3261, 96, 192, "Input"],
Cell[178198, 5890, 1733, 51, 132, "Input"],
Cell[179934, 5943, 1719, 50, 132, "Input"],
Cell[181656, 5995, 1172, 33, 112, "Input"],
Cell[182831, 6030, 1171, 33, 112, "Input"],
Cell[184005, 6065, 1179, 33, 112, "Input"]
}, Closed]],
Cell[185199, 6101, 75, 0, 26, "Text"],
Cell[185277, 6103, 1117, 42, 110, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[186419, 6149, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[186563, 6155, 171, 4, 29, "Text",
 Evaluatable->False],
Cell[186737, 6161, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"]
}, Closed]],
Cell[187086, 6173, 187, 4, 26, "Text"],
Cell[187276, 6179, 712, 32, 37, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[188013, 6215, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[188157, 6221, 184, 4, 29, "Text",
 Evaluatable->False],
Cell[188344, 6227, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"]
}, Closed]],
Cell[188693, 6239, 939, 42, 52, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[189657, 6285, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[189801, 6291, 184, 4, 29, "Text",
 Evaluatable->False],
Cell[189988, 6297, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"]
}, Closed]],
Cell[190337, 6309, 831, 35, 44, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[191193, 6348, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[191337, 6354, 184, 4, 29, "Text",
 Evaluatable->False],
Cell[191524, 6360, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"]
}, Closed]],
Cell[191873, 6372, 2340, 99, 142, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[194238, 6475, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[194382, 6481, 184, 4, 29, "Text",
 Evaluatable->False],
Cell[194569, 6487, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"]
}, Closed]],
Cell[194918, 6499, 390, 15, 32, "Text",
 Evaluatable->False],
Cell[195311, 6516, 2595, 102, 193, "Text"],
Cell[CellGroupData[{
Cell[197931, 6622, 157, 4, 29, "Text",
 Evaluatable->False],
Cell[198091, 6628, 286, 10, 35, "Text",
 Evaluatable->False],
Cell[198380, 6640, 1430, 42, 226, "Input"],
Cell[199813, 6684, 330, 12, 71, "Text",
 Evaluatable->False],
Cell[200146, 6698, 1160, 32, 152, "Input"],
Cell[201309, 6732, 75, 0, 29, "Text"],
Cell[201387, 6734, 813, 24, 92, "Input"],
Cell[202203, 6760, 552, 20, 89, "Text",
 Evaluatable->False],
Cell[202758, 6782, 1062, 31, 167, "Input"],
Cell[203823, 6815, 75, 0, 29, "Text"],
Cell[203901, 6817, 1177, 34, 136, "Input"],
Cell[205081, 6853, 475, 20, 35, "Text",
 Evaluatable->False],
Cell[205559, 6875, 103, 2, 29, "Text",
 Evaluatable->False],
Cell[205665, 6879, 1427, 44, 133, "Input"],
Cell[207095, 6925, 359, 14, 35, "Text",
 Evaluatable->False],
Cell[207457, 6941, 3156, 91, 172, "Input"],
Cell[210616, 7034, 1610, 45, 112, "Input"],
Cell[212229, 7081, 1641, 46, 112, "Input"],
Cell[213873, 7129, 1632, 46, 112, "Input"],
Cell[215508, 7177, 1611, 45, 112, "Input"],
Cell[217122, 7224, 1598, 45, 112, "Input"]
}, Closed]],
Cell[218735, 7272, 503, 19, 34, "Text",
 Evaluatable->False],
Cell[219241, 7293, 20533, 339, 253, "Text",
 Evaluatable->False],
Cell[239777, 7634, 2297, 83, 101, "Text"],
Cell[CellGroupData[{
Cell[242099, 7721, 157, 4, 29, "Text",
 Evaluatable->False],
Cell[242259, 7727, 407, 14, 37, "Text",
 Evaluatable->False],
Cell[242669, 7743, 1191, 37, 190, "Input"],
Cell[243863, 7782, 92, 2, 29, "Text",
 Evaluatable->False],
Cell[243958, 7786, 2498, 72, 232, "Input"],
Cell[246459, 7860, 778, 30, 81, "Text",
 Evaluatable->False],
Cell[247240, 7892, 3252, 95, 192, "Input"],
Cell[250495, 7989, 1089, 31, 112, "Input"],
Cell[251587, 8022, 1849, 53, 132, "Input"],
Cell[253439, 8077, 1720, 50, 132, "Input"],
Cell[255162, 8129, 1090, 31, 112, "Input"],
Cell[256255, 8162, 1875, 53, 132, "Input"],
Cell[258133, 8217, 1685, 49, 132, "Input"],
Cell[259821, 8268, 1094, 31, 112, "Input"],
Cell[260918, 8301, 1853, 53, 132, "Input"]
}, Closed]],
Cell[262786, 8357, 479, 18, 33, "Text",
 Evaluatable->False],
Cell[263268, 8377, 919, 34, 47, "Text"],
Cell[CellGroupData[{
Cell[264212, 8415, 157, 4, 29, "Text",
 Evaluatable->False],
Cell[264372, 8421, 372, 13, 36, "Text",
 Evaluatable->False],
Cell[264747, 8436, 1554, 47, 228, "Input"],
Cell[266304, 8485, 425, 16, 72, "Text",
 Evaluatable->False],
Cell[266732, 8503, 1372, 38, 152, "Input"],
Cell[268107, 8543, 75, 0, 29, "Text"],
Cell[268185, 8545, 736, 22, 92, "Input"],
Cell[268924, 8569, 574, 23, 90, "Text",
 Evaluatable->False],
Cell[269501, 8594, 1213, 36, 92, "Input"],
Cell[270717, 8632, 447, 17, 36, "Text",
 Evaluatable->False],
Cell[271167, 8651, 3359, 97, 212, "Input"],
Cell[274529, 8750, 1095, 31, 112, "Input"],
Cell[275627, 8783, 1928, 55, 132, "Input"],
Cell[277558, 8840, 1803, 52, 132, "Input"],
Cell[279364, 8894, 1092, 31, 112, "Input"],
Cell[280459, 8927, 1934, 55, 132, "Input"],
Cell[282396, 8984, 1918, 55, 132, "Input"],
Cell[284317, 9041, 1093, 31, 112, "Input"],
Cell[285413, 9074, 1936, 55, 132, "Input"]
}, Closed]],
Cell[287364, 9132, 281, 7, 26, "Text"],
Cell[287648, 9141, 294, 10, 29, "Text"],
Cell[287945, 9153, 287, 9, 29, "Text"],
Cell[288235, 9164, 249, 5, 29, "Text"],
Cell[288487, 9171, 317, 7, 29, "Text"]
}
]
*)

(* End of internal cache information *)
